# 06-02-20 manually read csv files

library(tidyverse)
library(RColorBrewer)
library(lubridate)

## 06-02-20 ozone data ----------------

# Get Ferfoz data and clean it up a bit ---------------------
ferfoz <- R.utils::loadToEnv("C:/Users/skoike/Desktop/tidy data/FERF1.RData")[["ferfoz"]]

## actual <- NA if: 
### 1_ actual < 0
### 2_ stdev > 1 (and stdev is not NA)
### 3_ actual - request > 0_.2 (and request is not NA)

ferfoz <- ferfoz %>% mutate(actual = ifelse(actual < 0, NA, actual),
                            actual = ifelse(stdev > 1 & !is.na(stdev), NA, actual),
                            actual = ifelse(!is.na(request) & (actual - request) > 0.2, NA, actual),
                            actual = ifelse(n == 0, NA, actual))


# Read in Baseline Data -------------------------------------
F89BL12R <- read_csv("C:/Users/skoike/Desktop/tidy data/12PPEXRE/F89BL12R.csv") # baseline ht/diam
F90W12R3 <- as_tibble(R.utils::loadToEnv("C:/Users/skoike/Desktop/tidy data/FERF1.RData")[["F90W12R3"]])
F90H12R3 <- read_csv("C:/Users/skoike/Desktop/tidy data/12PPEXRE/F90H12R3.csv") # Harvest ht/diam


data_list <- list("F89BL12R" = F89BL12R, "F90W12R3" = F90W12R3, "F90H12R3" = F90H12R3)
data_list
data_list %>% lapply(dim)

# Clean Up Data --------------------------------------------------

## F89BL12R

summary(F89BL12R)

noNeg <- function(x){ifelse(x < 0, NA, x)} 

F89BL12R_copy <- F89BL12R %>% 
  filter(DAY == 0) %>% 
  mutate_if(is.numeric, noNeg) %>% 
  mutate(DATE = mdy(DATE), # Convert Character Date to actual Date
         VOL = HT * DIAM^2) # Add Volume

#View(F89BL12R_copy)

## F90W12R3- Hvst 1 dry weights

#summary(F90W12R3) 
F90W12R3_copy <- F90W12R3 %>% 
  mutate(DATE = mdy(DATE)) %>% 
  select(DATE, OZ89, CH89, CH90, PLT, STEMDW, ROOTDW, TNDW, TOTALDW)

### F90H12R3- Hvst 1 growth measures, lengths & areas

#summary(F90H12R3)

F90H12R3_copy <- F90H12R3 %>% 
  mutate_if(is.numeric, noNeg) %>% 
  mutate(DATE = mdy(DATE),
         VOL = HT * DIAM^2)

# Joining Harvest and Dry Weight Data -------------------------------------------------

harvest3_data <- full_join(F90W12R3_copy, 
                           F90H12R3_copy %>% select(CH89, CH90, PLT, VOL), 
                           by = c("CH89", "CH90", "PLT"))

#View(harvest3_data)

# Joining Harvest and Base Line Data -------------------------------------------------

H3 <- left_join(harvest3_data, F89BL12R_copy %>% rename(CH89 = CH), 
                by = c("CH89", "PLT"),
                suffix = c("_h", "_bl")) %>% 
  select(OZ89, CH90, PLT, TNDW, STEMDW, ROOTDW, TOTALDW, VOL_bl, VOL_h) %>% 
  rename(OZ = OZ89, CH = CH90) %>% 
  mutate(OZ = as_factor(OZ),
         CH = as_factor(CH))

# OZ exposure
p <- ferfoz %>% 
  filter(ch %in% unique(H3$CH)) %>% 
  select(ch, actual, request, date, datetime) %>% 
  mutate(date = mdy(date),
         datetime = dmy_hms(datetime)) %>% 
  filter(between(date, mdy("06-05-1990"), mdy("10-03-1990"))) %>% 
  pivot_longer(cols = c(actual, request))

oz_plot <- p %>% 
  ggplot(aes(x = datetime, y = value, color = name)) +
  geom_line() + 
  scale_color_brewer(palette = "Set1") + 
  facet_wrap(. ~ ch) 
#oz_plot

#View(H3)

# Add log transformation 
H3 <- H3 %>% 
  mutate(TOTALDW = TNDW + STEMDW + ROOTDW, 
         LOGNEEDLEDW = log(TNDW + 0.01),
         LOGSTEMDW = log(STEMDW + 0.01),
         LOGROOTDW = log(ROOTDW + 0.01),
         LOGTOTALDW = log(TOTALDW + 0.01),
         LOGVOL_bl = log(VOL_bl + 0.01),
         LOGVOL_h = log(VOL_h + 0.01))

# Curosy Exploratory Data Analysis -----------------------------------

H3 %>%  # Pre-Treatment Data 
  ggplot() + 
  aes(x = CH, y = LOGVOL_bl, fill = OZ) + # Pre-trt vol_ by Chamber
  geom_boxplot() + 
  ggtitle("Basline Pre-Treatment Volume by Chamber")

H3 %>% 
  group_by(CH, OZ, PLT) %>%
  ggplot() + 
  aes(x = VOL_bl, y = VOL_h, color = OZ) + 
  geom_point() +
  geom_smooth(method = "lm", se = FALSE) + 
  scale_color_brewer(palette = "Set1")

H3 %>% 
  group_by(CH, PLT, OZ) %>% 
  pivot_longer(cols = c("VOL_bl", "VOL_h"), names_to = "time", values_to = "volume") %>% 
  ggplot() + 
  aes(x = OZ, y = log(volume), fill = time) + 
  geom_boxplot(alpha = 0.5) +
  ggtitle("Log Volume (Pre- and Post-Treatment) by Treatment")

H3 %>% 
  group_by(OZ) %>% 
  summarize(meanVolBefore = mean(LOGVOL_bl), 
            meanVolAfter = mean(LOGVOL_h, na.rm = TRUE)) # Summarize mean log-volume by treatment

# Join Exposure Metrics to Mean Chamber Data ----------------------------------------
test_df <- H3 %>% 
  group_by(CH, OZ) %>% 
  summarise_at(vars(starts_with("LOG"), ends_with("DW"), VOL_bl), mean, na.rm = TRUE) 

# Get OZ metrics ---------------------------------------------------
source("C:/Users/skoike/Desktop/tidy data/OZmetrics.R")


# Want 1990 data and exposure data in range of 06-05-1990 to 10-03-1990
otest1 <- ferfoz %>% 
  mutate(date = mdy(date)) %>% 
  filter(between(date, mdy("06-05-1990"), mdy("10-03-1990")))
exp_days_1 <- as.numeric(mdy("10-03-1990") - mdy("06-05-1990") + 1)

otest_90_df <- OZ.metrics(otest1) %>%  
  mutate_if(is.numeric, function(x){x * 92 / exp_days_1})

test_long <- full_join(H3 %>% select(OZ, CH, PLT, LOGNEEDLEDW, LOGSTEMDW, LOGROOTDW, LOGTOTALDW, LOGVOL_bl),
                       otest_90_df)

#write.csv(test_long, "12R_h3_data.csv", row.names = FALSE)

test2_df <- left_join(test_df, otest_90_df) %>% 
  ungroup() %>% 
  mutate(CH = as_factor(CH),
         Year = 1990,
         Harvest = 2,
         Exp_days = exp_days) %>% 
  select(Year, Harvest, Exp_days, everything())

#View(test2_df)

#write.csv(test2_df, "12R_h2_mean_data.csv", row.names = FALSE)
