# 06-02-20 manually read csv files

library(tidyverse)
library(RColorBrewer)
library(lubridate)

## 06-02-20 ozone data ----------------

# Get Ferfoz data and clean it up a bit ---------------------
ferfoz <- R.utils::loadToEnv("C:/Users/skoike/Desktop/tidy data/FERF1.RData")[["ferfoz"]]

## actual <- NA if: 
### 1. actual < 0
### 2. stdev > 1 (and stdev is not NA)
### 3. actual - request > 0.2 (and request is not NA)

ferfoz <- ferfoz %>% mutate(actual = ifelse(actual < 0, NA, actual),
                            actual = ifelse(stdev > 1 & !is.na(stdev), NA, actual),
                            actual = ifelse(!is.na(request) & (actual - request) > 0.2, NA, actual),
                            actual = ifelse(n == 0, NA, actual))


# Read in Baseline Data -------------------------------------
F89BL13 <- read_csv("C:/Users/skoike/Desktop/tidy data/13DFEXRE/F89BL13.csv") # baseline ht/diam
F89W13 <- read_csv("C:/Users/skoike/Desktop/tidy data/13DFEXRE/F89DW13.csv") # harvest dryweight 
F89H13 <- read_csv("C:/Users/skoike/Desktop/tidy data/13DFEXRE/F89H13.csv") # Harvest ht/diam


data_list <- list("F89BL13" = F89BL13, "F89W13" = F89W13, "F89H12R" = F89H13)
data_list
data_list %>% lapply(dim)

# Clean Up Data --------------------------------------------------

## F89BL13

summary(F89BL13)

noNeg <- function(x){ifelse(x < 0, NA, x)} 

F89BL13_copy <- F89BL13 %>% 
  filter(DAY == -7) %>% 
  mutate_if(is.numeric, noNeg) %>% 
  mutate(DATE = mdy(DATE), # Convert Character Date to actual Date
         VOL = HT * DIAM^2, # Add Volume
         OZ = as_factor(OZ),
         CH = as_factor(CH))

#View(F89BL13_copy)

## F89W13- Hvst 1 dry weights

#summary(F89W13) 
F89W13_copy <- F89W13 %>%  
  filter(DATE == "10/25/1989") %>%
  mutate_if(is.numeric, noNeg) %>%
  mutate(TNDW = N1TOTDW + N2TOTDW,
         TOTALDW = TNDW + STEMDW + TOTROOTW) %>% 
  rename(OZ = OZ89,
         CH = CH89,
         ROOTDW = TOTROOTW) %>% 
  mutate(DATE = mdy(DATE),
         OZ = as_factor(OZ),
         CH = as_factor(CH))

### F89H13- Hvst 1 growth measures, lengths & areas

#summary(F89H13)

F89H13_copy <- F89H13 %>% 
  filter(DATE == "10/25/1989") %>% 
  mutate_if(is.numeric, noNeg) %>% 
  mutate(DATE = mdy(DATE),
         OZ = as_factor(OZ),
         VOL = HT * DIAM^2, # Add Volume 
         CH = as_factor(CH))

# Joining Harvest and Dry Weight Data -------------------------------------------------

harvest1_data <- full_join(F89W13_copy, F89H13_copy, by = c("CH", "PLT"))

#View(harvest1_data)

# Joining Harvest and Base Line Data -------------------------------------------------
level_ord <- c("CONTROL", "EPHIGH", "EPLOW", "EPMED", "EPXLOW")
H1 <- left_join(harvest1_data, F89BL13_copy, 
                by = c("CH", "PLT"),
                suffix = c("_h", "_bl")) %>% 
  select(OZ.x, CH, PLT, TNDW, STEMDW, ROOTDW, TOTALDW, VOL_bl, VOL_h) %>% 
  rename(OZ = OZ.x) %>% 
  mutate(OZ = fct_relevel(OZ, level_ord))

# OZ exposure
g <- ferfoz %>% 
  filter(ch %in% unique(H1$CH)) %>% 
  select(ch, actual, request, date, datetime) %>% 
  mutate(date = mdy(date),
         datetime = dmy_hms(datetime)) %>% 
  filter(between(date, mdy("06-07-1989"), mdy("9-27-1989"))) %>% 
  pivot_longer(cols = c(actual, request))

oz_exp <- g %>% 
  ggplot(aes(x = datetime, y = value, color = name)) +
  geom_line() + 
  scale_color_brewer(palette = "Set1") + 
  facet_wrap(. ~ ch) 
#oz_exp

#View(H1)

# Add log transformation 
H1 <- H1 %>% 
  mutate(LOGNEEDLEDW = log(TNDW + 0.01),
         LOGSTEMDW = log(STEMDW + 0.01),
         LOGROOTDW = log(ROOTDW + 0.01),
         LOGTOTALDW = log(TOTALDW + 0.01),
         LOGVOL_bl = log(VOL_bl + 0.01),
         LOGVOL_h = log(VOL_h + 0.01))

# Curosy Exploratory Data Analysis -----------------------------------

H1 %>%  # Pre-Treatment Data 
  ggplot() + 
  aes(x = CH, y = LOGVOL_bl, fill = OZ) + # Pre-trt vol_ by Chamber
  geom_boxplot() + 
  ggtitle("Basline Pre-Treatment Volume by Chamber")

H1 %>% 
  group_by(CH, OZ, PLT) %>% 
  summarise(before = VOL_bl, after = VOL_h) %>% # Post-trt Vol by Pre-trt Vol 
  ggplot() + 
  aes(x = before, y = after, color = OZ) + 
  geom_point() +
  geom_smooth(method = "lm", se = FALSE, group = 1) + 
  scale_color_brewer(palette = "Set1")

H1 %>% 
  group_by(CH, PLT, OZ) %>% 
  summarize(Baseline = VOL_bl, Harvest = VOL_h) %>% 
  pivot_longer(cols = c("Baseline", "Harvest"), names_to = "time", values_to = "volume") %>% 
  ggplot() + 
  aes(x = OZ, y = log(volume), fill = time) + 
  geom_boxplot(alpha = 0.5) +
  ggtitle("Log Volume (Pre- and Post-Treatment) by Treatment")

H1 %>% 
  group_by(OZ) %>% 
  summarize(meanVolBefore = mean(LOGVOL_bl), 
            meanVolAfter = mean(LOGVOL_h, na.rm = TRUE)) # Summarize mean log-volume by treatment

# Join Exposure Metrics to Mean Chamber Data ----------------------------------------
test_df <- H1 %>% 
  group_by(CH, OZ) %>% 
  summarise_at(vars(starts_with("LOG"), ends_with("DW"), VOL_bl), mean, na.rm = TRUE) 

# Get OZ metrics ---------------------------------------------------
source("C:/Users/skoike/Desktop/tidy data/OZmetrics.R")

# Want 1990 data and exposure data in range of 06-07-1989 to 9-27-1989
otest1 <- ferfoz %>% 
  mutate(date = mdy(date)) %>% 
  filter(between(date, mdy("06-07-1989"), mdy("9-27-1989")))
exp_days_1 <- as.numeric(mdy("9-27-1989") - mdy("06-07-1989") + 1)

otest_89_df <- OZ.metrics(otest1) %>%  
  mutate_if(is.numeric, function(x){x * 92 / exp_days_1})


test_long <- full_join(H1 %>% select(OZ, CH, PLT, LOGNEEDLEDW, LOGSTEMDW, LOGROOTDW, LOGTOTALDW, LOGVOL_bl),
                       otest_89_df)

#write.csv(test_long, "13_h1_data.csv", row.names = FALSE)

test2_df <- left_join(test_df, otest_89_df) %>% 
  ungroup() %>% 
  mutate(CH = as_factor(CH),
         Year = 1989,
         Harvest = 1,
         Exp_days = exp_days_1) %>% 
  select(Year, Harvest, Exp_days, everything())

#View(test2_df)

#write.csv(test2_df, "13_h1_mean_data.csv", row.names = FALSE)
