# 06-02-20 manually read csv files

library(tidyverse)
library(RColorBrewer)
library(lubridate)

## 06-02-20 ozone data ----------------

# Get Ferfoz data and clean it up a bit ---------------------
ferfoz <- R.utils::loadToEnv("C:/Users/skoike/Desktop/tidy data/FERF1.RData")[["ferfoz"]]

## actual <- NA if: 
### 1. actual < 0
### 2. stdev > 1 (and stdev is not NA)
### 3. actual - request > 0.2 (and request is not NA)

ferfoz <- ferfoz %>% mutate(actual = ifelse(actual < 0, NA, actual),
                            actual = ifelse(stdev > 1 & !is.na(stdev), NA, actual),
                            actual = ifelse(!is.na(request) & (actual - request) > 0.2, NA, actual),
                            actual = ifelse(n == 0, NA, actual))


# Read in Baseline Data -------------------------------------
F89BL13 <- read_csv("C:/Users/skoike/Desktop/tidy data/13DFEXRE/F89BL13.csv") # baseline ht/diam
F90W13H3 <- read_csv("C:/Users/skoike/Desktop/tidy data/13DFEXRE/F90W13H3.csv") # harvest dryweight 
F90H13H3 <- read_csv("C:/Users/skoike/Desktop/tidy data/13DFEXRE/F90H13H3.csv") # Harvest ht/diam


data_list <- list("F89BL13" = F89BL13, "F90W13H3" = F90W13H3, "F90H13H3" = F90H13H3)
data_list
data_list %>% lapply(dim)

# Clean Up Data --------------------------------------------------

## F89BL13

summary(F89BL13)

noNeg <- function(x){ifelse(x < 0, NA, x)} 

F89BL13_copy <- F89BL13 %>% 
  filter(DAY == -7) %>% 
  mutate_if(is.numeric, noNeg) %>% 
  mutate(DATE = mdy(DATE), # Convert Character Date to actual Date
         VOL = HT * DIAM^2, # Add Volume
         OZ = as_factor(OZ)) %>% 
  rename(CH89 = CH)

#View(F89BL13_copy)

## F90W13H3- Hvst 3 dry weights

#summary(F90W13H3) 
F90W13H3_copy <- F90W13H3 %>%  
  mutate_if(is.numeric, noNeg) %>%
  mutate(TNDW = N1TOTDW + N2TOTDW + N3TOTDW,
         TOTALDW = TNDW + TOTSTEMW + TOTROOTW) %>% 
  rename(OZ = OZ89,
         STEMDW = TOTSTEMW,
         ROOTDW = TOTROOTW) %>% 
  mutate(DATE = mdy(DATE),
         OZ = as_factor(OZ))

### F90H13H3- Hvst 3 growth measures, lengths & areas

#summary(F90H13H3)

F90H13H3_copy <- F90H13H3 %>% 
  mutate_if(is.numeric, noNeg) %>% 
  mutate(DATE = mdy(DATE),
         OZ = as_factor(OZ),
         VOL = HT * DIAM^2) # Add Volume

# Joining Harvest and Dry Weight Data -------------------------------------------------

harvest3_data <- full_join(F90W13H3_copy, F90H13H3_copy, by = c("CH89", "CH90", "PLT"))

#View(harvest3_data)

# Joining Harvest and Base Line Data -------------------------------------------------
level_ord <- c("CONTROL", "EPHIGH", "EPLOW", "EPMED", "EPXLOW")

H3 <- left_join(harvest3_data, F89BL13_copy, 
                by = c("CH89", "PLT"),
                suffix = c("_h", "_bl")) %>% 
  select(OZ.x, CH89, CH90, PLT, TNDW, STEMDW, ROOTDW, TOTALDW, VOL_bl, VOL_h) %>% 
  rename(OZ = OZ.x) %>% 
  mutate(OZ = fct_relevel(OZ, level_ord))

# OZ exposure
g <- ferfoz %>% 
  filter(ch %in% unique(H3$CH90)) %>% 
  select(ch, actual, request, date, datetime) %>% 
  mutate(date = mdy(date),
         datetime = dmy_hms(datetime)) %>% 
  filter(between(date, mdy("06-05-1990"), mdy("10-03-1990"))) %>% 
  pivot_longer(cols = c(actual, request))

g %>% 
  ggplot(aes(x = datetime, y = value, color = name)) +
  geom_line() + 
  scale_color_brewer(palette = "Set1") + 
  facet_wrap(. ~ ch) 

#View(H3)

# Add log transformation 
H3 <- H3 %>% 
  mutate(LOGNEEDLEDW = log(TNDW + 0.01),
         LOGSTEMDW = log(STEMDW + 0.01),
         LOGROOTDW = log(ROOTDW + 0.01),
         LOGTOTALDW = log(TOTALDW + 0.01),
         LOGVOL_bl = log(VOL_bl + 0.01),
         LOGVOL_h = log(VOL_h + 0.01)) 

# Curosy Exploratory Data Analysis -----------------------------------
H3 <- H3 %>% mutate(CH = factor(CH90))

H3 %>%  # Pre-Treatment Data 
  ggplot() + 
  aes(x = CH, y = LOGVOL_bl, fill = OZ) + # Pre-trt vol_ by Chamber
  geom_boxplot() + 
  ggtitle("Basline Pre-Treatment Volume by Chamber")

H3 %>% 
  group_by(CH, OZ, PLT) %>% 
  summarise(before = VOL_bl, after = VOL_h) %>% # Post-trt Vol by Pre-trt Vol 
  ggplot() + 
  aes(x = before, y = after, color = OZ) + 
  geom_point() +
  geom_smooth(method = "lm", se = FALSE, aes(group = 1), color = "black") + 
  scale_color_brewer(palette = "Set1")

H3 %>% 
  group_by(CH, PLT, OZ) %>% 
  summarize(Baseline = VOL_bl, Harvest = VOL_h) %>% 
  pivot_longer(cols = c("Baseline", "Harvest"), names_to = "time", values_to = "volume") %>% 
  ggplot() + 
  aes(x = OZ, y = log(volume), fill = time) + 
  geom_boxplot(alpha = 0.5) +
  ggtitle("Log Volume (Pre- and Post-Treatment) by Treatment")

H3 %>% 
  group_by(OZ) %>% 
  summarize(meanVolBefore = mean(LOGVOL_bl), 
            meanVolAfter = mean(LOGVOL_h, na.rm = TRUE)) # Summarize mean log-volume by treatment

# Join Exposure Metrics to Mean Chamber Data ----------------------------------------
test_df <- H3 %>% 
  group_by(CH, OZ) %>% 
  summarise_at(vars(starts_with("LOG"), ends_with("DW"), VOL_bl), mean, na.rm = TRUE) 

# Get OZ metrics ---------------------------------------------------
source("C:/Users/skoike/Desktop/tidy data/OZmetrics.R")

# Want 1990 data and exposure data in range of 06/05/90 to 10/03/90
otest1 <- ferfoz %>% 
  mutate(date = mdy(date)) %>% 
  filter(between(date, mdy("06/05/90"), mdy("10/03/90")))
exp_days_1 <- as.numeric(mdy("10/03/90") - mdy("06/05/90") + 1)

otest_89_df <- OZ.metrics(otest1) %>%  
  mutate_if(is.numeric, function(x){x * 92 / exp_days_1})

test_long <- full_join(H3 %>% select(OZ, CH, PLT, LOGNEEDLEDW, LOGSTEMDW, LOGROOTDW, LOGTOTALDW, LOGVOL_bl),
                       otest_89_df)

#write.csv(test_long, "13_h3_data.csv", row.names = FALSE)

test2_df <- left_join(test_df, otest_89_df) %>% 
  ungroup() %>% 
  mutate(CH = as_factor(CH),
         Year = 1990,
         Harvest = 2,
         Exp_days = exp_days_1) %>% 
  select(Year, Harvest, Exp_days, everything())

#View(test2_df)

#write.csv(test2_df, "13_h2_mean_data.csv", row.names = FALSE)
