# 07-23-20 manually read csv files

library(tidyverse)
library(broom)
library(ggfortify)
library(lubridate)

## 07-23-20 ozone data ----------------

# Get Ferfoz data and clean it up a bit ---------------------
ferfoz <- R.utils::loadToEnv("C:/Users/skoike/Desktop/tidy data/FERF1.RData")[["ferfoz"]]

## actual <- NA if: 
### 1. actual < 0
### 2. stdev > 1 (and stdev is not NA)
### 3. actual - request > 0.2 (and request is not NA)

ferfoz <- ferfoz %>% mutate(actual = ifelse(actual < 0, NA, actual),
                            actual = ifelse(stdev > 1 & !is.na(stdev), NA, actual),
                            actual = ifelse(!is.na(request) & (actual - request) > 0.2, NA, actual))

# Read in Baseline Data -------------------------------------
F90BL25 <- read_csv("C:/Users/skoike/Desktop/tidy data/25SMEXDY/F90BL25.csv")
F90H25 <- read_csv("C:/Users/skoike/Desktop/tidy data/25SMEXDY/F90H25.csv")


data.list <- list("F90BL25" = F90BL25, "F90H25" = F90H25)
data.list
data.list %>% lapply(dim)

# Clean Up Data --------------------------------------------------

## F90BL25

glimpse(F90BL25) # Pre-, interim & post-trtmt baseline growth measures & bud cnts
summary(F90BL25)

OZ.rlvl <- c("CONTROL", "EPXLOW", "EPHIGH", "XLOWHI", "HIXLOW")
noNeg <- function(x){ifelse(x < 0, NA, x)} 

baseline <- F90BL25 %>% 
  mutate_if(is.numeric, noNeg) %>% 
  mutate(DATE = mdy(DATE), # Convert Character Date to actual Date
         VOL = HT * DIAM^2, # Add Volume
         LOGVOL = log(VOL + 0.01), 
         OZ = as_factor(OZ),
         CH = as_factor(CH)) %>% 
  filter(DATE == mdy("05-18-1990"))

#View(F90BL25.copy)

### F90H25- Hvst 1 growth measures, lengths & areas

#glimpse(F90H25)

foliar <- F90H25 %>% 
  filter(CH != 0) %>% 
  droplevels() %>% 
  mutate_if(is.numeric, noNeg) %>% 
  mutate(DATE = mdy(DATE),
         OZ = as_factor(OZ),
         VOL = HT * DIAM^2, # Add Volume 
         LOGVOL = log(VOL + 0.01),
         CH = as_factor(CH),
         LOGLFAREA = log(LFAREA + 0.01)) %>% 
  select(-HTSCAR, -NOTE)

harvest <- right_join(baseline, foliar, 
                      by = c("CH", "PLT", "ID", "LOCAT", "PROJ", "OZ", "O3", "SPECIES"),
                      suffix = c("_bl", "_h")) 

# EDA -------------------------------------------------------

harvest %>% # Boxplot
  ggplot() + 
  aes(x = CH, y = LOGLFAREA, fill = OZ) + 
  geom_boxplot() + 
  scale_fill_manual(values = brewer.pal(6, "Set1"))

# Get Ozone Exposure Metrics --------------------------------------------------------

# Want 1989 data and exposure data in range of 06-06-1989 to 9-18-1989
otest1 <- ferfoz %>% 
  mutate(date = mdy(date),
         datetime = dmy_hms(datetime)) %>% 
  filter(between(date, mdy("05-16-1990"), mdy("10-03-1990")))
exp_days <- as.numeric(mdy("10-03-1990") - mdy("05-16-1990") + 1)

# Get OZ metrics ---------------------------------------------------
source("C:/Users/skoike/Desktop/tidy data/OZmetrics.R")

# (Ozone) Exposure Metrics:
otest.90.df <- OZ.metrics(otest1) %>% 
  filter(CH %in% levels(harvest$CH)) %>% 
  droplevels() %>% 
  mutate_if(is.numeric, function(x){x * 92/exp_days})

test_w126_long <- left_join(harvest, otest.90.df) %>% # Get OZ metrics for chamber:plant combo 
  ungroup() 

test_w126_long %>% # See relationship between W126, LOGVOL_bl, and LOGLFAREA
  ggplot() + 
  aes(x = w126.12.8.adj, y = LOGVOL_bl, color = LOGLFAREA, shape = OZ) + 
  geom_point(size = 2, alpha = 0.5) + 
  scale_color_distiller(palette = "RdBu")

a <- left_join(otest1 %>% 
                 as_tibble() %>% 
                 mutate(ch = as_factor(ch)), 
               harvest %>% 
                 rename(ch = CH, trt = O3) %>% 
                 select(ch, OZ)) %>% 
  filter(!is.na(OZ)) %>% 
  droplevels()

a %>%
  ggplot() + 
  aes(x = datetime, y = actual, color = OZ) + 
  geom_line() +  
  facet_wrap(. ~ ch, nrow = 2) + 
  scale_color_brewer(palette = "Set1")

test_wide <- harvest %>% # LOG Measurements by chamber
  group_by(CH, OZ) %>% 
  summarise_at(vars(starts_with("LOG")), mean, na.rm = TRUE)

test2_df <- left_join(test_wide, otest.90.df) %>% 
  ungroup() %>% 
  mutate(CH = as_factor(CH))

# end chamber means -----------------------------------------------------------------

test_wide %>% 
  ggplot() + 
  aes(x = LOGVOL_bl, y = LOGLFAREA, color = OZ) + 
  geom_point() + 
  geom_text(mapping = aes(label = OZ), nudge_y = -0.02) + 
  scale_color_discrete(guide = FALSE)

# End Plots ---------------------------------------------------------------------

# 7-22-20 correlation analysis of biomass dry weight and ozone metrics -------------------------------
library(corrr)
corrs <- test2_df %>% 
  select(-c(CH, OZ)) %>% # Remove non-necessary variables
  correlate() %>% # Create correlation data frame
  select(1, 3, 4) # Select only responses for columns
head(corrs, 10) # First 10 rows

corrs %>% 
  filter(str_detect(rowname, "w126"))

# 7-22-20 ANOCOVA --------------------------------------------------------------

## Linearly Modeling log-leaf area Dry Weight with log-Volume as a Covariate
test.lm <- lm(LOGLFAREA ~ OZ + LOGVOL_bl, data = test2_df, na.action = "na.exclude") 
summary(test.lm) # Log-Volume not significant

test.lm <- lm(LOGLFAREA ~ OZ, data = test2_df, na.action = "na.exclude") 
summary(test.lm) 

# Regression Analysis ----------------------------------------------------------
library(minpack.lm)
g <- function(x, a, b, c){log(a) + (-(x/b)^c)}

# LOGLFAREA
ggplot(test2_df, aes(x = w126.12.8.adj, y = LOGLFAREA)) +
  geom_point(aes(color = OZ)) + 
  geom_smooth(method = "lm", se = FALSE)

lmcov_lfarea <- lm(LOGLFAREA ~ w126.12.8.adj + LOGVOL_bl, data = test2_df)
summary(lmcov_lfarea) 

lm_lfarea <- lm(LOGLFAREA ~ w126.12.8.adj, data = test2_df)
summary(lm_lfarea) 

lfarea_adj <- test2_df %>% 
  select(CH, OZ, LOGLFAREA, w126.12.8.adj, LOGVOL_bl) %>% 
  mutate(y = LOGLFAREA - coef(lmcov_lfarea)[1] - coef(lmcov_lfarea)[3]*LOGVOL_bl)
lmcov_lfarea1 <- lm(y ~ -1 + w126.12.8.adj, data = lfarea_adj)


ggplot(lfarea_adj, aes(x = w126.12.8.adj, y = y, color = OZ)) +
  geom_point(size = 1.5) + 
  geom_text(aes(label = CH), nudge_y = -0.075, show.legend = FALSE) + 
  geom_smooth(method = "lm", se = FALSE, aes(group = 1)) + 
  scale_color_brewer(palette = "Set1") + 
  labs(x = "92-Day 12-h W126 Rescale (ppm-hr)",
       y = "Adjusted Log Leaf Area",
       title = "Study 25: Sugar Maple Harvest 1 (92-Day Rescale)",
       subtitle = "Exposure Dates: 05-16-1990 - 10/03/1990") 

lfarea_h1_points <- lfarea_adj %>% mutate(Harvest = "Harvest 1")

#write.csv(lfarea_h1_points, "lfarea_h1_points.csv", row.names = FALSE)

