# 06-02-20 manually read csv files

library(tidyverse)
library(RColorBrewer)
library(lubridate)

## 06-02-20 ozone data ----------------

# Get Ferfoz data and clean it up a bit ---------------------
ferfoz <- R.utils::loadToEnv("C:/Users/skoike/Desktop/tidy data/FERF1.RData")[["ferfoz"]]

## actual <- NA if: 
### 1. actual < 0
### 2. stdev > 1 (and stdev is not NA)
### 3. actual - request > 0.2 (and request is not NA)

ferfoz <- ferfoz %>% mutate(actual = ifelse(actual < 0, NA, actual),
                            actual = ifelse(stdev > 1 & !is.na(stdev), NA, actual),
                            actual = ifelse(!is.na(request) & (actual - request) > 0.2, NA, actual),
                            actual = ifelse(n == 0, NA, actual))


# Read in Baseline Data -------------------------------------
F90BL26 <- read_csv("C:/Users/skoike/Desktop/tidy data/26PPEXDY/F90BL26.csv") # baseline
F90DW26 <- read_csv("C:/Users/skoike/Desktop/tidy data/26PPEXDY/F90DW26.add.csv") 
F90H26 <- read_csv("C:/Users/skoike/Desktop/tidy data/26PPEXDY/F90H26.csv")


data.list <- list("F90BL26" = F90BL26, "F90DW26" = F90DW26, "F90H26" = F90H26)
data.list
data.list %>% lapply(dim)

# Clean Up Data --------------------------------------------------

## F90BL26

glimpse(F90BL26) # Pre-, interim & post-trtmt baseline growth measures & bud cnts
summary(F90BL26)

noNeg <- function(x){ifelse(x < 0, NA, x)} 

F90BL26.copy <- F90BL26 %>% 
  mutate_if(is.numeric, noNeg) %>% 
  mutate(DATE = mdy(DATE), # Convert Character Date to actual Date
         VOL = HT * DIAM^2, # Add Volume
         OZ = as_factor(OZ),
         CH = as_factor(CH)) %>% 
  filter(DATE == mdy("05-16-1990"))

#View(F90BL26.copy)

## F90DW26- Hvst 1.1 cnts, CHO subsample dry wts

#glimpse(F90DW26.1) 
noNA <- function(x){ifelse(x == -99, NA, x)}

F90DW26 <- F90DW26 %>% 
  mutate_if(is.numeric, noNA) %>% 
  mutate(DATE = mdy(DATE),
         OZ90 = as_factor(OZ90),
         CH90 = as_factor(CH90),
         TOTALDW = N2TOTDW + STEMDW + TOTROOTW) %>% 
  rename(OZ = OZ90,
         CH = CH90,
         ROOTDW = TOTROOTW,
         NEEDLEDW = N2TOTDW) 

### F90H26- Hvst 1 growth measures, lengths & areas

#glimpse(F90H26)

F90H26.copy <- F90H26 %>% 
  filter(CH != 0) %>% 
  droplevels() %>% 
  mutate_if(is.numeric, noNA) %>% 
  mutate(DATE = mdy(DATE),
         OZ = as_factor(OZ),
         VOL = HT * DIAM^2, # Add Volume 
         CH = as_factor(CH)) %>% 
  select(-HTSCAR, -NOTE)

# Joining Harvest and Dry Weight Data -------------------------------------------------

harvest1.data <- left_join(F90DW26, F90H26.copy)

#View(harvest1.data)

# Joining Harvest and Base Line Data -------------------------------------------------

H1 <- left_join(harvest1.data, F90BL26.copy, 
                by = c("PROJ", "LOCAT", "SPECIES", "OZ", "O3", "ID",
                       "CH", "PLT"),
                suffix = c(".h", ".bl"))
# OZ exposure
g <- ferfoz %>% 
  filter(ch %in% unique(H1$CH)) %>% 
  select(ch, actual, request, date, datetime) %>% 
  mutate(date = mdy(date),
         datetime = dmy_hms(datetime)) %>% 
  filter(between(date, mdy("05-16-1990"), mdy("10-03-1990"))) %>% 
  pivot_longer(cols = c(actual, request))

#g %>% 
 
# ggplot(aes(x = datetime, y = value, color = name)) +
 # geom_line() + 
#  facet_wrap(.~ ch) + 
 # annotate(xmin = mdy_hms("05-16-1990 00:00:00"), xmax = mdy_hms("08-16-1990 00:00:00"), 
  #         geom = "rect", fill = "red", alpha = 0.1,
   #        ymin = 0, ymax = Inf)


#View(H1)

# Add log transformation 
H1 <- H1 %>% 
  mutate(LOGNEEDLEDW = log(NEEDLEDW + 0.01),
         LOGSTEMDW = log(STEMDW + 0.01),
         LOGROOTDW = log(ROOTDW + 0.01),
         LOGTOTALDW = log(TOTALDW + 0.01),
         LOGVOL.bl = log(VOL.bl + 0.01),
         LOGVOL.h = log(VOL.h + 0.01))

raw_data <- H1 %>% select(SPECIES, OZ, O3, ID, CH, PLT, VOL.bl, VOL.h, NEEDLEDW, STEMDW, ROOTDW, TOTALDW, 
                          LOGVOL.bl, LOGVOL.h, LOGNEEDLEDW, LOGSTEMDW, LOGROOTDW, LOGTOTALDW,
                          DATE.bl, DATE.h)
#write.csv(raw_data, "26_h1_raw.csv", row.names = FALSE)

# Curosy Exploratory Data Analysis -----------------------------------

H1 %>%  # Pre-Treatment Data 
  ggplot() + 
  aes(x = CH, y = LOGVOL.bl, fill = OZ) + # Pre-trt vol. by Chamber
  geom_boxplot() + 
  ggtitle("Basline Pre-Treatment Volume by Chamber")

H1 %>% 
  group_by(CH, PLT) %>% 
  summarise(before = VOL.bl, after = VOL.h) %>% # Post-trt Vol by Pre-trt Vol 
  ggplot() + 
  aes(x = before, y = after) + 
  geom_point() +
  geom_smooth(method = "lm", se = FALSE)

H1 %>% 
  group_by(CH, PLT, OZ) %>% 
  summarize(Baseline = VOL.bl, Harvest = VOL.h) %>% 
  pivot_longer(cols = c("Baseline", "Harvest"), names_to = "time", values_to = "volume") %>% 
  ggplot() + 
  aes(x = OZ, y = log(volume), fill = time) + 
  geom_boxplot(alpha = 0.5) +
  ggtitle("Log Volume (Pre- and Post-Treatment) by Treatment")

H1 %>% 
  group_by(OZ) %>% 
  summarize(meanVolBefore = mean(LOGVOL.bl), 
            meanVolAfter = mean(LOGVOL.h, na.rm = TRUE)) # Summarize mean log-volume by treatment

# Join Exposure Metrics to Mean Chamber Data ----------------------------------------
test.df <- H1 %>% 
  group_by(CH, OZ) %>% 
  summarise_at(vars(starts_with("LOG"), ends_with("DW"), VOL.bl), mean, na.rm = TRUE) 

#write.csv(test.df, "26_h1_means.csv", row.names = FALSE)

# Get OZ metrics ---------------------------------------------------
source("C:/Users/skoike/Desktop/tidy data/OZmetrics.R")

# Want 1990 data and exposure data in range of 05-16-1990 to 10-03-1990
otest1 <- ferfoz %>% 
  mutate(date = mdy(date)) %>% 
  filter(between(date, mdy("05-16-1990"), mdy("10-03-1990")))
exp_days_1 <- as.numeric(mdy("10-03-1990") - mdy("05-16-1990") + 1)

otest.90.df <- OZ.metrics(otest1) %>% 
  filter(CH %in% setdiff(levels(test.df$CH), c(1, 5, 7, 10))) %>% 
  mutate_if(is.numeric, function(x){x * 92 / exp_days_1})

#end exposure date = 8/16/90 for CH 1,5,7,10

otest15710 <- ferfoz %>% 
  mutate(date = mdy(date)) %>% 
  filter(between(date, mdy("05-16-1990"), mdy("08-16-1990")))
exp_days_2 <- as.numeric(mdy("08-16-1990") - mdy("05-16-1990") + 1)

otest15710.df <- OZ.metrics(otest15710) %>% 
  filter(CH %in% c(1, 5, 7, 10)) %>% 
  mutate_if(is.numeric, function(x){x * 92 / exp_days_2})

#Combine the Two
otest.90.comb <- full_join(otest.90.df, otest15710.df) 

CH.rlvl <- otest.90.comb$CH %>% 
  as.character() %>% 
  as.numeric() %>% 
  sort() %>% 
  as.character()

otest.90.comb <- otest.90.comb %>% 
  mutate(CH = fct_relevel(CH, CH.rlvl)) %>% 
  arrange(CH)

#write.csv(otest.90.comb, "26_h1_oz_metrics.csv", row.names = FALSE)

test_long <- full_join(H1 %>% 
                         select(OZ, CH, PLT, LOGNEEDLEDW, LOGSTEMDW, LOGROOTDW, LOGTOTALDW, LOGVOL.bl) %>% 
                         rename(LOGVOL_bl = LOGVOL.bl),
                       otest.90.comb)

#write.csv(test_long, "26_h1_data.csv", row.names = FALSE)

test2.df <- left_join(test.df, otest.90.comb) %>% 
  ungroup()  %>% 
  mutate(CH = as_factor(CH),
         Year = 1990,
         Harvest = 1,
         Exp_days = ifelse(CH %in% c(1, 5, 7, 10), exp_days_2, exp_days_1)) %>% 
  select(Year, Harvest, Exp_days, everything(), -LOGVOL.h, -N2SSDW, -N2RSTDW) %>% 
  rename(LOGVOL_bl = LOGVOL.bl)

#View(test2.df)

#write.csv(test2.df, "26_h1_mean_data.csv", row.names = FALSE)

