# 06-05-20 manually read csv files

library(tidyverse)
library(lubridate)
library(broom)
library(ggfortify)

## 06-05-20 ozone data ----------------

# Get Ferfoz data and clean it up a bit ---------------------

ferfoz <- R.utils::loadToEnv("C:/Users/skoike/Desktop/tidy data/FERF1.RData")[["ferfoz"]]

## actual <- NA if: 
### 1. actual < 0
### 2. stdev > 1 (and stdev is not NA)
### 3. actual - request > 0.2 (and request is not NA)

ferfoz <- ferfoz %>% mutate(actual = ifelse(actual < 0, NA, actual),
                            actual = ifelse(stdev > 1 & !is.na(stdev), NA, actual),
                            actual = ifelse(!is.na(request) & (actual - request) > 0.2, NA, actual),
                            actual = ifelse(n == 0, NA, actual))

# Read in Data -------------------------------------
F90BL26 <- read_csv("C:/Users/skoike/Desktop/tidy data/26PPEXDY/F90BL26.csv") # basline
F91BL26 <- read_csv("C:/Users/skoike/Desktop/tidy data/26PPEXDY/F91BL26.csv") # pre-season 2 baseline 
F91H26P2 <- read_csv("C:/Users/skoike/Desktop/tidy data/26PPEXDY/F91H26P2.csv") # carryover


data.list <- list("F90BL26" = F90BL26, "F91BL26" = F91BL26, "F91H26P2" = F91H26P2)
data.list
data.list %>% lapply(dim)

# Clean Up Data --------------------------------------------------

## F90BL26

#glimpse(F91BL26) # Pre-, interim & post-trtmt baseline growth measures & bud cnts
#summary(F91BL26)

OZ.rlvl <- c("CONTROL", "EPXLOW", "EPHIGH", "XLOWHI", "HIXLOW")
noNeg <- function(x){ifelse(x < 0, NA, x)} 

F90BL26.copy <- F90BL26 %>% 
  mutate_if(is.numeric, noNeg) %>% 
  mutate(DATE = mdy(DATE), # Convert Character Date to actual Date
         VOL = HT * DIAM^2, # Add Volume
         OZ = as_factor(OZ),
         CH = as_factor(CH)) %>% 
  filter(DATE == mdy("05-16-1990")) %>% 
  select(OZ, CH, PLT, VOL) %>% 
  rename(CH90 = CH)

F91BL26.copy <- F91BL26 %>% 
  mutate_if(is.numeric, noNeg) %>% 
  mutate(DATE = mdy(DATE), # Convert Character Date to actual Date
         OZ90 = as_factor(OZ90),
         OZ91 = as_factor(OZ91),
         CH90 = as_factor(CH90),
         CH91A = as_factor(CH91A),
         CH91B = as_factor(CH91B)) %>% 
  filter(OZ90 %in% OZ.rlvl) %>% 
  droplevels() %>% 
  select(OZ90, OZ91, CH90, PLT, CH91A, CH91B)

#View(F91BL26.copy)

baseline <- right_join(F90BL26.copy, F91BL26.copy)

## F91H26P2- Post-trtmt Hvst 2, hvst growth measures, cnts, CHO subsample, 100 ndl cnt subsample & bulk dry wts

#glimpse(F91H26P2)
#glimpse(F91H26P2) 

harvest2.data <- F91H26P2 %>% 
  mutate_if(is.numeric, noNeg) %>%
  rename(STEMDW = TOTSTEMW,
         ROOTDW = TOTROOTW) %>% 
  mutate(DATE = mdy(DATE),
         OZ90 = as_factor(OZ90),
         CH90 = as_factor(CH90),
         OZ91 = as_factor(OZ91),
         CH91A = as_factor(CH91A),
         CH91B = as_factor(CH91B),
         NEEDLEDW = N2TOTDW + N3TOTDW,
         TOTALDW = STEMDW + ROOTDW + NEEDLEDW,
         VOL = HT * DIAM^2) %>% 
  select(OZ90, OZ91, CH91A, CH91B, CH90, PLT, NEEDLEDW, STEMDW, ROOTDW, TOTALDW, VOL)

#View(harvest2.data)

# Looking at Misssingness --------------------------------------------------

harvest2.data %>% 
  group_by(OZ90, OZ91) %>% 
  select(NEEDLEDW, STEMDW, ROOTDW, TOTALDW) %>% 
  summarise_if(is.numeric, list(notNA = ~ sum(!is.na(.))))

harvest2.data %>% 
  group_by(OZ90, OZ91) %>% 
  select(NEEDLEDW, STEMDW, ROOTDW, TOTALDW) %>% 
  summarise_if(is.numeric, list(prop_notNA = ~ sum(!is.na(.))/length(.)))



# Joining Baseline and Dry Weight Data ---------------------------------------
H2 <- left_join(harvest2.data, baseline, 
                by = c("OZ90", "OZ91", "CH91A", "CH91B", "CH90", "PLT"),
                suffix = c(".h2", ".bl"))
#View(H2)

# Add log transformation and recode CH as a factor
H2 <- H2 %>% 
  mutate(LOGNEEDLEDW = log(NEEDLEDW + 0.01),
         LOGSTEMDW = log(STEMDW + 0.01),
         LOGROOTDW = log(ROOTDW + 0.01),
         LOGTOTALDW = log(TOTALDW + 0.01),
         LOGVOL.bl = log(VOL.bl + 0.01),
         LOGVOL.h2 = log(VOL.h2 + 0.01))

# Curosy Exploratory Data Analysis -----------------------------------

H2 %>%  # Pre-Treatment Data 
  ggplot() + 
  aes(x = CH91A, y = LOGVOL.bl) + # Pre-trt vol. by Chamber
  geom_boxplot() + 
  ggtitle("Basline Pre-Treatment Volume by Chamber")

H2 %>% 
  group_by(CH91A, CH91B, PLT) %>% 
  summarise(before = VOL.bl, after = VOL.h2) %>% # Post-trt Vol by Pre-trt Vol 
  ggplot() + 
  aes(x = before, y = after) + 
  geom_point() +
  geom_smooth(method = "lm", se = FALSE)

H2 %>% 
  group_by(OZ91) %>% 
  summarize(meanVolBefore = mean(LOGVOL.bl, na.rm = TRUE), 
            meanVolAfter = mean(LOGVOL.h2, na.rm = TRUE)) # Summarize mean log-volume by treatment

# Join Exposure Metrics to Mean Chamber Data ----------------------------------------
test.df <- H2 %>% 
  mutate(joinedCH = CH91A:CH91B) %>% 
  group_by(CH90, OZ90, CH91A, CH91B, joinedCH, OZ91) %>% 
  summarise_at(vars(starts_with("LOG"), ends_with("DW"), VOL.bl), mean, na.rm = TRUE)

#write.csv(test.df, "26_h3_means.csv", row.names = FALSE)

source("C:/Users/skoike/Desktop/tidy data/OZsplitmetrics.R")

# Want 1991 data and exposure data in range of 05-01-1991 to 09-16-1991
otest1 <- ferfoz %>% 
  distinct() %>% 
  mutate(date = mdy(date)) %>% 
  filter(between(date, mdy("05-01-1991"), mdy("09-16-1991")))
exp_days <- as.numeric(mdy("09-16-1991") - mdy("05-01-1991") + 1)

# Applying the split-chamber metrics to the data

otest.91.df <- test.df %>%
  split(1:nrow(.)) %>% 
  map_dfr(~ OZ.switch.metrics(otest1, CH1 = .x$CH91A, CH2 = .x$CH91B, split_date = mdy("06/30/1991"))) %>% 
  mutate_if(is.numeric, function(x){x * 92/exp_days})

#write.csv(otest.91.df, "26_h3_oz_metrics.csv", row.names = FALSE)

test_long <- full_join(H2 %>% 
                         select(OZ90, OZ91, CH90, CH91A, CH91B, PLT, LOGNEEDLEDW, LOGSTEMDW, LOGROOTDW, LOGTOTALDW, LOGVOL.bl) %>% 
                         rename(LOGVOL_bl = LOGVOL.bl) %>% 
                         mutate(joinedCH = factor(paste0(CH91A, ":", CH91B))),
                       otest.91.df)

#write.csv(test_long, "26_h3_data.csv", row.names = FALSE)

test2.df <- full_join(test.df, otest.91.df) %>% 
  ungroup() %>% 
  mutate(Year = 1991,
         Harvest = 2,
         Exp_days = exp_days) %>%
  rename(LOGVOL_bl = LOGVOL.bl,
         CHAMB = joinedCH,
         VOL_bl = VOL.bl,
         TREAT = OZ91) %>% 
  select(Year, Harvest, Exp_days, everything(), 
         -CH90, -CH91A, -CH91B, -LOGVOL.h2, -OZ90)

#write.csv(test2.df, "26_h2_mean_data.csv", row.names = FALSE)
