# 06-02-20 manually read csv files

library(tidyverse)
library(RColorBrewer)
library(lubridate)

## 06-02-20 ozone data ----------------

# Get Ferfoz data and clean it up a bit ---------------------
ferfoz <- R.utils::loadToEnv("C:/Users/skoike/Desktop/tidy data/FERF1.RData")[["ferfoz"]]

## actual <- NA if: 
### 1. actual < 0
### 2. stdev > 1 (and stdev is not NA)
### 3. actual - request > 0.2 (and request is not NA)

ferfoz <- ferfoz %>% mutate(actual = ifelse(actual < 0, NA, actual),
                            actual = ifelse(stdev > 1 & !is.na(stdev), NA, actual),
                            actual = ifelse(!is.na(request) & (actual - request) > 0.2, NA, actual),
                            actual = ifelse(n == 0, NA, actual))


# Read in Baseline Data -------------------------------------
F90BL27 <- read_csv("C:/Users/skoike/Desktop/tidy data/27RAEXRE/F90BL27.csv") # baseline ht/diam
F90DW27 <- as_tibble(R.utils::loadToEnv("C:/Users/skoike/Desktop/tidy data/FERF1.RData")[["F90W27"]]) # harvest dryweight 
F90H27 <- read_csv("C:/Users/skoike/Desktop/tidy data/27RAEXRE/F90H27.csv") # Harvest ht/diam


data_list <- list("F90BL27" = F90BL27, "F90DW27" = F90DW27, "F90H27" = F90H27)
data_list
data_list %>% lapply(dim)

# Clean Up Data --------------------------------------------------

## F90BL27

summary(F90BL27)

noNeg <- function(x){ifelse(x == -99, NA, x)} 

F90BL27_copy <- F90BL27 %>% 
  filter(DAY == -4) %>% 
  mutate_if(is.numeric, noNeg) %>% 
  mutate(DATE = mdy(DATE), # Convert Character Date to actual Date
         VOL = HT * DIAM^2) %>% 
  select(OZ, CH, PLT, VOL)

#View(F89BL14_copy)

## F90DW27- Hvst 1 dry weights

#summary(F90DW27) 
F90DW27_copy <- F90DW27 %>% 
  rename(OZ = OZ90,
         CH = CH90) %>% 
  select(OZ, CH, PLT, LEAFDW, STEMDW, ROOTDW, TOTALDW)

### F90H27- Hvst 1 growth measures, lengths & areas

#summary(F90H27)

F90H27_copy <- F90H27 %>% 
  filter(OZ != "NOO3") %>% 
  mutate_if(is.numeric, noNeg) %>% 
  mutate(DATE = mdy(DATE),
         VOL = HT * DIAM^2) %>% 
  select(OZ, CH, PLT, VOL) 

# Joining Harvest and Dry Weight Data -------------------------------------------------

harvest1_data <- full_join(F90DW27_copy, F90H27_copy, by = c("CH", "PLT", "OZ"))

#View(harvest1_data)

# Joining Harvest and Base Line Data -------------------------------------------------
level_ord <- c("CONTROL", "EPHIGH", "EPLOW", "EPMED", "EPXLOW")
H1 <- left_join(harvest1_data, F90BL27_copy, 
                by = c("CH", "PLT", "OZ"),
                suffix = c("_h", "_bl")) %>% 
  mutate(OZ = as_factor(OZ),
         OZ = fct_relevel(OZ, level_ord),
         CH = as_factor(CH))

# OZ exposure
p <- ferfoz %>% 
  filter(ch %in% unique(H1$CH)) %>% 
  select(ch, actual, request, date, datetime) %>% 
  mutate(date = mdy(date),
         datetime = dmy_hms(datetime)) %>% 
  filter(between(date, mdy("06-05-1990"), mdy("10-03-1990"))) %>% 
  pivot_longer(cols = c(actual, request))

oz_exp <- p %>% 
  ggplot(aes(x = datetime, y = value, color = name)) +
  geom_line() + 
  scale_color_brewer(palette = "Set1") + 
  facet_wrap(. ~ ch) 
#oz_exp 

#View(H1)

# Add log transformation 
H1 <- H1 %>% 
  mutate(LOGLEAFDW = log(LEAFDW + 0.01),
         LOGSTEMDW = log(STEMDW + 0.01),
         LOGROOTDW = log(ROOTDW + 0.01),
         LOGTOTALDW = log(TOTALDW + 0.01),
         LOGVOL_bl = log(VOL_bl + 0.01),
         LOGVOL_h = log(VOL_h + 0.01))

# Curosy Exploratory Data Analysis -----------------------------------

H1 %>%  # Pre-Treatment Data 
  ggplot() + 
  aes(x = CH, y = LOGVOL_bl, fill = OZ) + # Pre-trt vol_ by Chamber
  geom_boxplot() + 
  ggtitle("Basline Pre-Treatment Volume by Chamber")

H1 %>% 
  ggplot() + 
  aes(x = VOL_bl, y = VOL_h, color = OZ) + 
  geom_point() +
  geom_smooth(method = "lm", se = FALSE) + 
  scale_color_brewer(palette = "Set1")

H1 %>% 
  group_by(CH, PLT, OZ) %>% 
  summarize(Baseline = LOGVOL_bl, Harvest = LOGVOL_h) %>% 
  pivot_longer(cols = c("Baseline", "Harvest"), names_to = "time", values_to = "logvolume") %>% 
  ggplot() + 
  aes(x = OZ, y = logvolume, fill = time) + 
  geom_boxplot(alpha = 0.5) +
  ggtitle("Log Volume (Pre- and Post-Treatment) by Treatment")

H1 %>% 
  group_by(OZ) %>% 
  summarize(meanVolBefore = mean(LOGVOL_bl), 
            meanVolAfter = mean(LOGVOL_h, na.rm = TRUE)) # Summarize mean log-volume by treatment

# Join Exposure Metrics to Mean Chamber Data ----------------------------------------
test_df <- H1 %>% 
  group_by(CH, OZ) %>% 
  summarise_at(vars(starts_with("LOG"), ends_with("DW"), VOL_bl), mean, na.rm = TRUE) %>% 
  select(-LOGVOL_h) 

# Get OZ metrics ---------------------------------------------------
source("C:/Users/skoike/Desktop/tidy data/OZmetrics.R")

# Want 1990 data and exposure data in range of 06-05-1990 to 10-03-1990
otest1 <- ferfoz %>% 
  mutate(date = mdy(date)) %>% 
  filter(between(date, mdy("06-05-1990"), mdy("10-03-1990")))
exp_days_1 <- as.numeric(mdy("10-03-1990") - mdy("06-05-1990") + 1)

otest_90_df <- OZ.metrics(otest1) %>%  
  mutate_if(is.numeric, function(x){x * 92 / exp_days_1})

test_long <- full_join(H1 %>% select(OZ, CH, PLT, LOGLEAFDW, LOGSTEMDW, LOGROOTDW, LOGTOTALDW, LOGVOL_bl),
                       otest_90_df)

#write.csv(test_long, "27_h1_data.csv", row.names = FALSE)

test2_df <- left_join(test_df, otest_90_df) %>% 
  ungroup() %>% 
  mutate(CH = as_factor(CH),
         Year = 1990,
         Harvest = 1,
         Exp_days = exp_days_1) %>% 
  select(Year, Harvest, Exp_days, everything())

#View(test2_df)

#write.csv(test2_df, "27_h1_mean_data.csv", row.names = FALSE)
