# 06-02-20 manually read csv files

library(tidyverse)
library(RColorBrewer)
library(lubridate)

## 06-02-20 ozone data ----------------

# Get Ferfoz data and clean it up a bit ---------------------
ferfoz <- R.utils::loadToEnv("C:/Users/skoike/Desktop/tidy data/FERF1.RData")[["ferfoz"]]

## actual <- NA if: 
### 1. actual < 0
### 2. stdev > 1 (and stdev is not NA)
### 3. actual - request > 0.2 (and request is not NA)

ferfoz <- ferfoz %>% mutate(actual = ifelse(actual < 0, NA, actual),
                            actual = ifelse(stdev > 1 & !is.na(stdev), NA, actual),
                            actual = ifelse(!is.na(request) & (actual - request) > 0.2, NA, actual),
                            actual = ifelse(n == 0, NA, actual))


# Read in Baseline Data -------------------------------------
F91BL34 <- read_csv("C:/Users/skoike/Desktop/tidy data/34PPEXRE/F91BL34.csv") # baseline ht/diam
F91H34P1 <- read_csv("C:/Users/skoike/Desktop/tidy data/34PPEXRE/F91H34P1.csv") # harvest dryweight, ht/diam 

data_list <- list("F91BL34" = F91BL34, "F91H34P1" = F91H34P1)
data_list
data_list %>% lapply(dim)

# Clean Up Data --------------------------------------------------

## F91BL34

summary(F91BL34)

noNeg <- function(x){ifelse(x == -99, NA, x)} 

F91BL34_copy <- F91BL34 %>% 
  filter(DAY == -1) %>% 
  mutate_if(is.numeric, noNeg) %>%
  rename(OZ = OZ91,
         CH = CH91) %>% 
  mutate(DATE = mdy(DATE), # Convert Character Date to actual Date
         VOL = HT * DIAM^2, # Add Volume
         OZ = as_factor(OZ),
         CH = as_factor(CH))

#View(F91BL34_copy)

## F91H34P1- Hvst 1 dry weights

#summary(F91H34P1)

F91W34_copy <- F91H34P1 %>%  
  mutate_if(is.numeric, noNeg) %>%
  mutate(TOTALDW = TNDW + STDW + TRTDW,
         VOL = HT * DIAM^2) %>% 
  rename(OZ = OZ91,
         CH = CH91,
         NEEDLEDW = TNDW,
         STEMDW = STDW,
         ROOTDW = TRTDW) %>% 
  mutate(DATE = mdy(DATE),
         OZ = as_factor(OZ),
         CH = as_factor(CH))


# Joining Harvest and Dry Weight Data -------------------------------------------------

harvest1_data <- F91W34_copy %>% select(OZ, CH, PLT, NEEDLEDW, STEMDW, ROOTDW, TOTALDW, VOL)

#View(harvest1_data)

# Joining Harvest and Base Line Data -------------------------------------------------
H1 <- left_join(harvest1_data, F91BL34_copy %>% select(CH, PLT, VOL), 
                by = c("CH", "PLT"),
                suffix = c("_h", "_bl"))

# OZ exposure
p <- ferfoz %>% 
  filter(ch %in% unique(H1$CH)) %>% 
  select(ch, actual, request, date, datetime) %>% 
  mutate(date = mdy(date),
         datetime = dmy_hms(datetime)) %>% 
  filter(between(date, mdy("06-05-1991"), mdy("9-30-1991"))) %>% 
  pivot_longer(cols = c(actual, request))

oz_exp <- p %>% 
  ggplot(aes(x = datetime, y = value, color = name)) +
  geom_line() + 
  scale_color_brewer(palette = "Set1") + 
  facet_wrap(. ~ ch) 
#oz_exp 

#View(H1)

# Add log transformation 
H1 <- H1 %>% 
  mutate(LOGNEEDLEDW = log(NEEDLEDW + 0.01),
         LOGSTEMDW = log(STEMDW + 0.01),
         LOGROOTDW = log(ROOTDW + 0.01),
         LOGTOTALDW = log(TOTALDW + 0.01),
         LOGVOL_bl = log(VOL_bl + 0.01),
         LOGVOL_h = log(VOL_h + 0.01))

# Curosy Exploratory Data Analysis -----------------------------------

H1 %>%  # Pre-Treatment Data 
  ggplot() + 
  aes(x = CH, y = LOGVOL_bl, fill = OZ) + # Pre-trt vol_ by Chamber
  geom_boxplot() + 
  ggtitle("Basline Pre-Treatment Volume by Chamber")

H1 %>% 
  group_by(CH, OZ, PLT) %>% 
  summarise(before = VOL_bl, after = VOL_h) %>% # Post-trt Vol by Pre-trt Vol 
  ggplot() + 
  aes(x = before, y = after, color = OZ) + 
  geom_point() +
  geom_smooth(method = "lm", se = FALSE, aes(group = 1)) + 
  scale_color_brewer(palette = "Set1")

H1 %>% 
  group_by(CH, PLT, OZ) %>% 
  summarize(Baseline = VOL_bl, Harvest = VOL_h) %>% 
  pivot_longer(cols = c("Baseline", "Harvest"), names_to = "time", values_to = "volume") %>% 
  ggplot() + 
  aes(x = OZ, y = log(volume), fill = time) + 
  geom_boxplot(alpha = 0.5) +
  ggtitle("Log Volume (Pre- and Post-Treatment) by Treatment")

H1 %>% 
  group_by(OZ) %>% 
  summarize(meanVolBefore = mean(LOGVOL_bl), 
            meanVolAfter = mean(LOGVOL_h, na.rm = TRUE)) # Summarize mean log-volume by treatment

# Join Exposure Metrics to Mean Chamber Data ----------------------------------------
test_df <- H1 %>% 
  group_by(CH, OZ) %>% 
  summarise_at(vars(starts_with("LOG"), ends_with("DW"), VOL_bl), mean, na.rm = TRUE) 

# Get OZ metrics ---------------------------------------------------
source("C:/Users/skoike/Desktop/tidy data/OZmetrics.R")

# Want 1991 data and exposure data in range of 06-05-1991 to 9-30-1991
otest1 <- ferfoz %>% 
  distinct() %>% 
  mutate(date = mdy(date)) %>% 
  filter(between(date, mdy("06-05-1991"), mdy("9-30-1991")))
exp_days_1 <- as.numeric(mdy("09-30-1991") - mdy("06-05-1991") + 1)

otest_91_df <- OZ.metrics(otest1) %>%  
  mutate_if(is.numeric, function(x){x * 92 / exp_days_1})

test_long <- full_join(H1 %>% select(OZ, CH, PLT, LOGNEEDLEDW, LOGSTEMDW, LOGROOTDW, LOGTOTALDW, LOGVOL_bl),
                       otest_91_df)

#write.csv(test_long, "34_h1_data.csv", row.names = FALSE)

test2_df <- left_join(test_df, otest_91_df) %>% 
  ungroup() %>% 
  mutate(CH = as_factor(CH),
         Year = 1991,
         Harvest = 1,
         Exp_days = exp_days_1) %>% 
  select(Year, Harvest, Exp_days, everything()) 

#View(test2_df)

#write.csv(test2_df, "34_h1_mean_data.csv", row.names = FALSE)
