# 06-02-20 manually read csv files

library(tidyverse)
library(RColorBrewer)
library(lubridate)

## 06-02-20 ozone data ----------------

# Get Ferfoz data and clean it up a bit ---------------------
ferfoz <- R.utils::loadToEnv("C:/Users/skoike/Desktop/tidy data/FERF1.RData")[["ferfoz"]]

## actual <- NA if: 
### 1. actual < 0
### 2. stdev > 1 (and stdev is not NA)
### 3. actual - request > 0.2 (and request is not NA)

ferfoz <- ferfoz %>% mutate(actual = ifelse(actual < 0, NA, actual),
                            actual = ifelse(stdev > 1 & !is.na(stdev), NA, actual),
                            actual = ifelse(!is.na(request) & (actual - request) > 0.2, NA, actual),
                            actual = ifelse(n == 0, NA, actual))


# Read in Baseline Data -------------------------------------
F91BL35 <- read_csv("C:/Users/skoike/Desktop/tidy data/35DFEXRE/F91BL35.csv") # baseline ht/diam
F92H35P3 <- read_csv("C:/Users/skoike/Desktop/tidy data/35DFEXRE/F92H35P3.csv") # harvest dryweight, ht/diam 

data_list <- list("F91BL35" = F91BL35, "F92H35P3" = F92H35P3)
data_list
data_list %>% lapply(dim)

# Clean Up Data --------------------------------------------------

## F91BL35

summary(F91BL35)

noNeg <- function(x){ifelse(x <= -99, NA, x)} 

F91BL35_copy <- F91BL35 %>% 
  filter(DAY == -6) %>% 
  mutate_if(is.numeric, noNeg) %>% 
  mutate(DATE = mdy(DATE), # Convert Character Date to actual Date
         VOL = HT * DIAM^2) # Add Volume

#View(F91BL35_copy)

## F92H35P3- Hvst 1 dry weights

#summary(F92H35P3)

F92H35P3_copy <- F92H35P3 %>%  
  mutate_if(is.numeric, noNeg) %>%
  mutate(TOTALDW = TNDW + STDW + TRTDW,
         VOL = HT * DIAM^2) %>% 
  rename(NEEDLEDW = TNDW,
         STEMDW = STDW,
         ROOTDW = TRTDW) %>% 
  mutate(DATE = mdy(DATE))


# Joining Harvest and Dry Weight Data -------------------------------------------------

harvest3_data <- F92H35P3_copy %>% select(`OZ91/92`, CH91, CH92, PLT, NEEDLEDW, STEMDW, ROOTDW, TOTALDW, VOL)

#View(harvest3_data)

# Joining Harvest and Base Line Data -------------------------------------------------
H3 <- left_join(harvest3_data, F91BL35_copy %>% select(CH91, PLT, VOL), 
                by = c("CH91", "PLT"),
                suffix = c("_h", "_bl")) %>% 
  rename(OZ = `OZ91/92`,
         CH = CH92) %>% 
  mutate(OZ = as_factor(OZ),
         CH = as_factor(CH))

# OZ exposure
p <- ferfoz %>% 
  filter(ch %in% unique(H3$CH)) %>% 
  select(ch, actual, request, date, datetime) %>% 
  mutate(date = mdy(date),
         datetime = dmy_hms(datetime)) %>% 
  filter(between(date, mdy("06-02-1992"), mdy("9-21-1992"))) %>% 
  pivot_longer(cols = c(actual, request))

oz_exp <- p %>% 
  ggplot(aes(x = datetime, y = value, color = name)) +
  geom_line() + 
  scale_color_brewer(palette = "Set1") + 
  facet_wrap(. ~ ch) 
#oz_exp 

#View(H3)

# Add log transformation 
H3 <- H3 %>% 
  mutate(LOGNEEDLEDW = log(NEEDLEDW + 0.01),
         LOGSTEMDW = log(STEMDW + 0.01),
         LOGROOTDW = log(ROOTDW + 0.01),
         LOGTOTALDW = log(TOTALDW + 0.01),
         LOGVOL_bl = log(VOL_bl + 0.01),
         LOGVOL_h = log(VOL_h + 0.01))

# Curosy Exploratory Data Analysis -----------------------------------

H3 %>%  # Pre-Treatment Data 
  ggplot() + 
  aes(x = CH, y = LOGVOL_bl, fill = OZ) + # Pre-trt vol_ by Chamber
  geom_boxplot() + 
  ggtitle("Basline Pre-Treatment Volume by Chamber")

H3 %>% 
  group_by(CH, OZ, PLT) %>% 
  summarise(before = VOL_bl, after = VOL_h) %>% # Post-trt Vol by Pre-trt Vol 
  ggplot() + 
  aes(x = before, y = after, color = OZ) + 
  geom_point() +
  geom_smooth(method = "lm", se = FALSE, aes(group = 1)) + 
  scale_color_brewer(palette = "Set1")

H3 %>% 
  group_by(CH, PLT, OZ) %>% 
  summarize(Baseline = VOL_bl, Harvest = VOL_h) %>% 
  pivot_longer(cols = c("Baseline", "Harvest"), names_to = "time", values_to = "volume") %>% 
  ggplot() + 
  aes(x = OZ, y = log(volume), fill = time) + 
  geom_boxplot(alpha = 0.5) +
  ggtitle("Log Volume (Pre- and Post-Treatment) by Treatment")

H3 %>% 
  group_by(OZ) %>% 
  summarize(meanVolBefore = mean(LOGVOL_bl), 
            meanVolAfter = mean(LOGVOL_h, na.rm = TRUE)) # Summarize mean log-volume by treatment

# Join Exposure Metrics to Mean Chamber Data ----------------------------------------
test_df <- H3 %>% 
  group_by(CH, OZ) %>% 
  summarise_at(vars(starts_with("LOG"), ends_with("DW"), VOL_bl), mean, na.rm = TRUE) 


# Get OZ metrics ---------------------------------------------------
source("C:/Users/skoike/Desktop/tidy data/OZmetrics.R")

# Want 1992 data and exposure data in range of 06-02-1992 to 9-21-1992
otest1 <- ferfoz %>% 
  mutate(date = mdy(date)) %>% 
  filter(between(date, mdy("06-02-1992"), mdy("9-21-1992")))
exp_days_1 <- as.numeric(mdy("9-21-1992") - mdy("06-02-1992") + 1)

otest_92_df <- OZ.metrics(otest1) %>%  
  mutate_if(is.numeric, function(x){x * 92 / exp_days_1})

test_long <- full_join(H3 %>% select(OZ, CH, PLT, LOGNEEDLEDW, LOGSTEMDW, LOGROOTDW, LOGTOTALDW, LOGVOL_bl),
                       otest_92_df)

#write.csv(test_long, "35_h3_data.csv", row.names = FALSE)

test2_df <- left_join(test_df, otest_92_df) %>% 
  ungroup() %>% 
  mutate(CH = as_factor(CH),
         Year = 1992,
         Harvest = 2,
         Exp_days = exp_days_1) %>% 
  select(Year, Harvest, Exp_days, everything())

#View(test2_df)

#write.csv(test2_df, "35_h2_mean_data.csv", row.names = FALSE)
