# 06-04-20 manually read csv files

library(tidyverse)
library(broom)
library(ggfortify)
library(lubridate)

## 06-04-20 ozone data ----------------

# Get Ferfoz data and clean it up a bit ---------------------
ferfoz <- R.utils::loadToEnv("C:/Users/skoike/Desktop/tidy data/FERF1.RData")[["ferfoz"]]


## actual <- NA if: 
### 1. actual < 0
### 2. stdev > 1 (and stdev is not NA)
### 3. actual - request > 0.2 (and request is not NA)

ferfoz <- ferfoz %>% mutate(actual = ifelse(actual < 0, NA, actual),
                            actual = ifelse(stdev > 1 & !is.na(stdev), NA, actual),
                            actual = ifelse(!is.na(request) & (actual - request) > 0.2, NA, actual),
                            actual = ifelse(n == 0, NA, actual))


# Read in Baseline Data -------------------------------------
F91BL37 <- read_csv("C:/Users/skoike/Desktop/tidy data/37ASPEXR/F91BL37.csv")
F91DW37 <- read_csv("C:/Users/skoike/Desktop/tidy data/37ASPEXR/F91H37P1.csv")


data.list <- list("F91BL37" = F91BL37, "F91DW37" = F91DW37)
data.list
data.list %>% lapply(dim)

# Clean Up Data --------------------------------------------------

## F91BL36

#glimpse(F91BL37) # Pre- & post-trtmt baseline growth measures
#summary(F91BL37)

OZ.rlvl <- c("CONTROL", "EP70", "EP90", "EP150")
noNeg <- function(x){ifelse(x < 0, NA, x)} 
noNA <- function(x){ifelse(is.na(x), 0, x)} 

F91BL37.copy <- F91BL37 %>% 
  rename(OZ = OZ91,
         CH = CH91) %>% 
  mutate(DATE = mdy(DATE), # Convert Character Date to actual Date
         VOL = HT * DIAM^2, # Add Volume
         OZ = as_factor(OZ),
         CH = as_factor(CH),
         OZ = fct_relevel(OZ, OZ.rlvl)) %>% 
  filter(DAY == -1,
         OZ %in% OZ.rlvl) %>% 
  droplevels()

#View(F91BL36.copy)

## F91DW36- Post-trtmt hvst growth measures, cnts, leaf area & biomass dry wts

#glimpse(F91DW37) 
#summary(F91DW37)

F91DW37.copy <- F91DW37 %>%  
  rename(OZ = OZ91,
         CH = CH91,
         STEMDW = STDW,
         ROOTDW = RTDW,
         LEAFDW = LFDW) %>% 
  mutate_if(is.numeric, noNeg) %>% 
  mutate(DATE = mdy(DATE),
         OZ = as_factor(OZ),
         CH = as_factor(CH),
         OZ = fct_relevel(OZ, OZ.rlvl),
         VOL = HT * DIAM^2,
         TOTALDW = STEMDW + ROOTDW + LEAFDW)

F91DW37 %>% group_by(OZ91, CH91) %>% summarize(mlf = mean(LFDW, na.rm = TRUE), 
                                               mst = mean(STDW, na.rm = TRUE), 
                                               mrt = mean(RTDW, na.rm = TRUE),
                                               mtot = mean(LFDW + STDW + RTDW, na.rm = TRUE))
F91BL37
# Joining Harvest and Base Line Data -------------------------------------------------

H1 <- left_join(F91DW37.copy, F91BL37.copy, 
                by = c("OZ", "O391", "ID", "CH", "PLT"),
                suffix = c(".h", ".bl"))

#View(H1)

# Add log transformation 
H1 <- H1 %>% 
  mutate(LOGLEAFDW = log(LEAFDW + 0.01),
         LOGSTEMDW = log(STEMDW + 0.01),
         LOGROOTDW = log(ROOTDW + 0.01),
         LOGTOTALDW = log(TOTALDW + 0.01),
         LOGVOL.bl = log(VOL.bl + 0.01),
         LOGVOL.h = log(VOL.h + 0.01))

# Curosy Exploratory Data Analysis -----------------------------------

H1 %>%  # Pre-Treatment Data 
  ggplot() + 
  aes(x = CH, y = LOGVOL.bl, fill = OZ) + # Pre-trt vol. by Chamber
  geom_boxplot() + 
  ggtitle("Basline Pre-Treatment Volume by Chamber")

H1 %>% 
  group_by(CH, PLT) %>% 
  summarise(before = LOGVOL.bl, after = LOGVOL.h) %>% # Post-trt Vol by Pre-trt Vol 
  ggplot() + 
  aes(x = before, y = after) + 
  geom_point() +
  geom_smooth(method = "lm", se = FALSE)

H1 %>% 
  group_by(CH, PLT, OZ) %>% 
  summarize(Baseline = VOL.bl, Harvest = VOL.h) %>% 
  pivot_longer(cols = c("Baseline", "Harvest"), names_to = "time", values_to = "volume") %>% 
  ggplot() + 
  aes(x = OZ, y = log(volume), fill = time) + 
  geom_boxplot(alpha = 0.5) +
  ggtitle("Log Volume (Pre- and Post-Treatment) by Treatment")

H1 %>% 
  group_by(OZ) %>% 
  summarize(meanVolBefore = mean(LOGVOL.bl), 
            meanVolAfter = mean(LOGVOL.h, na.rm = TRUE)) # Summarize mean log-volume by treatment

# Join Exposure Metrics to Mean Chamber Data ----------------------------------------
test.df <- H1 %>% 
  group_by(CH, OZ) %>% 
  summarise_at(vars(starts_with("LOG"), ends_with("DW"), VOL.bl), mean, na.rm = TRUE) 

test.df %>% arrange(LOGTOTALDW)
# Get OZ metrics ---------------------------------------------------
source("C:/Users/skoike/Desktop/tidy data/OZmetrics.R")

# Want 1991 data and exposure data in range of 06-05-1991 to 09-11-1991
otest1 <- ferfoz %>% 
  distinct() %>% 
  mutate(date = mdy(date)) %>% 
  filter(between(date, mdy("06-05-1991"), mdy("9-11-1991")))
exp_days <- as.numeric(mdy("9-11-1991") - mdy("06-05-1991") + 1)

otest.91.df <- OZ.metrics(otest1) %>% 
  mutate_if(is.numeric, function(x){x * 92/exp_days})

test_long <- full_join(H1 %>% select(OZ, CH, PLT, LOGLEAFDW, LOGSTEMDW, LOGROOTDW, LOGTOTALDW, LOGVOL.bl),
                       otest.91.df) %>% 
  rename(LOGVOL_bl = LOGVOL.bl)

#write.csv(test_long, "37_h1_data.csv", row.names = FALSE)

test2.df <- left_join(test.df, otest.91.df) %>% 
  ungroup() %>% 
  mutate(CH = as_factor(CH),
         Year = 1991,
         Harvest = 1,
         Exp_days = exp_days) %>% 
  select(Year, Harvest, Exp_days, everything()) 

#test2.df

#write.csv(test2.df, "37_h1_mean_data.csv", row.names = FALSE)
