# 06-04-20 manually read csv files

library(tidyverse)
library(lubridate)
library(RColorBrewer)

## 06-04-20 ozone data ----------------

# Get Ferfoz data and clean it up a bit ---------------------
ferfoz <- R.utils::loadToEnv("C:/Users/skoike/Desktop/tidy data/FERF1.RData")[["ferfoz"]]

## actual <- NA if: 
### 1. actual < 0
### 2. stdev > 1 (and stdev is not NA)
### 3. actual - request > 0.2 (and request is not NA)

ferfoz <- ferfoz %>% mutate(actual = ifelse(actual < 0, NA, actual),
                            actual = ifelse(stdev > 1 & !is.na(stdev), NA, actual),
                            actual = ifelse(!is.na(request) & (actual - request) > 0.2, NA, actual),
                            actual = ifelse(n == 0, NA, actual))

# Read in Baseline Data -------------------------------------
F92BL44 <- read_csv("C:/Users/skoike/Desktop/tidy data/44RAEXRE/F92BL44.csv")
F92DW44 <- read_csv("C:/Users/skoike/Desktop/tidy data/44RAEXRE/F92H44P1.csv")


data.list <- list("F92BL44" = F92BL44, "F92DW44" = F92DW44)
data.list
data.list %>% lapply(dim)

# Clean Up Data --------------------------------------------------

## F91BL36

#glimpse(F92BL44) # Pre- & post-trtmt baseline growth measures
#summary(F92BL44)

OZ.rlvl <- c("CONTROL", "EP70", "EP90", "EP120", "EP150")
noNeg <- function(x){ifelse(x < 0, NA, x)} 

F92BL44.copy <- F92BL44 %>% 
  rename(OZ = OZ92,
         CH = CH92) %>% 
  mutate(DATE = mdy(DATE), # Convert Character Date to actual Date
         VOL = HT * DIAM^2, # Add Volume
         OZ = as_factor(OZ),
         CH = as_factor(CH)) %>%
  filter(DATE == mdy("06-01-1992")) 

#View(F92BL44.copy)

## F92DW44- Post-trtmt hvst growth measures, cnts, leaf area, subsamples & biomass dry wts

#glimpse(F92DW44) 
#summary(F92DW44)

F92DW44.copy <- F92DW44 %>%  
  rename(OZ = OZ92,
         CH = CH92,
         STEMDW = STDW,
         ROOTDW = RTDW,
         BRANCHDW = BRDW,
         LEAFDW = TLFDW) %>% 
  mutate_if(is.numeric, noNeg) %>% 
  mutate(DATE = mdy(DATE),
         OZ = as_factor(OZ),
         CH = as_factor(CH),
         OZ = fct_relevel(OZ, OZ.rlvl),
         VOL = HT * DIAM^2,
         TOTALDW = STEMDW + ROOTDW + BRANCHDW + LEAFDW) 

# Joining Harvest and Base Line Data -------------------------------------------------

H1 <- left_join(F92DW44.copy, F92BL44.copy, 
                by = c("OZ", "O392", "ID", "CH", "PLT"),
                suffix = c(".h", ".bl"))

#View(H1)

# Add log transformation 
H1 <- H1 %>% 
  mutate(LOGLEAFDW = log(LEAFDW + 0.01),
         LOGBRANCHDW = log(BRANCHDW + 0.01),
         LOGSTEMDW = log(STEMDW + 0.01),
         LOGROOTDW = log(ROOTDW + 0.01),
         LOGTOTALDW = log(TOTALDW + 0.01),
         LOGVOL.bl = log(VOL.bl + 0.01),
         LOGVOL.h = log(VOL.h + 0.01))

# Curosy Exploratory Data Analysis -----------------------------------

H1 %>%  # Pre-Treatment Data 
  ggplot() + 
  aes(x = CH, y = LOGVOL.bl, fill = OZ) + # Pre-trt vol. by Chamber
  geom_boxplot() + 
  ggtitle("Basline Pre-Treatment Volume by Chamber")

H1 %>% 
  group_by(CH, PLT) %>% 
  summarise(before = LOGVOL.bl, after = LOGVOL.h) %>% # Post-trt Vol by Pre-trt Vol 
  ggplot() + 
  aes(x = before, y = after) + 
  geom_point() +
  geom_smooth(method = "lm", se = FALSE)

H1 %>% 
  group_by(CH, PLT, OZ) %>% 
  summarize(Baseline = VOL.bl, Harvest = VOL.h) %>% 
  pivot_longer(cols = c("Baseline", "Harvest"), names_to = "time", values_to = "volume") %>% 
  ggplot() + 
  aes(x = OZ, y = log10(volume), fill = time) + 
  geom_boxplot(alpha = 0.5) +
  ggtitle("Log Volume (Pre- and Post-Treatment) by Treatment")

H1 %>% 
  group_by(OZ) %>% 
  summarize(meanVolBefore = mean(LOGVOL.bl), 
            meanVolAfter = mean(LOGVOL.h, na.rm = TRUE)) # Summarize mean log-volume by treatment

# Join Exposure Metrics to Mean Chamber Data ----------------------------------------
test.df <- H1 %>% 
  group_by(CH, OZ) %>% 
  summarise_at(vars(starts_with("LOG"), ends_with("DW"), VOL.bl), mean, na.rm = TRUE) %>% 
  select(-LOGVOL.h, -LFRSTDW, -SLFDW, -TPLTDW, -LAMSSDW, -PETSSDW) %>% 
  rename(LOGVOL_bl = LOGVOL.bl, VOL_bl = VOL.bl)

# Get OZ metrics ---------------------------------------------------
source("C:/Users/skoike/Desktop/tidy data/OZmetrics.R")

# Want 1992 data and exposure data in range of 06-02-1992 to 09-21-1992
otest1 <- ferfoz %>% 
  mutate(date = mdy(date)) %>% 
  filter(between(date, mdy("06-02-1992"), mdy("09-21-1992")))
exp_days <- as.numeric(mdy("09-21-1992") - mdy("06-02-1992") + 1)

g <- otest1 %>% 
  filter(ch %in% unique(H1$CH)) %>% 
  select(ch, actual, request, date, datetime) %>% 
  mutate(datetime = dmy_hms(datetime)) %>% 
  pivot_longer(cols = c(actual, request))

g %>% 
  ggplot(aes(x = datetime, y = value, color = name)) +
  geom_line() + 
  facet_wrap(.~ ch)

otest.92.df <- OZ.metrics(otest1) %>% 
  mutate_if(is.numeric, function(x){x * 92/exp_days})

test_long <- full_join(H1 %>% select(OZ, CH, PLT, LOGLEAFDW, LOGSTEMDW, LOGROOTDW, LOGTOTALDW, LOGVOL.bl),
                       otest.92.df) %>% 
  rename(LOGVOL_bl = LOGVOL.bl)

#write.csv(test_long, "44_h1_data.csv", row.names = FALSE)

test2.df <- left_join(test.df, otest.92.df) %>% 
  ungroup() %>% 
  mutate(CH = as_factor(CH),
         Year = 1992,
         Harvest = 1,
         Exp_days = exp_days) %>% 
  select(Year, Harvest, Exp_days, everything())

#test2.df

#write.csv(test2.df, "44_h1_mean_data.csv", row.names = FALSE)
