# 06-22-20 manually read csv files
library(tidyverse)
library(lubridate)
library(RColorBrewer)

## 06-22-20 ozone data ----------------

# Get Ferfoz data and clean it up a bit ---------------------
ferfoz <- R.utils::loadToEnv("C:/Users/skoike/Desktop/tidy data/FERF1.RData")[["ferfoz"]]

## actual <- NA if: 
### 1. actual < 0
### 2. stdev > 1 (and stdev is not NA)
### 3. actual - request > 0.2 (and request is not NA)

ferfoz <- ferfoz %>% mutate(actual = ifelse(actual < 0, NA, actual),
                            actual = ifelse(stdev > 1 & !is.na(stdev), NA, actual),
                            actual = ifelse(!is.na(request) & (actual - request) > 0.2, NA, actual),
                            actual = ifelse(n == 0, NA, actual))

# Load in Switch Metrics Functions

# Split Metrics 1: Calculated OZ metrics used in Treatment 1, when plants switch chambers once with no
# change in the ozone profile
source("C:/Users/skoike/Desktop/tidy data/OZsplitmetrics.R") 

# Read in Baseline Data -------------------------------------
F92BL45 <- read_csv("C:/Users/skoike/Desktop/tidy data/45PPEXDY/F92BL45.csv")
F92H45S3 <- read_csv("C:/Users/skoike/Desktop/tidy data/45PPEXDY/F92H45S3.csv")

# Look at Chambers used in study and their exposure profiles
g <- ferfoz %>% 
  filter(ch %in% c(3, 4, 6, 7, 8, 9, 11, 14, 19, 20, 21)) %>% 
  select(ch, actual, request, date, datetime) %>% 
  mutate(date = mdy(date),
         datetime = dmy_hms(datetime)) %>% 
  filter(between(date, mdy("5/13/92"), mdy("9/1/92"))) %>% 
  pivot_longer(cols = c(actual, request))

g %>% 
  ggplot(aes(x = datetime, y = value, color = name)) +
  geom_line() + 
  facet_wrap(.~ ch) + 
  annotate(xmin = mdy_hms("6/10/92 00:00:00"), xmax = mdy_hms("8/4/92 00:00:00"), 
           geom = "rect", fill = "red", alpha = 0.1,
           ymin = 0, ymax = Inf)


noNeg <- function(x){ifelse(x < 0, NA, x)} 

F92BL45.copy <- F92BL45 %>% 
  rename(OZ = OZ92) %>% 
  filter(DAY == -1) %>% 
  mutate(DATE = mdy(DATE), # Convert Character Date to actual Date
         VOL = HT * DIAM^2) # Add Volume


seq3.data <- F92H45S3 %>% 
  mutate_if(is.numeric, noNeg) %>%
  rename(STEMDW = TSTDW,
         ROOTDW = TRTDW,
         NEEDLEDW = TNDW,
         OZ = OZ92) %>% 
  mutate(DATE = mdy(DATE), # Convert Character Date to actual Date
         VOL = HT * DIAM^2, # Add Volume
         TOTALDW = STEMDW + ROOTDW + NEEDLEDW,
         VOL = HT * DIAM^2) 


F92BL45.nest <- F92BL45.copy %>%
  nest_by(EXP92, EXPER92, OZ)
F92BL45.nest %>% arrange(EXP92) # Seeing what ozone treatments go with what treatment codes 


# Treatment 6 -----------------------------------------------------------------

# EXPOSED DAY 1-112, HVST'D, 5/13/92 - 9/1/92

F92BL45.6 <- F92BL45.nest %>% 
  filter(EXP92 == 6) %>% 
  unnest(data)

#actual_exposure("5/13/92", "9/1/92", 6, 3, "6/09/92") # Chamber 6 exposure
#actual_exposure("5/13/92", "9/1/92", 14, 8, "06/09/92") # Chamber 14 exposure
#actual_exposure("5/13/92", "9/1/92", 20, 19, "06/09/92") # Chamber 20 exposure

# Join the sequence data with it's baseline 

seq3.p123 <- seq3.data %>% 
  filter(EXP92 == 6) %>% 
  full_join(F92BL45.6, 
            by = c("OZ", "O392", "CH92A", "CH92B", "PLTA", "PLTB", "SEQ", "EXPER92", "EXP92"),
            suffix = c("_h", "_bl"))

H.seq3.p123 <- seq3.p123 %>% # Add log data
  mutate(LOGNEEDLEDW = log(NEEDLEDW + 0.01),
         LOGSTEMDW = log(STEMDW + 0.01),
         LOGROOTDW = log(ROOTDW + 0.01),
         LOGTOTALDW = log(TOTALDW + 0.01),
         LOGVOL_bl = log(VOL_bl + 0.01),
         LOGVOL_h = log(VOL_h + 0.01))

H1 <- H.seq3.p123 %>% select(OZ, CH92A, CH92B, PLTA, PLTB, LOGVOL_bl,
                             LOGNEEDLEDW, LOGSTEMDW, LOGROOTDW, LOGTOTALDW) %>% 
  mutate(joinedCH = factor(paste0(CH92A, ":", CH92B)))

test.seq3.p123 <- H.seq3.p123 %>% # calculate means
  mutate(CH92A = as_factor(CH92A),
         CH92B = as_factor(CH92B),
         joinedCH = CH92A:CH92B) %>% 
  group_by(CH92A, CH92B, joinedCH, OZ, EXPER92, EXP92) %>% 
  summarise_at(vars(starts_with("LOG"), ends_with("DW"), VOL_bl), mean, na.rm = TRUE)

# Get FERF Data

otest.seq3.p123 <- ferfoz %>% 
  mutate(date = mdy(date)) %>% 
  filter(between(date, mdy("5/13/92"), mdy("9/1/92")))
exp_days <- as.numeric(mdy("9/1/92") - mdy("5/13/92") + 1)

# Applying the split-chamber metrics to the data

# get OZ metrics for switching chambers without switching treatments

otest.92.seq3.p123 <- test.seq3.p123 %>%
  split(1:nrow(.)) %>% 
  map_dfr(~ OZ.switch.metrics(otest.seq3.p123, CH1 = .x$CH92A, CH2 = .x$CH92B, split_date = mdy("06/09/1992"))) %>% 
  mutate_if(is.numeric, function(x){x * 92/exp_days})

test_long <- full_join(H1, otest.92.seq3.p123)

#write.csv(test_long, "45_h1_data.csv", row.names = FALSE)
test2.seq3.p123 <- full_join(test.seq3.p123, otest.92.seq3.p123) %>% 
  ungroup() %>% 
  rename(CHAMB = joinedCH) %>% 
  mutate(Year = 1992,
         Harvest = 1,
         Exp_days = exp_days) %>% 
  select(Year, Harvest, Exp_days, everything(),
         -CH92A, -CH92B, -EXPER92, -EXP92, -N1DW, -N2SSDW, -N2SSCHDW, -N2RSTDW, -TN2DW, 
         -STSSCHDW, -STRSTDW, -hdm4_7, -hdm4_11, -hdm4_19, -hdm4_6, -hdm4_3, -hdm4_21, -hdm4_8, -hdm4_14, -hdm4_20,
         -TAPRTDW, -LATRTDW)
names(test2.seq3.p123)

#write.csv(test2.seq3.p123, "45_h1_mean_data.csv", row.names = FALSE)
