# 06-10-20 manually read csv files

library(tidyverse)
library(broom)
library(ggfortify)
library(lubridate)

## 06-10-20 ozone data ----------------

# Get Ferfoz data and clean it up a bit ---------------------
ferfoz <- R.utils::loadToEnv("C:/Users/skoike/Desktop/tidy data/FERF1.RData")[["ferfoz"]]

## actual <- NA if: 
### 1. actual < 0
### 2. stdev > 1 (and stdev is not NA)
### 3. actual - request > 0.2 (and request is not NA)

ferfoz <- ferfoz %>% mutate(actual = ifelse(actual < 0, NA, actual),
                            actual = ifelse(stdev > 1 & !is.na(stdev), NA, actual),
                            actual = ifelse(!is.na(request) & (actual - request) > 0.2, NA, actual),
                            actual = ifelse(n == 0, NA, actual))

# Read in Baseline Data -------------------------------------
F94BL57 <- read_csv("C:/Users/skoike/Desktop/tidy data/57PPEXDY/F94BL57.csv")
F95H57P1 <- read_csv("C:/Users/skoike/Desktop/tidy data/57PPEXDY/F95H57P1.csv")

data.list <- list("F94BL57" = F94BL57, "F95H57P1" = F95H57P1)
data.list
data.list %>% lapply(dim)

# Clean Up Data --------------------------------------------------

## F94BL57

#glimpse(F94BL57) # Pre & post-trtmt baseline growth measures
#summary(F94BL57)

F94BL57.copy <- F94BL57 %>% 
  mutate(DATE = mdy(DATE), # Convert Character Date to actual Date
         VOL = HT * DIAM^2, # Add Volume
         OZ = as_factor(OZ),
         CH = as_factor(CH)) %>% 
  rename(CH94 = CH)

#View(F94BL57.copy)

## F95H57P1- Post-trtmt hvst growth measures, cnts, cho subsamples & biomass dry wts

#glimpse(F95H57P1) 
#summary(F95H57P1) 
noNeg <- function(x){ifelse(x < 0, NA, x)} 

harvest1.data <- F95H57P1 %>% 
  mutate_if(is.numeric, noNeg) %>% 
  rename(NEEDLEDW = TNDW,
         STEMDW = STDW, 
         ROOTDW = TRTDW) %>% 
  select(-TPLTDW) %>% 
  mutate(DATE = mdy(DATE),
         OZ = as_factor(OZ),
         CH94 = as_factor(CH94),
         CH95 = as_factor(CH95),
         TOTALDW = NEEDLEDW + STEMDW + ROOTDW,
         VOL = HT*DIAM^2) 

# Joining Harvest and Base Line Data -------------------------------------------------
H1 <- left_join(harvest1.data, F94BL57.copy, 
                by = c("OZ", "CH94", "SEQ", "ID", "PLT"),
                suffix = c("_h", "_bl")) %>% 
  filter(!is.na(CH95))

# Test to see if later exposed plants have different response to OZ ---------------------------------------
# Add log transformation 
H1 <- H1 %>% 
  mutate(LOGNEEDLEDW = log(NEEDLEDW + 0.01),
         LOGSTEMDW = log(STEMDW + 0.01),
         LOGROOTDW = log(ROOTDW + 0.01),
         LOGTOTALDW = log(TOTALDW + 0.01),
         LOGVOL_bl = log(VOL_bl + 0.01),
         LOGVOL_h = log(VOL_h + 0.01)) %>% 
  select(OZ, CH95, PLT, starts_with("LOG"), NEEDLEDW, STEMDW, ROOTDW, TOTALDW, VOL_bl)

# Curosy Exploratory Data Analysis -----------------------------------

H1 %>%  # Pre-Treatment Data 
  ggplot() + 
  aes(x = CH95, y = LOGVOL_bl, fill = OZ) + # Pre-trt vol. by Chamber
  geom_boxplot() + 
  ggtitle("Basline Pre-Treatment Volume by Chamber")

H1 %>% 
  ggplot() + 
  aes(x = LOGVOL_bl, y = LOGVOL_h, color = OZ) + 
  geom_point() + 
  geom_smooth(method = "lm", se = FALSE) + 
  geom_smooth(method = "lm", se = FALSE, aes(group = 1), color = "black")

H1 %>% 
  pivot_longer(cols = c("LOGVOL_bl", "LOGVOL_h"), 
                        names_to = "LOGVOL") %>% 
  ggplot() + 
  aes(x = OZ, y = value, fill = LOGVOL) + 
  geom_boxplot(alpha = 0.5)

H1 %>% 
  group_by(OZ, CH95) %>% 
  summarize(meanVolBefore = mean(LOGVOL_bl, na.rm = TRUE), 
            meanVolAfter = mean(LOGVOL_h, na.rm = TRUE)) # Summarize mean log-volume by treatment

# Join Exposure Metrics to Mean Chamber Data ----------------------------------------
test.df <- H1 %>% 
  group_by(CH95, OZ) %>% 
  summarise_at(vars(starts_with("LOG"), ends_with("DW"), VOL_bl), mean, na.rm = TRUE) 

# Get OZ metrics ---------------------------------------------------
source("C:/Users/skoike/Desktop/tidy data/OZmetrics.R")

# Want 1994 data and exposure data in range of 06-16-1995 to 10-05-1995
otest1 <- ferfoz %>% 
  distinct() %>% 
  mutate(date = mdy(date)) %>% 
  filter(between(date, mdy("06-16-1995"), mdy("10-05-1995"))) 
exp_days <- as.numeric(mdy("10-05-1995") - mdy("06-16-1995") + 1) 

otest.95.df <- OZ.metrics(otest1) %>% 
  rename(CH95 = CH) %>% 
  mutate_if(is.numeric, function(x){x * 92/exp_days})

test_long <- full_join(H1, otest.95.df) %>% 
  rename(CH = CH95)

#write.csv(test_long, "57_h3_data.csv", row.names = FALSE)

test2.df <- left_join(test.df, otest.95.df) %>% 
  ungroup() %>% 
  mutate(Year = 1995,
         Harvest = 2,
         Exp_days = exp_days) %>% 
  rename(CH = CH95)

#write.csv(test2.df, "57_h2_mean_data.csv", row.names = FALSE)
