clean_chamber <- function(chamber, year){
  require(tidyverse)
  require(lubridate)
  
  setNA <- function(x){ifelse(x == -999 | x == -999.90, NA, x)} # Will set values to missing
  
  cham_char <- substitute(chamber) %>% 
    deparse() %>% # get the chamber name as a character 
    str_replace_all(pattern = "[:alpha:]", "") %>%  # Just get the chamber number
    as.numeric()

  year_start <- paste(c("1/1/", year), collapse = "") # get actual date (not julian date)
  
  chamber <- chamber %>% 
    select_at(vars(starts_with("JUL") | starts_with("O3"))) %>% 
    rename_at(vars(starts_with("O3")), .funs = list(~ str_replace(., ",N,6,1", ""))) %>% 
    rename_at(vars(starts_with("O3")), .funs = list(~ str_replace(., "O3", ""))) %>% 
    rename("Julian" = "JULDAT,N,3,0") %>% # Renames column names to something more reasonable
    mutate_all(setNA) %>% # Sets some values to missing
    pivot_longer(cols = -Julian,
                 names_to = "Hour",
                 values_to = "OZ") %>% # puts in same format as FERF ozone data
    mutate(Hour = as.numeric(str_replace(Hour, "HR", "")), # Changes Hour column to be numeric
           Hour = hms::hms(hours = Hour), # Sets hour as a hour class variable
           Date = mdy(year_start) + Julian - 1, # gets actual date
           Datetime = ymd_hms(paste(Date, Hour)),
           Chamber = cham_char)
  
  return(chamber)
}

