# Get Ozone Exposure Metrics -------------------------------------

# (Ozone) Exposure Metrics:

OZ_metrics_neufeld <- function(data){
  
  otest1 <- data
  
  ## WXX- Sinusoidal
  wxx <- function(OZ, xx = 126){
    wxx <- OZ/(1 + 4403*exp(-xx*OZ)) # default xx = 126
    return(wxx)
  }
  
  ## AOTXX- Flat subtract
  aotxx <- function(OZ, xx){
    aotxx <- OZ - xx #the metric
    aotxx <- ifelse(aotxx < 0, 0, aotxx) #set aotxx to 0 if (aotxx < 0) 
    return(aotxx)
  }
  
  ## SumXX- Indicator
  sumxx <- function(OZ, xx){
    sumxx <- ifelse(OZ < xx, 0, OZ) #set sumxx to 0 if (OZ < xx)
    return(sumxx)
  }
  
  ## NXX
  nxx <- function(OZ, xx){
    nxx <- ifelse(OZ < xx, 0, 1) #set nxx to 0 if (OZ < xx) and to 1 otherwise
    return(nxx)
  }
  
  # Add various metrics to data frame
  otest1 <- otest1 %>% 
    mutate(OZ = OZ/1000,
           w126 = wxx(OZ),
           aot40 = aotxx(OZ, 0.04),
           aot50 = aotxx(OZ, 0.05),
           aot60 = aotxx(OZ, 0.06),
           aot70 = aotxx(OZ, 0.07),
           aot80 = aotxx(OZ, 0.08),
           aot90 = aotxx(OZ, 0.09),
           aot100 = aotxx(OZ, 0.10),
           sum06 = sumxx(OZ, 0.06),
           sum07 = sumxx(OZ, 0.07),
           sum08 = sumxx(OZ, 0.08),
           sum09 = sumxx(OZ, 0.09),
           sum10 = sumxx(OZ, 0.10),
           n08 = nxx(OZ, 0.08),
           n09 = nxx(OZ, 0.09),
           n10 = nxx(OZ, 0.10),
           n11 = nxx(OZ, 0.11),
           n12 = nxx(OZ, 0.12),
           n13 = nxx(OZ, 0.13),
           n14 = nxx(OZ, 0.14),
           n15 = nxx(OZ, 0.15)) %>% 
    rename(CH = Chamber)
  
  # Summarize Data by Exposure Windows ---------------------------------------------
  
  ### Looking at 24 hr exposure window
  # glimpse(otest1) to get the columns to specify
  
  otests <- otest1 %>% 
    group_by(CH) %>% 
    summarize_at(vars(OZ, w126:n15), sum, na.rm = TRUE) %>% 
    ungroup() # sum of 'OZ' and all metrics, grouped by chamber
  #View(otests)
  
  # Number of Observations (and non-NA observations) by chamber 
  otest.length <- otest1 %>% 
    group_by(CH) %>% 
    summarize(ot6 = length(OZ), # number of data points for OZ
              ot7 = sum(!is.na(OZ)), # number of non-NA data points for OZ
              prop = ot6/ot7) %>% 
    ungroup()
  
  ## Looking at exposures over a window of time
  
  ### Looking at times *between* 8 am and 8 pm (B-Test)
  
  btest <- otest1 %>% 
    filter(Hour > hms::hms(hours = 7) & Hour < hms::hms(hours = 20)) # Get the Hours
  
  btest.summary <- btest %>% 
    group_by(CH) %>% 
    summarize_at(vars(OZ, w126:n15), sum, na.rm = TRUE) %>% 
    ungroup() # sum of 'OZ' and all metrics, grouped by chamber
  
  #### B-Test Sample Size: Number of 'OZ' readings (and non-NA 'OZ' readings) by chamber during B-Test
  
  btest.summary.length <- btest %>% 
    group_by(CH) %>% 
    summarize(ot6b = length(OZ), # number of data points for OZ
              ot7b = sum(!is.na(OZ)), # number of non-NA data points for OZ
              prop = ot6b/ot7b) %>% 
    ungroup()
  
  
  ### Looking at times *between* 9 am and 8 pm (C-Test)
  
  ctest <- otest1 %>% 
    filter(Hour > hms::hms(hours = 8) & Hour < hms::hms(hours = 21)) # get the Hours
  
  ctest.summary <- ctest %>% 
    group_by(CH) %>% 
    summarize_at(vars(OZ, w126:n15), sum, na.rm = TRUE) %>% 
    ungroup() # sum of 'OZ' and all metrics, grouped by chamber
  
  #### C-Test Sample Size: Number of 'OZ' readings (and non-NA 'OZ' readings) by chamber during C-Test
  
  ctest.summary.length <- ctest %>% 
    group_by(CH) %>% 
    summarize(ot6c = length(OZ), # number of data points for OZ
              ot7c = sum(!is.na(OZ)), # number of non-NA data points for OZ
              prop = ot6c/ot7c) %>% 
    ungroup() 
  
  
  ### Looking at times *between* 7 am and 6 pm (D-Test)
  
  dtest <- otest1 %>% 
    filter(Hour > hms::hms(hours = 6) & Hour < hms::hms(hours = 19))
  
  dtest.summary <- dtest %>% 
    group_by(CH) %>% 
    summarize_at(vars(OZ, w126:n15), sum, na.rm = TRUE) %>% 
    ungroup()
  
  
  #### D-Test Sample Size: Number of 'OZ' readings (and non-NA 'OZ' readings) by chamber during D-Test
  
  dtest.summary.length <- dtest %>% 
    group_by(CH) %>% 
    summarize(ot6d = length(OZ), # number of data points for OZ
              ot7d = sum(!is.na(OZ)), # number of non-NA data points for OZ
              prop = ot6d/ot7d) %>% 
    ungroup() 
  
  # 5-5-20 
  
  ## 4th Highest Daily Max: Extract the 4th highest exposure level, by chamber, over all exposure days
  
  otesthdm4 <- otest1 %>% 
    group_by(CH, Julian) %>% # group by chamber and day
    summarize(dailyhigh = max(OZ, na.rm = TRUE)) %>% # find the daily maximum O3 in a chamber for all days
    mutate(dailyhigh = ifelse(is.infinite(dailyhigh), NA, dailyhigh)) %>% 
    arrange(CH, desc(dailyhigh)) %>%  # arrange the exposure levels from high to low (again at chamber level)
    slice(4) %>% # take the 4th highest daily maximum for that chamber
    select(-Julian) %>%  # discard exposure day
    ungroup()
  
  # Join Summary Data Together -------------------------------------------------
  
  # Join Data and add suffices
  otest.89.df <- full_join(otests, btest.summary, by = "CH", suffix = c(".24", ".12.8")) %>% # Combine 24 hr metrics with 12 hr (8am - 8pm)
    full_join(ctest.summary, by = "CH") %>% # Combine with 12 hr window (9 am to 8 pm)
    full_join(dtest.summary, by = "CH", suffix = c(".12.9", ".12.7")) %>% # Combine with 12 hr window (7 am to 6 pm)
    mutate(hdm4 = otesthdm4$dailyhigh) # add 4th highest daily max
  
  # Since there are some missing data, we weight exposure metrics by proportion of non-NA data for each time period of interest
  
  ## Recall prop_non_NA = proportion of non-NA data
  
  ### Adjustment for 24-hr period
  adjusted.24 <- otest.89.df %>% 
    select(CH, ends_with(".24")) %>% 
    mutate_at(vars(-CH), function(x){x*otest.length$prop})
  
  ### Adjustment for 12-hr period B-Test
  adjusted.12.8 <- otest.89.df %>% 
    select(CH, ends_with(".12.8")) %>% 
    mutate_at(vars(-CH), function(x){x*btest.summary.length$prop})
  
  ### Adjustment for 12-hr period C-Test
  adjusted.12.9 <- otest.89.df %>% 
    select(CH, ends_with(".12.9")) %>% 
    mutate_at(vars(-CH), function(x){x*ctest.summary.length$prop})
  
  ### Adjustment for 12-hr period D-Test
  adjusted.12.7 <- otest.89.df %>% 
    select(CH, ends_with(".12.7")) %>% 
    mutate_at(vars(-CH), function(x){x*dtest.summary.length$prop})
  
  ## Join with Metrics Data 
  otest.89.df <- otest.89.df %>% 
    full_join(adjusted.24, by = "CH", suffix = c("", ".adj")) %>% 
    full_join(adjusted.12.7, by = "CH", suffix = c("", ".adj")) %>% 
    full_join(adjusted.12.8, by = "CH", suffix = c("", ".adj")) %>% 
    full_join(adjusted.12.9, by = "CH", suffix = c("", ".adj")) %>% 
    rename(CHAMB = CH) 
  
  return(otest.89.df)
}