# Read in Data ---------------------------

library(tidyverse)
library(RColorBrewer)
library(lubridate)

bcherry <- read_csv("C:/Users/skoike/Desktop/tidy data/Neufeld/Seiji's Work/Black Cherry/blackcherry89_raw.csv") %>% 
  rename(CHAMB = Chamb,
         STEMDW = SHOOTDW) %>% 
  mutate(VOL_bl = Ini_ht*ini_diam^2,
         LOGVOL_bl = log(VOL_bl + 0.01),
         LOGROOTDW = log(ROOTDW + 0.01),
         LOGSTEMDW = log(STEMDW + 0.01),
         LOGLEAFDW = log(LEAFDW + 0.01),
         TOTALDW = ROOTDW + STEMDW + LEAFDW,
         LOGTOTALDW = log(TOTALDW + 0.01),
         CHAMB = as_factor(CHAMB)) 

bcherry %>% group_by(Trt, CHAMB) %>% tally()

# Join Data -----------------------------------------------------

oz_data <- read_csv("C:/Users/skoike/Desktop/tidy data/Neufeld/Seiji's Work/1989_oz.csv") %>% 
  mutate(Chamber = as_factor(Chamber)) %>% 
  filter(between(Date, mdy("6/14/1989"), mdy("8/28/1989")))

harvest_long <- full_join(bcherry, oz_data %>% rename(CHAMB = Chamber)) %>% 
  mutate(Trt = as_factor(Trt)) 

# EDA ------------------------------------------------------------

oz_by_date <- harvest_long %>% 
  filter(CHAMB %in% unique(bcherry$CHAMB)) %>% 
  ggplot() + 
  aes(x = Datetime, y = OZ/1000, color = Trt) + 
  geom_line() + 
  scale_color_brewer(palette = "Set1") +
  facet_wrap(. ~ factor(CHAMB), nrow = 3)

#oz_by_date
source("C:/Users/skoike/Desktop/tidy data/Neufeld/Seiji's Work/OZ_metrics_Neufeld.R")

exp_days <- as.numeric(max(oz_data$Date) - min(oz_data$Date) + 1)

oz_89 <- OZ_metrics_neufeld(oz_data %>% mutate(Chamber = as_factor(Chamber))) %>% 
  mutate(CHAMB = as_factor(CHAMB)) %>% 
  mutate_if(is.numeric, function(x){x * 92/exp_days})

bcherry_means <- bcherry %>% 
  group_by(Trt, CHAMB) %>% 
  summarise_at(vars(ends_with("DW"), contains("VOL")), mean)

harvest <- left_join(bcherry_means, oz_89) %>% 
  mutate(CHAMB = as_factor(CHAMB))  %>% 
  mutate(Year = 1989,
         Harvest = 1,
         Exp_days = exp_days) %>% 
  select(Year, Harvest, Exp_days, everything())

#write.csv(harvest, "bc_89_mean_data.csv", row.names = FALSE)
