# Read in Data ---------------------------

library(tidyverse)
library(RColorBrewer)
library(lubridate)

bcherry <- read_csv("C:/Users/skoike/Desktop/tidy data/Neufeld/Seiji's Work/Black Cherry/bcherry92.csv") %>% 
  rename(CHAMB = cham,
         Trt = trt,
         LOGTOTALDW = ltotal,
         LOGLEAFDW = lleafwt,
         LOGROOTDW = lrootwt,
         LOGSTEMDW = lstemwt,
         LOGBRANCHDW = lbrnchwt,
         LOGSHOOTDW = lshootwt)
vol_dat <- read_table("C:/Users/skoike/Desktop/tidy data/Neufeld/Seiji's Work/Black Cherry/bh92vol.txt") %>% 
  select(-c(X10, TRT_1, X12, CH_1, PLT_1)) %>% 
  mutate_if(is.character, as.numeric) %>% 
  rename(Trt = TRT, CHAMB = CH)

# Join Data -----------------------------------------------------
vol_long <- vol_dat %>% 
  pivot_longer(cols = -c(Trt, CHAMB, PLT),
               names_to = c(".value", "time"),
               names_pattern = "(\\w+).*?(\\d)") %>% 
  mutate(VOL_bl = HT * DIAM^2,
         LOGVOL_bl = log(VOL_bl + 0.01),
         Trt = as_factor(Trt),
         CHAMB = as_factor(CHAMB))

vol_long %>% 
  ggplot() + 
  aes(x = time, y = LOGVOL_bl, group = PLT, color = Trt) + 
  geom_line() + 
  scale_color_brewer(palette = "Set1") + 
  facet_wrap(. ~ CHAMB)

vol_dat <- vol_dat %>% 
  select(Trt, CHAMB, PLT, HT1, DIAM1) %>% 
  mutate(LOGVOL_bl = log(HT1 * DIAM1^2 + 0.01))

vol_dat_summ <- vol_dat %>% 
  group_by(Trt, CHAMB) %>% 
  summarize(LOGVOL_bl = mean(LOGVOL_bl, na.rm = TRUE))

bcherry <- full_join(bcherry, vol_dat_summ) %>% 
  mutate(CHAMB = as_factor(CHAMB))

oz_data <- read_csv("C:/Users/skoike/Desktop/tidy data/Neufeld/Seiji's Work/1992_oz.csv") %>% 
  filter(between(Date, mdy("05/20/1992"), mdy("10/06/1992"))) %>% 
  mutate(Chamber = as_factor(Chamber))

source("C:/Users/skoike/Desktop/tidy data/Neufeld/Seiji's Work/OZ_metrics_Neufeld.R")

exp_days <- as.numeric(max(oz_data$Date) - min(oz_data$Date) + 1)

oz_92 <- OZ_metrics_neufeld(oz_data) %>% 
  mutate_if(is.numeric, function(x){x * 92/exp_days})

harvest <- left_join(bcherry, oz_92) %>% 
  mutate(CHAMB = as_factor(CHAMB),
         Trt = factor(Trt, levels = as.character(c(1:5)))) %>% 
  mutate(Year = 1992,
         Harvest = 1,
         Exp_days = exp_days) %>% 
  select(Year, Harvest, Exp_days, everything())

#write.csv(harvest, "bc_92_mean_data.csv", row.names = FALSE)
