# Read in Data ---------------------------

library(tidyverse)
library(RColorBrewer)
library(lubridate)

chestnut <- read_table2("C:/Users/skoike/Desktop/tidy data/Neufeld/Seiji's Work/Chestnut Oak/chestnutoak.txt") %>%
  mutate_if(is.numeric, function(x){ifelse(x < 0, NA, x)}) %>% 
  rename(LEAFDW = LeafWt,
         SHOOTDW = WoodWt,
         ROOTDW = RootWt,
         Trt = TRT,
         CHAMB = CHAMBER) %>% 
  mutate(VOL = HGT * DIAM^2,
         LOGVOL_bl = log(VOL + 0.01),
         TOTALDW = LEAFDW + SHOOTDW + ROOTDW,
         LOGLEAFDW = log(LEAFDW + 0.01),
         LOGSHOOTDW = log(SHOOTDW + 0.01),
         LOGROOTDW = log(ROOTDW + 0.01),
         LOGTOTALDW = log(TOTALDW + 0.01),
         Trt = as_factor(Trt),
         CHAMB = as_factor(CHAMB))



oz_data <- read_csv("C:/Users/skoike/Desktop/tidy data/Neufeld/Seiji's Work/1991_oz.csv") %>% 
  mutate(Chamber = as_factor(Chamber)) %>% 
  filter(between(Date, mdy("05/23/1991"), mdy("10/08/1991")),
         Chamber %in% unique(chestnut$CHAMB)) %>% 
  droplevels()

harvest_long <- right_join(chestnut, oz_data %>% rename(CHAMB = Chamber))

# EDA ------------------------------------------------------------

oz_by_date <- harvest_long %>% 
  ggplot() + 
  aes(x = Datetime, y = OZ/1000, color = Trt) + 
  geom_line() + 
  scale_color_brewer(palette = "Set1") +
  facet_wrap(. ~ factor(CHAMB), nrow = 3)

#oz_by_date

# Box plots ----------------------------------------------------
chestnut %>% 
  ggplot() + 
  aes(x = factor(Trt), y = LOGLEAFDW, fill = Trt) + 
  scale_fill_brewer(palette = "Set1") + 
  guides(fill = FALSE) +
  geom_boxplot()
chestnut %>% 
  ggplot() + 
  aes(x = factor(Trt), y = LOGROOTDW, fill = Trt) + # One root bad
  scale_fill_brewer(palette = "Set1") + 
  guides(fill = FALSE) +
  geom_boxplot()
chestnut %>% 
  ggplot() + 
  aes(x = factor(Trt), y = LOGSHOOTDW, fill = Trt) + 
  scale_fill_brewer(palette = "Set1") + 
  guides(fill = FALSE) +
  geom_boxplot()
chestnut %>% 
  ggplot() + 
  aes(x = factor(Trt), y = LOGTOTALDW, fill = Trt) + 
  scale_fill_brewer(palette = "Set1") + 
  guides(fill = FALSE) +
  geom_boxplot()
chestnut %>% 
  ggplot() + 
  aes(x = factor(Trt), y = LOGVOL_bl, fill = Trt) + 
  scale_fill_brewer(palette = "Set1") + 
  guides(fill = FALSE) +
  geom_boxplot() 

# Scatter Plots -----------------------------------------


chestnut %>% 
  ggplot() +
  aes(x = LOGVOL_bl, y = LOGTOTALDW, fill = Trt, color = Trt) + 
  geom_point(shape = 21, size = 2, color = "black") +
  scale_fill_brewer(palette = "Set1") + 
  scale_color_brewer(palette = "Set1") +
  geom_smooth(method = "lm", se = FALSE) + 
  geom_smooth(method = "lm", aes(group = 1), color = "black", se = FALSE, linetype = "dashed")


test_df <- chestnut %>% 
  group_by(Trt, CHAMB) %>% 
  summarise_at(vars(starts_with("LOG"), ends_with("DW"), VOL), mean, na.rm = TRUE)

test_df %>% 
  ggplot() + 
  aes(x = LOGVOL_bl, y = LOGLEAFDW, color = Trt) + 
  geom_text(aes(label = CHAMB)) + 
  scale_color_brewer(palette = "Set1")
test_df %>% 
  ggplot() + 
  aes(x = LOGVOL_bl, y = LOGSHOOTDW, color = Trt) + 
  geom_text(aes(label = CHAMB)) + 
  scale_color_brewer(palette = "Set1")
test_df %>% 
  ggplot() + 
  aes(x = LOGVOL_bl, y = LOGROOTDW, color = Trt) + 
  geom_text(aes(label = CHAMB)) + 
  scale_color_brewer(palette = "Set1")
test_df %>% 
  ggplot() + 
  aes(x = LOGVOL_bl, y = LOGTOTALDW, color = Trt) + 
  geom_text(aes(label = CHAMB)) + 
  scale_color_brewer(palette = "Set1")

chestnut %>% 
  group_by(Trt) %>% 
  summarize(avg = mean(LOGTOTALDW, na.rm = TRUE),
            s = sd(LOGTOTALDW, na.rm = TRUE))

chestnut %>% 
  ggplot(aes(x = CHAMB, y = LOGVOL_bl, color = Trt, label = PLANTNO)) + 
  geom_text() + 
  scale_color_brewer(palette = "Set1")
chestnut %>% 
  ggplot(aes(x = CHAMB, y = LOGLEAFDW, color = Trt, label = PLANTNO)) + 
  geom_text() + 
  scale_color_brewer(palette = "Set1")
chestnut %>% 
  ggplot(aes(x = CHAMB, y = LOGSHOOTDW, color = Trt, label = PLANTNO)) + 
  geom_text() + 
  scale_color_brewer(palette = "Set1")
chestnut %>% 
  ggplot(aes(x = CHAMB, y = LOGROOTDW, color = Trt, label = PLANTNO)) + 
  geom_text() + 
  scale_color_brewer(palette = "Set1")
chestnut %>% 
  ggplot(aes(x = CHAMB, y = LOGTOTALDW, color = Trt, label = PLANTNO)) + 
  geom_text() + 
  scale_color_brewer(palette = "Set1")

source("C:/Users/skoike/Desktop/tidy data/Neufeld/Seiji's Work/OZ_metrics_Neufeld.R")

exp_days <- as.numeric(max(oz_data$Date) - min(oz_data$Date) + 1)

oz_91 <- OZ_metrics_neufeld(oz_data %>% mutate(Chamber = as_factor(Chamber))) %>% 
  mutate(CHAMB = as_factor(CHAMB)) %>% 
  mutate_if(is.numeric, function(x){x * 92/exp_days})

harvest <- left_join(test_df, oz_91) %>% 
  mutate(CHAMB = as_factor(CHAMB)) %>% 
  mutate(Year = 1991,
         Harvest = 1,
         Exp_days = exp_days) %>% 
  select(Year, Harvest, Exp_days, everything())

#write.csv(harvest, "chestnut_mean_data.csv", row.names = FALSE)
