library(tidyverse)
library(RColorBrewer)

# Read in Data --------------------------------------------------------

oz_88 <- read_csv("C:/Users/skoike/Desktop/tidy data/Neufeld/Seiji's Work/1988_oz_metrics.csv")
oz_long <- read_csv("C:/Users/skoike/Desktop/tidy data/Neufeld/Seiji's Work/1988_oz.csv")
red_maple <- read_csv("C:/Users/skoike/Desktop/tidy data/Neufeld/epa corvallis trip/trees/redmaple/redmaple1988rawbiomass.csv")


red_maple %>% group_by(O389) %>% tally()
red_maple %>% group_by(O389, CH89) %>% tally()

# Get Ready for Joining ------------------------------------------------

red_maple <- red_maple %>% 
  rename(ROOTDW = ROOTWT,
         SHOOTDW = SHOOTWT,
         LEAFDW = LEAFWT,
         CHAMB = CH89) %>% 
  mutate(TOTALDW = ROOTDW + SHOOTDW + LEAFDW,
         LOGROOT = log(ROOTDW + 0.01),
         LOGSHOOT = log(SHOOTDW + 0.01),
         LOGLEAF = log(LEAFDW + 0.01),
         LOGTOTAL = log(TOTALDW + 0.01),
         VOL_bl = INIHT * INIDM^2,
         VOL_h = HT * DIAM^2,
         LOGVOL_bl = log(VOL_bl + 0.01),
         LOGVOL_h = log(VOL_h + 0.01))

red_maple %>% group_by(CHAMB, O389) %>% tally()

oz_long <- right_join(oz_long, red_maple %>% rename(Chamber = CHAMB) %>% select(O389, Chamber)) %>% 
  mutate(O389 = as_factor(O389))

test_long <- full_join(red_maple %>% select(CHAMB, PLT, LOGROOT, LOGSHOOT, LOGLEAF, LOGTOTAL, LOGVOL_bl),
                       oz_88)

#write.csv(test_long, "redmaple_data.csv", row.names = FALSE)

oz_long %>% 
  ggplot() + 
  aes(x = Datetime, y = OZ, color = O389) + 
  geom_line() + 
  facet_wrap(. ~ Chamber, nrow = 3) + 
  scale_color_brewer(palette = "Set1")

test_df <- red_maple %>% 
  group_by(O389, CHAMB) %>% 
  summarise_at(vars(starts_with("LOG"), ends_with("DW"), VOL_bl), mean, na.rm = TRUE)

# Join Data ------------------------------------------------------------

combined_data <- left_join(test_df, oz_88) %>% 
  mutate(O389 = as_factor(O389),
         CHAMB = as_factor(CHAMB),
         Year = 1988,
         Harvest = 1,
         Exp_days = exp_days) %>% 
  select(Year, Harvest, Exp_days, everything())

combined_data %>% 
  group_by(O389) %>% 
  summarise(m1 = round(mean(w126.12.8.adj), 1),
            m2 = round(mean(aot40.12.8.adj), 1)) %>% 
  arrange(m1)

#write.csv(combined_data, "redmaple_mean_data.csv", row.names = FALSE)
