# Read in Data ---------------------------

library(tidyverse)
library(RColorBrewer)
library(lubridate)

sumac_harvest1 <- read_table2("C:/Users/skoike/Desktop/tidy data/Neufeld/Seiji's Work/Sumac/sumac_1.txt") %>%
  select(OBS, JULDATE, TRT, CHAM, PLANT, ROOTWT)
sumac_harvest2 <- read_table2("C:/Users/skoike/Desktop/tidy data/Neufeld/Seiji's Work/Sumac/sumac_2.txt") %>%
  select(-c(RS, TRT2, CHAM2, FLAG))

sumac <- full_join(sumac_harvest1, sumac_harvest2)

sumac <- sumac %>% 
  mutate_if(is.numeric, function(x){ifelse(x < 0, NA, x)}) %>% 
  rename(LEAFDW = LEAFWT,
         SHOOTDW = SHOOTWT,
         ROOTDW = ROOTWT,
         TOTALDW = TOTALWT,
         Trt = TRT,
         HGT = INIHT,
         DIAM = INIDM,
         CHAMB = CHAM) %>% 
  mutate(VOL = HGT * DIAM^2,
         LOGVOL = log(VOL + 0.01),
         LOGLEAFDW = log(LEAFDW + 0.01),
         LOGSHOOTDW = log(SHOOTDW + 0.01),
         LOGROOTDW = log(ROOTDW + 0.01),
         LOGTOTALDW = log(TOTALDW + 0.01),
         Trt = as_factor(Trt),
         CHAMB = as_factor(CHAMB))

sumac %>% group_by(Trt, CHAMB) %>% tally()

oz_data <- read_csv("C:/Users/skoike/Desktop/tidy data/Neufeld/Seiji's Work/1989_oz.csv") %>% 
  mutate(Chamber = as_factor(Chamber)) %>% 
  filter(between(Date, mdy("06/19/1989"), mdy("09/25/1989")),
         Chamber %in% unique(sumac$CHAMB)) %>% 
  droplevels()

harvest_long <- right_join(sumac, oz_data %>% rename(CHAMB = Chamber))

# EDA ------------------------------------------------------------

oz_by_date <- harvest_long %>% 
  ggplot() + 
  aes(x = Datetime, y = OZ/1000, color = Trt) + 
  geom_line() + 
  scale_color_brewer(palette = "Set1") +
  facet_wrap(. ~ factor(CHAMB), nrow = 3)

#oz_by_date

# Box plots ----------------------------------------------------
sumac %>% 
  ggplot() + 
  aes(x = factor(Trt), y = LOGLEAFDW, fill = Trt) + 
  scale_fill_brewer(palette = "Set1") + 
  guides(fill = FALSE) +
  geom_boxplot()
sumac %>% 
  ggplot() + 
  aes(x = factor(Trt), y = LOGROOTDW, fill = Trt) + # One root bad
  scale_fill_brewer(palette = "Set1") + 
  guides(fill = FALSE) +
  geom_boxplot()
sumac %>% 
  ggplot() + 
  aes(x = factor(Trt), y = LOGSHOOTDW, fill = Trt) + 
  scale_fill_brewer(palette = "Set1") + 
  guides(fill = FALSE) +
  geom_boxplot()
sumac %>% 
  ggplot() + 
  aes(x = factor(Trt), y = LOGTOTALDW, fill = Trt) + 
  scale_fill_brewer(palette = "Set1") + 
  guides(fill = FALSE) +
  geom_boxplot()
sumac %>% 
  ggplot() + 
  aes(x = factor(Trt), y = LOGVOL, fill = Trt) + 
  scale_fill_brewer(palette = "Set1") + 
  guides(fill = FALSE) +
  geom_boxplot() 

# Scatter Plots -----------------------------------------

sumac %>% 
  ggplot() +
  aes(x = LOGVOL, y = LOGTOTALDW, fill = Trt, color = Trt) + 
  geom_point(shape = 21, size = 2, color = "black") +
  scale_fill_brewer(palette = "Set1") + 
  scale_color_brewer(palette = "Set1") +
  geom_smooth(method = "lm", se = FALSE) + 
  geom_smooth(method = "lm", aes(group = 1), color = "black", se = FALSE, linetype = "dashed")

test_df <- sumac %>% 
  group_by(Trt, CHAMB) %>% 
  summarise_at(vars(starts_with("LOG"), ends_with("DW"), VOL), mean, na.rm = TRUE) 

test_df %>% 
  ggplot() + 
  aes(x = LOGVOL, y = LOGLEAFDW, color = Trt) + 
  geom_text(aes(label = CHAMB)) + 
  scale_color_brewer(palette = "Set1")
test_df %>% 
  ggplot() + 
  aes(x = LOGVOL, y = LOGSHOOTDW, color = Trt) + 
  geom_text(aes(label = CHAMB)) + 
  scale_color_brewer(palette = "Set1")
test_df %>% 
  ggplot() + 
  aes(x = LOGVOL, y = LOGROOTDW, color = Trt) + 
  geom_text(aes(label = CHAMB)) + 
  scale_color_brewer(palette = "Set1")
test_df %>% 
  ggplot() + 
  aes(x = LOGVOL, y = LOGTOTALDW, color = Trt) + 
  geom_text(aes(label = CHAMB)) + 
  scale_color_brewer(palette = "Set1")

sumac %>% 
  group_by(Trt) %>% 
  summarize(avg = mean(LOGTOTALDW, na.rm = TRUE),
            s = sd(LOGTOTALDW, na.rm = TRUE))

sumac %>% 
  ggplot(aes(x = CHAMB, y = LOGVOL, color = Trt, label = PLANT)) + 
  geom_text() + 
  scale_color_brewer(palette = "Set1")
sumac %>% 
  ggplot(aes(x = CHAMB, y = LOGLEAFDW, color = Trt, label = PLANT)) + 
  geom_text() + 
  scale_color_brewer(palette = "Set1")
sumac %>% 
  ggplot(aes(x = CHAMB, y = LOGSHOOTDW, color = Trt, label = PLANT)) + 
  geom_text() + 
  scale_color_brewer(palette = "Set1")
sumac %>% 
  ggplot(aes(x = CHAMB, y = LOGROOTDW, color = Trt, label = PLANT)) + 
  geom_text() + 
  scale_color_brewer(palette = "Set1")
sumac %>% 
  ggplot(aes(x = CHAMB, y = LOGTOTALDW, color = Trt, label = PLANT)) + 
  geom_text() + 
  scale_color_brewer(palette = "Set1")



source("C:/Users/skoike/Desktop/tidy data/Neufeld/Seiji's Work/OZ_metrics_Neufeld.R")

exp_days <- as.numeric(max(oz_data$Date) - min(oz_data$Date) + 1)

oz_89 <- OZ_metrics_neufeld(oz_data %>% mutate(Chamber = as_factor(Chamber))) %>% 
  mutate(CHAMB = as_factor(CHAMB)) %>% 
  mutate_if(is.numeric, function(x){x * 92/exp_days})

harvest <- left_join(test_df, oz_89) %>% 
  mutate(Year = 1989,
         Harvest = 1,
         Exp_days = exp_days) %>% 
  select(Year, Harvest, Exp_days, everything()) %>% 
  rename(LOGVOL_bl = LOGVOL, VOL_bl = VOL)

#write.csv(harvest, "sumac_mean_data.csv", row.names = FALSE)

ggplot(harvest) + 
  aes(x = w126.12.8.adj, y = LOGTOTALDW) + 
  geom_point(aes(fill = Trt), shape = 21, size = 3)
