# Read in Data ---------------------------

library(tidyverse)
library(RColorBrewer)
library(lubridate)

sweetgum_baseline <- read_csv("C:/Users/skoike/Desktop/tidy data/Neufeld/Seiji's Work/sweetgum/sweetgum_baseline.csv") %>% 
  mutate(HEIGHT = HEIGHT * 0.1,
         DIAMETER = DIAMETER * 0.1,
         VOL = HEIGHT * DIAMETER^2,
         LOGVOL = log(VOL + 0.01)) %>% 
  filter(TREATMENT != 0) %>% 
  droplevels()

sweetgum_harvest <- read_csv("C:/Users/skoike/Desktop/tidy data/Neufeld/Seiji's Work/sweetgum/sweetgum_harvest.csv") %>% 
  mutate(HEIGHT = HEIGHT * 0.1,
         DIAMETER = DIAMETER * 0.1,
         LEAFAREA = LEAFAREA * 0.01,
         ROOTWGT = ROOTWGT * 0.01,
         STEMWGT = STEMWGT * 0.01,
         LEAFWGT = LEAFWGT * 0.01,
         VOL = HEIGHT * DIAMETER^2,
         LOGVOL = log(VOL + 0.01),
         LOGROOTDW = log(ROOTWGT + 0.01),
         LOGSTEMDW = log(STEMWGT + 0.01),
         LOGLEAFDW = log(LEAFWGT + 0.01),
         TOTALWGT = ROOTWGT + STEMWGT + LEAFWGT,
         LOGTOTALDW = log(TOTALWGT + 0.01)) %>% 
  filter(TREATMENT != 0) %>% 
  droplevels()


# Join Data -----------------------------------------------------

sweetgum <- right_join(sweetgum_baseline, sweetgum_harvest, by = c("TREATMENT", "CHAMBER", "PLANTNO"), suffix = c("_bl", "_h")) %>% 
  select(TREATMENT, CHAMBER, PLANTNO, starts_with("LOG"), ends_with("WGT"), VOL_bl) %>% 
  rename(CHAMB = CHAMBER,
         Trt = TREATMENT) %>% 
  mutate(CHAMB = as_factor(CHAMB),
         Trt = as_factor(Trt))
  

oz_data <- read_csv("C:/Users/skoike/Desktop/tidy data/Neufeld/Seiji's Work/1989_oz.csv") %>% 
  mutate(Chamber = as_factor(Chamber)) %>% 
  filter(between(Date, mdy("06/19/1989"), mdy("09/28/1989")),
         Chamber %in% unique(sweetgum$CHAMB)) %>% 
  droplevels()

harvest_long <- right_join(sweetgum, oz_data %>% rename(CHAMB = Chamber))

# EDA ------------------------------------------------------------

oz_by_date <- harvest_long %>% 
  ggplot() + 
  aes(x = Datetime, y = OZ/1000, color = Trt) + 
  geom_line() + 
  scale_color_brewer(palette = "Set1") +
  facet_wrap(. ~ factor(CHAMB), nrow = 3)

#oz_by_date

# Box plots ----------------------------------------------------
sweetgum %>% 
  ggplot() + 
  aes(x = factor(Trt), y = LOGLEAFDW, fill = Trt) + 
  scale_fill_brewer(palette = "Set1") + 
  guides(fill = FALSE) +
  geom_boxplot()
sweetgum %>% 
  ggplot() + 
  aes(x = factor(Trt), y = LOGROOTDW, fill = Trt) + # One root bad
  scale_fill_brewer(palette = "Set1") + 
  guides(fill = FALSE) +
  geom_boxplot()
sweetgum %>% 
  ggplot() + 
  aes(x = factor(Trt), y = LOGSTEMDW, fill = Trt) + 
  scale_fill_brewer(palette = "Set1") + 
  guides(fill = FALSE) +
  geom_boxplot()
sweetgum %>% 
  ggplot() + 
  aes(x = factor(Trt), y = LOGTOTALDW, fill = Trt) + 
  scale_fill_brewer(palette = "Set1") + 
  guides(fill = FALSE) +
  geom_boxplot()
sweetgum %>% 
  ggplot() + 
  aes(x = factor(Trt), y = LOGVOL_bl, fill = Trt) + 
  scale_fill_brewer(palette = "Set1") + 
  guides(fill = FALSE) +
  geom_boxplot() 

# Scatter Plots -----------------------------------------

sweetgum %>% 
  ggplot() +
  aes(x = LOGVOL_bl, y = LOGVOL_h, fill = Trt, color = Trt) + 
  geom_point(shape = 21, size = 2, color = "black") +
  scale_fill_brewer(palette = "Set1") + 
  scale_color_brewer(palette = "Set1") +
  geom_smooth(method = "lm", se = FALSE) + 
  geom_smooth(method = "lm", aes(group = 1), color = "black", se = FALSE, linetype = "dashed")

sweetgum %>% 
  ggplot() +
  aes(x = LOGVOL_bl, y = LOGTOTALDW, fill = Trt, color = Trt) + 
  geom_point(shape = 21, size = 2, color = "black") +
  scale_fill_brewer(palette = "Set1") + 
  scale_color_brewer(palette = "Set1") +
  geom_smooth(method = "lm", se = FALSE) + 
  geom_smooth(method = "lm", aes(group = 1), color = "black", se = FALSE, linetype = "dashed")

sweetgum %>%
  pivot_longer(cols = c(LOGVOL_bl, LOGVOL_h)) %>% 
  mutate(name = factor(name, levels = c("LOGVOL_bl", "LOGVOL_h"))) %>% 
  ggplot() +
  aes(x = name, y = value, color = Trt) +
  facet_wrap(. ~ Trt) +
  geom_line(aes(group = PLANTNO)) +
  scale_color_brewer(palette = "Set1")

test_df <- sweetgum %>% 
  select(-LOGVOL_h) %>% 
  rename(ROOTDW = ROOTWGT, STEMDW = STEMWGT, LEAFDW = LEAFWGT) %>% 
  group_by(Trt, CHAMB) %>% 
  summarise_at(vars(starts_with("LOG"), ends_with("DW"), VOL_bl), mean, na.rm = TRUE)


test_df %>% 
  ggplot() + 
  aes(x = LOGVOL_bl, y = LOGLEAFDW, color = Trt) + 
  geom_text(aes(label = CHAMB)) + 
  scale_color_brewer(palette = "Set1")
test_df %>% 
  ggplot() + 
  aes(x = LOGVOL_bl, y = LOGSTEMDW, color = Trt) + 
  geom_text(aes(label = CHAMB)) + 
  scale_color_brewer(palette = "Set1")
test_df %>% 
  ggplot() + 
  aes(x = LOGVOL_bl, y = LOGROOTDW, color = Trt) + 
  geom_text(aes(label = CHAMB)) + 
  scale_color_brewer(palette = "Set1")
test_df %>% 
  ggplot() + 
  aes(x = LOGVOL_bl, y = LOGTOTALDW, color = Trt) + 
  geom_text(aes(label = CHAMB)) + 
  scale_color_brewer(palette = "Set1")

sweetgum %>% 
  group_by(Trt) %>% 
  summarize(avg = mean(LOGTOTALDW),
            s = sd(LOGTOTALDW))

sweetgum %>% 
  ggplot(aes(x = CHAMB, y = LOGVOL_bl, color = Trt, label = PLANTNO)) + 
  geom_text() + 
  scale_color_brewer(palette = "Set1")
sweetgum %>% 
  ggplot(aes(x = CHAMB, y = LOGLEAFDW, color = Trt, label = PLANTNO)) + 
  geom_text() + 
  scale_color_brewer(palette = "Set1")
sweetgum %>% 
  ggplot(aes(x = CHAMB, y = LOGSTEMDW, color = Trt, label = PLANTNO)) + 
  geom_text() + 
  scale_color_brewer(palette = "Set1")
sweetgum %>% 
  ggplot(aes(x = CHAMB, y = LOGROOTDW, color = Trt, label = PLANTNO)) + 
  geom_text() + 
  scale_color_brewer(palette = "Set1")
sweetgum %>% 
  ggplot(aes(x = CHAMB, y = LOGTOTALDW, color = Trt, label = PLANTNO)) + 
  geom_text() + 
  scale_color_brewer(palette = "Set1")
sweetgum %>% 
  ggplot(aes(x = CHAMB, y = LOGVOL_h, color = Trt, label = PLANTNO)) + 
  geom_text() + 
  scale_color_brewer(palette = "Set1")


source("C:/Users/skoike/Desktop/tidy data/Neufeld/Seiji's Work/OZ_metrics_Neufeld.R")

exp_days <- as.numeric(max(oz_data$Date) - min(oz_data$Date) + 1)

oz_89 <- OZ_metrics_neufeld(oz_data %>% mutate(Chamber = as_factor(Chamber))) %>% 
  mutate(CHAMB = as_factor(CHAMB)) %>% 
  mutate_if(is.numeric, function(x){x * 92/exp_days})

harvest <- right_join(test_df, oz_89) %>% 
  rename(TREAT = Trt) %>% 
  mutate(Year = 1989,
         Harvest = 1,
         Exp_days = exp_days) %>% 
  select(Year, Harvest, Exp_days, everything())

#write.csv(harvest, "sg_mean_data.csv", row.names = FALSE)

w126 <- harvest %>% arrange(w126.12.8.adj) %>% select(CHAMB, Trt, LOGTOTALDW, w126.12.8.adj) 
w126

w126 %>% 
  ggplot() + 
  aes(x = w126.12.8.adj, y = LOGTOTALDW, color = Trt, label = CHAMB) + 
  geom_text() + 
  scale_color_brewer(palette = "Set1") + 
  geom_smooth(method = "lm", se = FALSE, color = "black", linetype = "dashed")

# Correlation Analysis
library(corrr)
corrs <- harvest %>% 
  select(-c(CHAMB, Trt)) %>% # Remove non-necessary variables
  correlate() %>% # Create correlation data frame
  select(1:2, 4:7) # Select only responses for columns
head(corrs, 10) # First 10 rows

corrs %>% 
  arrange(desc(abs(LOGTOTALDW)))

corrs %>% 
  filter(str_detect(rowname, "w126"))

# ANCOVA ----------------------------------------------------------------------

## Linearly Modeling log-Stem Dry Weight with log-Volume as a Covariate
test_lm <- lm(LOGLEAFDW ~ Trt + LOGVOL_bl, data = harvest, na.action = "na.exclude") 
summary(test_lm) # Log-Volume not significant
test_lm <- lm(LOGLEAFDW ~ Trt, data = harvest, na.action = "na.exclude") 
summary(test_lm)


## Linearly Modeling log-Stem Dry Weight with log-Volume as a Covariate
test_lm <- lm(LOGSTEMDW ~ Trt + LOGVOL_bl, data = harvest, na.action = "na.exclude") 
summary(test_lm) # Log-Volume significant

## Linearly Modeling log-Root Dry Weight with log-Volume as a Covariate
test_lm <- lm(LOGROOTDW ~ Trt + LOGVOL_bl, data = harvest, na.action = "na.exclude")
summary(test_lm) # Log-Volume significant

## Linearly Modeling log-Total Dry Weight with log-Volume as a Covariate
test_lm <- lm(LOGTOTALDW ~ Trt + LOGVOL_bl, data = harvest, na.action = "na.exclude")
summary(test_lm) # Log-Volume significant 

# Regression Analysis ---------------------------------------------------------

library(minpack.lm)

#TOTALDW y = a * e^(-x/b)^c

g <- function(x, a, b, c){log(a) + (-(x/b)^c)} # Weibull Model 
f <- function(x, z, a, b, c, d){log(a + d*z) + (-(x/b)^c)} # Weibull Model w/ covariate

# Log Leaf --------------------------------------------------------------------

ggplot(harvest, aes(x = w126.12.8.adj, y = LOGLEAFDW)) + 
  geom_point() + 
  geom_smooth(method = "lm", se = FALSE) + 
  geom_smooth(method = "nls", se = FALSE,
              linetype = "dashed",
              formula = y ~ g(x, a, b, c),
              method.args = list(start = list(a = 1, b = 1, c = 1)))

weibcov_leaf <- nlsLM(LOGLEAFDW ~ f(w126.12.8.adj, LOGVOL_bl, a, b, c, d), data = harvest,
                      start = list(a = 1, b = 1, c = 1, d = 1))
summary(weibcov_leaf) # LOGVOL not significant

weib_leaf <- nls(LOGLEAFDW ~ g(w126.12.8.adj, a, b, c), data = harvest,
                   start = list(a = 1, b = 1, c = 1))
summary(weib_leaf)

lmcov_leaf <- lm(LOGLEAFDW ~ w126.12.8.adj + LOGVOL_bl, data = harvest)
summary(lmcov_leaf) # LOGVOL not significant

lm_leaf <- lm(LOGLEAFDW ~ w126.12.8.adj, data = harvest)
summary(lm_leaf) 

AIC(lm_leaf, weib_leaf) # Linear

leaf_adj <- harvest %>% 
  select(Trt, CHAMB, LOGLEAFDW, LOGVOL_bl, w126.12.8.adj) %>% 
  mutate(y = LOGLEAFDW - coef(lm_leaf)[1])
lm_leaf1 <- lm(y ~ -1 + w126.12.8.adj, data = leaf_adj)

# Log Stem --------------------------------------------------------------------

ggplot(harvest, aes(x = w126.12.8.adj, y = LOGSTEMDW)) + 
  geom_point() + 
  geom_smooth(method = "lm", se = FALSE) + 
  geom_smooth(method = "nls", se = FALSE,
              linetype = "dashed",
              formula = y ~ g(x, a, b, c),
              method.args = list(start = list(a = 1, b = 1, c = 1)))

weibcov_stem <- nlsLM(LOGSTEMDW ~ f(w126.12.8.adj, LOGVOL_bl, a, b, c, d), data = harvest,
                       start = list(a = 1, b = 1, c = 1, d = 1))
summary(weibcov_stem) # LOGVOL not significant

weib_stem <- nls(LOGSTEMDW ~ g(w126.12.8.adj, a, b, c), data = harvest,
                    start = list(a = 1, b = 1, c = 1))
summary(weib_stem)

lmcov_stem <- lm(LOGSTEMDW ~ w126.12.8.adj + LOGVOL_bl, data = harvest)
summary(lmcov_stem) # LOGVOL significant

AIC(lmcov_stem, weib_stem) # Linear w/ covariate

stem_adj <- harvest %>% 
  select(Trt, CHAMB, LOGSTEMDW, LOGVOL_bl, w126.12.8.adj) %>% 
  mutate(y = LOGSTEMDW - coef(lmcov_stem)[1] - coef(lmcov_stem)[3]*LOGVOL_bl)
lmcov_stem1 <- lm(y ~ -1 + w126.12.8.adj, data = stem_adj)


# Log Root --------------------------------------------------------------------

ggplot(harvest, aes(x = w126.12.8.adj, y = LOGROOTDW)) + 
  geom_point() + 
  geom_smooth(method = "lm", se = FALSE) + 
  geom_smooth(method = "nls", se = FALSE,
              linetype = "dashed",
              formula = y ~ g(x, a, b, c),
              method.args = list(start = list(a = 1, b = 1, c = 1)))

weibcov_root <- nlsLM(LOGROOTDW ~ f(w126.12.8.adj, LOGVOL_bl, a, b, c, d), data = harvest,
                      start = list(a = 1, b = 1, c = 1, d = 1))
summary(weibcov_root) # LOGVOL significant

lmcov_root <- lm(LOGROOTDW ~ w126.12.8.adj + LOGVOL_bl, data = harvest)
summary(lmcov_root) # LOGVOL significant

AIC(lmcov_root, weibcov_root) # Linear w/ covariate

root_adj <- harvest %>% 
  select(Trt, CHAMB, LOGROOTDW, LOGVOL_bl, w126.12.8.adj) %>% 
  mutate(y = LOGROOTDW - coef(lmcov_root)[1] - coef(lmcov_root)[3]*LOGVOL_bl)
lmcov_root1 <- lm(y ~ -1 + w126.12.8.adj, data = root_adj)


# Log Total --------------------------------------------------------------------

ggplot(harvest, aes(x = w126.12.8.adj, y = LOGTOTALDW)) + 
  geom_point() + 
  geom_smooth(method = "lm", se = FALSE) + 
  geom_smooth(method = "nls", se = FALSE,
              linetype = "dashed",
              formula = y ~ g(x, a, b, c),
              method.args = list(start = list(a = 1, b = 1, c = 1)))

weibcov_total <- nls(LOGTOTALDW ~ f(w126.12.8.adj, LOGVOL_bl, a, b, c, d), data = harvest,
                       start = list(a = 1, b = 1, c = 1, d = 1))
summary(weibcov_total) # LOGVOL not significant

weib_total <- nls(LOGTOTALDW ~ g(w126.12.8.adj, a, b, c), data = harvest,
                    start = list(a = 1, b = 1, c = 1))
summary(weib_total)

lmcov_total <- lm(LOGTOTALDW ~ w126.12.8.adj + LOGVOL_bl, data = harvest)
summary(lmcov_total) # LOGVOL significant

mean(residuals(lmcov_total)^2) # MSE
summary(lmcov_total)$r.squared

AIC(lmcov_total, weib_total) # Linear

total_adj <- harvest %>% 
  select(Trt, CHAMB, LOGTOTALDW, LOGVOL_bl, w126.12.8.adj) %>% 
  mutate(y = LOGTOTALDW - coef(lmcov_total)[1] - coef(lmcov_total)[3]*LOGVOL_bl)
lmcov_total1 <- lm(y ~ -1 + w126.12.8.adj, data = total_adj)

total_adj %>% 
  ggplot() + 
  aes(x = w126.12.8.adj, y = y, fill = Trt, label = CHAMB) + 
  geom_point(size = 2, shape = 21) + 
  scale_fill_brewer(palette = "Set1") + 
  geom_text(nudge_y = -0.01) + 
  geom_smooth(method = "lm", se = FALSE, 
              aes(group = 1), 
              color = "black",
              linetype = "dashed")

total_adj %>% 
  ggplot() + 
  aes(x = w126.12.8.adj, y = LOGVOL_bl, fill = Trt, label = CHAMB) + 
  geom_point(shape = 21, aes(size = LOGTOTALDW)) + 
  geom_text(nudge_y = -0.02)

summary(total_adj)

pred_grid <- expand.grid(w126.12.8.adj = seq(0, 32, by = 0.5),
                         LOGVOL_bl = seq(7.9, 9.3, by = 0.05))
pred_grid <- pred_grid %>% modelr::add_predictions(model = lmcov_total, var = "LOGTOTALDW")


pred_grid %>% 
  ggplot(aes(x = w126.12.8.adj, y = LOGVOL_bl, fill = LOGTOTALDW)) + 
  geom_raster() + 
  geom_point(data = total_adj,
             aes(x = w126.12.8.adj, y = LOGVOL_bl, size = LOGTOTALDW)) + 
  geom_text(data = total_adj,
            aes(x = w126.12.8.adj, y = LOGVOL_bl, label = CHAMB, color = Trt),
            nudge_y = -0.04, size = 5) + 
  scale_fill_gradient(low = "white", high = "darkgreen") + 
  scale_color_brewer(palette = "Oranges")

## data frame for plotting
obs_data <- harvest %>% 
  select(starts_with("LOG") & ends_with("DW"), w126.12.8.adj) %>% # pick out columns of interest
  mutate(LOGSTEMDW = stem_adj$y,
         LOGLEAFDW = leaf_adj$y,
         LOGROOTDW = root_adj$y,
         LOGTOTALDW = total_adj$y) %>% # give adjusted log stem dw 
  pivot_longer(cols = c(LOGLEAFDW, LOGSTEMDW, LOGROOTDW, LOGTOTALDW), names_to = "Measurement", values_to = "y")

### Create first plot and beautify
entire.w126.plot <- obs_data %>% 
  ggplot() + 
  aes(x = w126.12.8.adj, y = y, color = Measurement, shape = Measurement) + 
  geom_point(size = 2.5) +
  geom_smooth(data = obs_data,  method = "lm", se = FALSE) + 
  scale_color_manual(values = c("#E69F00", "#009E73", "#0072B2", "#D55E00"),
                     labels = c("Leaf", "Root", "Stem", "Total")) + 
  scale_shape_discrete(labels = c("Leaf", "Root", "Stem", "Total")) + 
  labs(x = "92-Day 12-h W126 Rescale (ppm-hr)",
       y = "Adjusted Log Total Dry Weight (g)",
       shape = NULL,
       color = NULL,
       title = "Sweetgum Neufeld (1989)",
       subtitle = "Exposure Dates: 06/30/1990 - 08/09/1990") + 
  theme(legend.text = element_text(size = 12),
        panel.grid.minor = element_line(color = "grey80"),
        legend.position = "top") 

entire.w126.plot

