# Read in Data ---------------------------

library(tidyverse)
library(RColorBrewer)
library(lubridate)

sycamore <- read_csv("C:/Users/skoike/Desktop/tidy data/Neufeld/Seiji's Work/Sycamore/sycamoredw.csv") %>% 
  mutate(VOL_bl = Ht_bl*Diam_bl^2,
         VOL = Ht*Diam_bl^2,
         LOGVOL_bl = log(VOL_bl + 0.01),
         LOGVOL = log(VOL + 0.01),
         LOGROOTDW = log(ROOTDW + 0.01),
         LOGSHOOTDW = log(SHOOTDW + 0.01),
         LOGLEAFDW = log(LEAFDW + 0.01),
         TOTALDW = ROOTDW + SHOOTDW + LEAFDW,
         LOGTOTALDW = log(TOTALDW + 0.01),
         Trt = as_factor(Trt),
         CHAMB = as_factor(CHAMB)) %>% 
  filter(Trt != 0) %>% 
  droplevels()

sycamore %>% group_by(Trt, CHAMB) %>% tally()
# Join Data -----------------------------------------------------

oz_data <- read_csv("C:/Users/skoike/Desktop/tidy data/Neufeld/Seiji's Work/1989_oz.csv") %>% 
  mutate(Chamber = as_factor(Chamber)) %>% 
  filter(between(Date, mdy("6/14/1989"), mdy("8/21/1989")))

harvest_long <- right_join(sycamore, oz_data %>% rename(CHAMB = Chamber))

# EDA ------------------------------------------------------------

oz_by_date <- harvest_long %>% 
  filter(CHAMB %in% unique(sycamore$CHAMB)) %>% 
  ggplot() + 
  aes(x = Datetime, y = OZ/1000, color = Trt) + 
  geom_line() + 
  scale_color_brewer(palette = "Set1") +
  facet_wrap(. ~ factor(CHAMB), nrow = 3)

#oz_by_date

# Box plots ----------------------------------------------------
sycamore %>% 
  ggplot() + 
  aes(x = factor(Trt), y = LOGLEAFDW, fill = Trt) + 
  scale_fill_brewer(palette = "Set1") + 
  guides(fill = FALSE) +
  geom_boxplot()
sycamore %>% 
  ggplot() + 
  aes(x = factor(Trt), y = LOGROOTDW, fill = Trt) + # One root bad
  scale_fill_brewer(palette = "Set1") + 
  guides(fill = FALSE) +
  geom_boxplot()
sycamore %>% 
  ggplot() + 
  aes(x = factor(Trt), y = LOGSHOOTDW, fill = Trt) + 
  scale_fill_brewer(palette = "Set1") + 
  guides(fill = FALSE) +
  geom_boxplot()
sycamore %>% 
  ggplot() + 
  aes(x = factor(Trt), y = LOGTOTALDW, fill = Trt) + 
  scale_fill_brewer(palette = "Set1") + 
  guides(fill = FALSE) +
  geom_boxplot()

# Scatter Plots -----------------------------------------

sycamore %>% 
  ggplot() +
  aes(x = LOGVOL_bl, y = LOGVOL, fill = Trt, color = Trt) + 
  geom_point(shape = 21, size = 2, color = "black") +
  scale_fill_brewer(palette = "Set1") + 
  scale_color_brewer(palette = "Set1") +
  geom_smooth(method = "lm", se = FALSE) + 
  geom_smooth(method = "lm", aes(group = 1), color = "black", se = FALSE, linetype = "dashed")

sycamore %>% 
  ggplot() +
  aes(x = LOGVOL_bl, y = LOGTOTALDW, fill = Trt, color = Trt) + 
  geom_point(shape = 21, size = 2, color = "black") +
  scale_fill_brewer(palette = "Set1") + 
  scale_color_brewer(palette = "Set1") +
  geom_smooth(method = "lm", se = FALSE) + 
  geom_smooth(method = "lm", aes(group = 1), color = "black", se = FALSE, linetype = "dashed")

sycamore %>%
  pivot_longer(cols = c(LOGVOL_bl, LOGVOL)) %>% 
  mutate(name = factor(name, levels = c("LOGVOL_bl", "LOGVOL"))) %>% 
  ggplot() +
  aes(x = name, y = value, color = Trt) +
  facet_wrap(. ~ Trt) +
  geom_line(aes(group = PLT)) +
  scale_color_brewer(palette = "Set1")

test_df <- sycamore %>% 
  select(Trt, CHAMB, PLT, ROOTDW, SHOOTDW, LEAFDW, VOL_bl, LOGVOL_bl, LOGROOTDW, LOGSHOOTDW, LOGLEAFDW, TOTALDW, LOGTOTALDW) %>% 
  group_by(Trt, CHAMB) %>% 
  summarise_at(vars(starts_with("LOG"), ends_with("DW"), VOL_bl), mean, na.rm = TRUE)


test_df %>% 
  ggplot() + 
  aes(x = LOGVOL_bl, y = LOGLEAFDW, color = Trt) + 
  geom_text(aes(label = Trt)) + 
  scale_color_brewer(palette = "Set1")
test_df %>% 
  ggplot() + 
  aes(x = LOGVOL_bl, y = LOGSHOOTDW, color = Trt) + 
  geom_text(aes(label = Trt)) + 
  scale_color_brewer(palette = "Set1")
test_df %>% 
  ggplot() + 
  aes(x = LOGVOL_bl, y = LOGROOTDW, color = Trt) + 
  geom_text(aes(label = Trt)) + 
  scale_color_brewer(palette = "Set1")
test_df %>% 
  ggplot() + 
  aes(x = LOGVOL_bl, y = LOGTOTALDW, color = Trt) + 
  geom_text(aes(label = Trt)) + 
  scale_color_brewer(palette = "Set1")

sycamore %>% 
  group_by(Trt) %>% 
  summarize(avg = mean(LOGTOTALDW),
            s = sd(LOGTOTALDW))


source("C:/Users/skoike/Desktop/tidy data/Neufeld/Seiji's Work/OZ_metrics_Neufeld.R")

exp_days <- as.numeric(max(oz_data$Date) - min(oz_data$Date) + 1)

oz_89 <- OZ_metrics_neufeld(oz_data %>% mutate(Chamber = as_factor(Chamber))) %>% 
  mutate(CHAMB = as_factor(CHAMB)) %>% 
  mutate_if(is.numeric, function(x){x * 92/exp_days})

harvest <- right_join(test_df, oz_89) %>% 
  mutate(Year = 1989,
         Harvest = 1,
         Exp_days = exp_days) %>% 
  select(Year, Harvest, Exp_days, everything())

harvest %>% arrange(w126.12.8.adj) %>% select(CHAMB, Trt, w126.12.8.adj) 

#write.csv(harvest, "sycamore_mean_data.csv", row.names = FALSE)

# Correlation Analysis
library(corrr)
corrs <- harvest %>% 
  ungroup() %>% 
  select(-c(CHAMB, Trt)) %>% # Remove non-necessary variables
  correlate() %>% # Create correlation data frame
  select(1:2, 4:7) # Select only responses for columns
head(corrs, 10) # First 10 rows

corrs %>% 
  arrange(desc(abs(LOGTOTALDW)))

corrs %>% 
  filter(str_detect(rowname, "w126"))

# ANCOVA ----------------------------------------------------------------------

## Linearly Modeling log-Stem Dry Weight with log-Volume as a Covariate
test_lm <- lm(LOGLEAFDW ~ Trt + LOGVOL_bl, data = harvest, na.action = "na.exclude") 
summary(test_lm) # Log-Volume not significant

## Linearly Modeling log-Stem Dry Weight with log-Volume as a Covariate
test_lm <- lm(LOGSHOOTDW ~ Trt + LOGVOL_bl, data = harvest, na.action = "na.exclude") 
summary(test_lm) # Log-Volume not significant

## Linearly Modeling log-Root Dry Weight with log-Volume as a Covariate
test_lm <- lm(LOGROOTDW ~ Trt + LOGVOL_bl, data = harvest, na.action = "na.exclude")
summary(test_lm) # Log-Volume not significant

## Linearly Modeling log-Total Dry Weight with log-Volume as a Covariate
test_lm <- lm(LOGTOTALDW ~ Trt + LOGVOL_bl, data = harvest, na.action = "na.exclude")
summary(test_lm) # Log-Volume not significant 

# Regression Analysis ---------------------------------------------------------

library(minpack.lm)

#TOTALDW y = a * e^(-x/b)^c

g <- function(x, a, b, c){log(a) + (-(x/b)^c)} # Weibull Model 
f <- function(x, z, a, b, c, d){log(a + d*z) + (-(x/b)^c)} # Weibull Model w/ covariate

# Log Leaf --------------------------------------------------------------------

ggplot(harvest, aes(x = w126.12.8.adj, y = LOGLEAFDW)) + 
  geom_point() + 
  geom_smooth(method = "lm", se = FALSE) + 
  geom_smooth(method = "nlsLM", se = FALSE,
              linetype = "dashed",
              formula = y ~ g(x, a, b, c),
              method.args = list(start = list(a = 1, b = 1, c = 1)))

weibcov_leaf <- nlsLM(LOGLEAFDW ~ f(w126.12.8.adj, LOGVOL_bl, a, b, c, d), data = harvest,
                      start = list(a = 1, b = 1, c = 1, d = 1))
summary(weibcov_leaf) # LOGVOL not significant

weib_leaf <- nlsLM(LOGLEAFDW ~ g(w126.12.8.adj, a, b, c), data = harvest,
                   start = list(a = 1, b = 1, c = 1))
summary(weib_leaf)

lmcov_leaf <- lm(LOGLEAFDW ~ w126.12.8.adj + LOGVOL_bl, data = harvest)
summary(lmcov_leaf) # LOGVOL not significant

lm_leaf <- lm(LOGLEAFDW ~ w126.12.8.adj, data = harvest)
summary(lm_leaf) 

AIC(lm_leaf, weib_leaf) # Linear

leaf_adj <- harvest %>% 
  select(Trt, CHAMB, LOGLEAFDW, LOGVOL_bl, w126.12.8.adj) %>% 
  mutate(y = LOGLEAFDW - coef(lm_leaf)[1])
lm_leaf1 <- lm(y ~ -1 + w126.12.8.adj, data = leaf_adj)

# Log Shoot --------------------------------------------------------------------

ggplot(harvest, aes(x = w126.12.8.adj, y = LOGSHOOTDW)) + 
  geom_point() + 
  geom_smooth(method = "lm", se = FALSE) + 
  geom_smooth(method = "nlsLM", se = FALSE,
              linetype = "dashed",
              formula = y ~ g(x, a, b, c),
              method.args = list(start = list(a = 1, b = 1, c = 1)))

weibcov_shoot <- nlsLM(LOGSHOOTDW ~ f(w126.12.8.adj, LOGVOL_bl, a, b, c, d), data = harvest,
                       start = list(a = 1, b = 1, c = 1, d = 1))
summary(weibcov_shoot) # LOGVOL not significant

weib_shoot <- nlsLM(LOGSHOOTDW ~ g(w126.12.8.adj, a, b, c), data = harvest,
                    start = list(a = 1, b = 1, c = 1))
summary(weib_shoot)

lmcov_shoot <- lm(LOGSHOOTDW ~ w126.12.8.adj + LOGVOL_bl, data = harvest)
summary(lmcov_shoot) # LOGVOL not significant

lm_shoot <- lm(LOGSHOOTDW ~ w126.12.8.adj, data = harvest)
summary(lm_shoot)

AIC(lm_shoot, weib_shoot) # Linear

shoot_adj <- harvest %>% 
  select(Trt, CHAMB, LOGSHOOTDW, LOGVOL_bl, w126.12.8.adj) %>% 
  mutate(y = LOGSHOOTDW - coef(lm_shoot)[1])
lm_shoot1 <- lm(y ~ -1 + w126.12.8.adj, data = shoot_adj)


# Log Root --------------------------------------------------------------------

ggplot(harvest, aes(x = w126.12.8.adj, y = LOGROOTDW)) + 
  geom_point() + 
  geom_smooth(method = "lm", se = FALSE) + 
  geom_smooth(method = "nlsLM", se = FALSE,
              linetype = "dashed",
              formula = y ~ g(x, a, b, c),
              method.args = list(start = list(a = 1, b = 1, c = 1)))

weibcov_root <- nlsLM(LOGROOTDW ~ f(w126.12.8.adj, LOGVOL_bl, a, b, c, d), data = harvest,
                      start = list(a = 1, b = 1, c = 1, d = 1))
summary(weibcov_root) # LOGVOL not significant

weib_root <- nlsLM(LOGROOTDW ~ g(w126.12.8.adj, a, b, c), data = harvest,
                   start = list(a = 1, b = 1, c = 1))
summary(weib_root)

lmcov_root <- lm(LOGROOTDW ~ w126.12.8.adj + LOGVOL_bl, data = harvest)
summary(lmcov_root) # LOGVOL not significant

lm_root <- lm(LOGROOTDW ~ w126.12.8.adj, data = harvest)
summary(lm_root) 

AIC(lm_root, weib_root) # Linear

root_adj <- harvest %>% 
  select(Trt, CHAMB, LOGROOTDW, LOGVOL_bl, w126.12.8.adj) %>% 
  mutate(y = LOGROOTDW - coef(lm_root)[1])
lm_root1 <- lm(y ~ -1 + w126.12.8.adj, data = root_adj)


# Log Total --------------------------------------------------------------------

ggplot(harvest, aes(x = w126.12.8.adj, y = LOGTOTALDW)) + 
  geom_point() + 
  geom_smooth(method = "lm", se = FALSE) + 
  geom_smooth(method = "nlsLM", se = FALSE,
              linetype = "dashed",
              formula = y ~ g(x, a, b, c),
              method.args = list(start = list(a = 1, b = 1, c = 1)))

weibcov_total <- nlsLM(LOGTOTALDW ~ f(w126.12.8.adj, LOGVOL_bl, a, b, c, d), data = harvest,
                       start = list(a = 1, b = 1, c = 1, d = 1))
summary(weibcov_total) # LOGVOL not significant

weib_total <- nlsLM(LOGTOTALDW ~ g(w126.12.8.adj, a, b, c), data = harvest,
                    start = list(a = 1, b = 1, c = 1))
summary(weib_total)

lmcov_total <- lm(LOGTOTALDW ~ w126.12.8.adj + LOGVOL_bl, data = harvest)
summary(lmcov_total) # LOGVOL not significant

lm_total <- lm(LOGTOTALDW ~ w126.12.8.adj, data = harvest)
summary(lm_total) 

mean(residuals(lm_total)^2) # MSE
summary(lm_total)$r.squared

AIC(lm_total, weib_total) # Linear

total_adj <- harvest %>% 
  select(Trt, CHAMB, LOGTOTALDW, LOGVOL_bl, w126.12.8.adj) %>% 
  mutate(y = LOGTOTALDW - coef(lm_total)[1])
lm_total1 <- lm(y ~ -1 + w126.12.8.adj, data = total_adj)

## data frame for plotting
obs_data <- harvest %>% 
  select(starts_with("LOG") & ends_with("DW"), w126.12.8.adj) %>% # pick out columns of interest
  mutate(LOGSHOOTDW = shoot_adj$y,
         LOGLEAFDW = leaf_adj$y,
         LOGROOTDW = root_adj$y,
         LOGTOTALDW = total_adj$y) %>% # give adjusted log stem dw 
  pivot_longer(cols = c(LOGLEAFDW, LOGSHOOTDW, LOGROOTDW, LOGTOTALDW), names_to = "Measurement", values_to = "y")

### Create first plot and beautify
entire.w126.plot <- obs_data %>% 
  ggplot() + 
  aes(x = w126.12.8.adj, y = y, color = Measurement, shape = Measurement) + 
  geom_point(size = 2.5) +
  geom_smooth(data = obs_data,  method = "lm", se = FALSE) + 
  scale_color_manual(values = c("#E69F00", "#009E73", "#0072B2", "#D55E00"),
                     labels = c("Leaf", "Root", "Shoot", "Total")) + 
  scale_shape_discrete(labels = c("Leaf", "Root", "Shoot", "Total")) + 
  labs(x = "92-Day 12-h W126 Rescale (ppm-hr)",
       y = "Adjusted Log Total Dry Weight (g)",
       shape = NULL,
       color = NULL,
       title = "Sycamore Neufeld (1989)",
       subtitle = "Exposure Dates: 06/13/1989 - 08/21/1989") + 
  theme(legend.text = element_text(size = 12),
        panel.grid.minor = element_line(color = "grey80"),
        legend.position = "top") 

entire.w126.plot

