# Read in Data ---------------------------

library(tidyverse)
library(RColorBrewer)
library(lubridate)

tablemt <- read_csv("C:/Users/skoike/Desktop/tidy data/Neufeld/Seiji's Work/Table Mountain Pine/tablemtpine.csv") %>%
  mutate_all(function(x){ifelse(x < 0, NA, x)}) %>% 
  rename(Trt = TREATMENT, 
         CHAMB = CHAMBER,
         NEEDLEDW = LEAFWGT90,
         STEMDW = STEMWGT90,
         ROOTDW = ROOTWGT) %>% 
  select(Trt, CHAMB, PLANTNO, HEIGHT, DIAMETER, ROOTDW, NEEDLEDW, STEMDW) %>% 
  mutate(Trt = as_factor(Trt),
         CHAMB = as_factor(CHAMB)) %>% 
  mutate_if(is.numeric, function(x){x*0.1}) %>% 
  mutate(LOGNEEDLEDW = log(NEEDLEDW + 0.01),
         LOGSTEMDW = log(STEMDW + 0.01),
         LOGROOTDW = log(ROOTDW + 0.01),
         TOTALDW = NEEDLEDW + STEMDW + ROOTDW,
         LOGTOTALDW = log(TOTALDW + 0.01),
         VOL_bl = HEIGHT * DIAMETER^2,
         LOGVOL_bl = log(VOL_bl + 0.01)) %>% 
  filter(Trt != 0) %>% 
  droplevels()

# Join Data -----------------------------------------------------

oz_data <- read_csv("C:/Users/skoike/Desktop/tidy data/Neufeld/Seiji's Work/1990_oz.csv") %>% 
  mutate(Chamber = as_factor(Chamber)) %>% 
  filter(between(Date, mdy("6/30/1990"), mdy("8/22/1990")))

harvest_long <- full_join(tablemt, oz_data %>% rename(CHAMB = Chamber)) %>% 
  mutate(Trt = as_factor(Trt)) 

# EDA ------------------------------------------------------------

oz_by_date <- harvest_long %>% 
  filter(CHAMB %in% unique(tablemt$CHAMB)) %>% 
  ggplot() + 
  aes(x = Datetime, y = OZ/1000, color = Trt) + 
  geom_line() + 
  scale_color_brewer(palette = "Set1") +
  facet_wrap(. ~ factor(CHAMB), nrow = 3)

#oz_by_date

source("C:/Users/skoike/Desktop/tidy data/Neufeld/Seiji's Work/OZ_metrics_Neufeld.R")

exp_days <- as.numeric(max(oz_data$Date) - min(oz_data$Date) + 1)

oz_90 <- OZ_metrics_neufeld(oz_data %>% mutate(Chamber = as_factor(Chamber))) %>% 
  mutate(CHAMB = as_factor(CHAMB)) %>% 
  mutate_if(is.numeric, function(x){x * 92/exp_days})

harvest_means <- tablemt %>% 
  group_by(Trt, CHAMB) %>% 
  summarise_at(vars(ends_with("DW"), contains("VOL")), mean, na.rm = TRUE)

harvest <- left_join(harvest_means, oz_90) %>% 
  mutate(Year = 1990,
         Harvest = 3,
         Exp_days = exp_days) %>% 
  select(Year, Harvest, Exp_days, everything())

#write.csv(harvest, "tablemt_mean_data.csv", row.names = FALSE)

ggplot(harvest) + 
  aes(x = w126.12.8.adj, y = LOGTOTALDW) + 
  geom_point(aes(fill = Trt), shape = 21, size = 3)
