# Read in Data ---------------------------

library(tidyverse)
library(RColorBrewer)
library(lubridate)

oz_data <- read_csv("C:/Users/skoike/Desktop/tidy data/Neufeld/Seiji's Work/1990_oz.csv") %>% 
  filter(between(Date, mdy("6/30/1990"), mdy("9/12/1990"))) %>% 
  mutate(Chamber = as_factor(Chamber))
tulip_pop <- read_csv("C:/Users/skoike/Desktop/tidy data/Neufeld/Seiji's Work/Tulip Poplar/ypoplar1990biomass.csv")

# Clean up Data a little --------------------

# lfct - LEAFDW count per tree
# lfarea - (cm2)
# woodwt - this is the aboveground weight, without leaves or boles (gms) - that is, the BRANCHDWes. Bolewt is the trunk weight (see below)
# lfwt - weight of leaves (gms)
# bolewt - weight of main trunk (gms)
# slm - Specific LEAFDW mass (ratio of LEAFDW weight to LEAFDW area) (gms/ cm2)
# lar - LEAFDW Area Ratio (ratio of LEAFDW area to TOTALDW dry weight, which includes roots) (cm2/gm)
# avglf - Average LEAFDW Area (mean of individual LEAFDW areas in cm2)

tulip_pop <- tulip_pop %>% 
  rename(BRANCHDW = woodwt,
         LEAFDW = lfwt,
         STEMDW = bolewt,
         CHAMB = cham) %>% 
  mutate(LOGBRANCHDW = log(BRANCHDW + 0.01),
         LOGLEAFDW = log(LEAFDW + 0.01),
         LOGSTEMDW = log(STEMDW + 0.01),
         TOTALDW = BRANCHDW + LEAFDW + STEMDW,
         LOGTOTALDW = log(TOTALDW + 0.01),
         CHAMB = as_factor(CHAMB))

test_df <- tulip_pop %>% 
  group_by(CHAMB, trt) %>% 
  summarize_at(vars(starts_with("LOG"), ends_with("DW")), mean, na.rm = TRUE)

# Join Data -----------------------------------------------------
source("C:/Users/skoike/Desktop/tidy data/Neufeld/Seiji's Work/OZ_metrics_Neufeld.R")

exp_days <- max(oz_data$Julian) - min(oz_data$Julian) + 1

oz_metrics <- OZ_metrics_neufeld(oz_data) %>% 
  mutate_if(is.numeric, function(x){x * 92/exp_days})

harvest <- left_join(test_df, oz_metrics) %>% 
  mutate(CHAMB = as_factor(CHAMB),
         Year = 1990,
         Harvest = 1,
         Exp_days = exp_days) %>% 
  select(Year, Harvest, Exp_days, everything()) %>% 
  rename(TREAT = trt)

test_long <- full_join(tulip_pop %>% select(trt, CHAMB, plant, LOGBRANCHDW, LOGLEAFDW, LOGSTEMDW, LOGTOTALDW),
          oz_metrics)

#write.csv(test_long, "tpop_90_data.csv", row.names = FALSE)
#write.csv(harvest, "tpop_90_mean_data.csv", row.names = FALSE)
