# Read in Data ---------------------------

library(tidyverse)
library(RColorBrewer)
library(lubridate)

oz_data <- read_csv("C:/Users/skoike/Desktop/tidy data/Neufeld/Seiji's Work/1991_oz.csv") %>% 
  filter(between(Date, mdy("5/1/1991"), mdy("10/8/1991"))) %>% 
  mutate(Chamber = as_factor(Chamber))
tulip_pop <- read_csv("C:/Users/skoike/Desktop/tidy data/Neufeld/Seiji's Work/Tulip Poplar/TP91DW.csv")

# Clean up Data a little --------------------

tulip_pop <- tulip_pop %>% 
  rename(STEMDW = BOLEWT,
         BRANCHDW = BRANCHWT,
         CHAMB = CHAM) %>% 
  mutate(LEAFDW = LFWTBOLE + LFWTBRAN,
         ROOTDW = SECRTWT + TAPRTWT,
         LOGBRANCHDW = log(BRANCHDW + 0.01),
         LOGLEAFDW = log(LEAFDW + 0.01),
         LOGSTEMDW = log(STEMDW + 0.01),
         LOGROOTDW = log(ROOTDW + 0.01),
         TOTALDW = BRANCHDW + LEAFDW + STEMDW + ROOTDW,
         LOGTOTALDW = log(TOTALDW + 0.01),
         VOL = INI.HT*INI.DIAM^2,
         LOGVOL_bl = log(VOL + 0.01),
         CHAMB = as_factor(CHAMB))

test_df <- tulip_pop %>% 
  group_by(CHAMB, TRT) %>% 
  summarize_at(vars(starts_with("LOG"), ends_with("DW"), VOL), mean, na.rm = TRUE) %>% 
  rename(VOL_bl = VOL, TREAT = TRT)

# Join Data -----------------------------------------------------
source("C:/Users/skoike/Desktop/tidy data/Neufeld/Seiji's Work/OZ_metrics_Neufeld.R")

exp_days <- max(oz_data$Julian) - min(oz_data$Julian) + 1

oz_metrics <- OZ_metrics_neufeld(oz_data) %>% 
  mutate_if(is.numeric, function(x){x * 92/exp_days})

harvest <- left_join(test_df, oz_metrics) %>% 
  mutate(CHAMB = as_factor(CHAMB),
         Year = 1991,
         Harvest = 2,
         Exp_days = exp_days) %>% 
  select(Year, Harvest, Exp_days, everything()) 

test_long <- full_join(tulip_pop %>% select(TRT, CHAMB, PLTNO, LOGBRANCHDW, LOGLEAFDW, LOGSTEMDW, LOGROOTDW, LOGTOTALDW, LOGVOL_bl),
                       oz_metrics)

#write.csv(test_long, "tpop_91_data.csv", row.names = FALSE)
#write.csv(harvest, "tpop_91_mean_data.csv", row.names = FALSE)

