library(tidyverse)
library(lubridate)
library(RColorBrewer)

# Read in Data ------------------------------------------------------
tpop <- read_csv("C:/Users/skoike/Desktop/tidy data/Neufeld/epa corvallis trip/trees/tulippoplar/biomass/TP92DW.csv") %>% 
  mutate(CH = as_factor(CH),
         TRT = as_factor(TRT)) %>% 
  rename(STEMDW = SHOOTDW)
tpop_vol <- read_table2("C:/Users/skoike/Desktop/tidy data/Neufeld/Seiji's Work/Tulip Poplar/TPvol.txt")
oz_data <- read_csv("C:/Users/skoike/Desktop/tidy data/Neufeld/Seiji's Work/1992_oz.csv") %>% 
  filter(between(Date, mdy("5/20/1992"), mdy("10/8/1992"))) %>% 
  mutate(Chamber = as_factor(Chamber))

# Clean Up Data -----------------------------------------------------
noNA <- function(x){ifelse(x == -99, NA, x)}
tpop <- tpop %>% 
  mutate_if(is.numeric, noNA) %>% 
  mutate(TOTALDW = ROOTDW + STEMDW + LEAFDW,
         LOGROOTDW = log(ROOTDW + 0.01),
         LOGSTEMDW = log(STEMDW + 0.01),
         LOGLEAFDW = log(LEAFDW + 0.01),
         LOGTOTAL = log(TOTALDW + 0.01))


tpop_vol_long <- tpop_vol %>% 
  select(-`SOILDEPTH-6/29`, -`DIAM-6/29-above`) %>% 
  pivot_longer(cols = names(tpop_vol)[-c(1:4, 6, 8)],
               names_to = c("Measurement", "Step"),
               names_sep = "-") %>% 
  mutate(Step = case_when(Step == "6/29" ~ "1",
                          Step == "7/17" ~ "2",
                          Step == "7/28" ~ "3",
                          Step == "8/11" ~ "4",
                          Step == "8/26" ~ "5",
                          Step == "9/9" ~ "6",
                          TRUE ~ "7"),
         Step = as.numeric(Step),
         Measurement = as_factor(Measurement)) %>% 
  pivot_wider(names_from = Measurement,
              values_from = value) %>% 
  mutate(HGT = HGT * 0.1,
         DIAM = DIAM * 0.1,
         VOL = HGT * DIAM^2,
         LOGVOL = log(VOL + 0.01),
         TREATMENT = as_factor(TREATMENT),
         CHAMBER = as_factor(CHAMBER)) %>% 
  rename(TRT = TREATMENT,
         CHAMB = CHAMBER,
         PLT = PLANTNO.)

# EDA ----------------------------------------------------------------
joined_long <- full_join(tpop %>% rename(Chamber = CH) %>% select(TRT, Chamber),
                         oz_data)

oz_fig <- joined_long %>% 
    mutate(TRT = TRT) %>% 
    ggplot() + 
    aes(x = Datetime, y = OZ, color = TRT) + 
    geom_line() + 
    facet_wrap(. ~ Chamber, nrow = 3) + 
    scale_color_brewer(palette = "Set1")

#oz_fig

tpop %>% 
  pivot_longer(cols = c(ROOTDW, STEMDW, LEAFDW),
               names_to = "Measurement",
               values_to = "DW") %>% 
  mutate(LDW = log(DW)) %>%
  ggplot() + 
  aes(x = CH, y = log(DW), fill = TRT) + 
  geom_boxplot() + 
  scale_fill_brewer(palette = "Set1") + 
  facet_wrap(. ~ Measurement)

tpop %>% 
  pivot_longer(cols = c(ROOTDW, STEMDW, LEAFDW),
               names_to = "Measurement",
               values_to = "DW") %>% 
  mutate(LDW = log(DW)) %>%
  ggplot() + 
  aes(x = TRT, y = log(DW), fill = TRT) + 
  geom_boxplot() + 
  scale_fill_brewer(palette = "Set1") + 
  facet_wrap(. ~ Measurement)

tpop_vol_long %>% 
  ggplot() + 
  aes(x = Step, y = LOGVOL, color = TRT) + 
  geom_point() + 
  geom_point(size = 2, shape = 21, color = "black") + 
  geom_line(aes(group = PLT)) + 
  scale_x_continuous(breaks = 1:7) + 
  facet_wrap(. ~ CHAMB, nrow = 3) +
  scale_color_brewer(palette = "Set1")

# Joining Data -----------------------------------------------------------------
source("C:/Users/skoike/Desktop/tidy data/Neufeld/Seiji's Work/OZ_metrics_Neufeld.R")

exp_days <- max(oz_data$Julian) - min(oz_data$Julian) + 1

oz_metrics <- OZ_metrics_neufeld(oz_data) %>% 
  mutate_if(is.numeric, function(x){x * 92/exp_days})

test_long <- tpop_vol_long %>% 
  filter(Step == 1) %>% 
  group_by(TRT, CHAMB) %>% 
  summarize_at(vars(starts_with("LOG"), ends_with("DW"), VOL), mean, na.rm = TRUE)

test_df <- tpop %>% 
  rename(CHAMB = CH) %>% 
  group_by(TRT, CHAMB) %>% 
  summarize_at(vars(starts_with("LOG"), ends_with("DW")), mean, na.rm = TRUE)

test2_df <- full_join(test_df, test_long) %>% 
  full_join(oz_metrics) %>% 
  ungroup() %>% 
  rename(LOGVOL_bl = LOGVOL, VOL_bl = VOL, TREAT = TRT, LOGTOTALDW = LOGTOTAL) %>% 
  mutate(Year = 1992,
         Harvest = 1,
         Exp_days = exp_days) %>% 
  select(Year, Harvest, Exp_days, everything())

test_long <- full_join(tpop %>% select(TRT, CH, PLT, LOGLEAFDW, LOGSTEMDW, LOGROOTDW, LOGTOTAL) %>% 
                         rename(CHAMB = CH),
                       tpop_vol_long %>% filter(Step == 1) %>% select(TRT, CHAMB, PLT, LOGVOL)) %>% 
  full_join(oz_metrics)

#write.csv(test_long, "tpop_92_data.csv", row.names = FALSE)
#write.csv(test2_df, "tpop_92_mean_data.csv", row.names = FALSE)
