library(tidyverse)
library(lubridate)

vp_vol <- read_csv("C:/Users/skoike/Desktop/tidy data/Neufeld/Seiji's Work/Virginia Pine/VPHTDM91.csv")

vp_vol_long <- vp_vol %>% 
  pivot_longer(cols = -c(trt, cham, pltno, flct0719, julbudbr, Ozone90, Ozone91),
               names_to = c(".value", "time"),
               names_pattern = "(\\w+).*?(\\d{4})") %>% 
  separate(time, into =  c("Month", "Day"), sep = 2) %>% 
  mutate(VOL = ht * dm^2,
         LOGVOL = log(VOL + 0.01), 
         Year = "1991",
         trt = as_factor(trt),
         cham = as_factor(cham),
         time = paste0(Month, "/", Day, "/", Year),
         time = mdy(time))

group_by(vp_vol_long, time) %>% tally()

vp_vol_long %>% 
  ggplot() + 
  aes(x = time, y = LOGVOL, group = pltno, color = trt) + 
  geom_line() + 
  facet_wrap(. ~ cham)

vp_vol_trunc <- vp_vol_long %>% 
  filter(time %in% c(min(.$time), max(.$time)))

vp_vol_trunc %>% 
  filter(VOL != 0) %>% 
  ggplot() + 
  aes(x = time, y = LOGVOL, group = pltno, color = trt) + 
  geom_line() + 
  facet_wrap(. ~ cham)

vp_vol_wide <- vp_vol_trunc %>% 
  mutate(harvest = ifelse(.$time == min(.$time), "bl", "h")) %>% 
  select(trt, cham, pltno, VOL, LOGVOL, harvest) %>% 
  pivot_wider(names_from = harvest, 
              values_from = c(VOL, LOGVOL))

#write.csv(vp_vol_wide, "vp_vol_91.csv", row.names = FALSE)