library(tidyverse)
library(lubridate)
library(RColorBrewer)

# Read in Data and tidy up ----------------------------------------

oz_90 <- read_csv("C:/Users/skoike/Desktop/tidy data/Neufeld/Seiji's Work/1990_oz.csv") %>%
  filter(between(Date, mdy("6/20/1990"), mdy("9/12/1990"))) %>% 
  rename(CHAMB = Chamber) %>% 
  mutate(CHAMB = as_factor(CHAMB)) 

vp_dw <- read_csv("C:/Users/skoike/Desktop/tidy data/Neufeld/Seiji's Work/Virginia Pine/VPBIO90.csv")

vp_dw <- vp_dw %>% 
  mutate(STEMDW = (FLUSH1STM + FLSUH2STM + FLUSH3STM + FLUSH4STM + FLUSH5STM)/100,
         NEEDLEDW = (WGT89 + FLUSH1 + FLUSH2 + FLUSH3 + FLUSH4 + FLUSH5)/100,
         ROOTDW = (TAPWGT + PRIMLATWT + TYPLATWT + PHOTOLATWT)/100,
         TOTALDW = STEMDW + NEEDLEDW + ROOTDW) %>% 
  select(TREATMENT, CHAMBER, PLANTNO, STEMDW, NEEDLEDW, ROOTDW, TOTALDW) %>% 
  mutate(CHAMBER = as_factor(CHAMBER),
         TREATMENT = as_factor(TREATMENT)) %>% 
  rename(CHAMB = CHAMBER)

vp_dw %>% group_by(TREATMENT, CHAMB) %>% tally()

# Ozone profiles ------------------------------------------------------

vp_long <- left_join(vp_dw, oz_90)

oz_fig <- vp_long %>% 
  ggplot() + 
  aes(x = Datetime, y = OZ/1000, color = TREATMENT) + 
  geom_line() +
  facet_wrap(. ~ CHAMB, nrow = 3) + 
  scale_color_brewer(palette = "Set1")
#oz_fig

# EDA -----------------------------------------------------------------
harvest <- vp_dw %>%
  mutate(LOGSTEMDW = log(STEMDW + 0.01),
         LOGNEEDLEDW = log(NEEDLEDW + 0.01),
         LOGROOTDW = log(ROOTDW + 0.01),
         LOGTOTALDW = log(TOTALDW + 0.01))

vp_dw_long <- harvest %>% 
  pivot_longer(cols = c(LOGSTEMDW, LOGNEEDLEDW, LOGROOTDW, LOGTOTALDW),
               names_to = "Measurement",
               values_to = "Tissue")

vp_dw_long %>% 
  ggplot() + 
  aes(x = CHAMB, y = Tissue, fill = TREATMENT) + 
  geom_boxplot() + 
  scale_fill_brewer(palette = "Set1") + 
  facet_wrap(. ~ Measurement)

vp_dw_long %>% 
  ggplot() + 
  aes(x = TREATMENT, y = Tissue, fill = TREATMENT) + 
  geom_boxplot() + 
  guides(fill = FALSE) + 
  scale_fill_brewer(palette = "Set1") + 
  facet_wrap(. ~ Measurement)

test_df <- harvest %>% 
  group_by(TREATMENT, CHAMB) %>% 
  summarize_at(vars(starts_with("LOG"), ends_with("DW")), mean, na.rm = TRUE)

exp_days <- as.numeric(max(oz_90$Date) - min(oz_90$Date) + 1)

source("C:/Users/skoike/Desktop/tidy data/Neufeld/Seiji's Work/OZ_metrics_Neufeld.R")

oz_90_metrics <- OZ_metrics_neufeld(oz_90 %>% rename(Chamber = CHAMB)) %>% 
  mutate(CHAMB = as_factor(CHAMB)) %>% 
  mutate_if(is.numeric, function(x){x * 92/exp_days})

test_long <- full_join(harvest %>% select(TREATMENT, CHAMB, PLANTNO, LOGSTEMDW, LOGNEEDLEDW, LOGROOTDW, LOGTOTALDW),
                       oz_90_metrics)

test2_df <- left_join(test_df, oz_90_metrics) %>% 
  mutate(Year = 1990,
         Harvest = 1,
         Exp_days = exp_days) %>% 
  select(Year, Harvest, Exp_days, everything())

#write.csv(test_long, "vpine_90_data.csv", row.names = FALSE)
#write.csv(test2_df, "vpine_90_mean_data.csv", row.names = FALSE)
