library(tidyverse)
library(lubridate)
library(RColorBrewer)

oz_91 <- read_csv("C:/Users/skoike/Desktop/tidy data/Neufeld/Seiji's Work/Virginia Pine/oz_91_data.csv") %>% 
  filter(between(Date, mdy("5/6/1991"), mdy("9/23/1991"))) %>% 
  rename(CHAMB = Chamber) %>% 
  mutate(CHAMB = as_factor(CHAMB))

vp_dw <- read_csv("C:/Users/skoike/Desktop/tidy data/Neufeld/Seiji's Work/Virginia Pine/VPBIO91.csv")
vp_vol <- read_csv("C:/Users/skoike/Desktop/tidy data/Neufeld/Seiji's Work/Virginia Pine/vp_vol_91.csv")

vp_dw <- vp_dw %>% 
  filter(!is.na(trt)) %>%
  mutate_if(is.character, as.numeric) %>% 
  mutate(STEMDW = BoleWt/1000,
         BRANCHDW = TotBrWt/1000,
         ROOTDW = rootwt/1000, 
         NEEDLEDW = (Needles90 + Needles91)/1000,
         TOTALDW = STEMDW + BRANCHDW + ROOTDW, NEEDLEDW,
         LOGSTEMDW = log(STEMDW + 0.01),
         LOGBRANCHDW = log(BRANCHDW + 0.01),
         LOGROOTDW = log(ROOTDW + 0.01),
         LOGNEEDLEDW = log(NEEDLEDW + 0.01),
         LOGTOTALDW = log(TOTALDW + 0.01)) %>% 
  select(trt, cham, pltno, LOGSTEMDW, LOGBRANCHDW, LOGROOTDW, LOGNEEDLEDW, LOGTOTALDW,
         STEMDW, BRANCHDW, ROOTDW, NEEDLEDW, TOTALDW)

harvest <- left_join(vp_dw, vp_vol) %>% 
  rename(Trt = trt, CHAMB = cham) %>% 
  mutate(Trt = factor(Trt, levels = 0:5),
         CHAMB = factor(CHAMB))
  
# EDA ----------------------------------------------------------------------------------

oz_by_date <- oz_91 %>% 
  left_join(harvest) %>% 
  filter(CHAMB %in% unique(harvest$CHAMB)) %>% 
  ggplot() + 
  aes(x = Datetime, y = OZ/1000, color = Trt) + 
  geom_line() + 
  scale_color_brewer(palette = "Set1") +
  facet_wrap(. ~ factor(CHAMB), nrow = 3)

#oz_by_date

# Box plots ----------------------------------------------------
harvest %>% 
  ggplot() + 
  aes(x = factor(Trt), y = LOGBRANCHDW, fill = Trt) + 
  scale_fill_brewer(palette = "Set1") + 
  labs(fill = FALSE) +
  geom_boxplot()
harvest %>% 
  ggplot() + 
  aes(x = Trt, y = LOGNEEDLEDW, fill = Trt) + 
  scale_fill_brewer(palette = "Set1") + 
  labs(fill = FALSE) +
  geom_boxplot()
harvest %>% 
  ggplot() + 
  aes(x = Trt, y = LOGROOTDW, fill = Trt) + 
  scale_fill_brewer(palette = "Set1") + 
  labs(fill = FALSE) +
  geom_boxplot()
harvest %>% 
  ggplot() + 
  aes(x = Trt, y = LOGSTEMDW, fill = Trt) + 
  scale_fill_brewer(palette = "Set1") + 
  labs(fill = FALSE) +
  geom_boxplot()
harvest %>% 
  ggplot() + 
  aes(x = Trt, y = LOGTOTALDW, fill = Trt) + 
  scale_fill_brewer(palette = "Set1") + 
  labs(fill = FALSE) +
  geom_boxplot()

harvest %>% 
  ggplot() + 
  aes(x = LOGVOL_bl, y = LOGVOL_h, fill = Trt) + 
  geom_point(shape = 21, color = "black", size = 2) + 
  geom_smooth(method = "lm", se = FALSE, aes(color = Trt)) + 
  scale_color_brewer(palette = "Set1") + 
  scale_fill_brewer(palette = "Set1")


test_df <- harvest %>% 
  group_by(Trt, CHAMB) %>% 
  summarize_at(vars(starts_with("LOG"), ends_with("DW"), VOL_bl), mean, na.rm = TRUE)

exp_days <- as.numeric(max(oz_91$Date) - min(oz_91$Date) + 1)

source("C:/Users/skoike/Desktop/tidy data/Neufeld/Seiji's Work/OZ_metrics_Neufeld.R")

oz_91_metrics <- OZ_metrics_neufeld(oz_91 %>% rename(Chamber = CHAMB)) %>% 
  mutate(CHAMB = as_factor(CHAMB)) %>% 
  mutate_if(is.numeric, function(x){x * 92/exp_days})

test_long <- left_join(harvest, oz_91_metrics)

test2_df <- left_join(test_df, oz_91_metrics %>% mutate(CHAMB = as_factor(CHAMB))) %>% 
  mutate(Year = 1991,
         Harvest = 2,
         Exp_days = exp_days) %>% 
  select(Year, Harvest, Exp_days, everything(), -LOGVOL_h)

#write.csv(test_long, "vpine_91_data.csv", row.names = FALSE)
#write.csv(test2_df, "vpine_91_mean_data.csv", row.names = FALSE)
