library(tidyverse)
library(lubridate)

oz_92 <- read_csv("C:/Users/skoike/Desktop/tidy data/Neufeld/Seiji's Work/1992_oz.csv") %>% 
  filter(between(Date, mdy("5/4/1992"), mdy("10/9/1992"))) %>% 
  rename(CHAMB = Chamber) %>% 
  mutate(CHAMB = as_factor(CHAMB)) 

vp1 <- read_table("C:/Users/skoike/Desktop/tidy data/Neufeld/Seiji's Work/Virginia Pine/vp1.txt")
vp2 <- read_table("C:/Users/skoike/Desktop/tidy data/Neufeld/Seiji's Work/Virginia Pine/vp2.txt")
vp3 <- read_table("C:/Users/skoike/Desktop/tidy data/Neufeld/Seiji's Work/Virginia Pine/vp3.txt")
vpine_dw <- full_join(vp1, vp2) %>% 
  full_join(vp3)
vpine_vol <- read_table2("C:/Users/skoike/Desktop/tidy data/Neufeld/Seiji's Work/Virginia Pine/VPvol.txt")

vpine_dw %>% group_by(CH92, PLT) %>% tally()
vpine_vol %>% group_by(CHAMBER, PLANT) %>% tally()

noNA <- function(x){ifelse(x == -999 | x < 0, NA, x)}

vpine_dw %>% select(NEEDLEW, LEAFW)

vpine <- vpine_dw %>% 
  select(CH92, OZ92, PLT, ROOTW, NEEDLEW, STEMW, BRANCHW, TOTALDW) %>%
  rename(CHAMB = CH92,
         PLANT = PLT,
         Trt = OZ92,
         ROOTDW = ROOTW,
         NEEDLEDW = NEEDLEW,
         STEMDW = STEMW,
         BRANCHDW = BRANCHW) %>% 
  mutate(LOGROOTDW = log(ROOTDW + 0.01),
         LOGNEEDLEDW = log(NEEDLEDW + 0.01),
         LOGSTEMDW = log(STEMDW + 0.01), 
         LOGBRANCHDW = log(BRANCHDW + 0.01),
         LOGTOTALDW = log(TOTALDW + 0.01)) %>% 
  mutate(CHAMB = as_factor(CHAMB),
         Trt = as_factor(Trt),
         PLANT = as_factor(PLANT))

vpine_vol_long <- vpine_vol %>% 
  pivot_longer(cols = names(vpine_vol)[-c(1:4)],
               names_to = c("Measurement", "Step"),
               names_sep = "-") %>% 
  mutate(Step = case_when(Step == "5/5" ~ "1",
                          Step == "6/5" ~ "2",
                          Step == "6/26" ~ "3",
                          Step == "7/17" ~ "4",
                          Step == "7/29" ~ "5",
                          Step == "8/11" ~ "6",
                          Step == "8/25" ~ "7",
                          TRUE ~ "8"),
         Step = as.numeric(Step),
         Measurement = as_factor(Measurement)) %>% 
  mutate(value = noNA(value)) %>% 
  pivot_wider(names_from = Measurement,
              values_from = value) %>% 
  mutate(HGT = HGT * 0.1,
         DIAM = DIAM * 0.1, 
         VOL = HGT * DIAM^2,
         LOGVOL = log(VOL + 0.01),
         TREATMENT = as_factor(TREATMENT),
         CHAMBER = as_factor(CHAMBER),
         PLANT = as_factor(PLANT)) %>% 
  rename(Trt = TREATMENT,
         CHAMB = CHAMBER) %>% 
  filter(Trt != 0) %>% 
  droplevels()

vpine_vol_wide <- vpine_vol_long %>% 
  filter(Step %in% c(1, 8)) %>% 
  pivot_wider(names_from = Step,
              values_from = c(HGT, DIAM, VOL, LOGVOL)) %>% 
  select(Trt, CHAMB, PLANT, VOL_1, LOGVOL_1, LOGVOL_8) %>% 
  rename(VOL_bl = VOL_1, 
         LOGVOL_bl = LOGVOL_1,
         LOGVOL_h = LOGVOL_8)

vpine <- left_join(vpine, vpine_vol_wide %>% select(-Trt), by = c("CHAMB", "PLANT"))

# EDA ----------------------------------------------------------------------
oz_chamb <- left_join(vpine %>% select(CHAMB, Trt), oz_92)
oz_fig <- oz_chamb %>% 
  filter(CHAMB %in% c(2, 6)) %>% 
  ggplot() +
  aes(x = Datetime, y = OZ/1000, color = Trt) +
  geom_line() + 
  scale_color_brewer(palette = "Set1") + 
  facet_wrap(. ~ CHAMB, nrow = 3)
#oz_fig

vpine %>% 
  ggplot() + 
  aes(x = CHAMB, y = LOGROOTDW, fill = Trt) + 
  geom_boxplot() +
  scale_fill_brewer(palette = "Set1")
vpine %>% 
  ggplot() + 
  aes(x = CHAMB, y = LOGNEEDLEDW, fill = Trt) + 
  geom_boxplot() +
  scale_fill_brewer(palette = "Set1")
vpine %>% 
  ggplot() + 
  aes(x = CHAMB, y = LOGSTEMDW, fill = Trt) + 
  geom_boxplot() +
  scale_fill_brewer(palette = "Set1")
vpine %>% 
  ggplot() + 
  aes(x = CHAMB, y = LOGBRANCHDW, fill = Trt) + 
  geom_boxplot() +
  scale_fill_brewer(palette = "Set1")
vpine %>% 
  ggplot() + 
  aes(x = CHAMB, y = LOGTOTALDW, fill = Trt) + 
  geom_boxplot() +
  scale_fill_brewer(palette = "Set1")

vpine_vol_long %>% 
  ggplot() + 
  aes(x = Step, y = LOGVOL, color = Trt) +
  geom_line(aes(group = PLANT)) + 
  scale_colour_brewer(palette = "Set1") +
  facet_wrap(. ~ CHAMB, nrow = 3)

vpine %>% 
  ggplot() + 
  aes(x = LOGVOL_bl, y = LOGROOTDW, color = Trt) + 
  geom_point() + 
  geom_point(size = 2, shape = 21, color = "black") + 
  geom_smooth(method = "lm", se = FALSE, aes(group = 1), color = "black") + 
  geom_smooth(method = "lm", se = FALSE, linetype = "dashed", size = 0.75) + 
  scale_color_brewer(palette = "Set1")
vpine %>% 
  ggplot() + 
  aes(x = LOGVOL_bl, y = LOGNEEDLEDW, color = Trt) + 
  geom_point() + 
  geom_point(size = 2, shape = 21, color = "black") +
  geom_smooth(method = "lm", se = FALSE, aes(group = 1), color = "black") + 
  geom_smooth(method = "lm", se = FALSE, linetype = "dashed", size = 0.75) +
  scale_color_brewer(palette = "Set1")
vpine %>% 
  ggplot() + 
  aes(x = LOGVOL_bl, y = LOGSTEMDW, color = Trt) + 
  geom_point() + 
  geom_point(size = 2, shape = 21, color = "black") +
  geom_smooth(method = "lm", se = FALSE, aes(group = 1), color = "black") + 
  geom_smooth(method = "lm", se = FALSE, linetype = "dashed", size = 0.75) +
  scale_color_brewer(palette = "Set1")
vpine %>% 
  ggplot() + 
  aes(x = LOGVOL_bl, y = LOGBRANCHDW, color = Trt) + 
  geom_point() + 
  geom_point(size = 2, shape = 21, color = "black") +
  geom_smooth(method = "lm", se = FALSE, aes(group = 1), color = "black") + 
  geom_smooth(method = "lm", se = FALSE, linetype = "dashed", size = 0.75) +
  scale_color_brewer(palette = "Set1")
vpine %>% 
  ggplot() + 
  aes(x = LOGVOL_bl, y = LOGTOTALDW, color = Trt) + 
  geom_point() + 
  geom_point(size = 2, shape = 21, color = "black") +
  geom_smooth(method = "lm", se = FALSE, aes(group = 1), color = "black") + 
  geom_smooth(method = "lm", se = FALSE, linetype = "dashed", size = 0.75) +
  scale_color_brewer(palette = "Set1")

vpine %>% 
  ggplot() + 
  aes(x = Trt, y = LOGROOTDW, fill = Trt) + 
  geom_boxplot() +
  scale_fill_brewer(palette = "Set1") + 
  theme(legend.position = "none")
vpine %>% 
  ggplot() + 
  aes(x = Trt, y = LOGNEEDLEDW, fill = Trt) + 
  geom_boxplot() +
  scale_fill_brewer(palette = "Set1") + 
  theme(legend.position = "none")
vpine %>% 
  ggplot() + 
  aes(x = Trt, y = LOGSTEMDW, fill = Trt) + 
  geom_boxplot() +
  scale_fill_brewer(palette = "Set1") + 
  theme(legend.position = "none")
vpine %>% 
  ggplot() + 
  aes(x = Trt, y = LOGBRANCHDW, fill = Trt) + 
  geom_boxplot() +
  scale_fill_brewer(palette = "Set1") + 
  theme(legend.position = "none")
vpine %>% 
  ggplot() + 
  aes(x = Trt, y = LOGTOTALDW, fill = Trt) + 
  geom_boxplot() +
  scale_fill_brewer(palette = "Set1") + 
  theme(legend.position = "none")

# Joining Data ---------------------------------------------------------------

test_df <- vpine %>% 
  group_by(Trt, CHAMB) %>% 
  summarize_at(vars(starts_with("LOG"), ends_with("DW"), VOL_bl), mean, na.rm = TRUE) 

exp_days <- max(oz_92$Julian) - min(oz_92$Julian) + 1 #159

source("C:/Users/skoike/Desktop/tidy data/Neufeld/Seiji's Work/OZ_metrics_Neufeld.R")

oz_92_metrics <- OZ_metrics_neufeld(oz_92 %>% 
                              rename(Chamber = CHAMB) %>% 
                              mutate(OZ = ifelse(Julian == 125 & Chamber %in% c(2, 12, 15) & Hour == hms::hms(hours = 8), NA, OZ))) %>% 
  mutate_if(is.numeric, function(x){x * 92/exp_days})

test_long <- left_join(vpine %>% select(CHAMB, PLANT, Trt, starts_with("LOG")),
                       oz_92_metrics)

test2_df <- left_join(test_df, oz_92_metrics) %>% 
  mutate(Year = 1992,
         Harvest = 1,
         Exp_days = exp_days) %>% 
  select(Year, Harvest, Exp_days, everything(), -LOGVOL_h)

#write.csv(test_long, "vpine_92_data.csv", row.names = FALSE)
#write.csv(test2_df, "vpine_92_mean_data.csv", row.names = FALSE)
