# Read in Data ---------------------------

library(tidyverse)
library(RColorBrewer)
library(lubridate)

yellowbeye <- read_table2("C:/Users/skoike/Desktop/tidy data/Neufeld/Seiji's Work/Yellow Buckeye/yellowbeye.txt") %>%
  mutate_if(is.numeric, function(x){ifelse(x < 0, NA, x)}) %>% 
  rename(LEAFDW = LEAFWGT,
         STEMDW = STEMWGT,
         ROOTDW = ROOTWGT,
         Trt = TREATMENT,
         CHAMB = CHAMBER) %>% 
  mutate(TOTALDW = LEAFDW + STEMDW + ROOTDW,
         LOGLEAFDW = log(LEAFDW + 0.01),
         LOGSTEMDW = log(STEMDW + 0.01),
         LOGROOTDW = log(ROOTDW + 0.01),
         LOGTOTALDW = log(TOTALDW + 0.01),
         Trt = as_factor(Trt),
         CHAMB = as_factor(CHAMB)) 

yellowbeye %>% group_by(Trt, CHAMB) %>% tally()

yellowbeye %>% 
  group_by(Trt, CHAMB) %>% 
  summarise(m = mean(TOTALDW, na.rm = TRUE),
            s = sd(TOTALDW, na.rm = TRUE)) %>% 
  arrange(desc(m))

oz_data <- read_csv("C:/Users/skoike/Desktop/tidy data/Neufeld/Seiji's Work/1990_oz.csv") %>% 
  mutate(Chamber = as_factor(Chamber)) %>% 
  filter(between(Date, mdy("06/30/1990"), mdy("07/30/1990")),
         Chamber %in% unique(yellowbeye$CHAMB)) %>% 
  droplevels()

harvest_long <- right_join(yellowbeye, oz_data %>% rename(CHAMB = Chamber))

# EDA ------------------------------------------------------------

oz_by_date <- harvest_long %>% 
  ggplot() + 
  aes(x = Datetime, y = OZ/1000, color = Trt) + 
  geom_line() + 
  scale_color_brewer(palette = "Set1") +
  facet_wrap(. ~ factor(CHAMB), nrow = 3)

#oz_by_date

# Box plots ----------------------------------------------------
yellowbeye %>% 
  ggplot() + 
  aes(x = factor(Trt), y = LOGLEAFDW, fill = Trt) + 
  scale_fill_brewer(palette = "Set1") + 
  guides(fill = FALSE) +
  geom_boxplot()
yellowbeye %>% 
  ggplot() + 
  aes(x = factor(Trt), y = LOGROOTDW, fill = Trt) + # One root bad
  scale_fill_brewer(palette = "Set1") + 
  guides(fill = FALSE) +
  geom_boxplot()
yellowbeye %>% 
  ggplot() + 
  aes(x = factor(Trt), y = LOGSTEMDW, fill = Trt) + 
  scale_fill_brewer(palette = "Set1") + 
  guides(fill = FALSE) +
  geom_boxplot()
yellowbeye %>% 
  ggplot() + 
  aes(x = factor(Trt), y = LOGTOTALDW, fill = Trt) + 
  scale_fill_brewer(palette = "Set1") + 
  guides(fill = FALSE) +
  geom_boxplot()

# Scatter Plots -----------------------------------------

test_df <- yellowbeye %>% 
  group_by(Trt, CHAMB) %>% 
  summarise_at(vars(starts_with("LOG"), ends_with("DW")), mean, na.rm = TRUE)


yellowbeye %>% 
  group_by(Trt) %>% 
  summarize(avg = mean(LOGTOTALDW, na.rm = TRUE),
            s = sd(LOGTOTALDW, na.rm = TRUE))

yellowbeye %>% 
  ggplot(aes(x = CHAMB, y = LOGLEAFDW, color = Trt, label = PLANTNO)) + 
  geom_text() + 
  scale_color_brewer(palette = "Set1")
yellowbeye %>% 
  ggplot(aes(x = CHAMB, y = LOGSTEMDW, color = Trt, label = PLANTNO)) + 
  geom_text() + 
  scale_color_brewer(palette = "Set1")
yellowbeye %>% 
  ggplot(aes(x = CHAMB, y = LOGROOTDW, color = Trt, label = PLANTNO)) + 
  geom_text() + 
  scale_color_brewer(palette = "Set1")
yellowbeye %>% 
  ggplot(aes(x = CHAMB, y = LOGTOTALDW, color = Trt, label = PLANTNO)) + 
  geom_text() + 
  scale_color_brewer(palette = "Set1")



source("C:/Users/skoike/Desktop/tidy data/Neufeld/Seiji's Work/OZ_metrics_Neufeld.R")

exp_days <- as.numeric(max(oz_data$Date) - min(oz_data$Date) + 1)

oz_90 <- OZ_metrics_neufeld(oz_data %>% mutate(Chamber = as_factor(Chamber))) %>% 
  mutate(CHAMB = as_factor(CHAMB)) %>% 
  mutate_if(is.numeric, function(x){x * 92/exp_days})

harvest <- right_join(test_df, oz_90) %>% 
  mutate(Year = 1990,
         Harvest = 1,
         Exp_days = exp_days) %>% 
  select(Year, Harvest, Exp_days, everything())

#write.csv(harvest, "yellowbeye_mean_data.csv", row.names = FALSE)

ggplot(harvest) + 
  aes(x = w126.12.8.adj, y = LOGTOTALDW) + 
  geom_point(aes(fill = Trt), shape = 21, size = 3)
