library(tidyverse)

# Read in predictive curve
DF <- read_csv("C:/Users/skoike/Desktop/Reanalysis/Douglas Fir/df_lines.csv")

# Read Parametric CI

para_ci <- read_csv("C:/Users/skoike/Desktop/Reanalysis/Douglas Fir/df_para_ci_combined_harvest.csv") %>% 
  mutate(ymin = ifelse(ymin < 0, 0, ymin)) %>% 
  arrange(x) 


new_pred <- data.frame(x = DF$x, new_ymin = 0)

# smooth out ymin
f <- function(x, a, b){
  a * x^b
}


plot(para_ci$x, para_ci$ymax)

y_upper_fcn <- minpack.lm::nlsLM(ymax ~ f(x, a, b), data = para_ci, start = list(a = 1, b = 1),
                                 control = nls.control(maxiter = 100))
new_ymax <- predict(y_upper_fcn, newdata = new_pred)
new_pred$new_ymax <- new_ymax

lines(new_pred$x, new_pred$new_ymax)

new_pred2 <- new_pred %>% 
  mutate_at(vars(-x), function(x){x*100})

ci_plot <- ggplot(new_pred2) +  
  aes(x = x) + 
  geom_ribbon(aes(ymin = new_ymin, ymax = new_ymax), alpha = 0.3) +
  geom_line(data = DF, aes(x = x, y = 100*(1 - exp(y))), size = 1, color = "blue") + 
  ylab("Predicted Relative Biomass Loss (%)") + 
  xlab("W126 (ppm-h)") 
ci_plot

# Export data for grid plot
#ggplot_build(ci_plot) data[[1]] has band info, data[[2]] has predicted curve

bands <- ggplot_build(ci_plot)$data[[1]] %>% select(x, ymin, ymax) %>% mutate(x = round(x, 7))
pred_curve <- ggplot_build(ci_plot)$data[[2]] %>% select(x, y) %>% mutate(x = round(x, 7))

df_info <- full_join(bands, pred_curve) %>% 
  mutate(Species = factor("Douglas Fir")) %>% 
  select(Species, x, y, ymin, ymax)

#write.csv(df_info, "df_bands.csv", row.names = FALSE)

