library(tidyverse)

study_13 <- read_csv("C:/Users/skoike/Desktop/Reanalysis/Douglas Fir/13_h2_mean_data.csv") %>% 
  mutate(Study = factor("Study 13"), .before = 1) %>% 
  rename(NEEDLEDW = TNDW,
         CHAMB = CH) 
study_35 <- read_csv("C:/Users/skoike/Desktop/Reanalysis/Douglas Fir/35_h2_mean_data.csv") %>% 
  mutate(Study = factor("Study 35"), .before = 1) %>% 
  rename(CHAMB = CH)

studies_h2 <- full_join(study_13, study_35) %>%  
  select(Harvest, Study, CHAMB, OZ, LOGNEEDLEDW, LOGSTEMDW, LOGROOTDW, LOGTOTALDW, LOGVOL_bl, everything()) %>% 
  mutate(Species = "Douglas-fir", .before = 1)

studies_h2 %>% 
  ggplot() + 
  aes(x = w126.12.8.adj, y = LOGTOTALDW, fill = Study, color = Study, size = LOGVOL_bl) + 
  geom_point(shape = 21, color = "black") + 
  scale_fill_brewer(palette = "Set1") + 
  scale_color_brewer(palette = "Set1") +
  geom_smooth(method = "lm", se = FALSE) + 
  guides(size = FALSE)


# Combine the studies ----------------------------------------------------------------

study_13 <- read_csv("C:/Users/skoike/Desktop/Reanalysis/Douglas Fir/13_h1_mean_data.csv") %>% 
  mutate(Study = factor("Study 13"), .before = 1) %>% 
  rename(NEEDLEDW = TNDW, 
         CHAMB = CH) 
study_35 <- read_csv("C:/Users/skoike/Desktop/Reanalysis/Douglas Fir/35_h1_mean_data.csv") %>% 
  mutate(Study = factor("Study 35"), .before = 1) %>% 
  rename(CHAMB = CH)

studies_h1 <- full_join(study_13, study_35) %>% 
  mutate(Species = "Douglas-fir", .before = 1)

studies_h1 %>% 
  ggplot() + 
  aes(x = w126.12.8.adj, y = LOGTOTALDW, fill = Study, color = Study, size = LOGVOL_bl) + 
  geom_point(shape = 21, color = "black") + 
  scale_fill_brewer(palette = "Set1") + 
  scale_color_brewer(palette = "Set1") +
  geom_smooth(method = "lm", se = FALSE) + 
  guides(size = FALSE)



DF <- full_join(studies_h1, studies_h2) %>% 
  mutate(Site = "FERF") %>% 
  rename(TREAT = OZ)

DF %>% 
  mutate(W126 = w126.12.8.adj*Exp_days/92) %>% 
  group_by(Study, Harvest, Site, TREAT) %>% 
  summarise(m = round(mean(W126), 1)) %>% 
  arrange(Study, Harvest, m)


DF <- DF %>% 
  group_by(Study, Harvest) %>% 
  mutate(is_35 = ifelse(Study == "Study 35", 1, 0),
         is_h2 = ifelse(Harvest == 2, 1, 0),
         centered_logvol = LOGVOL_bl - mean(LOGVOL_bl))

DF1 <- DF %>% 
  select(Species, Study, Site, Year, Harvest, Exp_days, CHAMB, TREAT, 
         ends_with("DW"), is_35, is_h2, centered_logvol, everything(), -LOGVOL_h) 

names(DF1)

#write.csv(DF, "df_chamber_mean_data.csv", row.names = FALSE)

ggplot(DF) + 
  aes(x = w126.12.8.adj, y = LOGTOTALDW, color = Study, shape = factor(Harvest)) + 
  geom_point() + 
  geom_smooth(method = "lm", se = FALSE)

ggplot(DF) + 
  aes(x = LOGVOL_bl, y = LOGTOTALDW, color = Study, shape = factor(Harvest)) + 
  geom_point() + 
  geom_smooth(method = "lm", se = FALSE)


ggplot(DF) + 
  aes(x = centered_logvol, y = LOGTOTALDW, color = Study, shape = factor(Harvest)) + 
  geom_point() + 
  geom_smooth(method = "lm", se = FALSE)

DF <- DF %>% select(Study, Harvest, centered_logvol, LOGVOL_bl, LOGTOTALDW, w126.12.8.adj, is_35, is_h2)

# Looks like Harvest 1 has significant logvol effects

library(lme4)

# Model 0: Common Logvol, C Estimated
nlform0 <- ~ log(a1 + a2*is_h2 + a3*is_h2*is_35 + d*centered_logvol) + (-(x/b)^c)

nlfun0 <- deriv(nlform0,
                namevec = c("a1", "a2", "a3", "b", "c", "d"),
                function.arg = c("x", "is_h2", "is_35", "centered_logvol", "a1", "a2", "a3", "b", "c", "d"))

nl0 <- nlmer(LOGTOTALDW ~ nlfun0(w126.12.8.adj, is_h2, is_35, centered_logvol, a1, a2, a3, b, c, d) ~ (a1 |Study) + (b|Study),
             data = DF, 
             control = nlmerControl(optimizer = "bobyqa",
                                    tolPwrss = 1e-9,
                                    optCtrl = list(maxfun = 2e5)),
             start = c(a1 = 1, a2 = 1, a3 = 1, b = 1, c = 1, d = 1))
summary(nl0) #b = 209, c = 2.5


# Model 1: Separate B and C by harvest
nlform1 <- ~ log(a1 + a2*is_h2 + a3*is_h2*is_35 + d*centered_logvol) + (-(x/(b + b2*is_h2))^(c + c2*is_h2))

nlfun1 <- deriv(nlform1,
                namevec = c("a1", "a2", "a3", "b", "b2", "c", "c2", "d"),
                function.arg = c("x", "is_h2", "is_35", "centered_logvol", "a1", "a2", "a3", "b", "b2", "c", "c2", "d"))

nl1 <- nlmer(LOGTOTALDW ~ nlfun1(w126.12.8.adj, is_h2, is_35, centered_logvol, a1, a2, a3, b, b2, c, c2, d) ~ (a1|Study) + (b|Study),
             data = DF, 
             control = nlmerControl(optimizer = "bobyqa",
                                    tolPwrss = 1e-9,
                                    optCtrl = list(maxfun = 2e5)),
             start = c(a1 = 1, a2 = 1, a3 = 1, b = 100, b2 = 1, c = 1, c2 = 1, d = 1))
summary(nl1) #b1 = 231, b2 = -39, c1 = 2.47, c2 = -0.04

lmtest::lrtest(nl0, nl1)

# Figure -------------------------------------------------------------------------------
nlform0
(coef_mod <- fixef(nl0))

DF1 <- DF %>% 
  mutate(adj_y = LOGTOTALDW - log(coef_mod[1]+ coef_mod[2]*is_h2 + coef_mod[3]*is_h2*is_35 + coef_mod[6]*centered_logvol))

pred1 <- tibble(w126.12.8.adj = c(seq(0, max(DF$w126.12.8.adj), by = 0.5), max(DF$w126.12.8.adj)),
                adj_y = -(w126.12.8.adj/coef_mod[4])^coef_mod[5])

DF_plot <- ggplot(DF1) + 
  aes(x = w126.12.8.adj, y = adj_y) + 
  geom_point(size = 2, aes(shape = factor(Harvest), fill = Study)) + 
  geom_line(data = pred1, size = 1) + 
  scale_shape_manual(values = c(21, 24)) + 
  scale_fill_brewer(palette = "Set1") + 
  guides(fill = guide_legend(override.aes = list(shape = 21)))

DF_plot

a <- round(100*(1 - exp(-(seq(10, 80, by = 10)/coef_mod[4])^coef_mod[5])), 1)

a

w126_frame <- DF %>% 
  group_by(Study, Harvest) %>% 
  summarize(min_w126 = min(w126.12.8.adj),
            max_w126 = max(w126.12.8.adj)) %>% 
  mutate(x = map2(min_w126, max_w126, seq, by = 0.01)) %>% 
  unnest(cols = x) 

coef_frame <- coef(nl0)[1] %>% 
  as.data.frame() %>% 
  rownames_to_column("Study") %>% 
  select(Study, ends_with("b"), ends_with("c")) %>% 
  rename(b = Study.b, c = Study.c)

DF_lines <- full_join(w126_frame, coef_frame) %>% 
  mutate(y = -(x/b)^c)

nlform0

intercept_frame <- coef(nl0)[1] %>% 
  as.data.frame() %>% 
  rownames_to_column("Study") %>% 
  select(Study, Study.a1, Study.a2, Study.a3, Study.d) %>% 
  rename(a1 = Study.a1, 
         a2 = Study.a2,
         a3 = Study.a3,
         d = Study.d)


DF_points <- full_join(DF, intercept_frame) %>% 
  mutate(adj_y = LOGTOTALDW - log(a1 + a2*is_h2 + a3*is_h2*is_35 + d*centered_logvol))

DF_sub <- DF %>% select(Study, Harvest) %>% mutate(Model = factor("Population"))

pred1_a <- pred1 %>% 
  mutate(Model = factor("Population")) %>% 
  full_join(DF_sub) %>% 
  rename(x = w126.12.8.adj, y = adj_y)

DF_lines <- DF_lines %>% mutate(Model = factor("Individual"))

pred <- full_join(DF_lines, pred1_a)

ggplot(DF_points) + 
  aes(x = w126.12.8.adj, y = adj_y) + 
  geom_point(size = 2, aes(shape = factor(Harvest), fill = Study)) + 
  geom_line(data = pred1, linetype = "dashed", size = 1) + 
  scale_shape_manual(values = c(21, 24)) + 
  scale_fill_brewer(palette = "Set1") + 
  scale_color_brewer(palette = "Set1") + 
  guides(fill = guide_legend(override.aes = list(shape = 21))) + 
  facet_wrap(. ~ Study) + 
  geom_line(data = DF_lines, aes(x = x, y = y, color = Study), size = 1)

ggplot(DF_points) + 
  aes(x = w126.12.8.adj, y = adj_y) + 
  geom_point(size = 2, aes(shape = factor(Harvest), fill = Study)) + 
  scale_shape_manual(values = c(21, 24)) + 
  scale_fill_brewer(palette = "Set1") + 
  guides(fill = guide_legend(override.aes = list(shape = 21)),
         shape = FALSE) + 
  facet_wrap(. ~ Harvest) + 
  geom_line(data = pred %>% filter(Model != "Individual"), aes(x = x, y = y, linetype = Model), color = "black", size = 0.8) + 
  geom_line(data = pred %>% filter(Model == "Individual"), aes(x = x, y = y, linetype = Model, color = Study), size = 1) + 
  scale_color_brewer(palette = "Set1") + 
  labs(x = "W126 (ppm-h)", y = "Adjusted Log Dry Weight (g)") + 
  theme_bw() +
  theme(text = element_text(size = 16),
        panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(),
        strip.background = element_blank())

DF_points

y_hat <- -(DF_points$w126.12.8.adj/coef_mod[4])^coef_mod[5]
y <- DF_points$adj_y

plot(y, y_hat)
abline(a = 0, b = 1)

SSRes <- sum((y - y_hat)^2)
SSTot <- sum((y - mean(y))^2)

1 - SSRes/SSTot

mean((y - y_hat)^2) 


#write.csv(DF_points, "df_figure_points.csv", row.names = FALSE)
#write.csv(pred, "df_figure_pred.csv", row.names = FALSE)

df_lines <- ggplot_build(DF_plot)$data[[2]] %>% 
  select(x, y) %>% 
  mutate(Species = factor("Douglas Fir"))

#write.csv(df_lines, "df_lines.csv", row.names = FALSE)

df_b <- tibble(b = coef_mod[4], c = coef_mod[5], Species = "Douglas Fir")

#write.csv(df_b, "df_params.csv", row.names = FALSE)
#write.csv(coef_mod, "df_all_params.csv")

# Likelihood Confidence Interval -----------------------------------------------

# Step 1: Pull out relevant variables so we don't have to refer to data 

y <- DF$LOGTOTALDW
x <- DF$w126.12.8.adj
Study <- DF$Study
is_h2 <- DF$is_h2
is_35 <- DF$is_35
logvol <- DF$centered_logvol

# Step 2: Reparameterize the model so we can create a confidence interval around predicted biomass loss (theta)
nlform0
fixef(nl0)

#Use Taylor series for convergence

nlform_k <- ~ log(a1 + a2*is_h2 + a3*is_h2*is_35 + d*logvol) + 
  ((x/x0)^2.463842 * 
     (log(0.5) - 
        2*(theta - 0.5)^1 - 
        2*(theta - 0.5)^2 - 
        2.66666666666667*(theta - 0.5)^3 - 
        4*(theta - 0.5)^4 - 
        6.4*(theta - 0.5)^5 - 
        10.6666666666667*(theta - 0.5)^6 - 
        18.2857142857143*(theta - 0.5)^7))

nlfun_k <- deriv(nlform_k,
                 namevec = c("a1", "a2", "a3", "d", "theta"),
                 function.arg = c("x", "x0", "logvol", "is_h2", "is_35", "a1", "a2", "a3", "d", "theta"))

# Step 3: At every break (e.g. 10, 20, 30, etc.), run the model at that fixed point, varying the value of theta


breaks <- c(seq(10, max(x), by = 5), max(x)) # our breaks

# Want a table where the log likelihoods are stored, one row for every theta, one column for every break

theta_vals <- seq(0, 0.5, by = 0.005) # 101 values for theta

M <- matrix(nrow = length(theta_vals), ncol = length(breaks) + 1)

LL <- as_tibble(M) %>% 
  mutate_all(as.numeric) %>% 
  rename(theta = V1) %>% 
  mutate(theta = theta_vals)

mle <- rep(NA, length(breaks))
ll_0 <- rep(NA, length(breaks))
1 - exp((-(breaks/coef_mod[4])^coef_mod[5]))

for(i in 1:(ncol(LL) - 1)){
  
  x0 <- rep(breaks[i], length(x)) # Get the break value of interest
  
  nm_0 <- nlmer(y ~ nlfun_k(x, x0, logvol, is_h2, is_35, a1, a2, a3, d, theta) ~ (a1|Study) + (theta|Study), # Fit Model to get MLE
                control = nlmerControl(optimizer = "bobyqa",
                                       optCtrl = list(maxfun = 2e5,
                                                      upper = c(rep(Inf, 6), 1),
                                                      lower = c(rep(-Inf, 6), 0))),
                start = c(a1 = 1, a2 = 1, a3 = 1, d = 1, theta = 0.1))
  
  mle[i] <- fixef(nm_0)["theta"] # get the mle for that value of x0
  ll_0[i] <- logLik(nm_0)
  for(j in 1:nrow(LL)){
    
    theta_lim <- as.numeric(LL[j, 1]) # Get theta value
    
    try({nm_k <- nlmer(y ~ nlfun_k(x, x0, logvol, is_h2, is_35, a1, a2, a3, d, theta) ~ (a1|Study) + (theta|Study),
                       control = nlmerControl(optimizer = "bobyqa", 
                                              optCtrl = list(maxfun = 2e5,
                                                             upper = c(rep(Inf, 6), theta_lim + 0.005),
                                                             lower = c(rep(-Inf, 6), theta_lim - 0.005))),
                       start = c(a1 = 1, a2 = 1, a3 = 1, d = 1, theta = theta_lim))}, silent = TRUE)
    # try() keeps loop running if it fails to converge
    
    LL[j, i + 1] <- as.numeric(logLik(nm_k)) # store log-likelihood
  }
}

#write.csv(LL, "df_LL_profile_combined_harvest.csv", row.names = FALSE)
#write.csv(ll_0, "df_ll_hat_combined_harvest.csv", row.names = FALSE)
#write.csv(mle, "df_mle_combined_harvest.csv", row.names = FALSE)

#LL <- read_csv("C:/Users/skoike/Desktop/Reanalysis/Douglas Fir/df_LL_profile_combined_harvest.csv")
#ll_0 <- read_csv("C:/Users/skoike/Desktop/Reanalysis/Douglas Fir/df_ll_hat_combined_harvest.csv")
#mle <- read_csv("C:/Users/skoike/Desktop/Reanalysis/Douglas Fir/df_mle_combined_harvest.csv")

#ll_hat <- as_vector(ll_0)
#mle <- as_vector(mle)

LL
ll_hat
mle

pred_0 <- 1 - exp(-(breaks/coef_mod[4])^coef_mod[5])

plot(mle, pred_0)
abline(a=0,b=1)

# Look at the LL profile
# The following figures show what this will look like at each cutoff point



qplot(theta, V2, data = LL, geom = "line") + 
  geom_vline(xintercept = mle[1], color = "red") + 
  geom_smooth()
qplot(theta, V3, data = LL, geom = "line") + 
  geom_vline(xintercept = mle[2], color = "red") + 
  geom_smooth()
qplot(theta, V4, data = LL, geom = "line") + 
  geom_vline(xintercept = mle[3], color = "red") + 
  geom_smooth()
qplot(theta, V5, data = LL, geom = "line") + 
  geom_vline(xintercept = mle[4], color = "red") + 
  geom_smooth() 
qplot(theta, V6, data = LL, geom = "line") + 
  geom_vline(xintercept = mle[5], color = "red") + 
  geom_smooth()
qplot(theta, V7, data = LL, geom = "line") + 
  geom_vline(xintercept = mle[6], color = "red") + 
  geom_smooth()
qplot(theta, V8, data = LL, geom = "line") + 
  geom_vline(xintercept = mle[7], color = "red") + 
  geom_smooth()
qplot(theta, V9, data = LL, geom = "line") + 
  geom_vline(xintercept = mle[8], color = "red") + 
  geom_smooth() 
qplot(theta, V10, data = LL, geom = "line") + 
  geom_vline(xintercept = mle[9], color = "red") + 
  geom_smooth() 
qplot(theta, V11, data = LL, geom = "line") + 
  geom_vline(xintercept = mle[10], color = "red") + 
  geom_smooth() 
qplot(theta, V12, data = LL, geom = "line") + 
  geom_vline(xintercept = mle[11], color = "red") + 
  geom_smooth() 
qplot(theta, V13, data = LL, geom = "line") + 
  geom_vline(xintercept = mle[12], color = "red") + 
  geom_smooth() 
qplot(theta, V14, data = LL, geom = "line") + 
  geom_vline(xintercept = mle[13], color = "red") + 
  geom_smooth() 
qplot(theta, V15, data = LL, geom = "line") + 
  geom_vline(xintercept = mle[14], color = "red") + 
  geom_smooth() 
qplot(theta, V16, data = LL, geom = "line") + 
  geom_vline(xintercept = mle[15], color = "red") + 
  geom_smooth() 
qplot(theta, V17, data = LL, geom = "line") + 
  geom_vline(xintercept = mle[16], color = "red") + 
  geom_smooth() 

LL_1 <- LL %>% select(-V2, -V3)

LL_2 <- LL_1 %>% pivot_longer(cols = -theta, names_to = "V", values_to = "LL")


ll_hat_frame <- tibble(V = colnames(LL_1)[-1], ll_hat = ll_hat[-c(1, 2)])

q <- qchisq(0.95, 1) # Critical value: LR ~ chi-sq(1)

LL_4 <- full_join(LL_2, ll_hat_frame) %>% 
  group_by(V) %>% 
  mutate(LR = 2 * (ll_hat - LL)) %>% # LR statistic 
  arrange(V) %>% 
  filter(LR <= q) %>% # Keep the values where we would not reject the null hypothesis
  slice(1, n()) %>% # Get the maximum and minimum of these theta values 
  select(V, theta) %>% 
  mutate(y = c("ymin", "ymax")) %>% 
  pivot_wider(names_from = y, values_from = theta) %>%
  mutate(V = str_replace(V, "V", ""),
         V = as.numeric(V)) %>% 
  arrange(V)

LL_4 

# adjust for the fact that the mle from above does not correspond exactly with original model

pred_0 <- 1 - exp(-(breaks/coef_mod[4])^coef_mod[5])

adj <- mle - pred_0

plot(mle, pred_0)
abline(a = 0, b = 1)

LL_4$adj <- adj[-c(1, 2)] 


LL_5 <- LL_4 %>%
  ungroup() %>% 
  mutate(ymin = ymin - adj,
         ymax = ymax - adj,
         x = breaks[-c(1, 2)]) %>% 
  select(-adj, -V)

LL_5

LL_6 <- LL_5 %>% 
  add_row(ymin = 0, ymax = 0, x = 0, .before = 1)

plot(LL_6$x, LL_6$ymax, type = "l", ylim = c(0, 0.6), xlim = c(0, 85))
lines(LL_6$x, LL_6$ymin)
lines(breaks, pred_0, lty = 2)


# Write file

write.csv(LL_6, "df_para_ci_combined_harvest.csv", row.names = FALSE)


