library(readr)
library(magrittr)
library(dplyr)

pred_wide <- read_csv("C:/Users/skoike/Desktop/Reanalysis/Douglas Fir/df_figure_pred.csv") %>% 
  filter(Model == "Individual")  %>% 
  mutate(Harvest = as.character(Harvest),
         Harvest = ifelse(Harvest == "1", "Harvest 1", "Harvest 2")) %>%
  select(x, y, Study, Harvest) %>% 
  pivot_wider(names_from = c(Study, Harvest), values_from = y, names_sep = ": ")

points_wide <- read_csv("C:/Users/skoike/Desktop/Reanalysis/Douglas Fir/df_figure_points.csv") %>% 
  select(w126.12.8.adj, adj_y, Study, Harvest)  %>% 
  mutate(Harvest = as.character(Harvest),
         Harvest = ifelse(Harvest == "1", "Harvest 1", "Harvest 2")) %>%
  pivot_wider(names_from = c(Study, Harvest), values_from = adj_y, names_sep = ": ") %>% 
  rename(x = w126.12.8.adj)

# Harvest 1  ------------------------------------------------------------

### 13 ------------------------

#dev.off()

png(file = "C:/Users/skoike/Desktop/df_fig.png", 
    width = 12, height = 9, units = "in", res = 700)

par(mfrow=c(1,2),mai=c(2,0,0,0),oma=c(2,4,1,1),cex=1.2,mex=1.2,lwd=4,cex.lab=1.2,cex.axis=1.2)

# Adjusted Total Dry Weight (Log grams)


plot(points_wide$x, points_wide$`Study 13: Harvest 1`, 
     pch = 16, ylim = c(-0.15, 0.15),
     ylab = "",
     xlab = "")
text(x = 75, y = 0.13, labels = "A", cex = 2)
lines(pred_wide$x, pred_wide$`Study 13: Harvest 1`)


### 35 ------------------------
points(points_wide$x, points_wide$`Study 35: Harvest 1`, col = "red", pch = 16)
lines(pred_wide$x, pred_wide$`Study 35: Harvest 1`, col = "red")


### Add Legend ----------------

legend(8, -.075,
       legend = c("Study 13", 
                  "Study 35"),
       pt.cex = 1,
       cex = 0.9,
       pch = 16,
       lwd = 2,
       bty = "n",
       col = c("black", "red"))



# Harvest 2 --------------------------------------

plot(points_wide$x, points_wide$`Study 13: Harvest 2`, 
     pch = 17, ylim = c(-.15, 0.15),
     yaxt = "n",
     ylab = "",
     xlab = "")
text(x = 75, y = 0.13, labels = "B", cex = 2)
lines(pred_wide$x, pred_wide$`Study 13: Harvest 2`)


### 35 ------------------------
points(points_wide$x, points_wide$`Study 35: Harvest 2`, col = "red", pch = 17)
lines(pred_wide$x, pred_wide$`Study 35: Harvest 2`, col = "red")


### Add Legend ----------------

legend(8, -.075,
       legend = c("Study 13", 
                  "Study 35"),
       pt.cex = 1,
       cex = 0.9,
       ncol = 1,
       pch = 17,
       lwd = 2,
       bty = "n",
       col = c("black", "red"))
mtext("W126 (ppm-h)", outer = TRUE, side = 1, line = -4, cex = 1.8)
mtext("Adjusted Total Dry Weight (log g)", outer = TRUE, line = 3, adj = 0.8, side = 2, cex = 1.8)

dev.off()
