library(tidyverse)

# Read in predictive curve
EWP <- read_csv("C:/Users/skoike/Desktop/Reanalysis/Eastern White Pine/ewp_lines.csv") %>% 
  mutate(y = 0)


para_ci <- read_csv("C:/Users/skoike/Desktop/Reanalysis/Eastern White Pine/ewp_para_ci.csv") %>% 
  mutate(ymin = ifelse(ymin < 0, 0, ymin)) %>% 
  mutate_at(vars(-x), function(x){x*100}) %>% 
  slice(-n())

para_ci

new_pred <- data.frame(x = EWP$x, ymin = 0)


# Smooth ymax
f <- function(x, a, b){
  a*x^b
}

plot(para_ci$x, para_ci$ymax)

y_upper_fcn <- minpack.lm::nlsLM(ymax ~ f(x, a, b), data = para_ci, start = list(a = 1, b = 0.1))

new_ymax <- predict(y_upper_fcn, newdata = new_pred)
new_pred$new_ymax <- new_ymax

lines(new_pred$x, new_pred$new_ymax)



ci_plot <- ggplot(new_pred) + 
  aes(x = x) + 
  geom_ribbon(aes(ymin = ymin, ymax = new_ymax), alpha = 0.3) +
  geom_line(data = EWP, aes(x = x, y = 100*(1 - exp(y))), size = 1, color = "blue") + 
  ylab("Predicted Relative Biomass Loss (%)") + 
  xlab("W126 (ppm-h)") + 
  scale_y_continuous(breaks = seq(0, 100, by = 20)) + 
  scale_x_continuous(breaks = seq(0, 90, by = 10))
ci_plot 

# Export data for grid plot
#ggplot_build(ci_plot) data[[1]] has band info, data[[2]] has predicted curve

bands <- ggplot_build(ci_plot)$data[[1]] %>% select(x, ymin, ymax) %>% mutate(x = round(x, 7))
pred_curve <- ggplot_build(ci_plot)$data[[2]] %>% select(x, y) %>% mutate(x = round(x, 7))

ewp_info <- full_join(bands, pred_curve) %>% 
  mutate(Species = factor("Eastern White Pine")) %>% 
  select(Species, x, y, ymin, ymax)

#write.csv(ewp_info, "ewp_bands.csv", row.names = FALSE)