library(tidyverse)

study_90 <- read_csv("C:/Users/skoike/Desktop/Reanalysis/Eastern White Pine/ewp_90_mean_data.csv") %>% 
  mutate(Species = "Eastern White Pine",
         Study = factor(1990),
         Site = "Michigan",
         .before = 1) %>% 
  filter(TREAT != 0)
study_91 <- read_csv("C:/Users/skoike/Desktop/Reanalysis/Eastern White Pine/ewp_91_mean_data.csv") %>% 
  mutate(Species = "Eastern White Pine",
         Study = factor(1991),
         Site = "Michigan",
         .before = 1)

studies <- full_join(study_90, study_91) %>%  
  select(Species, Study, Site, Year, Harvest, Exp_days, CHAMB, TREAT, LOGNEEDLEDW, 
         LOGSTEMDW, LOGROOTDW, LOGTOTALDW, LOGVOL_bl, everything()) %>% 
  rename(actual.24 = OZ.24,
         actual.24.adj = OZ.24.adj,
         actual.12.7 = OZ.12.7,
         actual.12.8 = OZ.12.8,
         actual.12.9 = OZ.12.9,
         actual.12.7.adj = OZ.12.7.adj,
         actual.12.8.adj = OZ.12.8.adj,
         actual.12.9.adj = OZ.12.9.adj) 

studies <- studies %>% mutate(TREAT = as_factor(TREAT))

studies %>% 
  mutate(W126 = w126.12.8.adj*Exp_days/92) %>% 
  group_by(Study, TREAT, Exp_days) %>% 
  summarise(m = mean(w126.12.8.adj, 1))

studies %>% 
  ggplot() + 
  aes(x = w126.12.8.adj, y = LOGTOTALDW, fill = Study, color = Study) + 
  geom_point(shape = 21, size = 2, color = "black") + 
  geom_smooth(method = "lm", se = FALSE)

studies %>% 
  ggplot() + 
  aes(x = LOGVOL_bl, y = LOGTOTALDW, fill = Study, color = Study) + 
  geom_point(shape = 21, size = 2, color = "black") + 
  geom_smooth(method = "lm", se = FALSE)


# Random effects Model ---------------------------------------------------
library(lme4)

EWP <- studies %>% 
  group_by(Study) %>% 
  mutate(centered_logvol = LOGVOL_bl - mean(LOGVOL_bl)) %>% 
  select(Species, Study, Site, Year, Harvest, Exp_days, CHAMB, TREAT, 
         ends_with("DW"), centered_logvol, everything())

#write.csv(studies, "ewp_chamber_mean_data.csv", row.names = FALSE)


# Random Coefficient Model -----------------------------------------------------

# Model 1
# Common B, C, Covariate

nform1 <- ~ log(a + d*logvol) + (-(x/b)) 

nfun1 <- deriv(nform1,
               namevec = c("a", "b", "d"),
               function.arg = c("x", "logvol", "a", "b", "d"))

nl1 <- nlmer(LOGTOTALDW ~ nfun1(w126.12.8.adj, centered_logvol, a, b, d) ~ (a|Study) + (b|Study),
             data = EWP,
             control = nlmerControl(optimizer = "bobyqa", optCtrl = list(maxfun = 2e5)),
             start = c(a = 1, b = -100, d = 1))
summary(nl1) # B = -653.72702

aug1 <- broom.mixed::augment(nl1)  

aug1 %>% 
  ggplot() + 
  aes(x = .fitted, y = .resid, fill = Study) + 
  geom_point(shape = 21, size = 2.5) + 
  geom_hline(yintercept = 0, color = "red") + 
  scale_fill_brewer(palette = "Set1")

# Model 2
# No Covariate

nform2 <- ~ log(a) + (-(x/b)) 

nfun2 <- deriv(nform2,
               namevec = c("a", "b"),
               function.arg = c("x", "a", "b"))

nl2 <- nlmer(LOGTOTALDW ~ nfun2(w126.12.8.adj, a, b) ~ (a|Study) + (b|Study),
             data = EWP,
             control = nlmerControl(optimizer = "bobyqa", optCtrl = list(maxfun = 2e5)),
             start = c(a = 1, b = -100))
summary(nl2) #B=-551.83378

aug2 <- broom.mixed::augment(nl2)  

aug2 %>% 
  ggplot() + 
  aes(x = .fitted, y = .resid, fill = Study) + 
  geom_point(shape = 21, size = 2.5) + 
  geom_hline(yintercept = 0, color = "red") + 
  scale_fill_brewer(palette = "Set1")

# Comparing Models --------------------------------------------------------------------------------
nform1 # Covariate, C = 1
nform2 # No Covariate, C = 1

fixef(nl1)
fixef(nl2)

mean(aug1$.resid^2) 
mean(aug2$.resid^2) # smallest

(SSRes1 <- sum(aug1$.resid^2)) 
(SSRes2 <- sum(aug2$.resid^2)) # smallest

meanY <- mean(aug1$LOGTOTALDW)
SStot <- sum((aug1$LOGTOTALDW - meanY)^2) 

(r_sq_1 <- 1 - SSRes1/SStot) 
(r_sq_2 <- 1 - SSRes2/SStot) # Largest

anova(nl2, nl1)

SSreg <- sum((aug2$.fitted - meanY)^2)

SSreg/SStot

# Even though nl1 fits better, nl2 fits almost as well and is a simpler model

broom::tidy(nl2)

# Figure 
nform2
#broom::tidy(nl2) %>% View()
(coef_mod <- fixef(nl2))

EWP <- EWP %>% 
  mutate(adj_y = LOGTOTALDW - log(coef_mod[1]))

pred <- tibble(w126.12.8.adj =  c(seq(0, max(EWP$w126.12.8.adj), by = 0.5), max(EWP$w126.12.8.adj)),
               adj_y = -(w126.12.8.adj/coef_mod[2]))

EWP_plot <- ggplot(EWP) + 
  aes(x = w126.12.8.adj, y = adj_y) + 
  geom_point(size = 2, shape = 21, aes(fill = Study)) + 
  geom_line(data = pred, size = 1) + 
  scale_fill_brewer(palette = "Set1") 
EWP_plot

round(100*(1 - exp(-(c(10, 20, 30, 40, 50)/coef_mod[2]))), 1) 

ewp_lines <- ggplot_build(EWP_plot)$data[[2]] %>% 
  select(x, y) %>% 
  mutate(Species = factor("Eastern White Pine"))

#write.csv(ewp_lines, "ewp_lines.csv", row.names = FALSE)

ewp_b <- tibble(b = coef_mod[2], c = 1, Species = "Eastern White Pine")

#write.csv(ewp_b, "ewp_params.csv", row.names = FALSE)
#write.csv(coef_mod, "ewp_all_params.csv")

w126_frame <- EWP %>% 
  group_by(Study) %>% 
  summarize(min_w126 = min(w126.12.8.adj),
            max_w126 = max(w126.12.8.adj)) %>% 
  mutate(x = map2(min_w126, max_w126, seq, by = 0.01)) %>% 
  unnest(cols = x) 

coef_frame <- coef(nl2)[1] %>% 
  as.data.frame() %>% 
  rownames_to_column("Study") %>% 
  select(Study, ends_with("b")) %>% 
  rename(b = Study.b)

EWP_lines <- full_join(w126_frame, coef_frame) %>% 
  mutate(y = -(x/b))

nform2

intercept_frame <- coef(nl2)[1] %>% 
  as.data.frame() %>% 
  rownames_to_column("Study") %>% 
  select(Study, Study.a)


EWP_points <- full_join(EWP, intercept_frame) %>% 
  rename(a = Study.a) %>% 
  mutate(adj_y = LOGTOTALDW - log(a))

EWP_sub <- EWP %>% select(Study) %>% mutate(Model = factor("Population"))

pred1_a <- pred %>% 
  mutate(Model = factor("Population")) %>% 
  full_join(EWP_sub) %>% 
  rename(x = w126.12.8.adj, y = adj_y)

EWP_lines <- EWP_lines %>% mutate(Model = factor("Individual"))

pred2 <- full_join(EWP_lines, pred1_a)

ggplot(EWP_points) + 
  aes(x = w126.12.8.adj, y = adj_y) + 
  geom_point(size = 2, shape = 21, aes(fill = Study)) + 
  scale_fill_brewer(palette = "Set1") +
  facet_wrap(. ~ Study) +
  geom_line(data = pred2 %>% filter(Model == "Individual"), aes(x = x, y = y, linetype = Model, color = Study), size = 1) + 
  scale_color_brewer(palette = "Set1") + 
  geom_line(data = pred2 %>% filter(Model != "Individual"), aes(x = x, y = y, linetype = Model), color = "black", size = 1) 

coef(nl2)
summary(nl2)

y_hat <- -(EWP_points$w126.12.8.adj/coef_mod[2])
y <- EWP_points$adj_y

plot(y, y_hat)
abline(a = 0, b = 1)

SSRes <- sum((y - y_hat)^2)
SSTot <- sum((y - mean(y))^2)

1 - SSRes/SSTot

mean((y - y_hat)^2) 



# Likelihood Confidence Interval -----------------------------------------------

# Step 1: Pull out relevant variables so we don't have to refer to data 

y <- EWP$LOGTOTALDW
x <- EWP$w126.12.8.adj
Study <- EWP$Study

# Step 2: Reparameterize the model so we can create a confidence interval around predicted biomass loss (theta)

nlform_k <- ~ log(a) + ((x/x0) * log(1 - theta))

nlfun_k <- deriv(nlform_k,
                 namevec = c("a", "theta"),
                 function.arg = c("x", "x0", "a", "theta"))

# Step 3: At every break (e.g. 10, 20, 30, etc.), run the model at that fixed point, varying the value of theta

breaks <- c(seq(5, max(x), by = 5), max(x)) # our breaks

# Want a table where the log likelihoods are stored, one row for every theta, one column for every break

theta_vals <- seq(-0.5, 0.5, by = 0.005) # 101 values for theta

M <- matrix(nrow = length(theta_vals), ncol = length(breaks)+ 1)

LL <- as_tibble(M) %>% # This will hold our likelihoods for every value of x0
  mutate_all(as.numeric) %>% 
  rename(theta = V1) %>%  
  mutate(theta = theta_vals)

mle <- rep(NA, length(breaks)) # this will hold the maximum likelihood estimate from initial model
ll_hat <- rep(NA, length(breaks)) # this will hold the log likelihood from initial model

for(i in 1:(ncol(LL) - 1)){
  
  x0 <- rep(breaks[i], length(x)) # Get the break value of interest
  
  nm_0 <- nlmer(y ~ nlfun_k(x, x0, a, theta) ~ (a|Study) + (theta|Study), # Fit Model to get MLE
                control = nlmerControl(optimizer = "bobyqa",
                                       optCtrl = list(maxfun = 2e5,
                                                      upper = c(Inf, Inf, Inf, 0.5), # bounds theta between 0 and 1
                                                      lower = c(-Inf, -Inf, -Inf, -0.5))),
                start = c(a = 10, theta = 0))
  
  mle[i] <- fixef(nm_0)["theta"] # get the mle for that fixed value of x0
  ll_hat[i] <- logLik(nm_0) # get the log-likelihood for that fixed value of x0
  for(j in 1:nrow(LL)){
    
    theta_lim <- as.numeric(LL[j, 1]) # Get theta value
    
    try({nm_k <- nlmer(y ~ nlfun_k(x, x0, a, theta) ~ (a|Study) + (theta|Study), # Fit Model to get MLE
                        control = nlmerControl(optimizer = "bobyqa",
                                               optCtrl = list(maxfun = 2e5,
                                                             upper = c(Inf, Inf, Inf, theta_lim + 0.005), # have tight bound on theta
                                                             lower = c(-Inf, -Inf, -Inf, theta_lim - 0.005))),
                       start = c(a = 10, theta = theta_lim))}, silent = TRUE)
    # try() keeps loop running if it fails to converge
    
    LL[j, i + 1] <- as.numeric(logLik(nm_k)) # store log-likelihood
  }
}

#write.csv(LL, "ewp_LL_profile_harvest1.csv", row.names = FALSE)
#write.csv(ll_hat, "ewp_ll_hat_harvest1.csv", row.names = FALSE)
#write.csv(mle, "ewp_mle_harvest1.csv", row.names = FALSE)

#LL <- read_csv("C:/Users/skoike/Desktop/Reanalysis/Eastern White Pine/ewp_LL_profile_harvest1.csv")
#ll_hat <- read_csv("C:/Users/skoike/Desktop/Reanalysis/Eastern White Pine/ewp_ll_hat_harvest1.csv")
#mle <- read_csv("C:/Users/skoike/Desktop/Reanalysis/Eastern White Pine/ewp_mle_harvest1.csv")

#ll_0 <- as_vector(ll_0)
#mle <- as_vector(mle)

LL
ll_hat
mle

# Look at the LL profile
qplot(theta, V2, data = LL, geom = "line") + geom_vline(xintercept = mle[1], color = "red")
qplot(theta, V3, data = LL, geom = "line") + geom_vline(xintercept = mle[2], color = "red")
qplot(theta, V4, data = LL, geom = "line") + geom_vline(xintercept = mle[3], color = "red")
qplot(theta, V5, data = LL, geom = "line") + geom_vline(xintercept = mle[4], color = "red")
qplot(theta, V6, data = LL, geom = "line") + geom_vline(xintercept = mle[5], color = "red")
qplot(theta, V7, data = LL, geom = "line") + geom_vline(xintercept = mle[6], color = "red")
qplot(theta, V8, data = LL, geom = "line") + geom_vline(xintercept = mle[7], color = "red")
qplot(theta, V9, data = LL, geom = "line") + geom_vline(xintercept = mle[8], color = "red")


# The profiles are well-behaved except for w126 = 40

LL_1 <- LL


# The following lines will do a apply the GAM en masse 

LL_2 <- LL_1 %>% 
  pivot_longer(cols = -theta, names_to = "V", values_to = "LL")

ll_hat_frame <- tibble(V = colnames(LL)[-1], ll_hat)

#ll_hat_frame <- tibble(V = colnames(LL)[-1], ll_hat) %>% rename(ll_hat = x)

q <- qchisq(0.95, 1) # Critical value: LR ~ chi-sq(1)

LL_4 <- full_join(LL_2, ll_hat_frame) %>% 
  group_by(V) %>% 
  mutate(LR = 2 * (ll_hat - LL)) %>% # LR statistic
  filter(LR <= q) %>% # Keep the values where we would not reject the null hypothesis
  slice(1, n()) %>% # Get the maximum and minimum of these theta values 
  select(V, theta) %>% 
  mutate(y = c("ymin", "ymax")) %>% 
  pivot_wider(names_from = y, values_from = theta) %>% 
  arrange(ymax)

LL_4

# adjust for the fact that the mle from above does not correspond exactly with original model

pred_0 <- 1 - exp(-(breaks/coef_mod[2]))


adj <- mle - pred_0

plot(mle, pred_0)
abline(a = 0, b = 1)

#LL_4 <- LL_4 %>% ungroup() %>% slice(1:5)

LL_4$adj <- adj

LL_5 <- LL_4 %>%
  ungroup() %>% 
  mutate(ymin = ymin - adj,
         ymax = ymax - adj,
         x = breaks) %>% 
  select(-adj, -V)

LL_5

LL_6 <- LL_5 %>% 
  mutate(ymin = ifelse(ymin < 0, 0, ymin)) %>% 
  add_row(ymin = 0, ymax = 0, x = 0, .before = 1)

LL_6

plot(LL_6$x, LL_6$ymax, type = "l", ylim = c(0, 0.6), xlim = c(0, 85))
lines(LL_6$x, LL_6$ymin)
lines(breaks, pred_0, lty = 2)


#View(LL_5)

# Write file

write.csv(LL_6, "ewp_para_ci.csv", row.names = FALSE)

