library(tidyverse)

bc_lines <- read_csv("C:/Users/skoike/Desktop/Reanalysis/Black Cherry/bc_bands.csv") %>% 
  mutate(is_connifer = factor("No")) %>% 
  select(-ymin, -ymax)
df_lines <- read_csv("C:/Users/skoike/Desktop/Reanalysis/Douglas Fir/df_bands.csv") %>% 
  mutate(is_connifer = factor("Yes")) %>% 
  select(-ymin, -ymax)
ewp_lines <- read_csv("C:/Users/skoike/Desktop/Reanalysis/Eastern White Pine/ewp_bands.csv") %>% 
  mutate(y = 0,
         is_connifer = factor("Yes")) %>% 
  select(-ymin, -ymax) # Negative Slope, i.e. no ozone effect
pp_lines <- read_csv("C:/Users/skoike/Desktop/Reanalysis/Ponderosa Pine Supplement/pp_bands.csv") %>% 
  mutate(is_connifer = factor("Yes")) %>% 
  select(-ymin, -ymax)
qa_lines <- read_csv("C:/Users/skoike/Desktop/Reanalysis/Quaking Aspen/qa_bands.csv") %>% 
  mutate(is_connifer = factor("No")) %>% 
  select(-ymin, -ymax)
ra_lines <- read_csv("C:/Users/skoike/Desktop/Reanalysis/Red Alder/ra_bands.csv") %>% 
  mutate(is_connifer = factor("No")) %>% 
  select(-ymin, -ymax)
rm_lines <- read_csv("C:/Users/skoike/Desktop/Reanalysis/Red Maple/rm_bands.csv") %>% 
  mutate(is_connifer = factor("No")) %>% 
  select(-ymin, -ymax)
sm_lines <- read_csv("C:/Users/skoike/Desktop/Reanalysis/Sugar Maple/sm_bands.csv") %>% 
  mutate(is_connifer = factor("No")) %>% 
  select(-ymin, -ymax)
tp_lines <- read_csv("C:/Users/skoike/Desktop/Reanalysis/Tulip Poplar/tp_bands.csv") %>% 
  mutate(is_connifer = factor("No")) %>% 
  select(-ymin, -ymax)
vp_lines <- read_csv("C:/Users/skoike/Desktop/Reanalysis/Virginia Pine/vp_bands.csv") %>% 
  mutate(is_connifer = factor("Yes")) %>% 
  select(-ymin, -ymax)

# New Species
#ehem_lines <- read_csv("C:/Users/skoike/Desktop/Reanalysis/New Species/Eastern Hemlock/ehem_bands.csv") %>% 
#  mutate(is_connifer = factor("Yes")) %>% 
#  select(-ymin, -ymax)
sum_lines <- read_csv("C:/Users/skoike/Desktop/Reanalysis/New Species/Sumac/sum_bands.csv") %>% 
  mutate(is_connifer = factor("No"),
         Species = "Winged Sumac") %>%
  select(-ymin, -ymax)
sg_lines <- read_csv("C:/Users/skoike/Desktop/Reanalysis/New Species/Sweetgum/sg_bands.csv") %>% 
  mutate(is_connifer = factor("No")) %>% 
  select(-ymin, -ymax)
syc_lines <- read_csv("C:/Users/skoike/Desktop/Reanalysis/New Species/Sycamore/syc_bands.csv") %>% 
  mutate(is_connifer = factor("No")) %>% 
  select(-ymin, -ymax)
tmp_lines <- read_csv("C:/Users/skoike/Desktop/Reanalysis/New Species/Table Mountain Pine/tmp_bands.csv") %>% 
  mutate(is_connifer = factor("Yes")) %>% 
  select(-ymin, -ymax)
yep_lines <- read_csv("C:/Users/skoike/Desktop/Reanalysis/New Species/Yellow Buckeye/ybe_bands.csv") %>% 
  mutate(is_connifer = factor("No")) %>% 
  select(-ymin, -ymax)
chest_lines <- read_csv("C:/Users/skoike/Desktop/Reanalysis/New Species/Chestnut Oak/chest_bands.csv") %>% 
  mutate(is_connifer = factor("No")) %>% 
  select(-ymin, -ymax)

all_lines <- full_join(bc_lines, df_lines) %>% 
  full_join(ewp_lines) %>% 
  full_join(pp_lines) %>% 
  full_join(qa_lines) %>% 
  full_join(ra_lines) %>% 
  full_join(rm_lines) %>% 
  full_join(sm_lines) %>% 
  full_join(tp_lines) %>% 
  full_join(vp_lines) %>% 
  #full_join(ehem_lines) %>% 
  full_join(sum_lines) %>% 
  full_join(sg_lines) %>% 
  full_join(syc_lines) %>% 
  full_join(tmp_lines) %>%
  full_join(yep_lines) %>% 
  full_join(chest_lines)

(ann_location <- all_lines %>% group_by(Species) %>% slice(n()))

ggplot(all_lines) +
  aes(x = x, y = y, color = is_connifer, group = Species) + 
  geom_line(size = 1) + 
  guides(color = FALSE) + 
  scale_color_manual(values = c("black", "red")) + 
  geom_text(data = ann_location, aes(label = Species), hjust = 0, vjust = -0.07) + 
  scale_x_continuous(breaks = seq(0, 120, by = 20), limits = c(0, 115)) +
  labs(x = "W126 (ppm-h)", y = "Relative Biomass Loss (%)") + 
  theme_bw() + 
  theme(text = element_text(size = 12),
        panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(),
        strip.background = element_blank())

ggplot(all_lines) +
  aes(x = x, y = y, color = is_connifer, group = Species) + 
  geom_line(size = 1) + 
  guides(color = FALSE) + 
  scale_color_manual(values = c("black", "red")) + 
  annotate("text", x = 31.1, y = 47.0, label = "Black Cherry", hjust = -0.05, vjust = -0.07) + 
  annotate("text", x = 85.5, y = 10, label = "Douglas-fir", hjust = -0.05, color = "red") +
  annotate("text", x = 39.8, y = 0, label = "Eastern White Pine, Table Mountain Pine", hjust = -0.05, color = "red") +
  annotate("text", x = 85.5, y = 37.5, label = "Ponderosa Pine", hjust = -0.05, color = "red") + 
  annotate("text", x = 87.2, y = 60.8, label = "Quaking Aspen", hjust = -0.05, vjust = -0.07) + 
  annotate("text", x = 85.5, y = 38.9, label = "Red Alder", hjust = -0.05, vjust = -0.07) +
  annotate("text", x = 108.8, y = 22.2, label = "Red Maple", hjust = -0.05, vjust = -0.07) + 
  annotate("text", x = 84.8, y = 12, label = "Sugar Maple", hjust = -0.05, vjust = -0.07) + 
  annotate("text", x = 23.8, y = 38.8, label = "Winged Sumac", hjust = 1, vjust = -0.07) + 
  annotate("text", x = 30.5, y = 41.5, label = "Sweetgum", hjust = 0, vjust = -0.3) + 
  annotate("text", x = 32.9, y = 21.7, label = "Sycamore", hjust = -0.05, vjust = -0.07) + 
  annotate("text", x = 31.8, y = 39.5, label = "Tulip Poplar", hjust = -0.05, vjust = -0.07) + 
  
  annotate("text", 
           x = c(33, 34.3, 36),
           y = 3.71, size = 3.7, vjust = 0.4, hjust = 0.5,
           label = c("(A)", ",", "(B)"),
           color = c("red", "black", "black")) +
  
  annotate("text", x = 32.3, y = 0, label = "Yellow Buckeye", hjust = 0.3, vjust = 1.5) + 
  annotate("text", x = 100, y = 53, label = "(A) Virginia Pine", hjust = 0, color = "red") +
  annotate("text", x = 100, y = 51, label = "(B) Chestnut Oak", hjust = 0, color = "black") +
  annotate("rect", xmin = 99, xmax = 117, ymin = 49.5, ymax = 54, alpha = 0, color = "black") + 
  scale_x_continuous(breaks = seq(0, 120, by = 20), limits = c(0, 120)) +
  scale_y_continuous(breaks = seq(0, 60, by = 10)) + 
  labs(x = "W126 (ppm-h)", y = "Predicted Relative Biomass Loss (%)") + 
  theme_bw() + 
  theme(text = element_text(size = 16),
        panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(),
        strip.background = element_blank())

#ggsave("Species_comp.png", width = 12, height = 9, units = "in")

ann_location

all_lines %>% 
  filter(x %in% seq(10, 50, by = 10)) %>% 
  mutate(y = round(y, 1)) %>% 
  pivot_wider(names_from = x, values_from = y) %>% 
  arrange(Species)
