library(tidyverse)

chestnut <- read_csv("C:/Users/skoike/Desktop/Reanalysis/New Species/Chestnut Oak/chestnut_mean_data.csv") %>% 
  mutate(Study = factor(1991),
         Site = "SMNP",
         Species = "Chestnut Oak", 
         .before = 1)

studies <- chestnut %>% 
  select(Species, Study, Site, Year, Harvest, Exp_days, CHAMB, Trt, everything())

studies %>% 
  ggplot() + 
  aes(x = LOGVOL_bl, y = LOGTOTALDW, fill = Study, color = Study) + 
  geom_point(shape = 21, size = 2, color = "black") + 
  geom_smooth(method = "lm", se = FALSE)

studies %>% 
  ggplot() + 
  aes(x = w126.12.8.adj, y = LOGTOTALDW, fill = Study, color = Study) + 
  geom_point(shape = 21, size = 2, color = "black") + 
  geom_smooth(method = "lm", se = FALSE)


# Random effects Model ---------------------------------------------------
library(lme4)

CHEST <- studies %>%
  rename(TREAT = Trt,
         VOL_bl = VOL,
         actual.24 = OZ.24,
         actual.24.adj = OZ.24.adj,
         actual.12.7 = OZ.12.7,
         actual.12.8 = OZ.12.8,
         actual.12.9 = OZ.12.9,
         actual.12.7.adj = OZ.12.7.adj,
         actual.12.8.adj = OZ.12.8.adj,
         actual.12.9.adj = OZ.12.9.adj) %>% 
  mutate(TREAT = case_when(TREAT == 1 ~ "CF",
                           TREAT == 2 ~ "0.5x",
                           TREAT == 3 ~ "1x",
                           TREAT == 4 ~ "1.5x",
                           TREAT == 5 ~ "2x",
                           TRUE ~ "AA"),
         TREAT = as_factor(TREAT))

CHEST %>% 
  mutate(W126 = w126.12.8.adj*Exp_days/92) %>% 
  group_by(Study, Harvest, Site, TREAT) %>% 
  summarise(m = round(mean(W126), 1))

CHEST %>% nest_by(Study, Exp_days)

C1 <- CHEST %>% filter(TREAT != "AA") %>% mutate(centered_logvol = LOGVOL_bl - mean(LOGVOL_bl))

C2 <- CHEST %>% filter(TREAT == "AA")

C3 <- full_join(C1, C2) %>%
  select(Species, Study, Site, Year, Harvest, Exp_days, CHAMB, TREAT, 
         ends_with("DW"), centered_logvol, LOGVOL_bl, VOL_bl,
         everything())
  

#write.csv(C3, "chest_chamber_mean_data.csv", row.names = FALSE)

CHEST <- C1

# No covariate set c = 1 -------------------------------
nform2 <- ~ log(a) + (-(x/b))

nfun2 <- deriv(nform2,
               namevec = c("a", "b"),
               function.arg = c("x", "a", "b"))

nm2 <- nlmer(LOGTOTALDW ~ nfun2(w126.12.8.adj, a, b) ~ a + b | Study,
             data = CHEST,
             control = nlmerControl(optimizer = "bobyqa", optCtrl = list(maxfun = 2e5)),
             start = c(a = 1, b = 1))
summary(nm2) # B = 2151.36

aug2 <- broom.mixed::augment(nm2)

aug2 %>% 
  ggplot() + 
  aes(x = .fitted, y = .resid, color = Study) + 
  geom_point() + 
  geom_hline(yintercept = 0, color = "red") + 
  scale_color_brewer(palette = "Set1")

aug2 %>% 
  ggplot() + 
  aes(sample = .resid) + 
  geom_qq() + 
  geom_qq_line()

# Covariate, C = 1
nform4 <- ~ log(a + d*logvol) + (-(x/b))

nfun4 <- deriv(nform4,
               namevec = c("a", "b", "d"),
               function.arg = c("x", "logvol", "a", "b", "d"))

nm4 <- nlmer(LOGTOTALDW ~ nfun4(w126.12.8.adj, centered_logvol, a, b, d) ~ a + b | Study,
             data = CHEST,
             control = nlmerControl(optimizer = "bobyqa", 
                                    optCtrl = list(maxfun = 2e5)),
             start = c(a = 1, b = 1, d = 1))
summary(nm4) 

aug4 <- broom.mixed::augment(nm4)

aug4 %>% 
  ggplot() + 
  aes(x = .fitted, y = .resid, color = Study) + 
  geom_point() + 
  geom_hline(yintercept = 0, color = "red") + 
  scale_color_brewer(palette = "Set1")

aug4 %>% 
  ggplot() + 
  aes(sample = .resid) + 
  geom_qq() + 
  geom_qq_line()


# Model Comparison ---------------------------------

fixef(nm2) # No Covariate
fixef(nm4) # Covariate

mean(aug2$.resid^2) 
mean(aug4$.resid^2) # Smallest 


(SSRes2 <- sum(aug2$.resid^2)) # smallest 
(SSRes4 <- sum(aug4$.resid^2)) 

meanY <- mean(aug2$LOGTOTALDW) 
SStot <- sum((aug2$LOGTOTALDW - meanY)^2) 

(r_sq_2 <- 1 - SSRes2/SStot) # Largest
(r_sq_4 <- 1 - SSRes4/SStot) 


SSreg <- sum((aug4$.fitted - meanY)^2)
SSreg/SStot

# Figure 
nform4
(coef_mod <- fixef(nm4))
broom::tidy(nm4)

CHEST <- CHEST %>% mutate(adj_y = LOGTOTALDW - log(coef_mod[1] + coef_mod[3]*centered_logvol))

pred <- tibble(w126.12.8.adj =  c(seq(0, max(CHEST$w126.12.8.adj), by = 0.5), max(CHEST$w126.12.8.adj)),
               adj_y = -(w126.12.8.adj/coef_mod[2]))

CHEST_plot <- ggplot(CHEST) + 
  aes(x = w126.12.8.adj, y = adj_y, color = Study) +
  geom_point(size = 2) + 
  geom_line(data = pred, color = "black", size = 0.75)
CHEST_plot

round(100*(1 - exp(-(c(10, 20, 30, 40, 50)/coef_mod[2]))), 1)

chest_lines <- ggplot_build(CHEST_plot)$data[[2]] %>% 
  select(x, y) %>% 
  mutate(Species = factor("Chestnut"))

#write.csv(chest_lines, "chest_lines.csv", row.names = FALSE)

chest_b <- tibble(b = coef_mod[2], c = 1, Species = "Chestnut Oak")

#write.csv(chest_b, "chest_params.csv", row.names = FALSE)
#write.csv(coef_mod, "chest_all_params.csv")

y_hat <- -(CHEST$w126.12.8.adj/coef_mod[2])
y <- CHEST$adj_y

plot(y, y_hat)
abline(a = 0, b = 1)

SSRes <- sum((y - y_hat)^2)
SSTot <- sum((y - mean(y))^2)

1 - SSRes/SSTot

mean((y - y_hat)^2) 


# Likelihood Confidence Interval -----------------------------------------------

# Step 1: Pull out relevant variables so we don't have to refer to data 

y <- CHEST$LOGTOTALDW
x <- CHEST$w126.12.8.adj
Study <- CHEST$Study
logvol <- CHEST$centered_logvol

# Step 2: Reparameterize the model so we can create a confidence interval around predicted biomass loss (theta)

nform4
nlform_k <- ~ log(a + d*logvol) + ((x/x0) * log(1 - theta))

nlfun_k <- deriv(nlform_k,
                 namevec = c("a", "d", "theta"),
                 function.arg = c("x", "x0", "logvol", "a", "d", "theta"))

# Step 3: At every break (e.g. 10, 20, 30, etc.), run the model at that fixed point, varying the value of theta

breaks <- c(seq(10, max(x), by = 5), max(x)) # our breaks

# Want a table where the log likelihoods are stored, one row for every theta, one column for every break

theta_vals <- seq(0, 1, by = 0.01) # 101 values for theta

M <- matrix(nrow = length(theta_vals), ncol = length(breaks)+ 1)

LL <- as_tibble(M) %>% # This will hold our likelihoods for every value of x0
  mutate_all(as.numeric) %>% 
  rename(theta = V1) %>%  
  mutate(theta = theta_vals)

mle <- rep(NA, length(breaks)) # this will hold the maximum likelihood estimate from initial model
ll_hat <- rep(NA, length(breaks)) # this will hold the log likelihood from initial model

for(i in 1:(ncol(LL) - 1)){
  
  x0 <- rep(breaks[i], length(x)) # Get the break value of interest
  
  nm_0 <- nlmer(y ~ nlfun_k(x, x0, logvol, a, d, theta) ~ theta|Study, # Fit Model to get MLE
                control = nlmerControl(optimizer = "bobyqa",
                                       optCtrl = list(maxfun = 2e5,
                                                      upper = c(Inf, Inf, Inf, 1), # bounds theta between 0 and 1
                                                      lower = c(-Inf, -Inf, -Inf, 0))),
                start = c(a = 1, d = 1, theta = 0.5))
  
  mle[i] <- fixef(nm_0)["theta"] # get the mle for that fixed value of x0
  ll_hat[i] <- logLik(nm_0) # get the log-likelihood for that fixed value of x0
  for(j in 1:nrow(LL)){
    
    theta_lim <- as.numeric(LL[j, 1]) # Get theta value
    
    try({nm_k <- nlmer(y ~ nlfun_k(x, x0, logvol, a, d, theta) ~ theta|Study, # fit the model
                       control = nlmerControl(optimizer = "bobyqa",
                                              optCtrl = list(maxfun = 2e5,
                                                             upper = c(Inf, Inf, Inf, theta_lim + 0.005), # have tight bound on theta
                                                             lower = c(-Inf, -Inf, -Inf, theta_lim - 0.005))),
                       start = c(a = 1, d = 1, theta = theta_lim))}, silent = TRUE)
    # try() keeps loop running if it fails to converge
    
    LL[j, i + 1] <- as.numeric(logLik(nm_k)) # store log-likelihood
  }
}

#write.csv(LL, "chest_LL_profile.csv", row.names = FALSE)
#write.csv(ll_hat, "chest_ll_hat.csv", row.names = FALSE)
#write.csv(mle, "chest_mle_combined.csv", row.names = FALSE)

#LL <- read_csv("C:/Users/skoike/Desktop/Reanalysis/New Species/Chestnut Oak/chest_LL_profile.csv")
#ll_0 <- read_csv("C:/Users/skoike/Desktop/Reanalysis/New Species/Chestnut Oak/chest_ll_hat.csv")
#mle <- read_csv("C:/Users/skoike/Desktop/Reanalysis/New Species/Chestnut Oak/chest_mle_combined.csv")

#ll_hat <- as_vector(ll_0)
#mle <- as_vector(mle)

LL
ll_hat
mle

# Look at the LL profile
qplot(theta, V2, data = LL, geom = "line") + geom_vline(xintercept = mle[1], color = "red")
qplot(theta, V3, data = LL, geom = "line") + geom_vline(xintercept = mle[2], color = "red")
qplot(theta, V4, data = LL, geom = "line") + geom_vline(xintercept = mle[3], color = "red")
qplot(theta, V5, data = LL, geom = "line") + geom_vline(xintercept = mle[4], color = "red")
qplot(theta, V6, data = LL, geom = "line") + geom_vline(xintercept = mle[5], color = "red")



# The profiles are well-behaved, but we'll take a small window around the MLE and add a smoothing curve in order
# to be precise when creating the likelihood CI

LL_1 <- LL 

LL_2 <- LL_1 %>% pivot_longer(cols = -theta, names_to = "V", values_to = "LL")

ll_hat_frame <- tibble(V = colnames(LL)[-1], ll_hat)

q <- qchisq(0.95, 1) # Critical value: LR ~ chi-sq(1)

LL_4 <- full_join(LL_2, ll_hat_frame) %>% 
  group_by(V) %>% 
  mutate(LR = 2 * (ll_hat - LL)) %>% # LR statistic
  filter(LR <= q) %>% # Keep the values where we would not reject the null hypothesis
  slice(1, n()) %>% # Get the maximum and minimum of these theta values 
  select(V, theta) %>% 
  mutate(y = c("ymin", "ymax")) %>% 
  pivot_wider(names_from = y, values_from = theta) %>%
  mutate(V = str_replace(V, "V", ""),
         V = as.numeric(V)) %>% 
  arrange(V)

LL_4
# adjust for the fact that the mle from above does not correspond exactly with original model

pred_0 <- 1 - exp(-(breaks/coef_mod[2]))

adj <- mle - pred_0

plot(mle, pred_0)
abline(a = 0, b = 1)

LL_4$adj <- adj

LL_5 <- LL_4 %>%
  ungroup() %>% 
  mutate(ymin = ymin - adj,
         ymax = ymax - adj,
         x = breaks) %>% 
  select(-adj, -V)

LL_5

LL_6 <- LL_5 %>% 
  mutate(ymin = ifelse(ymin < 0, 0, ymin)) %>% 
  add_row(ymin = 0, ymax = 0, x = 0, .before = 1)

LL_6

plot(LL_6$x, LL_6$ymax, type = "l", ylim = c(0, 0.6), xlim = c(0, 85))
lines(LL_6$x, LL_6$ymin)
lines(breaks, pred_0, lty = 2)


# Write file

write.csv(LL_6, "chest_para_ci.csv", row.names = FALSE)
