library(tidyverse)

# Read in predictive curve
SUM <- read_csv("C:/Users/skoike/Desktop/Reanalysis/New Species/Sumac/sum_lines.csv")

# Read Parametric CI

para_ci <- read_csv("C:/Users/skoike/Desktop/Reanalysis/New Species/Sumac/sum_para_ci.csv") %>% 
  arrange(x)

new_pred <- data.frame(x = SUM$x)

# smooth out ymin
f <- function(x, a, b){
  a * x^b
}

plot(para_ci$x, para_ci$ymin)

y_lower_fcn <- minpack.lm::nlsLM(ymin ~ f(x, a, b), data = para_ci,
                   start = list(a = 1, b = 1))
new_ymin <- predict(y_lower_fcn, newdata = new_pred)
new_pred$new_ymin <- new_ymin

lines(new_pred$x, new_pred$new_ymin)


# Smooth ymax

plot(para_ci$x, para_ci$ymax)

y_upper_fcn <- minpack.lm::nlsLM(ymax ~ f(x, a, b), data = para_ci,
                   start = list(a = 1, b = 1))
new_ymax <- predict(y_upper_fcn, newdata = new_pred)
new_pred$new_ymax <- new_ymax

lines(new_pred$x, new_pred$new_ymax)

new_pred <- new_pred %>% mutate_at(vars(-x), function(x){x*100})

ci_plot <- ggplot(new_pred) + 
  aes(x = x) + 
  geom_ribbon(aes(ymin = new_ymin, ymax = new_ymax), alpha = 0.3) +
  geom_line(data = SUM, aes(x = x, y = 100*(1 - exp(y))), size = 1, color = "blue") + 
  ylab("Predicted Relative Biomass Loss (%)") + 
  xlab("W126 (ppm-h)") + 
  scale_y_continuous(breaks = c(0, 10, 20, 30, 40, 50, 60)) + 
  scale_x_continuous(breaks = c(10, 20, 30))

ci_plot + ggtitle("Sumac")

# Export data for grid plot
#ggplot_build(ci_plot) data[[1]] has band info, data[[2]] has predicted curve

bands <- ggplot_build(ci_plot)$data[[1]] %>% select(x, ymin, ymax) %>% mutate(x = round(x, 7))
pred_curve <- ggplot_build(ci_plot)$data[[2]] %>% select(x, y) %>% mutate(x = round(x, 7))

sum_info <- full_join(bands, pred_curve) %>% 
  mutate(Species = factor("Sumac")) %>% 
  select(Species, x, y, ymin, ymax)

#write.csv(sum_info, "sum_bands.csv", row.names = FALSE)
