library(tidyverse)

sweetgum <- read_csv("C:/Users/skoike/Desktop/Reanalysis/New Species/Sweetgum/sg_mean_data.csv") %>% 
  mutate(Species = "Sweetgum",
         Study = factor(1990),
         Site = "SMNP") %>% 
  rename(actual.24 = OZ.24,
         actual.24.adj = OZ.24.adj,
         actual.12.7 = OZ.12.7,
         actual.12.8 = OZ.12.8,
         actual.12.9 = OZ.12.9,
         actual.12.7.adj = OZ.12.7.adj,
         actual.12.8.adj = OZ.12.8.adj,
         actual.12.9.adj = OZ.12.9.adj)

studies <- sweetgum %>%  
  select(Species, Study, Site, Year, Harvest, Exp_days, CHAMB, TREAT, everything())

studies %>% 
  filter(TREAT != 0) %>% 
  ggplot() + 
  aes(x = LOGVOL_bl, y = LOGTOTALDW, fill = Study, color = Study) + 
  geom_point(shape = 21, size = 2, color = "black") + 
  geom_smooth(method = "lm", se = FALSE)

studies %>% 
  filter(TREAT != 0) %>%
  ggplot() + 
  aes(x = w126.12.8.adj, y = LOGTOTALDW, fill = Study, color = Study) + 
  geom_point(shape = 21, size = 2, color = "black") + 
  geom_smooth(method = "lm", se = FALSE)


# Random effects Model ---------------------------------------------------
library(lme4)

SG <- studies %>% 
  mutate(TREAT = case_when(TREAT == 1 ~ "CF",
                           TREAT == 2 ~ "0.5x",
                           TREAT == 3 ~ "1x",
                           TREAT == 4 ~ "1.5x",
                           TREAT == 5 ~ "2x",
                           TRUE ~ "AA"),
         TREAT = as_factor(TREAT))

SG %>% 
  mutate(W126 = w126.12.8.adj*Exp_days/92) %>% 
  group_by(Study, Harvest, Site, TREAT) %>% 
  summarise(m = round(mean(W126), 1))

SG1 <- SG %>% filter(TREAT != "AA") %>% mutate(centered_logvol = LOGVOL_bl - mean(LOGVOL_bl))
SG2 <- SG %>% filter(TREAT == "AA")

SG3 <- full_join(SG1, SG2) %>% 
  select(Species, Study, Site, Year, Harvest, Exp_days, CHAMB, TREAT, 
         ends_with("DW"), centered_logvol, everything()) 

#write.csv(SG3, "sg_chamber_mean_data.csv", row.names = FALSE)

SG <- SG1

# No covariate, estimate c
nform1 <- ~ log(a) + (-(input/b)^c)

nfun1 <- deriv(nform1,
               namevec = c("a", "b", "c"),
               function.arg = c("input", "a", "b", "c"))

nm1 <- nlmer(LOGTOTALDW ~ nfun1(w126.12.8.adj, a, b, c) ~ b + c | Study,
             data = SG,
             control = nlmerControl(optimizer = "bobyqa", 
                                    optCtrl = list(maxfun = 2e5)),
             start = c(a = 1, b = 1, c = 1))
summary(nm1) # B = 34.3, C = 9.6

aug1 <- broom.mixed::augment(nm1)

aug1 %>% 
  ggplot() + 
  aes(x = .fitted, y = .resid, color = Study) + 
  geom_point() + 
  geom_hline(yintercept = 0, color = "red") + 
  scale_color_brewer(palette = "Set1")

aug1 %>% 
  ggplot() + 
  aes(sample = .resid) + 
  geom_qq() + 
  geom_qq_line()


# No covariate set c = 1 -------------------------------

nform2 <- ~ log(a) + (-(x/b))

nfun2 <- deriv(nform2,
               namevec = c("a", "b"),
               function.arg = c("x", "a", "b"))

nm2 <- nlmer(LOGTOTALDW ~ nfun2(w126.12.8.adj, a, b) ~ (b | Study),
             data = SG,
             control = nlmerControl(optimizer = "bobyqa", optCtrl = list(maxfun = 2e5)),
             start = c(a = 1, b = 40))
summary(nm2) # B = 100

aug2 <- broom.mixed::augment(nm2)

aug2 %>% 
  ggplot() + 
  aes(x = .fitted, y = .resid, color = Study) + 
  geom_point() + 
  geom_hline(yintercept = 0, color = "red") + 
  scale_color_brewer(palette = "Set1")

aug2 %>% 
  ggplot() + 
  aes(sample = .resid) + 
  geom_qq() + 
  geom_qq_line()


# Covariate, estimate c
nform3 <- ~ log(a + d*logvol) + (-(x/b)^c)

nfun3 <- deriv(nform3,
               namevec = c("a", "b", "c", "d"),
               function.arg = c("x", "logvol", "a", "b", "c", "d"))

nm3 <- nlmer(LOGTOTALDW ~ nfun3(w126.12.8.adj, centered_logvol, a, b, c, d) ~ b + c | Study,
             data = SG,
             control = nlmerControl(optimizer = "bobyqa", 
                                    optCtrl = list(maxfun = 2e5)),
             start = c(a = 50, b = 1, c = 1, d = 1))
summary(nm3) # B = 34.6, C = 9.7

aug3 <- broom.mixed::augment(nm3)

aug3 %>% 
  ggplot() + 
  aes(x = .fitted, y = .resid, color = Study) + 
  geom_point() + 
  geom_hline(yintercept = 0, color = "red") + 
  scale_color_brewer(palette = "Set1")

aug3 %>% 
  ggplot() + 
  aes(sample = .resid) + 
  geom_qq() + 
  geom_qq_line()

# Covariate, C = 1
nform4 <- ~ log(a + d*logvol) + (-(x/b))

nfun4 <- deriv(nform4,
               namevec = c("a", "b", "d"),
               function.arg = c("x", "logvol", "a", "b", "d"))

nm4 <- nlmer(LOGTOTALDW ~ nfun4(w126.12.8.adj, centered_logvol, a, b, d) ~ b | Study,
             data = SG,
             control = nlmerControl(optimizer = "bobyqa", 
                                    optCtrl = list(maxfun = 2e5)),
             start = c(a = 50, b = 50, d = 1))
summary(nm4) # B = 138.4

aug4 <- broom.mixed::augment(nm4)

aug4 %>% 
  ggplot() + 
  aes(x = .fitted, y = .resid, color = Study) + 
  geom_point() + 
  geom_hline(yintercept = 0, color = "red") + 
  scale_color_brewer(palette = "Set1")

aug4 %>% 
  ggplot() + 
  aes(sample = .resid) + 
  geom_qq() + 
  geom_qq_line()

# Covariate, estimated, but bound
nform5 <- ~ log(a + d*logvol) + (-(x/b)^c)

nfun5 <- deriv(nform5,
               namevec = c("a", "b", "c", "d"),
               function.arg = c("x", "logvol", "a", "b", "c", "d"))

nm5 <- nlmer(LOGTOTALDW ~ nfun5(w126.12.8.adj, centered_logvol, a, b, c, d) ~ b + c | Study,
             data = SG,
             control = nlmerControl(optimizer = "bobyqa", 
                                    optCtrl = list(maxfun = 2e5,
                                                   upper = c(rep(Inf, 5), 3, Inf),
                                                   lower = c(rep(-Inf, 5), 0, -Inf))),
             start = c(a = 50, b = 1, c = 1, d = 1))
summary(nm5) # B = 44.5, C = 3

aug5 <- broom.mixed::augment(nm5)

aug5 %>% 
  ggplot() + 
  aes(x = .fitted, y = .resid, color = Study) + 
  geom_point() + 
  geom_hline(yintercept = 0, color = "red") + 
  scale_color_brewer(palette = "Set1")

aug5 %>% 
  ggplot() + 
  aes(sample = .resid) + 
  geom_qq() + 
  geom_qq_line()



# Model Comparison ---------------------------------

fixef(nm1) # Estimated C
fixef(nm2) # Set C = 1
fixef(nm3) # Covariate, estimated C
fixef(nm4) # Covariate, C = 1
fixef(nm5) # Covariate, estimated, bound C


mean(aug1$.resid^2) 
mean(aug2$.resid^2)  
mean(aug3$.resid^2) # smallest 
mean(aug4$.resid^2) 
mean(aug5$.resid^2) 



(SSRes1 <- sum(aug1$.resid^2))  
(SSRes2 <- sum(aug2$.resid^2)) 
(SSRes3 <- sum(aug3$.resid^2)) # smallest
(SSRes4 <- sum(aug4$.resid^2)) 
(SSRes5 <- sum(aug5$.resid^2)) 


meanY <- mean(aug1$LOGTOTALDW) 
SStot <- sum((aug1$LOGTOTALDW - meanY)^2) 

(r_sq_1 <- 1 - SSRes1/SStot)
(r_sq_2 <- 1 - SSRes2/SStot) 
(r_sq_3 <- 1 - SSRes3/SStot) # largest
(r_sq_4 <- 1 - SSRes4/SStot) 
(r_sq_5 <- 1 - SSRes5/SStot) 

SSreg <- sum((aug1$.fitted - meanY)^2)
SSreg/SStot

# Figure 
nform1
(coef_mod <- fixef(nm1))
broom::tidy(nm1)

SG1 <- SG %>% mutate(adj_y = LOGTOTALDW - log(coef_mod[1])) %>% 
  select(w126.12.8.adj, adj_y)

pred1 <- tibble(w126.12.8.adj =  c(seq(0, max(SG1$w126.12.8.adj), by = 0.5), max(SG1$w126.12.8.adj)),
               adj_y = -(w126.12.8.adj/coef_mod[2])^coef_mod[3])

SG_plot1 <- ggplot(SG1) + 
  aes(x = w126.12.8.adj, y = adj_y) +
  geom_point(size = 2, color = "red") + 
  geom_line(data = pred1, color = "black", size = 0.75)
SG_plot1

round(100*(1 - exp(-(c(10, 20, 30, 40, 50)/coef_mod[2])^coef_mod[3])), 1)

y_hat <- -(SG1$w126.12.8.adj/coef_mod[2])^coef_mod[3]
y <- SG1$adj_y

plot(y, y_hat)
abline(a = 0, b = 1)

SSRes <- sum((y - y_hat)^2)
SSTot <- sum((y - mean(y))^2)

1 - SSRes/SSTot

mean((y - y_hat)^2) 


# Linear

nform4
(coef_mod2 <- fixef(nm4))

SG2 <- SG %>% mutate(adj_y = LOGTOTALDW - log(coef_mod2[1] + coef_mod2[3]*centered_logvol)) %>% 
  select(w126.12.8.adj, adj_y)

pred2 <- tibble(w126.12.8.adj =  c(seq(0, max(SG2$w126.12.8.adj), by = 0.5), max(SG2$w126.12.8.adj)),
                adj_y = -(w126.12.8.adj/coef_mod2[2]))

SG_plot2 <- ggplot(SG2) + 
  aes(x = w126.12.8.adj, y = adj_y) +
  geom_point(size = 2, color = "red") + 
  geom_line(data = pred2, color = "black", size = 0.75)
SG_plot2

# bound

nform5
(coef_mod3 <- fixef(nm5))

SG3 <- SG %>% mutate(adj_y = LOGTOTALDW - log(coef_mod3[1] + coef_mod3[3]*centered_logvol)) %>% 
  select(w126.12.8.adj, adj_y)

pred3 <- tibble(w126.12.8.adj =  c(seq(0, max(SG3$w126.12.8.adj), by = 0.5), max(SG3$w126.12.8.adj)),
                adj_y = -(w126.12.8.adj/coef_mod3[2])^coef_mod3[3])

SG_plot3 <- ggplot(SG3) + 
  aes(x = w126.12.8.adj, y = adj_y) +
  geom_point(size = 2, color = "red") + 
  geom_line(data = pred3, color = "black", size = 0.75)
SG_plot3


# Compare the Plots --------------------------------------
pred4 <- full_join(pred1 %>% mutate(Model = factor("Nonlinear")),
                   pred2 %>% mutate(Model = factor("Linear"))) %>% 
  full_join(pred3 %>% mutate(Model = factor("Bound")))

SG4 <- full_join(SG1 %>% mutate(Model = factor("Nonlinear")),
                 SG2 %>% mutate(Model = factor("Linear"))) %>% 
  full_join(SG3 %>% mutate(Model = factor("Bound")))

ggplot(SG4) + 
  aes(x = w126.12.8.adj, y = adj_y) + 
  geom_point(shape = 21, fill = "red", size = 2) + 
  geom_line(data = pred4, size = 1) + 
  facet_wrap(. ~ Model)

sg_lines <- ggplot_build(SG_plot1)$data[[2]] %>% 
  select(x, y) %>% 
  mutate(Species = factor("Sweetgum"))

#write.csv(sg_lines, "sg_lines.csv", row.names = FALSE)


sg_b <- tibble(b = coef_mod[2], c = coef_mod[3], Species = "Sweetgum")

#write.csv(sg_b, "sg_params.csv", row.names = FALSE)
#write.csv(coef_mod, "sg_all_params.csv")


# Likelihood Confidence Interval -----------------------------------------------

# Step 1: Pull out relevant variables so we don't have to refer to data 

y <- SG$LOGTOTALDW
x <- SG$w126.12.8.adj
Study <- SG$Study

# Step 2: Reparameterize the model so we can create a confidence interval around predicted biomass loss (theta)
coef_mod[3]
nform1
nlform_k <- ~ log(a) +  + ((x/x0)^9.693885  * log(1 - theta))

nlfun_k <- deriv(nlform_k,
                 namevec = c("a", "theta"),
                 function.arg = c("x", "x0", "a", "theta"))

# Step 3: At every break (e.g. 10, 20, 30, etc.), run the model at that fixed point, varying the value of theta

breaks <- c(seq(10, max(x), by = 5), max(x)) # our breaks

# Want a table where the log likelihoods are stored, one row for every theta, one column for every break

theta_vals <- seq(0, 1, by = 0.01) # 101 values for theta

M <- matrix(nrow = length(theta_vals), ncol = length(breaks)+ 1)

LL <- as_tibble(M) %>% # This will hold our likelihoods for every value of x0
  mutate_all(as.numeric) %>% 
  rename(theta = V1) %>%  
  mutate(theta = theta_vals)

mle <- rep(NA, length(breaks)) # this will hold the maximum likelihood estimate from initial model
ll_hat <- rep(NA, length(breaks)) # this will hold the log likelihood from initial model

for(i in 1:(ncol(LL) - 1)){
  
  x0 <- rep(breaks[i], length(x)) # Get the break value of interest
  
  nm_0 <- nlmer(y ~ nlfun_k(x, x0, a, theta) ~ theta | Study, # Fit Model to get MLE
                control = nlmerControl(optimizer = "bobyqa",
                                       optCtrl = list(maxfun = 2e5,
                                                      upper = c(Inf, Inf, 1), # bounds theta between 0 and 1
                                                      lower = c(-Inf, -Inf, 0))),
                start = c(a = 1, theta = 0.5))
  
  mle[i] <- fixef(nm_0)["theta"] # get the mle for that fixed value of x0
  ll_hat[i] <- logLik(nm_0) # get the log-likelihood for that fixed value of x0
  for(j in 1:nrow(LL)){
    
    theta_lim <- as.numeric(LL[j, 1]) # Get theta value
    
    try({nm_k <- nlmer(y ~ nlfun_k(x, x0, a, theta) ~ theta | Study, # fit the model
                       control = nlmerControl(optimizer = "bobyqa",
                                              optCtrl = list(maxfun = 2e5,
                                                             upper = c(Inf, Inf, theta_lim + 0.005), # have tight bound on theta
                                                             lower = c(-Inf, -Inf, theta_lim - 0.005))),
                       start = c(a = 1, theta = theta_lim))}, silent = TRUE)
    # try() keeps loop running if it fails to converge
    
    LL[j, i + 1] <- as.numeric(logLik(nm_k)) # store log-likelihood
  }
}

#write.csv(LL, "sg_LL_profile.csv", row.names = FALSE)
#write.csv(ll_hat, "sg_ll_hat.csv", row.names = FALSE)
#write.csv(mle, "sg_mle.csv", row.names = FALSE)

#LL <- read_csv("C:/Users/skoike/Desktop/Reanalysis/New Species/Sweetgum/sg_LL_profile.csv")
#ll_0 <- read_csv("C:/Users/skoike/Desktop/Reanalysis/New Species/Sweetgum/sg_ll_hat.csv")
#mle <- read_csv("C:/Users/skoike/Desktop/Reanalysis/New Species/Sweetgum/sg_mle.csv")

#ll_hat <- as_vector(ll_0)
#mle <- as_vector(mle)

LL
ll_hat
mle

# Look at the LL profile
qplot(theta, V2, data = LL, geom = "line") + geom_vline(xintercept = mle[1], color = "red")
qplot(theta, V3, data = LL, geom = "line") + geom_vline(xintercept = mle[2], color = "red")
qplot(theta, V4, data = LL, geom = "line") + geom_vline(xintercept = mle[3], color = "red")
qplot(theta, V5, data = LL, geom = "line") + geom_vline(xintercept = mle[4], color = "red")
qplot(theta, V6, data = LL, geom = "line") + geom_vline(xintercept = mle[5], color = "red")
qplot(theta, V7, data = LL, geom = "line") + geom_vline(xintercept = mle[6], color = "red")


LL_1 <- LL 

LL_2 <- LL_1 %>% pivot_longer(cols = -theta, names_to = "V", values_to = "LL")

ll_hat_frame <- tibble(V = colnames(LL)[-1], ll_hat)

q <- qchisq(0.95, 1) # Critical value: LR ~ chi-sq(1)

LL_4 <- full_join(LL_2, ll_hat_frame) %>%
  group_by(V) %>% 
  mutate(LR = 2 * (ll_hat - LL)) %>% # LR statistic
  filter(LR <= q) %>% # Keep the values where we would not reject the null hypothesis
  slice(1, n()) %>% # Get the maximum and minimum of these theta values 
  select(V, theta) %>% 
  mutate(y = c("ymin", "ymax")) %>% 
  pivot_wider(names_from = y, values_from = theta) %>%
  mutate(V = str_replace(V, "V", ""),
         V = as.numeric(V)) %>% 
  arrange(V)

LL_4
# adjust for the fact that the mle from above does not correspond exactly with original model

pred_0 <- 1 - exp(-(breaks/coef_mod[2])^coef_mod[3])

adj <- mle - pred_0

plot(mle, pred_0)
abline(a = 0, b = 1)

LL_4$adj <- adj

LL_5 <- LL_4 %>%
  ungroup() %>% 
  mutate(ymin = ymin - adj,
         ymax = ymax - adj,
         x = breaks) %>% 
  select(-adj, -V)

LL_5

LL_6 <- LL_5 %>% 
  mutate(ymin = ifelse(ymin < 0, 0, ymin)) %>% 
  add_row(ymin = 0, ymax = 0, x = 0, .before = 1)

LL_6

plot(LL_6$x, LL_6$ymax, type = "l", ylim = c(0, 0.6), xlim = c(0, 85))
lines(LL_6$x, LL_6$ymin)
lines(breaks, pred_0, lty = 2)


# Write file

write.csv(LL_6, "sg_para_ci.csv", row.names = FALSE)
