library(tidyverse)

# Read in predictive curve
PP <- read_csv("C:/Users/skoike/Desktop/Reanalysis/Ponderosa Pine Supplement/pp_lines_combined_harvest.csv")

# Read Parametric CI

para_ci <- read_csv("C:/Users/skoike/Desktop/Reanalysis/Ponderosa Pine Supplement/pp_para_ci_combined_harvest.csv") %>% 
  arrange(x) %>% 
  mutate_at(vars(-x), function(x){x*100})

plot(para_ci$x, para_ci$ymax, type = "l")
lines(para_ci$x, para_ci$ymin, type = "l")
lines(PP$x, 100*(1 - exp(PP$y)))

new_pred <- data.frame(x = PP$x)

# smooth out ymin
f <- function(x, a, b){
  a * x^b
}

plot(para_ci$x, para_ci$ymin) 

y_lower_fcn <- minpack.lm::nlsLM(ymin ~ f(x, a, b), data = para_ci, start = list(a = 1, b = 1))

new_pred$new_ymin <- predict(y_lower_fcn, newdata = new_pred)

plot(para_ci$x, para_ci$ymin) 
lines(new_pred$x, new_pred$new_ymin)

new_ymin
para_ci$ymin
# Smooth ymax

plot(para_ci$x, para_ci$ymax)

y_upper_fcn <- minpack.lm::nlsLM(ymax ~ f(x, a, b), data = para_ci[-c(2, 3), ], start = list(a = 1, b = 1),
                                 control = nls.control(maxiter = 100))
new_ymax <- predict(y_upper_fcn, newdata = new_pred)
new_pred$new_ymax <- new_ymax

lines(new_pred$x, new_pred$new_ymax)


ci_plot <- ggplot(new_pred) +  
  aes(x = x) + 
  geom_ribbon(aes(ymin = new_ymin, ymax = new_ymax), alpha = 0.3) +
  geom_line(data = PP, aes(x = x, y = 100*(1 - exp(y))), size = 1, color = "blue") + 
  ylab("Predicted Relative Biomass Loss (%)") + 
  xlab("W126 (ppm-h)") 
ci_plot

# Export data for grid plot
#ggplot_build(ci_plot) data[[1]] has band info, data[[2]] has predicted curve

bands <- ggplot_build(ci_plot)$data[[1]] %>% select(x, ymin, ymax) %>% mutate(x = round(x, 7))
pred_curve <- ggplot_build(ci_plot)$data[[2]] %>% select(x, y) %>% mutate(x = round(x, 7))

pp_info <- full_join(bands, pred_curve) %>% 
  mutate(Species = factor("Ponderosa Pine")) %>% 
  select(Species, x, y, ymin, ymax)

#write.csv(pp_info, "pp_bands.csv", row.names = FALSE)

