library(tidyverse)
library(lme4)

# Harvest 1 Studies -----------------------------------------------------------------

study_12r <- read_csv("C:/Users/skoike/Desktop/Reanalysis/Ponderosa Pine/12R_h1_mean_data.csv") %>% 
  mutate(Study = factor("Study 12R"), 
         CH = as_factor(CH),
         .before = 1) %>% 
  rename(NEEDLEDW = TNDW)
study_12d <- read_csv("C:/Users/skoike/Desktop/Reanalysis/Ponderosa Pine/12D_h1_mean_data.csv") %>% 
  mutate(Study = factor("Study 12D"), 
         CH = as_factor(CH), 
         .before = 1) %>% 
  rename(NEEDLEDW = TNDW) 

# Remove duplicated rows from 12D

dups <- full_join(study_12d, study_12r) %>% 
  select(-Study) %>% 
  arrange(CH)

d_ch <- dups %>% group_by(CH) %>% tally() %>% filter(n == 2)

d_ch

study_12d <- study_12d %>% filter(!CH %in% d_ch$CH)

study_26 <- read_csv("C:/Users/skoike/Desktop/Reanalysis/Ponderosa Pine/26_h1_mean_data.csv") %>% 
  mutate(Study = factor("Study 26"), 
         CH = as_factor(CH),
         .before = 1) %>% 
  rename(VOL_bl = VOL.bl)
study_34 <- read_csv("C:/Users/skoike/Desktop/Reanalysis/Ponderosa Pine/34_h1_mean_data.csv") %>% 
  mutate(Study = factor("Study 34"), 
         CH = as_factor(CH),
         .before = 1)
study_45 <- read_csv("C:/Users/skoike/Desktop/Reanalysis/Ponderosa Pine/45_h1_mean_data.csv") %>% 
  mutate(Study = factor("Study 45"), 
         CHAMB = as_factor(CHAMB),
         .before = 1) %>% 
  rename(CH = CHAMB)
study_48 <- read_csv("C:/Users/skoike/Desktop/Reanalysis/Ponderosa Pine/48_h1_mean_data.csv") %>% 
  mutate(Study = factor("Study 48"),
         CH = as_factor(CH))

harvest1 <- full_join(study_12d, study_12r) %>% 
  full_join(study_26) %>% 
  full_join(study_34) %>% 
  full_join(study_45) %>% 
  full_join(study_48) %>% 
  rename(TREAT = OZ,
         CHAMB = CH) %>% 
  mutate(Species = "Ponderosa Pine",
         Site = "FERF") %>% 
  select(Species, Study, Site, Year, Harvest, Exp_days, CHAMB, TREAT, everything(),
         -LOGVOL_h, -TAPRTDW, -LROOTDW)

# Harvest 3 Studies -----------------------------------------------------------------

study_12r <- read_csv("C:/Users/skoike/Desktop/Reanalysis/Ponderosa Pine/12R_h2_mean_data.csv") %>% 
  mutate(Study = factor("Study 12R"), CH = as_factor(CH)) %>% 
  rename(TREAT = OZ, NEEDLEDW = TNDW, CHAMB = CH) %>% 
  select(-LOGVOL_h)
study_26 <- read_csv("C:/Users/skoike/Desktop/Reanalysis/Ponderosa Pine/26_h2_mean_data.csv") %>% 
  mutate(Study = factor("Study 26")) %>% 
  select(-starts_with("hdm4_"))
study_34 <- read_csv("C:/Users/skoike/Desktop/Reanalysis/Ponderosa Pine/34_h2_mean_data.csv") %>% 
  mutate(Study = factor("Study 34"), CH = as_factor(CH)) %>% 
  rename(TREAT = OZ, CHAMB = CH) %>% 
  select(-LOGVOL_h)
study_57 <- read_csv("C:/Users/skoike/Desktop/Reanalysis/Ponderosa Pine/57_h2_mean_data.csv") %>% 
  mutate(Study = factor("Study 57"), CH = as_factor(CH)) %>% 
  rename(TREAT = OZ, CHAMB = CH) %>% 
  select(-LOGVOL_h)

harvest2 <- full_join(study_12r, study_26) %>% 
  full_join(study_34) %>% 
  full_join(study_57) %>% 
  mutate(Harvest = 2, Species = "Ponderosa Pine", Site = "FERF") %>% 
  select(Species, Study, Site, Year, Harvest, Exp_days, CHAMB, TREAT, everything())

#View(harvest2)
# Join the Harvests ---------------------------------------------------------------------------

PP <- full_join(harvest1, harvest2) 

PP %>% 
  mutate(W126 = w126.12.8.adj*Exp_days/92) %>% 
  group_by(Study, Harvest, Site, TREAT) %>% 
  summarise(m = round(mean(W126), 1)) %>% 
  arrange(Study, Harvest, m)

PP %>% 
  filter(Study == "Study 26") %>% 
  mutate(W126 = w126.12.8.adj*Exp_days/92) %>% 
  group_by(Study, Harvest, Site, Exp_days, TREAT) %>% 
  summarise(m = round(mean(W126), 1)) %>% 
  arrange(Study, Harvest, m)

PP %>% 
  group_by(Study, Harvest, Year) %>% 
  tally()
  
PP <- PP %>% 
  group_by(Study, Harvest) %>% 
  mutate(is_48 = ifelse(Study == "Study 48", 1, 0),
         is_h2 = ifelse(Harvest == 2, 1, 0),
         centered_logvol = LOGVOL_bl - mean(LOGVOL_bl))

PP1 <- PP %>% 
  select(Species, Study, Site, Year, Harvest, Exp_days, CHAMB, TREAT, 
         ends_with("DW"), is_48, is_h2, centered_logvol, everything())
#write.csv(PP1, "pp_chamber_mean_data.csv", row.names = FALSE)

ggplot(PP) + 
  aes(x = w126.12.8.adj, y = LOGTOTALDW, 
      shape = as_factor(Harvest), fill = Study, 
      color = Study, linetype = as_factor(Harvest)) + 
  geom_point(size = 2.5, color = "black") + 
  geom_smooth(method = "lm", se = FALSE) +
  scale_shape_manual(values = c(21, 24)) +
  scale_fill_brewer(palette = "Set1") + 
  scale_color_brewer(palette = "Set1")

ggplot(PP) + 
  aes(x = centered_logvol, y = LOGTOTALDW, 
      shape = as_factor(Harvest), fill = Study, 
      color = Study, linetype = as_factor(Harvest)) + 
  geom_point(size = 2.5, color = "black", alpha = 0.7) + 
  geom_smooth(method = "lm", se = FALSE) +
  scale_shape_manual(values = c(21, 24)) +
  scale_fill_brewer(palette = "Set1") + 
  scale_color_brewer(palette = "Set1")

fitmodel <- function(df){lm(LOGTOTALDW ~ centered_logvol, data = df)}

PP %>% 
  group_by(Study, Harvest) %>% 
  nest() %>% 
  mutate(model = map(data, fitmodel),
         tidied = map(model, broom::tidy)) %>% 
  unnest(tidied) %>% 
  filter(term == "centered_logvol")

# Harvest 48 has significant logvol

# Random Coefficient Model -----------------------------------------------------

PP <- PP %>% select(Study, Harvest, is_h2, is_48, centered_logvol, w126.12.8.adj, LOGTOTALDW)

# Model 0
nform0 <- ~ log(a + a48*is_48 + a3*is_h2 + d*is_48*logvol) + (-(x/b)^c)

nfun0 <- deriv(nform0,
              namevec = c("a", "a48", "a3", "b", "c", "d"),
              function.arg = c("x", "logvol", "is_48", "is_h2", "a", "a48", "a3", "b", "c", "d"))

nl0 <- nlmer(LOGTOTALDW ~ nfun0(w126.12.8.adj, centered_logvol, is_48, is_h2, a, a48, a3, b, c, d) ~ (a|Study) + (b+c|Study:Harvest),
            data = PP,
            control = nlmerControl(optimizer = "bobyqa", tolPwrss = 1e-9, optCtrl = list(maxfun = 2e5)),
            start = c(a = 1, a48 = 1, a3 = 1, b = 1, c = 1, d = 1))
summary(nl0) # B = 145, C = 1.4

augnl0 <- broom.mixed::augment(nl0)  

augnl0 %>% 
  ggplot() + 
  aes(x = .fitted, y = .resid, fill = Study, shape = factor(Harvest)) + 
  geom_point(size = 2.5) + 
  scale_shape_manual(values = c(21, 24)) + 
  geom_hline(yintercept = 0, color = "red") + 
  scale_fill_brewer(palette = "Set1")

augnl0 %>% 
  ggplot() + 
  aes(sample = .resid) + 
  geom_qq() + 
  geom_qq_line()

coef(nl0)


# Model 1
# Common B, C
# (Fixed) Unique intercept for study 48
# (Random) intercepts for harvest 1 and 3
# Covariate only for study 48

nform <- ~ log(a + a48*is_48 + a3*is_h2 + d*is_48*logvol) + (-(x/b)^c)

nfun <- deriv(nform,
              namevec = c("a", "a48", "a3", "b", "c", "d"),
              function.arg = c("x", "logvol", "is_48", "is_h2", "a", "a48", "a3", "b", "c", "d"))

nl <- nlmer(LOGTOTALDW ~ nfun(w126.12.8.adj, centered_logvol, is_48, is_h2, a, a48, a3, b, c, d) ~ (a|Study) + (a3|Study) + (b|Study) + (c|Study),
            data = PP,
            control = nlmerControl(optimizer = "bobyqa", optCtrl = list(maxfun = 2e5)),
            start = c(a = 1, a48 = 1, a3 = 1, b = 10, c = 1, d = 1))
summary(nl) # B = 136.67, C = 1.5937

augnl <- broom.mixed::augment(nl)  

augnl %>% 
  ggplot() + 
  aes(x = .fitted, y = .resid, fill = Study) + 
  geom_point(shape = 21, size = 2.5) + 
  geom_hline(yintercept = 0, color = "red") + 
  scale_fill_brewer(palette = "Set1")

augnl %>% 
  ggplot() + 
  aes(sample = .resid) + 
  geom_qq() + 
  geom_qq_line()

# Model 2
# Common B
# C = 1
# (Fixed) Unique intercept for study 48
# (Random) intercepts for harvest 1 and 3
# Covariate only for study 48


nform2 <- ~ log(a + a48*is_48 + a3*is_h2 + d*is_48*logvol) + (-(x/b))

nfun2 <- deriv(nform2,
               namevec = c("a", "a48", "a3", "b", "d"),
               function.arg = c("x", "logvol", "is_48", "is_h2", "a", "a48", "a3", "b", "d"))

nl2 <- nlmer(LOGTOTALDW ~ nfun2(w126.12.8.adj, centered_logvol, is_48, is_h2, a, a48, a3, b, d) ~ a + a3 + b | Study,
            data = PP,
            control = nlmerControl(optimizer = "bobyqa", optCtrl = list(maxfun = 2e5)),
            start = c(a = 1, a48 = 1, a3 = 1, b = 1, d = 1))
summary(nl2) # B = 184.039

augnl2 <- broom.mixed::augment(nl2)  

augnl2 %>% 
  ggplot() + 
  aes(x = .fitted, y = .resid, fill = Study) + 
  geom_point(shape = 21, size = 2.5) + 
  geom_hline(yintercept = 0, color = "red") + 
  scale_fill_brewer(palette = "Set1")

augnl2 %>% 
  ggplot() + 
  aes(sample = .resid) + 
  geom_qq() + 
  geom_qq_line()

# Model Comparison ---------------------------------------------------------

fixef(nl0)
fixef(nl)
fixef(nl2)

# nl <- B = 132, C = 1.74
# nl2 <- B = 184.03, C = 1

anova(nl2, nl) # p > 0.05 -> simpler (nl2) (p ~ 0.08)

mean(augnl0$.resid^2) 
mean(augnl$.resid^2) # Lower MSE
mean(augnl2$.resid^2) 

sum((augnl0$.resid)^2)
sum((augnl$.resid)^2) # Lower SSE
sum((augnl2$.resid)^2)


meanY <- mean(augnl$LOGTOTALDW) 
SStot <- sum((augnl$LOGTOTALDW - meanY)^2) 

SSRes0 <- sum(augnl0$.resid^2)
SSRes <- sum(augnl$.resid^2)
SSRes2 <- sum(augnl2$.resid^2)

(r_sq_0 <- 1 - SSRes0/SStot)
(r_sq <- 1 - SSRes/SStot) # Higher R2
(r_sq_2 <- 1 - SSRes2/SStot)


# Model B: Different B and C by Harvest

nformb <- ~ log(a + a48*is_48 + a3*is_h2 + d*is_48*logvol) + (-(x/(b + b2*is_h2))^(c + c2*is_h2))

nfunb <- deriv(nformb,
              namevec = c("a", "a48", "a3", "b", "b2", "c", "c2", "d"),
              function.arg = c("x", "logvol", "is_48", "is_h2", "a", "a48", "a3", "b", "b2", "c", "c2", "d"))

nlb <- nlmer(LOGTOTALDW ~ nfunb(w126.12.8.adj, centered_logvol, is_48, is_h2, a, a48, a3, b, b2, c, c2, d) ~ (a + a3 + b + c|Study),
            data = PP,
            control = nlmerControl(optimizer = "bobyqa", optCtrl = list(maxfun = 2e5)),
            start = c(a = 1, a48 = 1, a3 = 1, b = 1, b2 = 1, c = 1, c2 = 1, d = 1))
summary(nlb) # B = 162.9, B2 = -43.5, C = 1.48046, C2 = 0.02184

lmtest::lrtest(nl, nlb)


# Figure ---------------------------------------------------------------------------
nform
#broom::tidy(nl) %>% View()
(coef_mod <- fixef(nl))

PP1 <- PP %>% 
  mutate(adj_y = LOGTOTALDW - log(coef_mod[1] + coef_mod[2]*is_48 + coef_mod[3]*is_h2 + (coef_mod[6]*is_48)*centered_logvol))

pred1 <- tibble(w126.12.8.adj = c(seq(0, max(PP$w126.12.8.adj), by = 0.5), max(PP$w126.12.8.adj)),
                adj_y = -(w126.12.8.adj/coef_mod[4])^coef_mod[5])

PP_plot <- ggplot(PP1) + 
  aes(x = w126.12.8.adj, y = adj_y) + 
  geom_point(size = 2, aes(shape = factor(Harvest), fill = Study)) + 
  geom_line(data = pred1, size = 1) + 
  scale_shape_manual(values = c(21, 24)) + 
  scale_fill_brewer(palette = "Set1") + 
  guides(fill = guide_legend(override.aes = list(shape = 21)))

PP_plot

a <- round(100*(1 - exp(-(c(10, 20, 30, 40, 50)/coef_mod[4])^coef_mod[5])), 1)

a

round(100*(1 - exp(-(80/coef_mod[4])^coef_mod[5])), 1)

w126_frame <- PP %>% 
  group_by(Study, Harvest) %>% 
  summarize(min_w126 = min(w126.12.8.adj),
            max_w126 = max(w126.12.8.adj)) %>% 
  mutate(x = map2(min_w126, max_w126, seq, by = 0.01)) %>% 
  unnest(cols = x) 

coef_frame <- coef(nl)[1] %>% 
  as.data.frame() %>% 
  rownames_to_column("Study") %>% 
  select(Study, ends_with("b"), ends_with("c")) %>% 
  rename(b = Study.b, c = Study.c)

PP_lines <- full_join(w126_frame, coef_frame) %>% 
  mutate(y = -(x/b)^c)

nform

intercept_frame <- coef(nl)[1] %>% 
  as.data.frame() %>% 
  rownames_to_column("Study") %>% 
  select(Study, Study.a, Study.a48, Study.a3, Study.d)


PP_points <- full_join(PP, intercept_frame) %>% 
  mutate(Study.a48 = Study.a48 * is_48,
         Study.a3 = Study.a3 * is_h2,
         Study.d = Study.d * is_48) %>% 
  rename(a = Study.a, 
         a48 = Study.a48,
         a3 = Study.a3,
         d = Study.d) %>% 
  mutate(adj_y = LOGTOTALDW - log(a + a48 + a3 + d*centered_logvol))


PP_sub <- PP %>% select(Study, Harvest) %>% mutate(Model = factor("Population"))

pred1_a <- pred1 %>% 
  mutate(Model = factor("Population")) %>% 
  full_join(PP_sub) %>% 
  rename(x = w126.12.8.adj, y = adj_y)

PP_lines <- PP_lines %>% mutate(Model = factor("Individual"))

pred <- full_join(PP_lines, pred1_a)

ggplot(PP_points) + 
  aes(x = w126.12.8.adj, y = adj_y) + 
  geom_point(size = 2, aes(shape = factor(Harvest), fill = Study)) + 
  geom_line(data = pred1, linetype = "dashed", alpha = 0.5) + 
  scale_shape_manual(values = c(21, 24)) + 
  scale_fill_brewer(palette = "Set1") + 
  guides(fill = guide_legend(override.aes = list(shape = 21))) + 
  facet_wrap(. ~ Study, nrow = 2) + 
  geom_line(data = PP_lines, aes(x = x, y = y), size = 1)

ggplot(PP_points) + 
  aes(x = w126.12.8.adj, y = adj_y) + 
  geom_point(size = 2, aes(shape = factor(Harvest), fill = Study)) + 
  scale_shape_manual(values = c(21, 24)) + 
  scale_fill_brewer(palette = "Set1") + 
  guides(fill = guide_legend(override.aes = list(shape = 21)),
         shape = FALSE) + 
  facet_wrap(. ~ Harvest) + 
  geom_line(data = pred %>% filter(Model == "Individual"), aes(x = x, y = y, linetype = Model, color = Study), size = 1) + 
  scale_color_brewer(palette = "Set1") + 
  geom_line(data = pred %>% filter(Model != "Individual"), aes(x = x, y = y, linetype = Model), color = "black", size = 1) 


y_hat <- -(PP_points$w126.12.8.adj/coef_mod[4])^coef_mod[5]
y <- PP_points$adj_y

plot(y, y_hat)
abline(a = 0, b = 1)

SSRes <- sum((y - y_hat)^2)
SSTot <- sum((y - mean(y))^2)

1 - SSRes/SSTot

mean((y - y_hat)^2) 


#write.csv(PP_points, "pp_figure_points.csv", row.names = FALSE)
#write.csv(pred, "pp_figure_pred.csv", row.names = FALSE)

pp_lines <- ggplot_build(PP_plot)$data[[2]] %>% 
  select(x, y) %>% 
  mutate(Species = factor("Ponderosa Pine"))

#write.csv(pp_lines, "pp_lines_combined_harvest.csv", row.names = FALSE)

pp_b <- tibble(b = coef_mod[4], c = coef_mod[5], Species = "Ponderosa Pine")

#write.csv(pp_b, "pp_params.csv", row.names = FALSE)
#write.csv(coef_mod, "pp_all_params.csv")

# Likelihood Confidence Interval -----------------------------------------------

# Step 1: Pull out relevant variables so we don't have to refer to data 

y <- PP$LOGTOTALDW
x <- PP$w126.12.8.adj
logvol <- PP$centered_logvol
Study <- PP$Study
is_48 <- PP$is_48
is_h2 <- PP$is_h2

# Step 2: Reparameterize the model so we can create a confidence interval around predicted biomass loss (theta)

#new_c
coef_mod[5]

nlform_k <- ~ log(a + a48*is_48 + a3*is_h2 + d*is_48*logvol) + 
  ((x/x0)^1.593675  * log(1 - theta))

nlfun_k <- deriv(nlform_k,
                 namevec = c("a", "a48", "a3", "d", "theta"),
                 function.arg = c("x", "x0", "logvol", "is_48", "is_h2", "a", "a48", "a3", "d", "theta"))

# Step 3: At every break (e.g. 10, 20, 30, etc.), run the model at that fixed point, varying the value of theta

breaks <- c(seq(10, max(x), by = 5), max(x)) # our breaks

# Want a table where the log likelihoods are stored, one row for every theta, one column for every break

theta_vals <- seq(0.005, 0.65, by = 0.005) # 101 values for theta

M <- matrix(nrow = length(theta_vals), ncol = length(breaks) + 1)

LL <- as_tibble(M) %>% # This will hold our likelihoods for every value of x0
  mutate_all(as.numeric) %>% 
  rename(theta = V1) %>%  
  mutate(theta = theta_vals)

mle <- rep(NA, length(breaks)) # this will hold the maximum likelihood estimate from initial model
ll_hat <- rep(NA, length(breaks)) # this will hold the log likelihood from initial model

for(i in 1:(ncol(LL) - 1)){
  
  x0 <- rep(breaks[i], length(x)) # Get the break value of interest
  
  nm_0 <- nlmer(y ~ nlfun_k(x, x0, logvol, is_48, is_h2, a, a48, a3, d, theta) ~ (a|Study) + (a3|Study) + (theta|Study), # Fit Model to get MLE
                control = nlmerControl(optimizer = "bobyqa",
                                       tolPwrss = 2e-7,
                                       optCtrl = list(maxfun = 2e5,
                                                      upper = c(rep(Inf, 7), 1),
                                                      lower = c(rep(-Inf, 7), 0))),
                start = c(a = 1, a48 = 1, a3 = 1, d = 1, theta = 0.25))
  
  mle[i] <- fixef(nm_0)["theta"] # get the mle for that fixed value of x0
  ll_hat[i] <- logLik(nm_0) # get the log-likelihood for that fixed value of x0
  for(j in 1:nrow(LL)){
    theta_lim <- as.numeric(LL[j, 1]) # Get theta value
    try({nm_k <- nlmer(y ~ nlfun_k(x, x0, logvol, is_48, is_h2, a, a48, a3, d, theta) ~ (a|Study) + (a3|Study) + (theta|Study), # Fit Model to get MLE
                       control = nlmerControl(optimizer = "bobyqa",
                                              tolPwrss = 2e-7,
                                              optCtrl = list(maxfun = 2e5,
                                                             upper = c(rep(Inf, 7), theta_lim + 0.005),
                                                             lower = c(rep(-Inf, 7), theta_lim - 0.005))),
                       start = c(a = 1, a48 = 1, a3 = 1, d = 1, theta = theta_lim))}, silent = TRUE)
    # try() keeps loop running if it fails to converge
    
    LL[j, i + 1] <- as.numeric(logLik(nm_k)) # store log-likelihood
  }
}  

#write.csv(LL, "pp_LL_profile_combined_harvest.csv", row.names = FALSE)
#write.csv(ll_hat, "pp_ll_hat_combined_harvest.csv", row.names = FALSE)
#write.csv(mle, "pp_mle_combined_harvest.csv", row.names = FALSE)

#LL <- read_csv("C:/Users/skoike/Desktop/Reanalysis/Ponderosa Pine Supplement/pp_LL_profile_combined_harvest.csv")
#ll_hat <- read_csv("C:/Users/skoike/Desktop/Reanalysis/Ponderosa Pine Supplement/pp_ll_hat_combined_harvest.csv")
#mle <- read_csv("C:/Users/skoike/Desktop/Reanalysis/Ponderosa Pine Supplement/pp_mle_combined_harvest.csv")

#ll_hat <- as_vector(ll_hat)
#mle <- as_vector(mle)

LL
ll_hat
mle

# Look at the LL profile
# The following figures show what this will look like at each cutoff point
qplot(theta, V2, data = LL, geom = "line") + 
  geom_vline(xintercept = mle[1], color = "red") 
qplot(theta, V3, data = LL, geom = "line") + 
  geom_vline(xintercept = mle[2], color = "red") 
qplot(theta, V4, data = LL, geom = "line") + 
  geom_vline(xintercept = mle[3], color = "red") 
qplot(theta, V5, data = LL, geom = "line") + 
  geom_vline(xintercept = mle[4], color = "red") 
qplot(theta, V6, data = LL, geom = "line") + 
  geom_vline(xintercept = mle[5], color = "red") 
qplot(theta, V7, data = LL, geom = "line") + 
  geom_vline(xintercept = mle[6], color = "red") 
qplot(theta, V8, data = LL, geom = "line") + 
  geom_vline(xintercept = mle[7], color = "red") 
qplot(theta, V9, data = LL, geom = "line") + 
  geom_vline(xintercept = mle[8], color = "red") 
qplot(theta, V10, data = LL, geom = "line") + 
  geom_vline(xintercept = mle[9], color = "red") 
qplot(theta, V11, data = LL, geom = "line") + 
  geom_vline(xintercept = mle[10], color = "red") 
qplot(theta, V12, data = LL, geom = "line") + 
  geom_vline(xintercept = mle[11], color = "red") 
qplot(theta, V13, data = LL, geom = "line") + 
  geom_vline(xintercept = mle[12], color = "red") 
qplot(theta, V14, data = LL, geom = "line") + 
  geom_vline(xintercept = mle[13], color = "red") 
qplot(theta, V15, data = LL, geom = "line") + 
  geom_vline(xintercept = mle[14], color = "red") 
qplot(theta, V16, data = LL, geom = "line") + 
  geom_vline(xintercept = mle[15], color = "red") 
qplot(theta, V17, data = LL, geom = "line") + 
  geom_vline(xintercept = mle[16], color = "red") 

# The profiles are not really well-behaved, so we'll take a small window around the MLE and add a smoothing curve in order
# to be precise when creating the likelihood CI

LL_1 <- LL 

# The following lines will do a apply the GAM en masse 

LL_2 <- LL_1 %>% pivot_longer(cols = -theta, names_to = "V", values_to = "LL")


ll_hat_frame <- tibble(V = colnames(LL)[-1], ll_hat)


q <- qchisq(0.95, 1) # Critical value: LR ~ chi-sq(1)

LL_4 <- full_join(LL_2, ll_hat_frame) %>% 
  group_by(V) %>% 
  mutate(LR = 2 * (ll_hat - LL)) %>% # LR statistic
  filter(LR <= q) %>% # Keep the values where we would not reject the null hypothesis
  slice(1, n()) %>% # Get the maximum and minimum of these theta values 
  select(V, theta) %>% 
  mutate(y = c("ymin", "ymax")) %>% 
  pivot_wider(names_from = y, values_from = theta) %>%
  mutate(V = str_replace(V, "V", ""),
         V = as.numeric(V)) %>% 
  arrange(V)

LL_4

# adjust for the fact that the mle from above does not correspond exactly with original model

pred_0 <- 1 - exp(-(breaks/coef_mod[4])^coef_mod[5])

adj <- mle - pred_0

plot(mle, pred_0)
abline(a = 0, b = 1)

LL_4$adj <- adj[-c(16, 17)]

LL_5 <- LL_4 %>%
  ungroup() %>% 
  mutate(ymin = ymin - adj,
         ymax = ymax - adj,
         x = breaks[-c(16, 17)]) %>% 
  select(-adj, -V)

LL_5

LL_6 <- LL_5 %>% 
  add_row(ymin = 0, ymax = 0, x = 0, .before = 1)

plot(LL_6$x, LL_6$ymax, type = "l", ylim = c(0, 0.6), xlim = c(0, 85))
lines(LL_6$x, LL_6$ymin)
lines(breaks, pred_0, lty = 2)


LL_7 <- LL_6 %>% slice(-c(3, 5))

# Write file

write.csv(LL_7, "pp_para_ci_combined_harvest.csv", row.names = FALSE)
