library(tidyverse)

study_11 <- read_csv("C:/Users/skoike/Desktop/Reanalysis/Quaking Aspen/11_h1_mean_data.csv") %>% 
  mutate(Study = factor("Study 11"),
         Site = "FERF") %>% 
  rename(LOGVOL_bl = LOGVOL.bl, VOL_bl = VOL.bl, CHAMB = CH, TREAT = OZ) %>% 
  select(-LOGVOL.h1)
study_37 <- read_csv("C:/Users/skoike/Desktop/Reanalysis/Quaking Aspen/37_h1_mean_data.csv") %>% 
  mutate(Study = factor("Study 37"),
         Site = "FERF") %>% 
  rename(LOGVOL_bl = LOGVOL.bl, VOL_bl = VOL.bl, CHAMB = CH, TREAT = OZ) %>% 
  select(-LOGVOL.h)
study_90 <- read_csv("C:/Users/skoike/Desktop/Reanalysis/Quaking Aspen/aspen_clone_90_mean_data.csv") %>% 
  mutate(Study = factor("1990"),
         Site = "Michigan",
         TREAT = as.character(TREAT)) %>% 
  select(-COARSEDW, -FINEDW, -LOGCOARSEDW, -LOGFINEDW, -LOGVOL_h) %>% 
  mutate(TREAT = case_when(TREAT == "5" ~ "1",
                           TREAT == "1" ~ "2",
                           TREAT == "2" ~ "3",
                           TREAT == "3" ~ "4",
                           TREAT == "4" ~ "5",
                           TREAT == "6" ~ "6")) #Treatment codes were messed up
study_91 <- read_csv("C:/Users/skoike/Desktop/Reanalysis/Quaking Aspen/aspen_clone_91_mean_data.csv") %>% 
  mutate(Study = factor("1991"),
         Site = "Michigan",
         TREAT = as.character(TREAT)) %>% 
  select(-LOGVOL_h)
study_seedling <- read_csv("C:/Users/skoike/Desktop/Reanalysis/Quaking Aspen/aspen_seed_mean_data.csv") %>% 
  mutate(Study = factor("Seedling"),
         Site = "Michigan",
         TREAT = as.character(TREAT)) %>% 
  rename(CHAMB = CHAMBER) %>% 
  select(-LOGVOL_h)

studies_ferf <- full_join(study_11, study_37) 

studies_clone <- full_join(study_90, study_91) %>% 
  mutate(Study = paste0(Year, ": ", CLONE), .before = 1) %>% 
  full_join(study_seedling) %>% 
  mutate(TREAT = as.character(TREAT)) %>% 
  rename(actual.24 = OZ.24,
         actual.24.adj = OZ.24.adj,
         actual.12.7 = OZ.12.7,
         actual.12.8 = OZ.12.8,
         actual.12.9 = OZ.12.9,
         actual.12.7.adj = OZ.12.7.adj,
         actual.12.8.adj = OZ.12.8.adj,
         actual.12.9.adj = OZ.12.9.adj) 

studies <- full_join(studies_ferf, studies_clone) %>% 
  mutate(Species = "Quaking Aspen") %>% 
  select(Species, Study, Site, Year, CLONE, Harvest, Exp_days, CHAMB, TREAT, everything())

ggplot(studies) + 
  aes(x = LOGVOL_bl, y = LOGTOTALDW, fill = Study, color = Study) + 
  geom_point(shape = 21, size = 2, color = "black") + 
  scale_fill_brewer(palette = "Paired") + 
  geom_smooth(method = "lm", se = FALSE) + 
  scale_color_brewer(palette = "Paired") + 
  theme_bw()

studies %>% select(Study, TREAT, Exp_days, w126.12.8.adj) 

ggplot(studies) + 
  aes(x = w126.12.8.adj, y = LOGTOTALDW, fill = Study, color = Study) + 
  geom_point(shape = 21, size = 2, color = "black") + 
  scale_fill_brewer(palette = "Paired") + 
  geom_smooth(method = "lm", se = FALSE) + 
  scale_color_brewer(palette = "Paired") + 
  theme_bw()

studies %>% 
  mutate(W126 = w126.12.8.adj*Exp_days/92) %>% 
  group_by(Study, TREAT, Exp_days) %>% 
  summarise(m = round(mean(W126), 1)) %>% 
  arrange(Study, m)

studies %>% 
  nest_by(Study, Exp_days)


QA <- studies %>% 
  group_by(Study) %>% 
  mutate(centered_logvol = LOGVOL_bl - mean(LOGVOL_bl)) %>% 
  select(Species, Study, Site, Year, Harvest, Exp_days, CHAMB, TREAT, 
         ends_with("DW"), centered_logvol, everything())

#write.csv(QA, "qa_chamber_mean_data.csv", row.names = FALSE)

fitmodel <- function(df){lm(LOGTOTALDW ~ centered_logvol, data = df)}

QA %>% 
  group_by(Study) %>% 
  nest() %>% 
  mutate(model = map(data, fitmodel),
         tidied = map(model, broom::tidy)) %>% 
  unnest(tidied) %>% 
  filter(term == "centered_logvol") %>% 
  arrange(p.value)

QA1 <- QA %>% mutate(sig_logvol = ifelse(Study %in% c("1990: 216", "1991: 259"), 1, 0))

studies %>% group_by(Study) %>% tally()

#write.csv(studies, "qa_harvest_1.csv", row.names = FALSE)

# Random effects Model ---------------------------------------------------
library(lme4)

QA <- QA1 %>% select(Study, centered_logvol, w126.12.8.adj, LOGTOTALDW, sig_logvol)

ggplot(QA, aes(x = w126.12.8.adj, y = LOGTOTALDW, color = Study)) + 
  geom_point(size = 2) + 
  geom_smooth(method = "lm", se = FALSE)

qplot(centered_logvol, LOGTOTALDW, data = QA1, geom = "point", color = Study)

#####################

nform <- ~ log(a) + (-(input/b)) #Doesn't converge

nfun <- deriv(nform,
              namevec = c("a", "b"),
              function.arg = c("input", "a", "b"))

nm <- nlmer(LOGTOTALDW ~ nfun(w126.12.8.adj, a, b) ~ (b|Study), # Doesn't converge with random a
            data = QA,
            control = nlmerControl(optimizer = "bobyqa",
                                   optCtrl = list(maxfun = 2e5)),
            start = c(a = 50, b = 100))
summary(nm) # b = 58

aug <- broom.mixed::augment(nm)

ggplot(aug) + 
  aes(sample = .resid) + 
  geom_qq() + 
  geom_qq_line()


####################

# With Common Covariate, B, C 
nform1 <- ~ log(a + d * logvol) + (-(x/b)^c)

nfun1 <- deriv(nform1,
               namevec = c("a", "b", "c", "d"),
               function.arg = c("x", "logvol", "a", "b", "c", "d"))

nm1 <- nlmer(LOGTOTALDW ~ nfun1(w126.12.8.adj, centered_logvol, a, b, c, d) ~ a + b + c | Study,
             data = QA,
             control = nlmerControl(optimizer = "bobyqa",
                                    optCtrl = list(maxfun = 2e7)),
             start = c(a = 10, b = 50, c = 1, d = 1))
summary(nm1) #C = 1.4


aug1 <- broom.mixed::augment(nm1)

ggplot(aug1) + 
  aes(sample = .resid) + 
  geom_qq() + 
  geom_qq_line()

ggplot(aug1) + # pretty left-skewed
  aes(x = .resid) + 
  geom_histogram(aes(y = ..density..)) + 
  geom_density()

# With Covariate for some studies, B, C 
nform2 <- ~ log(a + d*sig_logvol*logvol) + (-(x/b)^c)

nfun2 <- deriv(nform2,
               namevec = c("a", "b", "c", "d"),
               function.arg = c("x", "logvol", "sig_logvol", "a", "b", "c", "d"))

nm2 <- nlmer(LOGTOTALDW ~ nfun2(w126.12.8.adj, centered_logvol, sig_logvol, a, b, c, d) ~ a + b + c | Study,
             data = QA,
             control = nlmerControl(optimizer = "bobyqa",
                                    optCtrl = list(maxfun = 2e7)),
             start = c(a = 10, b = 1, c = 1, d = 1))
summary(nm2) # C = 1.2

aug2 <- broom.mixed::augment(nm2)

ggplot(aug2) + 
  aes(sample = .resid) + 
  geom_qq() + 
  geom_qq_line()

ggplot(aug2) + # somewhat left-skewed
  aes(x = .resid) + 
  geom_histogram(aes(y = ..density..)) + 
  geom_density()

# With Covariate for some studies, B
nform3 <- ~ log(a + d*sig_logvol*logvol) + (-(x/b))

nfun3 <- deriv(nform3,
               namevec = c("a", "b", "d"),
               function.arg = c("x", "logvol", "sig_logvol", "a", "b", "d"))

nm3 <- nlmer(LOGTOTALDW ~ nfun3(w126.12.8.adj, centered_logvol, sig_logvol, a, b, d) ~ (a + b | Study),
             data = QA,
             control = nlmerControl(optimizer = "bobyqa",
                                    optCtrl = list(maxfun = 2e7)),
             start = c(a = 10, b = 1, d = 1))
summary(nm3) # C = 1.23

aug3 <- broom.mixed::augment(nm3)

ggplot(aug3) + 
  aes(sample = .resid) + 
  geom_qq() + 
  geom_qq_line()

ggplot(aug3) + 
  aes(x = .resid) + 
  geom_histogram(aes(y = ..density..)) + 
  geom_density()

# No Covariate, B, C 
nform4 <- ~ log(a) + (-(x/b)^c)

nfun4 <- deriv(nform4,
               namevec = c("a", "b", "c"),
               function.arg = c("x", "logvol", "a", "b", "c"))

nm4 <- nlmer(LOGTOTALDW ~ nfun4(w126.12.8.adj, centered_logvol, a, b, c) ~ (a + b | Study) + (c|Study),
             data = QA,
             control = nlmerControl(optimizer = "bobyqa", 
                                    optCtrl = list(maxfun = 2e7)),
             start = c(a = 1, b = 1, c = 1))
summary(nm4) #c = 1.25


aug4 <- broom.mixed::augment(nm4)

ggplot(aug4) + 
  aes(sample = .resid) + 
  geom_qq() + 
  geom_qq_line()

ggplot(aug4) + # pretty left-skewed
  aes(x = .resid) + 
  geom_histogram(aes(y = ..density..)) + 
  geom_density()

# With Common Covariate, B, C fixed (not random)

nform6 <- ~ log(a + d*logvol) + (-(x/b)^c)

nfun6 <- deriv(nform6,
               namevec = c("a", "b", "c", "d"),
               function.arg = c("x", "logvol", "a", "b", "c", "d"))

nm6 <- nlmer(LOGTOTALDW ~ nfun6(w126.12.8.adj, centered_logvol, a, b, c, d) ~ a + b | Study,
             data = QA,
             control = nlmerControl(optimizer = "bobyqa",
                                    tolPwrss = 1e-9,
                                    optCtrl = list(maxfun = 2e7)),
             start = c(a = 10, b = 100, c = 1, d = 1))
summary(nm6) #B = 93, C = 0.9774

aug6 <- broom.mixed::augment(nm6)

ggplot(aug6) + 
  aes(sample = .resid) + 
  geom_qq() + 
  geom_qq_line()

ggplot(aug6) + 
  aes(x = .resid) + 
  geom_histogram(aes(y = ..density..)) + 
  geom_density()


# Comparing models ------------------------------------------------

nform1 # common covariate, c random
nform2 # covariate for some, c random
nform4 # No covariate
nform6 # common covariate, c fixed

fixef(nm1) 
fixef(nm2) 
fixef(nm4) 
fixef(nm6) 


mean(aug1$.resid^2) 
mean(aug2$.resid^2)    
mean(aug4$.resid^2)
mean(aug6$.resid^2) # smallest

(SSRes1 <- sum(aug1$.resid^2))  
(SSRes2 <- sum(aug2$.resid^2)) 
(SSRes3 <- sum(aug3$.resid^2))   
(SSRes4 <- sum(aug4$.resid^2))  
(SSRes6 <- sum(aug6$.resid^2)) # smallest  

meanY <- mean(aug1$LOGTOTALDW) 
SStot <- sum((aug1$LOGTOTALDW - meanY)^2) 

(r_sq_1 <- 1 - SSRes1/SStot)
(r_sq_2 <- 1 - SSRes2/SStot)
(r_sq_3 <- 1 - SSRes3/SStot) 
(r_sq_4 <- 1 - SSRes4/SStot)
(r_sq_6 <- 1 - SSRes6/SStot) # largest

# Definitely going for common covariate, c fixed

SSreg <- sum((aug6$.fitted - meanY)^2)
SSreg/SStot

# Figure 
nform6

broom::tidy(nm6)

(coef_mod <- fixef(nm6))

QA <- QA %>% 
  mutate(adj_y = LOGTOTALDW - log(coef_mod[1] + coef_mod[4]*centered_logvol))

pred <- tibble(w126.12.8.adj = c(seq(0, max(QA$w126.12.8.adj), by = 0.5), max(QA$w126.12.8.adj)),
               adj_y = -(w126.12.8.adj/coef_mod[2])^coef_mod[3])

QA_plot <- ggplot(QA) + 
  aes(x = w126.12.8.adj, y = adj_y) +
  geom_point(aes(fill = Study), size = 2, shape = 21) + 
  geom_line(data = pred, color = "black", size = 0.75) 
QA_plot

qa_lines <- ggplot_build(QA_plot)$data[[2]] %>% 
  select(x, y) %>% 
  mutate(Species = factor("Quaking Aspen"))

#write.csv(qa_lines, "qa_lines.csv", row.names = FALSE)

qa_b <- tibble(b = coef_mod[2], c = coef_mod[3], Species = "Quaking Aspen")

round(100*(1 - exp(-(c(10, 20, 30, 40, 50)/coef_mod[2]))), 1) 

#write.csv(qa_b, "qa_params.csv", row.names = FALSE)
#write.csv(coef_mod, "qa_all_params.csv")

w126_frame <- QA %>% 
  group_by(Study) %>% 
  summarize(min_w126 = min(w126.12.8.adj),
            max_w126 = max(w126.12.8.adj)) %>% 
  mutate(x = map2(min_w126, max_w126, seq, by = 0.01)) %>% 
  unnest(cols = x) 

coef_frame <- coef(nm6)[1] %>% 
  as.data.frame() %>% 
  rownames_to_column("Study") %>% 
  select(Study, ends_with("b"), ends_with("c")) %>% 
  rename(b = Study.b, c = Study.c)

QA_lines <- full_join(w126_frame, coef_frame) %>% 
  mutate(y = -(x/b)^c)

nform6

intercept_frame <- coef(nm6)[1] %>% 
  as.data.frame() %>% 
  rownames_to_column("Study") %>% 
  select(Study, Study.a, Study.d)


QA_points <- full_join(QA, intercept_frame) %>% 
  rename(a = Study.a,
         d = Study.d) %>% 
  mutate(adj_y = LOGTOTALDW - log(a + d*centered_logvol))

QA_sub <- QA %>% select(Study) %>% mutate(Model = factor("Population"))

pred1_a <- pred %>% 
  mutate(Model = factor("Population")) %>% 
  full_join(QA_sub) %>% 
  rename(x = w126.12.8.adj, y = adj_y)

QA_lines <- QA_lines %>% mutate(Model = factor("Individual"))

pred2 <- full_join(QA_lines, pred1_a)

ggplot(QA_points) + 
  aes(x = w126.12.8.adj, y = adj_y) + 
  geom_point(shape = 21, size = 2, aes(fill = Study)) + 
  guides(fill = FALSE, color = FALSE) + 
  facet_wrap(. ~ Study, nrow = 2) + 
  geom_line(data = pred2 %>% filter(Model == "Individual"), aes(x = x, y = y, linetype = Model, color = Study), size = 1) + 
  geom_line(data = pred2 %>% filter(Model != "Individual"), aes(x = x, y = y, linetype = Model), color = "black", size = 1) 

ggplot(QA_points) + 
  aes(x = w126.12.8.adj, y = adj_y) + 
  geom_point(shape = 21, size = 2, aes(fill = Study)) + 
  geom_line(data = pred2 %>% filter(Model == "Individual"), aes(x = x, y = y, linetype = Model, color = Study), size = 1) + 
  geom_line(data = pred2 %>% filter(Model != "Individual"), aes(x = x, y = y, linetype = Model), color = "black", size = 1) 

y_hat <- -(QA_points$w126.12.8.adj/coef_mod[2])^coef_mod[3]
y <- QA_points$adj_y

plot(y, y_hat)
abline(a = 0, b = 1)

SSRes <- sum((y - y_hat)^2)
SSTot <- sum((y - mean(y))^2)

1 - SSRes/SSTot

mean((y - y_hat)^2) 


# Likelihood Confidence Interval -----------------------------------------------

# Step 1: Pull out relevant variables so we don't have to refer to data 

y <- QA$LOGTOTALDW
x <- QA$w126.12.8.adj
logvol <- QA$centered_logvol
Study <- QA$Study

# Step 2: Reparameterize the model so we can create a confidence interval around predicted biomass loss (theta)
coef_mod
nform6

# Use Taylor Series expansion around 0.5 to help with convergence

nlform_k <- ~ log(a + d*logvol) + ((x/x0) * (log(0.5) - 
                                               2*(theta - 0.5)^1 - 
                                               2*(theta - 0.5)^2 - 
                                               2.66666666666667*(theta - 0.5)^3 -
                                               4*(theta - 0.5)^4 - 
                                               6.4*(theta - 0.5)^5 -
                                               10.6666666666667*(theta - 0.5)^6 - 
                                               18.2857142857143*(theta - 0.5)^7))

nlfun_k <- deriv(nlform_k,
                 namevec = c("a", "d", "theta"),
                 function.arg = c("x", "x0", "logvol", "a", "d", "theta"))

# Step 3: At every break (e.g. 10, 20, 30, etc.), run the model at that fixed point, varying the value of theta

breaks <- c(seq(10, max(x), by = 5)) # our breaks

# Want a table where the log likelihoods are stored, one row for every theta, one column for every break

theta_vals <- seq(0, 1, by = 0.01) # 101 values for theta

M <- matrix(nrow = length(theta_vals), ncol = length(breaks)+ 1)

LL <- as_tibble(M) %>% # This will hold our likelihoods for every value of x0
  mutate_all(as.numeric) %>% 
  rename(theta = V1) %>%  
  mutate(theta = theta_vals)

mle <- rep(NA, length(breaks)) # this will hold the maximum likelihood estimate from initial model
ll_hat <- rep(NA, length(breaks)) # this will hold the log likelihood from initial model

for(i in 1:(ncol(LL) - 1)){
  
  x0 <- rep(breaks[i], length(x)) # Get the break value of interest
  
  nm_0 <- nlmer(y ~ nlfun_k(x, x0, logvol, a, d, theta) ~ theta | Study, # Fit Model to get MLE
                control = nlmerControl(optimizer = "bobyqa",
                                       #tolPwrss = 1e-5,
                                       optCtrl = list(maxfun = 2e5,
                                                      upper = c(Inf, Inf, Inf, 1), # bounds theta between 0 and 1
                                                      lower = c(-Inf, -Inf, -Inf, 0))),
                start = c(a = 4, d = 1, theta = 0.1))
  
  mle[i] <- fixef(nm_0)["theta"] # get the mle for that fixed value of x0
  ll_hat[i] <- logLik(nm_0) # get the log-likelihood for that fixed value of x0
  for(j in 1:nrow(LL)){
    
    theta_lim <- as.numeric(LL[j, 1]) # Get theta value
    
    try({nm_k <- nlmer(y ~ nlfun_k(x, x0, logvol, a, d, theta) ~ theta | Study, # fit the model
                       control = nlmerControl(optimizer = "bobyqa", 
                                              #tolPwrss = 6e-6, # reduce the tolerance to get convergence
                                              optCtrl = list(maxfun = 2e5,
                                                             upper = c(Inf, Inf, Inf, theta_lim + 0.005), # have tight bound on theta
                                                             lower = c(-Inf, -Inf, -Inf, theta_lim - 0.005))),
                       start = c(a = 4, d = 1, theta = theta_lim))}, silent = TRUE)
    # try() keeps loop running if it fails to converge
    
    LL[j, i + 1] <- as.numeric(logLik(nm_k)) # store log-likelihood
  }
}

#write.csv(LL, "qa_LL_profile_harvest1.csv", row.names = FALSE)
#write.csv(ll_hat, "qa_ll_hat_harvest1.csv", row.names = FALSE)
#write.csv(mle, "qa_mle_harvest1.csv", row.names = FALSE)

#LL <- read_csv("C:/Users/skoike/Desktop/Reanalysis/Quaking Aspen/qa_LL_profile_harvest1.csv")
#ll_0 <- read_csv("C:/Users/skoike/Desktop/Reanalysis/Quaking Aspen/qa_ll_hat_harvest1.csv")
#mle <- read_csv("C:/Users/skoike/Desktop/Reanalysis/Quaking Aspen/qa_mle_harvest1.csv")

#ll_hat <- as_vector(ll_0)
#mle <- as_vector(mle)

LL
ll_hat
mle


# Look at the LL profile
qplot(theta, V2, data = LL, geom = "line") + geom_vline(xintercept = mle[1], color = "red")
qplot(theta, V3, data = LL, geom = "line") + geom_vline(xintercept = mle[2], color = "red")
qplot(theta, V4, data = LL, geom = "line") + geom_vline(xintercept = mle[3], color = "red")
qplot(theta, V5, data = LL, geom = "line") + geom_vline(xintercept = mle[4], color = "red")
qplot(theta, V6, data = LL, geom = "line") + geom_vline(xintercept = mle[5], color = "red")
qplot(theta, V7, data = LL, geom = "line") + geom_vline(xintercept = mle[6], color = "red")
qplot(theta, V8, data = LL, geom = "line") + geom_vline(xintercept = mle[7], color = "red")
qplot(theta, V9, data = LL, geom = "line") + geom_vline(xintercept = mle[8], color = "red")
qplot(theta, V10, data = LL, geom = "line") + geom_vline(xintercept = mle[9], color = "red")
qplot(theta, V11, data = LL, geom = "line") + geom_vline(xintercept = mle[10], color = "red")
qplot(theta, V12, data = LL, geom = "line") + geom_vline(xintercept = mle[11], color = "red")
qplot(theta, V13, data = LL, geom = "line") + geom_vline(xintercept = mle[12], color = "red")
qplot(theta, V14, data = LL, geom = "line") + geom_vline(xintercept = mle[13], color = "red")
qplot(theta, V15, data = LL, geom = "line") + geom_vline(xintercept = mle[14], color = "red")
qplot(theta, V16, data = LL, geom = "line") + geom_vline(xintercept = mle[15], color = "red")
qplot(theta, V17, data = LL, geom = "line") + geom_vline(xintercept = mle[16], color = "red")


# Since the profiles are so erratic, we take a small window around the MLE 

LL_1 <- LL 

LL_2 <- LL_1 %>% pivot_longer(cols = -theta, names_to = "V", values_to = "LL")

ll_hat_frame <- tibble(V = colnames(LL)[-1], ll_hat)

q <- qchisq(0.95, 1) # Critical value: LR ~ chi-sq(1)

LL_4 <- full_join(LL_2, ll_hat_frame) %>% 
  group_by(V) %>% 
  mutate(LR = 2 * (ll_hat - LL)) %>% # LR statistic
  filter(LR <= q) %>% # Keep the values where we would not reject the null hypothesis
  slice(1, n()) %>% # Get the maximum and minimum of these theta values 
  select(V, theta) %>% 
  mutate(y = c("ymin", "ymax")) %>% 
  pivot_wider(names_from = y, values_from = theta) %>%
  mutate(V = str_replace(V, "V", ""),
         V = as.numeric(V)) %>% 
  arrange(V)


LL_4

# adjust for the fact that the mle from above does not correspond exactly with original model

pred_0 <- 1 - exp(-(breaks/coef_mod[2])^coef_mod[3])

plot(mle, pred_0)
abline(a = 0, b = 1)

adj <- mle - pred_0

LL_4$adj <- adj

LL_5 <- LL_4 %>%
  ungroup() %>% 
  mutate(ymin = ymin - adj,
         ymax = ymax - adj,
         x = breaks) %>% 
  select(-adj, -V)

LL_6 <- LL_5 %>% 
  add_row(ymin = 0, ymax = 0, x = 0, .before = 1)

LL_6

plot(LL_6$x, LL_6$ymax, type = "l")
lines(LL_6$x, LL_6$ymin)
lines(breaks, pred_0, lty = 2)


# Write file

write.csv(LL_6, "qa_para_ci.csv", row.names = FALSE)

