# 4-13-21 Likelihood Confidence Interval -----------------------------------------------

QA <- qacombined

# Step 1: Pull out relevant variables so we don't have to refer to data 

y <- QA$LOGTOTALDW[QA$TREAT!="AA"]
x <- QA$w126.12.8.adj[QA$TREAT!="AA"]
Study <- QA$Study.fac[QA$TREAT!="AA"]
z <- QA$centered_logvol[QA$TREAT!="AA"]
is_Seedling <- QA$is_Seedling[QA$TREAT!="AA"]
is_MI <- QA$is_MI[QA$TREAT!="AA"]
is_216 <- QA$is_216[QA$TREAT!="AA"]
is_259 <- QA$is_259[QA$TREAT!="AA"]
is_F91 <- QA$is_F91[QA$TREAT!="AA"]
is_216259 <- is_216+is_259
is_MI91 <- QA$is_MI91[QA$TREAT!="AA"]

# Step 2: Reparameterize the model so we can create a confidence interval around predicted biomass loss (theta)

#nlform_k <- ~ log(a+d*z) + ((x/x0) * log(1 - theta))

#nlfun_k <- deriv(nlform_k,
#                 namevec = c("a", "d","theta"),
#                 function.arg = c("x", "z","x0", "a", "d","theta"))

# Step 3: At every break (e.g. 10, 20, 30, etc.), run the model at that fixed point, varying the value of theta

breaks <- c(seq(5, max(x), by = 5), max(x)) # our breaks

# Want a table where the log likelihoods are stored, one row for every theta, one column for every break

theta_vals <- seq(0.2, .4, by = 0.005) # 101 values for theta

M <- matrix(nrow = length(theta_vals), ncol = length(breaks)+ 1)

#LL <- as_tibble(M) %>% # This will hold our likelihoods for every value of x0
#  mutate_all(as.numeric) %>% 
#  rename(theta = V1) %>%  
#  mutate(theta = theta_vals)

LL <- data.frame(M)
names(LL)[1] <- "theta"
names(LL)[2:(length(breaks)+1)] <- paste("V",c(2:(length(breaks)+1)),sep="")
LL$theta <- theta_vals

SSE <- LL

mle <- rep(NA, length(breaks)) # this will hold the maximum likelihood estimate from initial model
ll_hat <- rep(NA, length(breaks)) # this will hold the log likelihood from initial model
sse_hat <- rep(NA, length(breaks)) # this will hold the sse from initial model

# 4-12-21 i=1:11 ran

for(i in 1:(ncol(LL) - 1)){

  x0 <- rep(breaks[i], length(x)) # Get the break value of interest

# 3-24-21 final model 
  
#  nls_0 <- nls(y ~ log(a + a_90*is_90)-(x/b),
#  start=list(a = .21, b = 404, a_90=.7))

# 4-13-21 reparametrization of final model, convergence sensitive to start value of theta =0.1 works, 0.2 does not run

   nls_0 <- nls(y ~ log(a + a3*is_Seedling +a_F91*is_F91+a_MI91*is_MI91+(d+is_MI*d_MI) *z)+(x/x0)*log(1-theta),control=list(maxiter=10000),
   start=list(a = 63, a_MI91=-25,d = 40,a3=-48,a_F91=19,d_MI=-28,theta=.3))

#  nm_0 <- nlmer(y ~ nlfun_k(x, is_90, x0, a, a_90, theta) ~  (theta|Study), # Fit Model to get MLE
#                control = nlmerControl(
#                                      optCtrl = list(maxfun = 2e5,
#                                                      upper = c(Inf, Inf, Inf, 0.5), 
#                                                      lower = c(-Inf, -Inf, -Inf, -0.5))),
#                start = c(a = 10, a_90=.7, theta = 0))
  
  mle[i] <- coef(nls_0)[7] # get the mle for that fixed value of x0
  ll_hat[i] <- logLik(nls_0) # get the log-likelihood for that fixed value of x0
  sse_hat[i] <- sum(residuals(nls_0)^2)


for(j in 1:nrow(LL)){

    theta_lim <- as.numeric(LL[j, 1]) # Get theta value
    theta_vec <- rep(theta_lim,length(x))

    nm_k <- nls(y ~ log(a + a3*is_Seedling +a_F91*is_F91+a_MI91*is_MI91+(d+is_MI*d_MI) *z)+(x/x0)*log(1-theta_vec),control=list(maxiter=10000), 
                                      start = c(a = 63, a_MI91=-25,d = 20,a3=-48,a_F91=19,d_MI=-10))
    # try() keeps loop running if it fails to converge
    
    LL[j, i + 1] <- as.numeric(logLik(nm_k)) # store log-likelihood
    SSE[j,i+1] <- sum(residuals(nm_k)^2)
  }
}

mle
 [1] 0.06664616 0.12885061 0.18690937 0.24109874 0.29167660 0.33888363 0.38294450 0.42406888 0.46245248 0.49827797 0.53171580 0.56292516

ll_hat
 [1] 0.3570772 0.3570772 0.3570772 0.3570772 0.3570772 0.3570772 0.3570772 0.3570772 0.3570772 0.3570772 0.3570772 0.3570772

sse_hat
[1] 8.09672 8.09672 8.09672 8.09672 8.09672 8.09672 8.09672 8.09672 8.09672 8.09672 8.09672 8.09672

write.csv(LL, "C:\\Users\\hlee05\\Documents\\ehl\\critdoc2020\\seijizip\\Reanalysis\\New Species\\Chestnut Oak\\chest_LL_profile_ehl.csv", row.names = FALSE)
write.csv(ll_hat, "C:\\Users\\hlee05\\Documents\\ehl\\critdoc2020\\seijizip\\Reanalysis\\New Species\\Chestnut Oak\\chest_ll_hat_ehl.csv", row.names = FALSE)
write.csv(mle, "C:\\Users\\hlee05\\Documents\\ehl\\critdoc2020\\seijizip\\Reanalysis\\New Species\\Chestnut Oak\\chest_mle_ehl.csv", row.names = FALSE)

#LL <- read_csv("C:/Users/skoike/Desktop/Reanalysis/Eastern White Pine/ewp_LL_profile_harvest1.csv")
#ll_hat <- read_csv("C:/Users/skoike/Desktop/Reanalysis/Eastern White Pine/ewp_ll_hat_harvest1.csv")
#mle <- read_csv("C:/Users/skoike/Desktop/Reanalysis/Eastern White Pine/ewp_mle_harvest1.csv")

#ll_0 <- as_vector(ll_0)
#mle <- as_vector(mle)

LL
ll_hat
mle

# Look at the LL profile
qplot(theta, V2, data = LL, geom = "line") + geom_vline(xintercept = mle[1], color = "red")
qplot(theta, V3, data = LL, geom = "line") + geom_vline(xintercept = mle[2], color = "red")
qplot(theta, V4, data = LL, geom = "line") + geom_vline(xintercept = mle[3], color = "red")
qplot(theta, V5, data = LL, geom = "line") + geom_vline(xintercept = mle[4], color = "red")
qplot(theta, V6, data = LL, geom = "line") + geom_vline(xintercept = mle[5], color = "red")
qplot(theta, V7, data = LL, geom = "line") + geom_vline(xintercept = mle[6], color = "red")
qplot(theta, V8, data = LL, geom = "line") + geom_vline(xintercept = mle[7], color = "red")
qplot(theta, V9, data = LL, geom = "line") + geom_vline(xintercept = mle[8], color = "red")


# The profiles are well-behaved except for w126 = 40

LL_1 <- LL

# 3-24-21 cannot run block of code starting here --------------------------------------
# The following lines will do a apply the GAM en masse 

LL_2 <- LL_1 %>% 
  pivot_longer(cols = -theta, names_to = "V", values_to = "LL")

ll_hat_frame <- tibble(V = colnames(LL)[-1], ll_hat)

#ll_hat_frame <- tibble(V = colnames(LL)[-1], ll_hat) %>% rename(ll_hat = x)

q <- qchisq(0.95, 1) # Critical value: LR ~ chi-sq(1)

LL_4 <- full_join(LL_2, ll_hat_frame) %>% 
  group_by(V) %>% 
  mutate(LR = 2 * (ll_hat - LL)) %>% # LR statistic
  filter(LR <= q) %>% # Keep the values where we would not reject the null hypothesis
  slice(1, n()) %>% # Get the maximum and minimum of these theta values 
  select(V, theta) %>% 
  mutate(y = c("ymin", "ymax")) %>% 
  pivot_wider(names_from = y, values_from = theta) %>% 
  arrange(ymax)

LL_4

# adjust for the fact that the mle from above does not correspond exactly with original model

pred_0 <- 1 - exp(-(breaks/coef_mod[2]))


adj <- mle - pred_0

plot(mle, pred_0)
abline(a = 0, b = 1)

#LL_4 <- LL_4 %>% ungroup() %>% slice(1:5)

LL_4$adj <- adj

LL_5 <- LL_4 %>%
  ungroup() %>% 
  mutate(ymin = ymin - adj,
         ymax = ymax - adj,
         x = breaks) %>% 
  select(-adj, -V)

LL_5

LL_6 <- LL_5 %>% 
  mutate(ymin = ifelse(ymin < 0, 0, ymin)) %>% 
  add_row(ymin = 0, ymax = 0, x = 0, .before = 1)

LL_6

plot(LL_6$x, LL_6$ymax, type = "l", ylim = c(0, 0.6), xlim = c(0, 85))
lines(LL_6$x, LL_6$ymin)
lines(breaks, pred_0, lty = 2)

# end unusable code -------------------

# 3-29-21 manually find 9-% and 96% likelihood intervals
# 3-29-21 mle = estimates of theta for break=5,10,...,35
# 3-29-21 ll_hat is the log likelihood at mle
# 3-29-21 LL is the log likelihood at theta=0 to 1 in 0.005
# 3-29-21 find theta based on c[hi-squared LRT = -2*(LL-ll_hat) which is dist as chi-squared with 1 DF

q95 <- qchisq(0.95, 1)
q975 <- qchisq(0.975, 1)

# 3-24-21 calculate LRT for each theta=0 to 1 in 0.005

LRT <- LL
for (j in 2:(length(breaks)+1)) LRT[,j] <- -2*(LL[,j]-ll_hat[j-1])

# 3-24-21 find upper and lower values for 90% likelihood interval

lower.90 <- rep(NA,length(breaks))
upper.90 <- rep(NA,length(breaks))
lower.95 <- rep(NA,length(breaks))
upper.95 <- rep(NA,length(breaks))

test.value.lower.90 <- rep(NA,length(breaks))
test.value.upper.90 <- rep(NA,length(breaks))
test.value.lower.95 <- rep(NA,length(breaks))
test.value.upper.95 <- rep(NA,length(breaks))

for (j in 2:(length(breaks)+1)){
lower.calc <- LRT[LRT$theta<mle[j-1],c(1,j)]
upper.calc <- LRT[LRT$theta>mle[j-1],c(1,j)]

min.diff.lower.90 <- min(abs(lower.calc[,2]-q95))
min.diff.upper.90 <- min(abs(upper.calc[,2]-q95))
nlower <- dim(lower.calc)
nupper <- dim(upper.calc)

obs.lower.90 <- c(1:nlower[1])[abs(lower.calc[,2]-q95)==min.diff.lower.90]
lower.90[j-1] <- lower.calc$theta[min(obs.lower.90)]

obs.upper.90 <- c(1:nupper[1])[abs(upper.calc[,2]-q95)==min.diff.upper.90]
upper.90[j-1] <- upper.calc$theta[max(obs.upper.90)]

test.value.lower.90[j-1] <- min.diff.lower.90
test.value.upper.90[j-1] <- min.diff.upper.90

min.diff.lower.95 <- min(abs(lower.calc[,2]-q975))
min.diff.upper.95 <- min(abs(upper.calc[,2]-q975))

obs.lower.95 <- c(1:nlower[1])[abs(lower.calc[,2]-q975)==min.diff.lower.95]
lower.95[j-1] <- lower.calc$theta[min(obs.lower.95)]

obs.upper.95 <- c(1:nupper[1])[abs(upper.calc[,2]-q975)==min.diff.upper.95]
upper.95[j-1] <- upper.calc$theta[max(obs.upper.95)]

test.value.lower.95[j-1] <- min.diff.lower.95
test.value.upper.95[j-1] <- min.diff.upper.95

}

mle
lower.90
upper.90
lower.95
upper.95

mle
 [1] 0.06664616 0.12885061 0.18690937 0.24109874 0.29167660 0.33888363 0.38294450 0.42406888 0.46245248 0.49827797 0.53171580 0.56292516
[13]         NA         NA         NA         NA         NA         NA
> lower.90
 [1]    NA    NA    NA 0.205 0.245 0.290 0.330 0.365 0.400 0.400 0.400    NA    NA    NA    NA    NA    NA    NA
> upper.90
 [1] 0.200 0.200 0.215 0.275 0.335 0.385 0.400    NA    NA    NA    NA    NA    NA    NA    NA    NA    NA    NA
> lower.95
 [1]    NA    NA    NA 0.200 0.240 0.280 0.320 0.355 0.390 0.400 0.400    NA    NA    NA    NA    NA    NA    NA
> upper.95
 [1] 0.20 0.20 0.22 0.28 0.34 0.39 0.40   NA   NA   NA  

#View(LL_5)

# Write file

#write.csv(LL_6, "ewp_para_ci.csv", row.names = FALSE)

#LL_6_90_ehl <- data.frame(ymin=lower.90,ymax=upper.90,x=breaks)
#LL_6_95_ehl <- data.frame(ymin=lower.95,ymax=upper.95,x=breaks)

#write.csv(LL_6_90_ehl, "C:\\Users\\hlee05\\Documents\\ehl\\critdoc2020\\seijizip\\Reanalysis\\New Species\\Chestnut Oak\\chest_para_ci_90_ehl.csv", row.names = FALSE)
#write.csv(LL_6_95_ehl, "C:\\Users\\hlee05\\Documents\\ehl\\critdoc2020\\seijizip\\Reanalysis\\New Species\\Chestnut Oak\\chest_para_ci_95_ehl.csv", row.names = FALSE)


# 3-29-21 F-test intervals -------------------

f95 <- qf(0.95, 1,length(x)-3)
f975 <- qf(0.975, 1,length(x)-3)

# 3-25-21 calculate F-test for each theta=0 to 1 in 0.005

Ftest <- SSE

sse_full <- mean(sse_hat)
dfe_full <- length(x)-3
mse_full <- sse_full/dfe_full

for (j in 2:(length(breaks)+1)) Ftest[,j] <- (SSE[,j]-sse_full)/mse_full

# 3-24-21 find upper and lower values for 90% likelihood interval

lower.90.f <- rep(NA,length(breaks))
upper.90.f <- rep(NA,length(breaks))
lower.95.f <- rep(NA,length(breaks))
upper.95.f <- rep(NA,length(breaks))

test.value.lower.90.f <- rep(NA,length(breaks))
test.value.upper.90.f <- rep(NA,length(breaks))
test.value.lower.95.f <- rep(NA,length(breaks))
test.value.upper.95.f <- rep(NA,length(breaks))

for (j in 2:(length(breaks)+1)){
lower.calc <- Ftest[Ftest$theta<mle[j-1],c(1,j)]
upper.calc <- Ftest[Ftest$theta>mle[j-1],c(1,j)]

min.diff.lower.90 <- min(abs(lower.calc[,2]-f95))
min.diff.upper.90 <- min(abs(upper.calc[,2]-f95))
nlower <- dim(lower.calc)
nupper <- dim(upper.calc)

obs.lower.90 <- c(1:nlower[1])[abs(lower.calc[,2]-f95)==min.diff.lower.90]
lower.90.f[j-1] <- lower.calc$theta[min(obs.lower.90)]

obs.upper.90 <- c(1:nupper[1])[abs(upper.calc[,2]-f95)==min.diff.upper.90]
upper.90.f[j-1] <- upper.calc$theta[max(obs.upper.90)]

test.value.lower.90.f[j-1] <- min.diff.lower.90
test.value.upper.90.f[j-1] <- min.diff.upper.90

min.diff.lower.95 <- min(abs(lower.calc[,2]-f975))
min.diff.upper.95 <- min(abs(upper.calc[,2]-f975))

obs.lower.95 <- c(1:nlower[1])[abs(lower.calc[,2]-f975)==min.diff.lower.95]
lower.95.f[j-1] <- lower.calc$theta[min(obs.lower.95)]

obs.upper.95 <- c(1:nupper[1])[abs(upper.calc[,2]-f975)==min.diff.upper.95]
upper.95.f[j-1] <- upper.calc$theta[max(obs.upper.95)]

test.value.lower.95.f[j-1] <- min.diff.lower.95
test.value.upper.95.f[j-1] <- min.diff.upper.95

}

#F_6_90_ehl <- data.frame(ymin=lower.90.f,ymax=upper.90.f,x=breaks)
#F_6_95_ehl <- data.frame(ymin=lower.95.f,ymax=upper.95.f,x=breaks)

#write.csv(F_6_90_ehl, "C:\\Users\\hlee05\\Documents\\ehl\\critdoc2020\\seijizip\\Reanalysis\\New Species\\Chestnut Oak\\chest_para_ci_90_ehl.csv", row.names = FALSE)
#write.csv(F_6_95_ehl, "C:\\Users\\hlee05\\Documents\\ehl\\critdoc2020\\seijizip\\Reanalysis\\New Species\\Chestnut Oak\\chest_para_ci_95_ehl.csv", row.names = FALSE)

mle
[1] 0.006145574 0.012253389 0.018323621 0.024356505 0.030352520 0.033469924

lower.90.f
[1] 0 0 0 0 0 0 chisq LRT 3-29-21
[1] 0 0 0 0 0 0 Ftest 3-29-21

upper.90.f
[1] 0.025 0.050 0.075 0.095 0.120 0.130 chisq LRT 3-29-21
[1] 0.030 0.055 0.080 0.105 0.130 0.145 Ftest 3-25-21

lower.95.f
[1] 0 0 0 0 0 0 chisq LRT 3-29-21
[1] 0 0 0 0 0 0 Ftest 3-25-21

upper.95.f
[1] 0.030 0.055 0.080 0.105 0.130 0.145 chisq LRT 3-29-21
[1] 0.030 0.060 0.090 0.120 0.150 0.165 Ftest 3-29-21

test.value.lower.90.f
[1] 0.54437059 0.26494318 0.20924534 0.03361821 0.13920381 0.09180134 0.06058916

test.value.upper.90.f
[1] 0.3213711 0.3213711 0.1083434 0.2251277 0.1165635 0.1561929 0.1772407

test.value.lower.95.f
[1] 0.59995810 0.27346821 0.18478066 0.17512846 0.02440662 0.13127825 0.10821215

test.value.upper.95.f
[1] 0.28783934 0.11588852 0.04730283 0.11588852 0.11732731 0.06221793 0.07865864

# 4-13-21 wald interval - final calculations for confidence intervals for RM

breaks <- c(seq(5, max(x), by = 5), max(x)) # our breaks

t975 <- qt(.975,length(x)-7)
t95 <- qt(.95,length(x)-7)

lower.90.wald <- rep(NA,length(breaks))
upper.90.wald <- rep(NA,length(breaks))
lower.95.wald <- rep(NA,length(breaks))
upper.95.wald <- rep(NA,length(breaks))
mle <- rep(NA,length(breaks))

start.theta <- rep(0.1,length(breaks))
start.theta[4:length(breaks)] <- 0.6

# 4-13-21 only 1:9 converged w start theta=0.15
for (i in 1:length(breaks)){

  x0 <- rep(breaks[i], length(x)) # Get the break value of interest
 
   nls_0 <- nls(y ~ log(a + a3*is_Seedling +a_F91*is_F91+a_MI91*is_MI91+(d+is_MI*d_MI) *z)+(x/x0)*log(1-theta),control=list(maxiter=10000),
   start=list(a = 63, a_MI91=-25,d = 40,a3=-48,a_F91=19,d_MI=-28,theta=.3))

mle[i] <- coef(nls_0)[7]
upper.95.wald[i] <- coef(nls_0)[7] +t975*sqrt(vcov(nls_0)[7,7])
lower.95.wald[i] <- coef(nls_0)[7] -t975*sqrt(vcov(nls_0)[7,7])
upper.90.wald[i] <- coef(nls_0)[7] +t95*sqrt(vcov(nls_0)[7,7])
lower.90.wald[i] <- coef(nls_0)[7] -t95*sqrt(vcov(nls_0)[7,7])
}

mle
lower.90.wald
upper.90.wald
lower.95.wald
upper.95.wald

wald_6_90_ehl <- data.frame(ymin=lower.90.wald,ymax=upper.90.wald,x=breaks)
wald_6_95_ehl <- data.frame(ymin=lower.95.wald,ymax=upper.95.wald,x=breaks)

write.csv(wald_6_90_ehl, "C:\\Users\\hlee05\\Documents\\ehl\\critdoc2020\\seijizip\\Reanalysis\\Quaking Aspen\\qa_para_ci_90_ehl.csv", row.names = FALSE)
write.csv(wald_6_95_ehl, "C:\\Users\\hlee05\\Documents\\ehl\\critdoc2020\\seijizip\\Reanalysis\\Quaking Aspen\\qa_para_ci_95_ehl.csv", row.names = FALSE)

 mle
 [1] 0.06664616 0.12885061 0.18690937 0.24109874 0.29167660 0.33888363 0.38294450 0.42406888 0.46245248 0.49827797 0.53171580 0.56292516
[13] 0.59205454 0.61924270 0.64462018 0.66830344 0.69040969 0.69968180
> lower.90.wald
 [1] 0.0569595 0.1107685 0.1615938 0.2095942 0.2549205 0.2977159 0.3381165 0.3762512 0.4122429 0.4462076 0.4782557 0.5084919 0.5370152
[14] 0.5639199 0.5892964 0.6132241 0.6357882 0.6453221
> upper.90.wald
 [1] 0.07633281 0.14693276 0.21222494 0.27260326 0.32843267 0.38005134 0.42777254 0.47188651 0.51266209 0.55034834 0.58517589 0.61735844
[13] 0.64709384 0.67456545 0.69994392 0.72338276 0.74503122 0.75404154
> lower.95.wald
 [1] 0.05507876 0.10725766 0.15667857 0.20347736 0.24778402 0.28972287 0.32941271 0.36696705 0.40249425 0.43609769 0.46787598 0.49792318
[13] 0.52632888 0.55317856 0.57855487 0.60253000 0.62518293 0.63476765
> upper.95.wald
 [1] 0.07821356 0.15044357 0.21714018 0.27872013 0.33556918 0.38804440 0.43647628 0.48117071 0.52241072 0.56045824 0.59555563 0.62792713
[13] 0.65778019 0.68530684 0.71068550 0.73407688 0.75563645 0.76459594

# end likelihood intervals ----------------

# 3-15-21

qacombined <- read.table(
"C:\\Users\\hlee05\\Documents\\ehl\\critdoc2020\\seijizip\\Mean Dry Weight Programs\\Mean Dry Weights\\qa_chamber_mean_data.csv", sep=",",header=T,fill=T)

qacombined$Study.fac <- as.factor(qacombined$Study)
qacombined$Site.fac <- as.factor(qacombined$Site)

n <- dim(qacombined)

qacombined$is_F89 <- rep(0,n[1])
qacombined$is_F89[qacombined$Site=="FERF"&qacombined$Year==1989] <- 1

qacombined$is_F91 <- rep(0,n[1])
qacombined$is_F91[qacombined$Site=="FERF"&qacombined$Year==1991] <- 1

qacombined$is_271 <- rep(0,n[1])
qacombined$is_271[qacombined$Study=="1990: 271"|qacombined$Study=="1991: 271"] <- 1

qacombined$is_216 <- rep(0,n[1])
qacombined$is_216[qacombined$Study=="1990: 216"|qacombined$Study=="1991: 216"] <- 1

qacombined$is_253 <- rep(0,n[1])
qacombined$is_253[qacombined$Study=="1990: 253"|qacombined$Study=="1991: 253"] <- 1

qacombined$is_259 <- rep(0,n[1])
qacombined$is_259[qacombined$Study=="1990: 259"|qacombined$Study=="1991: 259"] <- 1

qacombined$is_Seedling <- rep(0,n[1])
qacombined$is_Seedling[qacombined$Study=="Seedling"|qacombined$Site=="FERF"] <- 1

qacombined$is_FERF <- rep(0,n[1])
qacombined$is_FERF[qacombined$Site=="FERF"] <- 1

qacombined$is_MI <- rep(0,n[1])
qacombined$is_MI[qacombined$Site=="Michigan"] <- 1

# 3-15-21 TREAT=6 is AA

tapply(qacombined$w126.12.8.adj,list(qacombined$Study,qacombined$TREAT,qacombined$Site),mean)

unique(qacombined$Study[qacombined$Site=="Michigan"])

plot(qacombined$w126.12.8.adj,qacombined$LOGTOTALDW,pch=16,type="n")
points(qacombined$w126.12.8.adj[qacombined$Site=="FERF"&qacombined$Year==1989],qacombined$LOGTOTALDW[qacombined$Site=="FERF"&qacombined$Year==1989],pch=16,type="p")
points(qacombined$w126.12.8.adj[qacombined$Site=="FERF"&qacombined$Year==1991],qacombined$LOGTOTALDW[qacombined$Site=="FERF"&qacombined$Year==1991],pch=16,type="p",col="red")
points(qacombined$w126.12.8.adj[qacombined$Site=="Michigan"&qacombined$Study=="1990: 216"],qacombined$LOGTOTALDW[qacombined$Site=="Michigan"&qacombined$Study=="1990: 216"],pch=16,type="p",col="green")
points(qacombined$w126.12.8.adj[qacombined$Site=="Michigan"&qacombined$Study=="1990: 253"],qacombined$LOGTOTALDW[qacombined$Site=="Michigan"&qacombined$Study=="1990: 253"],pch=16,type="p",col="orange")
points(qacombined$w126.12.8.adj[qacombined$Site=="Michigan"&qacombined$Study=="1990: 259"],qacombined$LOGTOTALDW[qacombined$Site=="Michigan"&qacombined$Study=="1990: 259"],pch=16,type="p",col="purple")
points(qacombined$w126.12.8.adj[qacombined$Site=="Michigan"&qacombined$Study=="1990: 271"],qacombined$LOGTOTALDW[qacombined$Site=="Michigan"&qacombined$Study=="1990: 271"],pch=16,type="p",col="blue")

points(qacombined$w126.12.8.adj[qacombined$Site=="Michigan"&qacombined$Study=="1991: 216"],qacombined$LOGTOTALDW[qacombined$Site=="Michigan"&qacombined$Study=="1991: 216"],pch=16,type="p",col="green")
points(qacombined$w126.12.8.adj[qacombined$Site=="Michigan"&qacombined$Study=="Seedling"],qacombined$LOGTOTALDW[qacombined$Site=="Michigan"&qacombined$Study=="Seedling"],pch=16,type="p",col="orange")
points(qacombined$w126.12.8.adj[qacombined$Site=="Michigan"&qacombined$Study=="1991: 259"],qacombined$LOGTOTALDW[qacombined$Site=="Michigan"&qacombined$Study=="1991: 259"],pch=16,type="p",col="purple")
points(qacombined$w126.12.8.adj[qacombined$Site=="Michigan"&qacombined$Study=="1991: 271"],qacombined$LOGTOTALDW[qacombined$Site=="Michigan"&qacombined$Study=="1991: 271"],pch=16,type="p",col="blue")


x <- c(0:90)
y89 <- log(9.7063)-(x/115.15)^1.0471
y91 <- log(9.7063+20.9932)-(x/115.15)^1.0471
points(x,y89,type="l")
points(x,y91,type="l")

yM90 <- log(67.273)-(x/44.1)
yM90.271 <- log(67.273)-(x/(44.1+213.489))
points(x,yM90,type="l")
points(x,yM90.271,type="l")

yM91 <- log(36.47)-(x/74.9)
points(x,yM91,type="l")

nform1 <- ~ log(a + d * logvol) + (-(x/b)^c)
nform2 <- ~ log(a + d * logvol) -(x/b)
nform3 <- ~ log(a ) -(x/b)
nform4 <- ~ log(a + a3*is_F91 +d * logvol) + (-(x/b)^c)
nform5 <- ~ log(a +d * logvol) + (-(x/(b+b271*is_271)))
nform6 <- ~ log(a + a3*is_Seedling +d * logvol) -(x/b)
nform7 <- ~ log(a + a3*is_Seedling +d * logvol) -(x/(b+b271*is_271))
nform8 <- ~ log(a + a3*is_Seedling + a91*is_F91+d * logvol) -(x/(b+b271*is_271))
nform9 <- ~ log(a + a3*is_Seedling + a_FERF*is_FERF+is_MI*d * logvol) -(x/(b+b271*is_271))
nform10 <- ~ log(a + a3*is_Seedling + a_F91*is_F91+is_MI*d * logvol) -(x/(b+b271*is_271))
nform11 <- ~ log(a + a3*is_Seedling + a_F91*is_F91+(d+is_MI*d_MI) * logvol) -(x/b)
nform12 <- ~ log(a + a3*is_Seedling +a_F91*is_F91+(d+is_MI*d_MI) *logvol)-x/(b+b_216259*(is_216+is_259))
nform13 <- ~ log(a + a3*is_Seedling +a_F91*is_F91+a_MI91*is_MI91+(d+is_MI*d_MI) *logvol)-(x/b)
nform14 <- ~ log(a + a3*is_Seedling +a_F91*is_F91+a_MI91*is_MI91+d *logvol)-(x/b)

nfun13 <- deriv(nform13,
               namevec = c("a", "b",  "d","a3","a_F91","d_MI","a_MI91"),
               function.arg = c("x", "logvol", "is_Seedling","is_F91","is_MI","is_MI91","a", "b",  "d","a3","a_F91","d_MI","a_MI91"))

nfun1 <- deriv(nform1,
               namevec = c("a", "b", "c", "d"),
               function.arg = c("x", "logvol", "a", "b", "c", "d"))

nfun2 <- deriv(nform2,
               namevec = c("a", "b", "d"),
               function.arg = c("x", "logvol", "a", "b", "d"))

nfun3 <- deriv(nform3,
               namevec = c("a", "b"),
               function.arg = c("x", "a", "b"))

nfun4 <- deriv(nform4,
               namevec = c("a", "b", "c", "d","a3"),
               function.arg = c("x", "logvol", "is_F91","a", "b", "c", "d","a3"))

nfun5 <- deriv(nform5,
               namevec = c("a", "b", "d","b271"),
               function.arg = c("x", "logvol", "is_271","a", "b", "d","b271"))

nfun6 <- deriv(nform6,
               namevec = c("a", "b",  "d","a3"),
               function.arg = c("x", "logvol", "is_Seedling","a", "b",  "d","a3"))

nfun7 <- deriv(nform7,
               namevec = c("a", "b",  "d","a3","b271"),
               function.arg = c("x", "logvol", "is_Seedling","is_271","a", "b",  "d","a3","b271"))

nfun8 <- deriv(nform8,
               namevec = c("a", "b",  "d","a3","a91","b271"),
               function.arg = c("x", "logvol", "is_Seedling","is_271","is_F91","a", "b",  "d","a3","a91","b271"))

nfun9 <- deriv(nform9,
               namevec = c("a", "b",  "d","a3","a_FERF","b271"),
               function.arg = c("x", "logvol", "is_Seedling","is_271","is_FERF","is_MI","a", "b",  "d","a3","a_FERF","b271"))

nfun10 <- deriv(nform10,
               namevec = c("a", "b",  "d","a3","a_F91","b271"),
               function.arg = c("x", "logvol", "is_Seedling","is_271","is_F91","is_MI","a", "b",  "d","a3","a_F91","b271"))

nfun11 <- deriv(nform11,
               namevec = c("a", "b",  "d","a3","a_F91","d_MI"),
               function.arg = c("x", "logvol", "is_Seedling","is_F91","is_MI","a", "b",  "d","a3","a_F91","d_MI"))

nfun12 <- deriv(nform12,
               namevec = c("a", "b",  "d","a3","a_F91","d_MI","b_216259"),
               function.arg = c("x", "logvol", "is_Seedling","is_F91","is_MI","is_216","is_259","a", "b",  "d","a3","a_F91","d_MI","b_216259"))

nfun13 <- deriv(nform13,
               namevec = c("a", "b",  "d","a3","a_F91","d_MI","a_MI91"),
               function.arg = c("x", "logvol", "is_Seedling","is_F91","is_MI","is_MI91","a", "b",  "d","a3","a_F91","d_MI","a_MI91"))

nfun14 <- deriv(nform14,
               namevec = c("a", "b",  "d","a3","a_F91","a_MI91"),
               function.arg = c("x", "logvol", "is_Seedling","is_F91","is_MI91","a", "b",  "d","a3","a_F91","a_MI91"))


# 3-15-21 step 1 unable to run

nm1 <- nlmer(LOGTOTALDW ~ nfun1(w126.12.8.adj, centered_logvol, a, b, c, d) ~ (a + b  | Study.fac),
             data = qacombined[qacombined$TREAT !="6",],
             control = nlmerControl(
                                    optCtrl = list(maxfun = 2e7)),
             start = c(a = 64, b = 40, c = 1, d = 12))
summary(nm1)

# 3-15-21 step 2 set c=1 unable to run

nm2 <- nlmer(LOGTOTALDW ~ nfun2(w126.12.8.adj, centered_logvol, a, b,  d) ~ a  +b +d| Study.fac,
             data = qacombined[qacombined$TREAT !="6",],
             control = nlmerControl(
                                    optCtrl = list(maxfun = 2e7)),
             start = c(a = 41, b = 93,  d = 12))
summary(nm2)

# 3-16-21 step 3 set c=1, drop covariate unable to run

nm3 <- nlmer(LOGTOTALDW ~ nfun3(w126.12.8.adj, a, b) ~ a  | Study.fac,
             data = qacombined[qacombined$TREAT !="6",],
             control = nlmerControl(
                                    optCtrl = list(maxfun = 2e7)),
             start = c(a = 41, b = 93))
summary(nm3)

# 3-15-21 step 4 2 FERF studies only, able to run with random coef for d

nm1 <- nlmer(LOGTOTALDW ~ nfun1(w126.12.8.adj, centered_logvol, a, b, c, d) ~ (d  | Study.fac),
             data = qacombined[qacombined$Site=="FERF",],
             control = nlmerControl(
                                    optCtrl = list(maxfun = 2e7)),
             start = c(a = 17, b = 71, c = 1.5, d = 36))
summary(nm1)

# 3-15-21 step 5 2 FERF studies only, separate a, able to run with random coef for d

nm4 <- nlmer(LOGTOTALDW ~ nfun4(w126.12.8.adj, centered_logvol, is_F91, a, b, c, d, a3) ~ (d  | Study.fac),
             data = qacombined[qacombined$Site=="FERF",],
             control = nlmerControl(
                                    optCtrl = list(maxfun = 2e7)),
             start = c(a = 17, b = 71, c = 1.5, d = 36,a3=3))
summary(nm4)

# 3-15-21 step 6 1990 Michigan studies only, clones 216 & 253 &259; able to run by changing start values; problem conv include 271
# 3-15-21 random coef for a & b near zero

nm2 <- nlmer(LOGTOTALDW ~ nfun2(w126.12.8.adj, centered_logvol, a, b, d) ~ (a +b | Study.fac),
             data = qacombined[qacombined$Year==1990&qacombined$Site=="Michigan"&qacombined$TREAT !="6"&(qacombined$Study=="1990: 216"|qacombined$Study=="1990: 253"|qacombined$Study=="1990: 259"),],
             control = nlmerControl(
                                    optCtrl = list(maxfun = 2e7)),
             start = c(a = 63, b = 40, d = 13))
summary(nm2)

# 3-15-21 step 7 1990 Michigan studies only, clones 216 & 253 &259 &271

nm5 <- nlmer(LOGTOTALDW ~ nfun5(w126.12.8.adj, centered_logvol, is_271,a, b, d,b271) ~ (a +b | Study.fac),
             data = qacombined[qacombined$Year==1990&qacombined$Site=="Michigan"&qacombined$TREAT !="6",],
             control = nlmerControl(
                                    optCtrl = list(maxfun = 2e7)),
             start = c(a = 63, b = 40, d = 13,b271=10))
summary(nm5)

# 3-15-21 step 8 1991 Michigan studies only, clones 216 &259 ; able to run 

nm2 <- nlmer(LOGTOTALDW ~ nfun2(w126.12.8.adj, centered_logvol,a, b, d) ~ (a +b | Study.fac),
             data = qacombined[qacombined$Year==1991&qacombined$Site=="Michigan"&qacombined$TREAT !="6"&(qacombined$Study=="1991: 216"|qacombined$Study=="1991: 259"),],
             control = nlmerControl(
                                    optCtrl = list(maxfun = 2e7)),
             start = c(a = 63, b = 40, d = 13))
summary(nm2)

# 3-15-21 step 9 1991 Michigan studies only, clones 216 &259&271 ; unable to run 

nm5 <- nlmer(LOGTOTALDW ~ nfun5(w126.12.8.adj, centered_logvol,is_271,a, b, d,b271) ~ (a+b | Study.fac),
             data = qacombined[qacombined$Year==1991&qacombined$Site=="Michigan"&qacombined$TREAT !="6"&(qacombined$Study=="1991: 216"|qacombined$Study=="1991: 259"|qacombined$Study=="1991: 271"),],
             control = nlmerControl(
                                    optCtrl = list(maxfun = 2e7)),
             start = c(a = 36, b = 74, d = 13,b271=100))
summary(nm5)

# 3-15-21 step 9 1991 Michigan studies only, clones 216 &271&Seedling ; able to run 

nm4 <- nlmer(LOGTOTALDW ~ nfun4(w126.12.8.adj, centered_logvol,is_Seedling,a, b, c,d,a3) ~ (b | Study.fac),
             data = qacombined[qacombined$Year==1991&qacombined$Site=="Michigan"&qacombined$TREAT !="6"&(qacombined$Study=="1991: 216"|qacombined$Study=="1991: 271"|qacombined$Study=="Seedling"),],
             control = nlmerControl(
                                    optCtrl = list(maxfun = 2e7)),
             start = c(a = 20, b = 64, c=1,d = 13,a3=20))
summary(nm4)

# 3-15-21 step 10 1991 Michigan studies only, clones 216 &271&Seedling ; set c=1 able to run 

nm6 <- nlmer(LOGTOTALDW ~ nfun6(w126.12.8.adj, centered_logvol,is_Seedling,a, b,d,a3) ~ (b | Study.fac),
             data = qacombined[qacombined$Year==1991&qacombined$Site=="Michigan"&qacombined$TREAT !="6"&(qacombined$Study=="1991: 216"|qacombined$Study=="1991: 271"|qacombined$Study=="Seedling"),],
             control = nlmerControl(
                                    optCtrl = list(maxfun = 2e7)),
             start = c(a = 20, b = 64, d = 13,a3=20))
summary(nm6)

# 3-15-21 step 11 1991 Michigan studies only, clones 216,259 &271&Seedling ; set c=1 unable to run 

nm6 <- nlmer(LOGTOTALDW ~ nfun6(w126.12.8.adj, centered_logvol,is_Seedling,a, b,d,a3) ~ (b | Study.fac),
             data = qacombined[qacombined$Year==1991&qacombined$Site=="Michigan"&qacombined$TREAT !="6"&(qacombined$Study=="1991: 216"|qacombined$Study=="1991: 259"|qacombined$Study=="1991: 271"|qacombined$Study=="Seedling"),],
             control = nlmerControl(
                                    optCtrl = list(maxfun = 2e7)),
             start = c(a = 20, b = 64, d = 13,a3=20))
summary(nm6)

# 3-15-21 step 11 1991 Michigan studies only, clones 216,259 &271&Seedling ; set c=1 able to run w good start values 

nm7 <- nlmer(LOGTOTALDW ~ nfun7(w126.12.8.adj, centered_logvol, is_Seedling,is_271,a, b,d,a3,b271) ~ (d | Study.fac),
             data = qacombined[qacombined$Year==1991&qacombined$Site=="Michigan"&qacombined$TREAT !="6"&(qacombined$Study=="1991: 216"|qacombined$Study=="1991: 259"|qacombined$Study=="1991: 271"|qacombined$Study=="Seedling"),],
             control = nlmerControl(
                                    optCtrl = list(maxfun = 2e7)),
             start = c(a = 37, b = 104, d = 10,a3=-20,b271=20))
summary(nm7)

# 3-15-21 step 12 1990&1991 Michigan studies only, clones 216,259 &271&Seedling ; set c=1 able to run w good start values 

nm7 <- nlmer(LOGTOTALDW ~ nfun7(w126.12.8.adj, centered_logvol, is_Seedling,is_271,a, b,d,a3,b271) ~ (a+b | Study.fac),
             data = qacombined[qacombined$Site=="Michigan"&qacombined$TREAT !="6",],
             control = nlmerControl(
                                    optCtrl = list(maxfun = 2e7)),
             start = c(a = 37, b = 104, d = 10,a3=-20,b271=20))
summary(nm7)

# 3-16-21 step 13 FERF , 1990&1991 Michigan studies only, clones 216,259 &271&Seedling ; set c=1 unable to run 

nm8 <- nlmer(LOGTOTALDW ~ nfun8(w126.12.8.adj, centered_logvol, is_Seedling,is_271,is_F89,a, b,d,a3,a91,b271) ~ (a+b | Study.fac),
             data = qacombined[qacombined$TREAT !="6",],
             control = nlmerControl(
                                    optCtrl = list(maxfun = 2e7)),
             start = c(a = 37, b = 104, d = 10,a3=-20,a91=21,b271=70))
summary(nm8)

# 3-17-21 step 14 FERF , 1990&1991 Michigan studies only, clones 216,259 &271&Seedling ; set c=1 unable to run 

nm9 <- nlmer(LOGTOTALDW ~ nfun9(w126.12.8.adj, centered_logvol, is_Seedling,is_271,is_FERF,is_MI,a, b,d,a3,a_FERF,b271) ~ (a | Study.fac),
             data = qacombined[qacombined$TREAT !="6",],
             control = nlmerControl(
                                    optCtrl = list(maxfun = 2e7)),
             start = c(a = 37, b = 104, d = 10,a3=-20,a_FERF=-10,b271=70))
summary(nm9)

# 3-17-21 step 15 FERF , 1990&1991 Michigan studies only, clones 216,259 &271&Seedling ; set c=1 unable to run 

nm10 <- nlmer(LOGTOTALDW ~ nfun10(w126.12.8.adj, centered_logvol, is_Seedling,is_271,is_F91,is_MI,a, b,d,a3,a_F91,b271) ~ (a | Study.fac),
             data = qacombined[qacombined$TREAT !="6",],
             control = nlmerControl(
                                    optCtrl = list(maxfun = 2e7)),
             start = c(a = 53, b = 67, d = 11,a3=-38,a_F91=20,b271=40))
summary(nm10)

# 3-17-21 step 16 FERF , 1990&1991 Michigan studies, model w/o random coef 

qa.w126.12.8.nls <- nls(LOGTOTALDW ~ log(a + a3*is_Seedling +a_F91*is_F91+(d+is_MI*d_MI) *centered_logvol)-(w126.12.8.adj/(b+b271*is_271)),data=qacombined[qacombined$TREAT !="AA",],
start=list(a = 37, b = 104, d = 50,a3=-20,a_F91=-10,b271=70,d_MI=-40))
summary(qa.w126.12.8.nls)
error <- residuals(qa.w126.12.8.nls)
sse.full <- sum(error^2)
tss <- sum(qacombined$LOGTOTALDW[qacombined$TREAT !="AA"]^2)-mean(qacombined$LOGTOTALDW[qacombined$TREAT !="AA"])^2*length(qacombined$LOGTOTALDW[qacombined$TREAT !="AA"])
pred <- predict(qa.w126.12.8.nls)

r2.full <- 1-sse.full/tss
sse.full
r2.full

# 3-17-21 step 17 FERF , 1990&1991 Michigan studies, model w/o random coef 

qa.w126.12.8.nls <- nls(LOGTOTALDW ~ log(a + a3*is_Seedling +a_F91*is_F91+(d+is_MI*d_MI) *centered_logvol)-(w126.12.8.adj/b),data=qacombined[qacombined$TREAT !="AA",],
start=list(a = 58, b = 93, c=1,d = 50,a3=-20,a_F91=-10,d_MI=-40))
summary(qa.w126.12.8.nls)
error <- residuals(qa.w126.12.8.nls)
sse.red <- sum(error^2)
tss <- sum(qacombined$LOGTOTALDW[qacombined$TREAT !="AA"]^2)-mean(qacombined$LOGTOTALDW[qacombined$TREAT !="AA"])^2*length(qacombined$LOGTOTALDW[qacombined$TREAT !="AA"])
pred <- predict(qa.w126.12.8.nls)

r2.red <- 1-sse.red/tss
sse.red
r2.red

# 3-17-21 step 18 FERF , 1990&1991 Michigan studies only, clones 216,259 &271&Seedling ; set c=1 unable to run 

nm11 <- nlmer(LOGTOTALDW ~ nfun11(w126.12.8.adj, centered_logvol, is_Seedling,is_F91,is_MI,a, b,d,a3,a_F91,d_MI) ~ (a+b | Study.fac),
             data = qacombined[qacombined$TREAT !="6",],
             control = nlmerControl(
                                    optCtrl = list(maxfun = 2e7)),
             start = c(a = 53, b = 67, d = 48,a3=-38,a_F91=20,d_MI=-40))
summary(nm11)

# 3-17-21 step 19 FERF , 1990&1991 Michigan studies, model w/o random coef *** --> no longer final model used in manuscript

qa.w126.12.8.nls <- nls(LOGTOTALDW ~ log(a + a3*is_Seedling +a_F91*is_F91+(d+is_MI*d_MI) *centered_logvol)-(w126.12.8.adj/(b+b_216259*is_216+b_216259*is_259)),data=qacombined[qacombined$TREAT !="AA",],
start=list(a = 37, b = 104,d = 50,a3=-20,a_F91=-10,d_MI=-40,b_216259=-10))
summary(qa.w126.12.8.nls)
error <- residuals(qa.w126.12.8.nls)
sse.red <- sum(error^2)
tss <- sum(qacombined$LOGTOTALDW[qacombined$TREAT !="AA"]^2)-mean(qacombined$LOGTOTALDW[qacombined$TREAT !="AA"])^2*length(qacombined$LOGTOTALDW[qacombined$TREAT !="AA"])
pred <- predict(qa.w126.12.8.nls)

r2.red <- 1-sse.red/tss
sse.red
r2.red
sse.red/length(qacombined$LOGTOTALDW[qacombined$TREAT !="AA"])

# 4-13-21 step 20 include is_MI91, drop b_216259 --> use this final model in manuscript

n <- dim(qacombined)
qacombined$is_MI91 <- rep(0,n[1])
qacombined$is_MI91[qacombined$Study=="1991: 216"|qacombined$Study=="1991: 259"|qacombined$Study=="1991: 271"] <- 1

qa.w126.12.8.nls <- nls(LOGTOTALDW ~ log(a + a3*is_Seedling +a_F91*is_F91+a_MI91*is_MI91+(d+is_MI*d_MI) *centered_logvol)-(w126.12.8.adj/b),data=qacombined[qacombined$TREAT !="AA",],
start=list(a = 37, b = 104,d = 50,a3=-20,a_F91=-10,d_MI=-40,a_MI91=-5))
summary(qa.w126.12.8.nls)
error <- residuals(qa.w126.12.8.nls)
sse.red <- sum(error^2)
tss <- sum(qacombined$LOGTOTALDW[qacombined$TREAT !="AA"]^2)-mean(qacombined$LOGTOTALDW[qacombined$TREAT !="AA"])^2*length(qacombined$LOGTOTALDW[qacombined$TREAT !="AA"])
pred <- predict(qa.w126.12.8.nls)

r2.red <- 1-sse.red/tss
sse.red
r2.red
sse.red/length(qacombined$LOGTOTALDW[qacombined$TREAT !="AA"])

# 4-13-21 prbl calculations for table 6 --> used in manuscript

w <- c(1:6)*10
b <- coef(qa.w126.12.8.nls)[2]
c <- 1
prbl.low <- (1-exp(-(w/b)^c))*100
prbl.low
[1] 12.88508 24.10991 33.88841 42.40694 49.82785 56.29257 4-13-21
[1] 12.87474 24.09188 33.86485 42.37958 49.79805 56.26142 old

loss <- .06
w.6.low <- (-log(1-loss))^(1/c)*b
w.6.low
      b 
4.48561 

# 4-19-21 test diff in HEL HEH DP
# 4-19-21 study 11 had HEL HEH DP EPLOW EPHI

n <- dim(qacombined)
qacombined$is_F11_HEL <- rep(0,n[1])
qacombined$is_F11_HEL[qacombined$Study=="Study 11"&qacombined$TREAT=="HELLOW"] <- 1

qacombined$is_F11_HEH <- rep(0,n[1])
qacombined$is_F11_HEH[qacombined$Study=="Study 11"&qacombined$TREAT=="HELHI"] <- 1

qacombined$is_F11_DP <- rep(0,n[1])
qacombined$is_F11_DP[qacombined$Study=="Study 11"&qacombined$TREAT=="DAILY"] <- 1

qa.w126.12.8.nls2 <- nls(LOGTOTALDW ~ log(a + a3*is_Seedling +a_F91*is_F91+a_MI91*is_MI91+(d+is_MI*d_MI) *centered_logvol)-(w126.12.8.adj/b)+a_F11_HEL*is_F11_HEL+a_F11_HEH*is_F11_HEH+a_F11_DP*is_F11_DP,data=qacombined[qacombined$TREAT !="AA",],
start=list(a = 37, b = 104,d = 50,a3=-20,a_F91=-10,d_MI=-40,a_MI91=-5,a_F11_HEL=1,a_F11_HEH=-1,a_F11_DP=-1))
summary(qa.w126.12.8.nls2)
error <- residuals(qa.w126.12.8.nls2)
sse.full <- sum(error^2)
tss <- sum(qacombined$LOGTOTALDW[qacombined$TREAT !="AA"]^2)-mean(qacombined$LOGTOTALDW[qacombined$TREAT !="AA"])^2*length(qacombined$LOGTOTALDW[qacombined$TREAT !="AA"])
pred <- predict(qa.w126.12.8.nls2)

r2.full <- 1-sse.full/tss
sse.full
r2.full
sse.full/length(qacombined$LOGTOTALDW[qacombined$TREAT !="AA"])

# 4-20-21 added a_F91_DP only

qa.w126.12.8.nls3 <- nls(LOGTOTALDW ~ log(a + a3*is_Seedling +a_F91*is_F91+a_MI91*is_MI91+(d+is_MI*d_MI) *centered_logvol)-(w126.12.8.adj/b)+a_F11_DP*is_F11_DP,data=qacombined[qacombined$TREAT !="AA",],
start=list(a = 37, b = 104,d = 50,a3=-20,a_F91=-10,d_MI=-40,a_MI91=-5,a_F11_DP=-1))
summary(qa.w126.12.8.nls3)
error <- residuals(qa.w126.12.8.nls3)
sse.full <- sum(error^2)
tss <- sum(qacombined$LOGTOTALDW[qacombined$TREAT !="AA"]^2)-mean(qacombined$LOGTOTALDW[qacombined$TREAT !="AA"])^2*length(qacombined$LOGTOTALDW[qacombined$TREAT !="AA"])
pred <- predict(qa.w126.12.8.nls3)

r2.full <- 1-sse.full/tss
sse.full
r2.full
sse.full/length(qacombined$LOGTOTALDW[qacombined$TREAT !="AA"])


# 4-14-21 add random coef to final model above, drop d_MI, could not run this model

qa.nlmer <- nlmer(LOGTOTALDW ~ nfun14(w126.12.8.adj, centered_logvol, is_Seedling,is_F91,is_MI91,a, b,d,a3,a_F91,a_MI91) ~ a  | Study.fac,
             data = qacombined[qacombined$TREAT !="6",],
             control = nlmerControl(optimizer = "bobyqa",
                                    optCtrl = list(maxfun = 2e7)),
             start = c(a = 37, b = 104,d = 15,a3=-50,a_F91=18,a_MI91=-27))
summary(qa.nlmer)

error <- residuals(qa.nlmer)
sse <- sum(error^2)
tss <- sum(qacombined$LOGTOTALDW^2)-mean(qacombined$LOGTOTALDW)^2*length(qacombined$LOGTOTALDW)
pred <- predict(qa.nlmer)
1-sse/tss

n <- dim(qacombined[qacombined$TREAT !="6",])
pt(-11.311,n[1]-8)
[1] 8.563521e-21
pt(-6.648,n[1]-8)
[1] 4.96999e-10

# 3-16-21 step 4 FERF

Nonlinear mixed model fit by maximum likelihood  ['nlmerMod']
Formula: LOGTOTALDW ~ nfun1(w126.12.8.adj, centered_logvol, a, b, c, d) ~      d | Study.fac
   Data: qacombined[qacombined$Site == "FERF", ]
Control: nlmerControl(optCtrl = list(maxfun = 2e+07))

     AIC      BIC   logLik deviance df.resid 
    49.6     56.4    -18.8     37.6       17 

Scaled residuals: 
    Min      1Q  Median      3Q     Max 
-1.2747 -0.9686 -0.5319  1.0886  1.4657 

Random effects:
 Groups    Name Variance  Std.Dev. 
 Study.fac d    1.382e-08 0.0001175
 Residual       3.000e-01 0.5477096
Number of obs: 23, groups:  Study.fac, 2

Fixed effects:
  Estimate Std. Error t value
a  17.3484     3.4169   5.077
b  71.5376    13.4608   5.315
c   1.5192     0.7533   2.017
d  36.4149    33.1196   1.099

# 3-16-21 step 5 FERF w separate a; why is it not possible to fit random coef for a? ***

Nonlinear mixed model fit by maximum likelihood  ['nlmerMod']
Formula: LOGTOTALDW ~ nfun4(w126.12.8.adj, centered_logvol, is_F91, a,      b, c, d, a3) ~ (d | Study.fac)
   Data: qacombined[qacombined$Site == "FERF", ]
Control: nlmerControl(optCtrl = list(maxfun = 2e+07))

     AIC      BIC   logLik deviance df.resid 
     4.5     12.5      4.7     -9.5       16 

Scaled residuals: 
    Min      1Q  Median      3Q     Max 
-1.4714 -0.6972 -0.2263  0.2801  3.0646 

Random effects:
 Groups    Name Variance Std.Dev.
 Study.fac d    0.0000   0.000   
 Residual       0.0388   0.197   
Number of obs: 23, groups:  Study.fac, 2

Fixed effects:
   Estimate Std. Error t value
a    9.7063     0.8505  11.413
b  115.1533    24.8908   4.626
c    1.0471     0.3788   2.764
d    8.5320     9.6662   0.883
a3  20.9932     2.5226   8.322

# 3-15-21 step 6 1990 Michigan exc clone 271

Nonlinear mixed model fit by maximum likelihood  ['nlmerMod']
Formula: LOGTOTALDW ~ nfun2(w126.12.8.adj, centered_logvol, a, b, d) ~      (a + b | Study.fac)
   Data: qacombined[qacombined$Year == 1990 & qacombined$Site == "Michigan" &  
    qacombined$TREAT != "6" & (qacombined$Study == "1990: 216" |  
    qacombined$Study == "1990: 253" | qacombined$Study == "1990: 259"),      ]
Control: nlmerControl(optCtrl = list(maxfun = 2e+07))

     AIC      BIC   logLik deviance df.resid 
     0.7     13.4      6.6    -13.3       38 

Scaled residuals: 
    Min      1Q  Median      3Q     Max 
-3.6615 -0.5162  0.0517  0.6111  1.9971 

Random effects:
 Groups    Name Variance  Std.Dev.  Corr
 Study.fac a    1.673e-10 1.293e-05     
           b    1.455e-08 1.206e-04 0.68
 Residual       4.360e-02 2.088e-01     
Number of obs: 45, groups:  Study.fac, 3

Fixed effects:
  Estimate Std. Error t value
a   64.077      2.815  22.766
b   49.804      8.368   5.952
d   12.749      3.356   3.798

# 3-15-21 step 7 1990 Michigan inc clone 271 ***

Nonlinear mixed model fit by maximum likelihood  ['nlmerMod']
Formula: LOGTOTALDW ~ nfun5(w126.12.8.adj, centered_logvol, is_271, a,      b, d, b271) ~ (a + b | Study.fac)
   Data: qacombined[qacombined$Year == 1990 & qacombined$Site == "Michigan" &  
    qacombined$TREAT != "6" & (qacombined$Study == "1990: 216" |  
    qacombined$Study == "1990: 253" | qacombined$Study == "1990: 259" |      qacombined$Study == "1990: 271"), ]
Control: nlmerControl(optCtrl = list(maxfun = 2e+07))

     AIC      BIC   logLik deviance df.resid 
    -9.9      6.8     13.0    -25.9       52 

Scaled residuals: 
    Min      1Q  Median      3Q     Max 
-3.9397 -0.4437 -0.0322  0.5805  2.3498 

Random effects:
 Groups    Name Variance Std.Dev. Corr 
 Study.fac a    20.28092 4.5034        
           b    70.74596 8.4111   -1.00
 Residual        0.03608 0.1899        
Number of obs: 60, groups:  Study.fac, 4

Fixed effects:
     Estimate Std. Error t value
a      67.273      3.205  20.991
b      44.114      7.349   6.002
d      12.886      3.056   4.217
b271  213.489    286.046   0.746

# 3-16-21 michigan 1991 216&259

Nonlinear mixed model fit by maximum likelihood  ['nlmerMod']
Formula: LOGTOTALDW ~ nfun2(w126.12.8.adj, centered_logvol, a, b, d) ~      (a + b | Study.fac)
   Data: qacombined[qacombined$Year == 1991 & qacombined$Site == "Michigan" &  
    qacombined$TREAT != "6" & (qacombined$Study == "1991: 216" |      qacombined$Study == "1991: 259"), ]
Control: nlmerControl(optCtrl = list(maxfun = 2e+07))

     AIC      BIC   logLik deviance df.resid 
    -9.1     -2.9     11.6    -23.1       11 

Scaled residuals: 
     Min       1Q   Median       3Q      Max 
-1.62812 -0.43348  0.07537  0.59747  1.89106 

Random effects:
 Groups    Name Variance Std.Dev. Corr
 Study.fac a    2.53328  1.5916       
           b    0.02693  0.1641   1.00
 Residual       0.01482  0.1218       
Number of obs: 18, groups:  Study.fac, 2

Fixed effects:
  Estimate Std. Error t value
a   36.469      1.958  18.630
b   74.899     12.561   5.963
d   14.437      3.816   3.783

# 3-16-21 michigan 1991 216&271&Seedling

Nonlinear mixed model fit by maximum likelihood  ['nlmerMod']
Formula: LOGTOTALDW ~ nfun4(w126.12.8.adj, centered_logvol, is_Seedling,      a, b, c, d, a3) ~ (b | Study.fac)
   Data: qacombined[qacombined$Year == 1991 & qacombined$Site == "Michigan" &      qacombined$TREAT != "6" & (qacombined$Study == "1991: 216" |      qacombined$Study == "1991: 271" | qacombined$Study == "Seedling"),      ]
Control: nlmerControl(optCtrl = list(maxfun = 2e+07))

     AIC      BIC   logLik deviance df.resid 
   -14.2     -3.8     14.1    -28.2       26 

Scaled residuals: 
    Min      1Q  Median      3Q     Max 
-1.8821 -0.9945  0.2960  0.5648  2.1113 

Random effects:
 Groups    Name Variance  Std.Dev. 
 Study.fac b    5.190e-11 7.204e-06
 Residual       2.488e-02 1.577e-01
Number of obs: 33, groups:  Study.fac, 3

Fixed effects:
   Estimate Std. Error t value
a   38.1787     2.7657  13.804
b  187.9741   316.2742   0.594
c    0.6388     0.6174   1.035
d   11.1604     3.7842   2.949
a3 -20.1649     1.8998 -10.614

# 3-16-21 michigan 1991 216&271&Seedling set c=1

Nonlinear mixed model fit by maximum likelihood  ['nlmerMod']
Formula: LOGTOTALDW ~ nfun6(w126.12.8.adj, centered_logvol, is_Seedling,      a, b, d, a3) ~ (b | Study.fac)
   Data: qacombined[qacombined$Year == 1991 & qacombined$Site == "Michigan" &      qacombined$TREAT != "6" & (qacombined$Study == "1991: 216" |      qacombined$Study == "1991: 271" | qacombined$Study == "Seedling"),      ]
Control: nlmerControl(optCtrl = list(maxfun = 2e+07))

     AIC      BIC   logLik deviance df.resid 
   -15.9     -7.0     14.0    -27.9       27 

Scaled residuals: 
    Min      1Q  Median      3Q     Max 
-1.8728 -0.8567  0.2449  0.7013  2.2220 

Random effects:
 Groups    Name Variance  Std.Dev.
 Study.fac b    1.278e-08 0.000113
 Residual       2.510e-02 0.158437
Number of obs: 33, groups:  Study.fac, 3

Fixed effects:
   Estimate Std. Error t value
a    37.272      1.911  19.507
b   102.951     24.599   4.185
d    10.526      3.544   2.970
a3  -19.807      1.693 -11.702

# 3-16-21 michigan 1991 216&259&271&Seedling set c=1 ***

Nonlinear mixed model fit by maximum likelihood  ['nlmerMod']
Formula: LOGTOTALDW ~ nfun7(w126.12.8.adj, centered_logvol, is_Seedling,      is_271, a, b, d, a3, b271) ~ (d | Study.fac)
   Data: qacombined[qacombined$Year == 1991 & qacombined$Site == "Michigan" &      qacombined$TREAT != "6" & (qacombined$Study == "1991: 216" |      qacombined$Study == "1991: 259" | qacombined$Study == "1991: 271" |      qacombined$Study == "Seedling"), ]
Control: nlmerControl(optCtrl = list(maxfun = 2e+07))

     AIC      BIC   logLik deviance df.resid 
   -23.3    -11.1     18.6    -37.3       35 

Scaled residuals: 
    Min      1Q  Median      3Q     Max 
-1.9455 -0.7475  0.1882  0.6754  2.4000 

Random effects:
 Groups    Name Variance Std.Dev.
 Study.fac d    0.0000   0.0000  
 Residual       0.0241   0.1553  
Number of obs: 42, groups:  Study.fac, 4

Fixed effects:
     Estimate Std. Error t value
a      36.234      1.528  23.716
b      81.334     13.554   6.001
d      13.702      2.974   4.607
a3    -17.993      1.437 -12.519
b271   45.500     46.410   0.980

# 3-16-21 1990-1991 michigan studies ***

Nonlinear mixed model fit by maximum likelihood  ['nlmerMod']
Formula: LOGTOTALDW ~ nfun7(w126.12.8.adj, centered_logvol, is_Seedling,      is_271, a, b, d, a3, b271) ~ (a + b | Study.fac)
   Data: qacombined[qacombined$Site == "Michigan" & qacombined$TREAT !=      "6", ]
Control: nlmerControl(optCtrl = list(maxfun = 2e+07))

     AIC      BIC   logLik deviance df.resid 
   -15.1      8.6     16.5    -33.1       93 

Scaled residuals: 
    Min      1Q  Median      3Q     Max 
-4.3021 -0.4138  0.0451  0.6902  2.3652 

Random effects:
 Groups    Name Variance  Std.Dev. Corr 
 Study.fac a    259.18453 16.0992       
           b    486.17241 22.0493  -1.00
 Residual         0.03177  0.1782       
Number of obs: 102, groups:  Study.fac, 8

Fixed effects:
     Estimate Std. Error t value
a      52.417      6.049   8.665
b      65.316      9.658   6.763
d      13.195      2.174   6.070
a3    -22.867     11.918  -1.919
b271   77.841     49.181   1.583

# 3-17-21 FERF and MI studies no random coef ***

Formula: LOGTOTALDW ~ log(a + a3 * is_Seedling + a_F91 * is_F91 + is_MI * 
    d * centered_logvol) - (w126.12.8.adj/(b + b271 * is_271))

Parameters:
      Estimate Std. Error t value Pr(>|t|)    
a       54.588      2.018  27.046  < 2e-16 ***
b       67.288      7.110   9.464  < 2e-16 ***
d       10.649      3.095   3.441 0.000776 ***
a3     -38.813      2.055 -18.883  < 2e-16 ***
a_F91   20.230      4.206   4.810 4.03e-06 ***
b271    42.842     52.866   0.810 0.419163    
---
Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

Residual standard error: 0.3186 on 133 degrees of freedom

Number of iterations to convergence: 6 
Achieved convergence tolerance: 1.787e-06

> error <- residuals(qa.w126.12.8.nls)
> sse.full <- sum(error^2)
> tss <- sum(qacombined$LOGTOTALDW[qacombined$TREAT !="AA"]^2)-mean(qacombined$LOGTOTALDW[qacombined$TREAT !="AA"])^2*length(qacombined$LOGTOTALDW[qacombined$TREAT !="AA"])
> pred <- predict(qa.w126.12.8.nls)
> 
> r2.full <- 1-sse.full/tss
> sse.full
[1] 13.50285
> r2.full
[1] 0.834603

# 3-17-21 FERF and MI studies no random coef --> do not use this final model in manuscript

Formula: LOGTOTALDW ~ log(a + a3 * is_Seedling + a_F91 * is_F91 + (d + 
    is_MI * d_MI) * centered_logvol) - (w126.12.8.adj/(b + b_216259 * 
    is_216 + b_216259 * is_259))

Parameters:
         Estimate Std. Error t value Pr(>|t|)    
a          58.093      2.156  26.950  < 2e-16 ***
b          72.557      8.628   8.409 5.85e-14 ***
d          40.024     19.364   2.067  0.04070 *  
a3        -42.664      2.221 -19.207  < 2e-16 ***
a_F91      19.662      3.901   5.041 1.50e-06 ***
d_MI      -29.161     19.333  -1.508  0.13386    
b_216259  -30.805      9.656  -3.190  0.00178 ** 
---
Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

Residual standard error: 0.3062 on 132 degrees of freedom

Number of iterations to convergence: 8 
Achieved convergence tolerance: 7.73e-06

> error <- residuals(qa.w126.12.8.nls)
> sse.red <- sum(error^2)
> tss <- sum(qacombined$LOGTOTALDW[qacombined$TREAT !="AA"]^2)-mean(qacombined$LOGTOTALDW[qacombined$TREAT !="AA"])^2*length(qacombined$LOGTOTALDW[qacombined$TREAT !="AA"])
> pred <- predict(qa.w126.12.8.nls)
> 
> r2.red <- 1-sse.red/tss
> sse.red
[1] 12.37406
> r2.red
[1] 0.8484297

# 4-13-21 added is_MI91, dropped b_216259 --> use as final model in manuscript (4-19-21 test for F11 DP significant)

Formula: LOGTOTALDW ~ log(a + a3 * is_Seedling + a_F91 * is_F91 + a_MI91 * 
    is_MI91 + (d + is_MI * d_MI) * centered_logvol) - (w126.12.8.adj/b)

Parameters:
       Estimate Std. Error t value Pr(>|t|)    
a        63.190      1.965  32.152  < 2e-16 ***
b        72.494      6.585  11.008  < 2e-16 ***
d        40.361     15.597   2.588   0.0107 *  
a3      -47.695      1.953 -24.415  < 2e-16 ***
a_F91    19.609      3.151   6.222 6.03e-09 ***
d_MI    -28.215     15.574  -1.812   0.0723 .  
a_MI91  -25.377      2.562  -9.905  < 2e-16 ***
---
Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

Residual standard error: 0.2477 on 132 degrees of freedom

Number of iterations to convergence: 8 
Achieved convergence tolerance: 4.236e-06

> error <- residuals(qa.w126.12.8.nls)
> sse.red <- sum(error^2)
> tss <- sum(qacombined$LOGTOTALDW[qacombined$TREAT !="AA"]^2)-mean(qacombined$LOGTOTALDW[qacombined$TREAT !="AA"])^2*length(qacombined$LOGTOTALDW[qacombined$TREAT !="AA"])
> pred <- predict(qa.w126.12.8.nls)
> 
> r2.red <- 1-sse.red/tss
> sse.red
[1] 8.09672
> r2.red
[1] 0.900823

# 4-19-21 test for F11 HEL HEH DP --> DP is less damaging than EP and HEH --> use as final model in manuscript (4-19-21 test for F11 DP significant)

Formula: LOGTOTALDW ~ log(a + a3 * is_Seedling + a_F91 * is_F91 + a_MI91 * 
    is_MI91 + (d + is_MI * d_MI) * centered_logvol) - (w126.12.8.adj/b) + 
    a_F11_HEL * is_F11_HEL + a_F11_HEH * is_F11_HEH + a_F11_DP * 
    is_F11_DP

Parameters:
          Estimate Std. Error t value Pr(>|t|)    
a          63.7703     1.9407  32.859  < 2e-16 ***
b          67.1820     5.9894  11.217  < 2e-16 ***
d          26.0736    16.8853   1.544  0.12500    
a3        -47.8458     1.9407 -24.654  < 2e-16 ***
a_F91      19.9905     3.1834   6.280 4.78e-09 ***
d_MI      -13.5332    16.9148  -0.800  0.42513    
a_MI91    -25.3217     2.5128 -10.077  < 2e-16 ***
a_F11_HEL  -0.2907     0.1830  -1.589  0.11462    
a_F11_HEH  -0.2343     0.1807  -1.297  0.19701    
a_F11_DP    0.5167     0.1906   2.712  0.00761 ** 
---
Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

Residual standard error: 0.2399 on 129 degrees of freedom

Number of iterations to convergence: 8 
Achieved convergence tolerance: 2.769e-06

> error <- residuals(qa.w126.12.8.nls2)
> sse.full <- sum(error^2)
> tss <
- sum(qacombined$LOGTOTALDW[qacombined$TREAT !="AA"]^2)-mean(qacombined$LOGTOTALDW[qacombined$TREAT !="AA"])^2*length(qacombined$LOGTOTALDW[qacombined$TREAT !="AA"])
> pred <- predict(qa.w126.12.8.nls2)
> 
> r2.full <- 1-sse.full/tss
> sse.full
[1] 7.421466
> r2.full
[1] 0.9090942

# 4-20-21

Formula: LOGTOTALDW ~ log(a + a3 * is_Seedling + a_F91 * is_F91 + a_MI91 * 
    is_MI91 + (d + is_MI * d_MI) * centered_logvol) - (w126.12.8.adj/b) + 
    a_F11_DP * is_F11_DP

Parameters:
         Estimate Std. Error t value Pr(>|t|)    
a         63.8281     1.9501  32.731  < 2e-16 ***
b         66.4346     5.7604  11.533  < 2e-16 ***
d         36.3737    15.5293   2.342  0.02067 *  
a3       -48.3006     1.9347 -24.966  < 2e-16 ***
a_F91     20.5617     3.1849   6.456 1.92e-09 ***
d_MI     -24.0690    15.5159  -1.551  0.12325    
a_MI91   -25.2900     2.5349  -9.977  < 2e-16 ***
a_F11_DP   0.5346     0.1909   2.801  0.00587 ** 
---
Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1

Residual standard error: 0.2415 on 131 degrees of freedom

Number of iterations to convergence: 9 
Achieved convergence tolerance: 1.389e-06

> sse.full
[1] 7.639772
> r2.full
[1] 0.9064201
> sse.full/length(qacombined$LOGTOTALDW[qacombined$TREAT !="AA"])
[1] 0.05496239

# 4-14-21 added random coef for a --> do not use this as final model in manuscript

Nonlinear mixed model fit by maximum likelihood  ['nlmerMod']
Formula: LOGTOTALDW ~ nfun13(w126.12.8.adj, centered_logvol, is_Seedling,  
    is_F91, is_MI, is_MI91, a, b, d, a3, a_F91, d_MI, a_MI91) ~      a | Study.fac
   Data: qacombined[qacombined$TREAT != "6", ]
Control: nlmerControl(optimizer = "bobyqa", optCtrl = list(maxfun = 2e+07))

     AIC      BIC   logLik deviance df.resid 
   -18.1      7.3     18.1    -36.1      116 

Scaled residuals: 
    Min      1Q  Median      3Q     Max 
-4.6861 -0.6016  0.1061  0.5907  3.2746 

Random effects:
 Groups    Name Variance Std.Dev.
 Study.fac a    21.41829 4.6280  
 Residual        0.03771 0.1942  
Number of obs: 125, groups:  Study.fac, 10

Fixed effects:
       Estimate Std. Error t value
a        63.312      2.880  21.980
b        94.511     10.146   9.315
d        14.805      9.525   1.554
a3      -49.129      4.344 -11.311
a_F91    18.260      6.127   2.980
d_MI     -1.359      9.696  -0.140
a_MI91  -27.190      4.090  -6.648

1-sse/tss
[1] 0.9459237



# end ehl -----------------------------------

library(tidyverse)

study_11 <- read_csv("C:/Users/skoike/Desktop/Reanalysis/Quaking Aspen/11_h1_mean_data.csv") %>% 
  mutate(Study = factor("Study 11"),
         Site = "FERF") %>% 
  rename(LOGVOL_bl = LOGVOL.bl, VOL_bl = VOL.bl, CHAMB = CH, TREAT = OZ) %>% 
  select(-LOGVOL.h1)
study_37 <- read_csv("C:/Users/skoike/Desktop/Reanalysis/Quaking Aspen/37_h1_mean_data.csv") %>% 
  mutate(Study = factor("Study 37"),
         Site = "FERF") %>% 
  rename(LOGVOL_bl = LOGVOL.bl, VOL_bl = VOL.bl, CHAMB = CH, TREAT = OZ) %>% 
  select(-LOGVOL.h)
study_90 <- read_csv("C:/Users/skoike/Desktop/Reanalysis/Quaking Aspen/aspen_clone_90_mean_data.csv") %>% 
  mutate(Study = factor("1990"),
         Site = "Michigan",
         TREAT = as.character(TREAT)) %>% 
  select(-COARSEDW, -FINEDW, -LOGCOARSEDW, -LOGFINEDW, -LOGVOL_h) %>% 
  mutate(TREAT = case_when(TREAT == "5" ~ "1",
                           TREAT == "1" ~ "2",
                           TREAT == "2" ~ "3",
                           TREAT == "3" ~ "4",
                           TREAT == "4" ~ "5",
                           TREAT == "6" ~ "6")) #Treatment codes were messed up
study_91 <- read_csv("C:/Users/skoike/Desktop/Reanalysis/Quaking Aspen/aspen_clone_91_mean_data.csv") %>% 
  mutate(Study = factor("1991"),
         Site = "Michigan",
         TREAT = as.character(TREAT)) %>% 
  select(-LOGVOL_h)
study_seedling <- read_csv("C:/Users/skoike/Desktop/Reanalysis/Quaking Aspen/aspen_seed_mean_data.csv") %>% 
  mutate(Study = factor("Seedling"),
         Site = "Michigan",
         TREAT = as.character(TREAT)) %>% 
  rename(CHAMB = CHAMBER) %>% 
  select(-LOGVOL_h)

studies_ferf <- full_join(study_11, study_37) 

studies_clone <- full_join(study_90, study_91) %>% 
  mutate(Study = paste0(Year, ": ", CLONE), .before = 1) %>% 
  full_join(study_seedling) %>% 
  mutate(TREAT = as.character(TREAT)) %>% 
  rename(actual.24 = OZ.24,
         actual.24.adj = OZ.24.adj,
         actual.12.7 = OZ.12.7,
         actual.12.8 = OZ.12.8,
         actual.12.9 = OZ.12.9,
         actual.12.7.adj = OZ.12.7.adj,
         actual.12.8.adj = OZ.12.8.adj,
         actual.12.9.adj = OZ.12.9.adj) 

studies <- full_join(studies_ferf, studies_clone) %>% 
  mutate(Species = "Quaking Aspen") %>% 
  select(Species, Study, Site, Year, CLONE, Harvest, Exp_days, CHAMB, TREAT, everything())

ggplot(studies) + 
  aes(x = LOGVOL_bl, y = LOGTOTALDW, fill = Study, color = Study) + 
  geom_point(shape = 21, size = 2, color = "black") + 
  scale_fill_brewer(palette = "Paired") + 
  geom_smooth(method = "lm", se = FALSE) + 
  scale_color_brewer(palette = "Paired") + 
  theme_bw()

studies %>% select(Study, TREAT, Exp_days, w126.12.8.adj) 

ggplot(studies) + 
  aes(x = w126.12.8.adj, y = LOGTOTALDW, fill = Study, color = Study) + 
  geom_point(shape = 21, size = 2, color = "black") + 
  scale_fill_brewer(palette = "Paired") + 
  geom_smooth(method = "lm", se = FALSE) + 
  scale_color_brewer(palette = "Paired") + 
  theme_bw()

studies %>% 
  mutate(W126 = w126.12.8.adj*Exp_days/92) %>% 
  group_by(Study, TREAT, Exp_days) %>% 
  summarise(m = round(mean(W126), 1)) %>% 
  arrange(Study, m)

studies %>% 
  nest_by(Study, Exp_days)


QA <- studies %>% 
  group_by(Study) %>% 
  mutate(centered_logvol = LOGVOL_bl - mean(LOGVOL_bl)) %>% 
  select(Species, Study, Site, Year, Harvest, Exp_days, CHAMB, TREAT, 
         ends_with("DW"), centered_logvol, everything())

#write.csv(QA, "qa_chamber_mean_data.csv", row.names = FALSE)

fitmodel <- function(df){lm(LOGTOTALDW ~ centered_logvol, data = df)}

QA %>% 
  group_by(Study) %>% 
  nest() %>% 
  mutate(model = map(data, fitmodel),
         tidied = map(model, broom::tidy)) %>% 
  unnest(tidied) %>% 
  filter(term == "centered_logvol") %>% 
  arrange(p.value)

QA1 <- QA %>% mutate(sig_logvol = ifelse(Study %in% c("1990: 216", "1991: 259"), 1, 0))

studies %>% group_by(Study) %>% tally()

#write.csv(studies, "qa_harvest_1.csv", row.names = FALSE)

# Random effects Model ---------------------------------------------------
library(lme4)

QA <- QA1 %>% select(Study, centered_logvol, w126.12.8.adj, LOGTOTALDW, sig_logvol)

ggplot(QA, aes(x = w126.12.8.adj, y = LOGTOTALDW, color = Study)) + 
  geom_point(size = 2) + 
  geom_smooth(method = "lm", se = FALSE)

qplot(centered_logvol, LOGTOTALDW, data = QA1, geom = "point", color = Study)

#####################

nform <- ~ log(a) + (-(input/b)) #Doesn't converge

nfun <- deriv(nform,
              namevec = c("a", "b"),
              function.arg = c("input", "a", "b"))

nm <- nlmer(LOGTOTALDW ~ nfun(w126.12.8.adj, a, b) ~ (b|Study), # Doesn't converge with random a
            data = QA,
            control = nlmerControl(optimizer = "bobyqa",
                                   optCtrl = list(maxfun = 2e5)),
            start = c(a = 50, b = 100))
summary(nm) # b = 58

aug <- broom.mixed::augment(nm)

ggplot(aug) + 
  aes(sample = .resid) + 
  geom_qq() + 
  geom_qq_line()


####################

# With Common Covariate, B, C 
nform1 <- ~ log(a + d * logvol) + (-(x/b)^c)

nfun1 <- deriv(nform1,
               namevec = c("a", "b", "c", "d"),
               function.arg = c("x", "logvol", "a", "b", "c", "d"))

nm1 <- nlmer(LOGTOTALDW ~ nfun1(w126.12.8.adj, centered_logvol, a, b, c, d) ~ a + b + c | Study,
             data = QA,
             control = nlmerControl(optimizer = "bobyqa",
                                    optCtrl = list(maxfun = 2e7)),
             start = c(a = 10, b = 50, c = 1, d = 1))
summary(nm1) #C = 1.4


aug1 <- broom.mixed::augment(nm1)

ggplot(aug1) + 
  aes(sample = .resid) + 
  geom_qq() + 
  geom_qq_line()

ggplot(aug1) + # pretty left-skewed
  aes(x = .resid) + 
  geom_histogram(aes(y = ..density..)) + 
  geom_density()

# With Covariate for some studies, B, C 
nform2 <- ~ log(a + d*sig_logvol*logvol) + (-(x/b)^c)

nfun2 <- deriv(nform2,
               namevec = c("a", "b", "c", "d"),
               function.arg = c("x", "logvol", "sig_logvol", "a", "b", "c", "d"))

nm2 <- nlmer(LOGTOTALDW ~ nfun2(w126.12.8.adj, centered_logvol, sig_logvol, a, b, c, d) ~ a + b + c | Study,
             data = QA,
             control = nlmerControl(optimizer = "bobyqa",
                                    optCtrl = list(maxfun = 2e7)),
             start = c(a = 10, b = 1, c = 1, d = 1))
summary(nm2) # C = 1.2

aug2 <- broom.mixed::augment(nm2)

ggplot(aug2) + 
  aes(sample = .resid) + 
  geom_qq() + 
  geom_qq_line()

ggplot(aug2) + # somewhat left-skewed
  aes(x = .resid) + 
  geom_histogram(aes(y = ..density..)) + 
  geom_density()

# With Covariate for some studies, B
nform3 <- ~ log(a + d*sig_logvol*logvol) + (-(x/b))

nfun3 <- deriv(nform3,
               namevec = c("a", "b", "d"),
               function.arg = c("x", "logvol", "sig_logvol", "a", "b", "d"))

nm3 <- nlmer(LOGTOTALDW ~ nfun3(w126.12.8.adj, centered_logvol, sig_logvol, a, b, d) ~ (a + b | Study),
             data = QA,
             control = nlmerControl(optimizer = "bobyqa",
                                    optCtrl = list(maxfun = 2e7)),
             start = c(a = 10, b = 1, d = 1))
summary(nm3) # C = 1.23

aug3 <- broom.mixed::augment(nm3)

ggplot(aug3) + 
  aes(sample = .resid) + 
  geom_qq() + 
  geom_qq_line()

ggplot(aug3) + 
  aes(x = .resid) + 
  geom_histogram(aes(y = ..density..)) + 
  geom_density()

# No Covariate, B, C 
nform4 <- ~ log(a) + (-(x/b)^c)

nfun4 <- deriv(nform4,
               namevec = c("a", "b", "c"),
               function.arg = c("x", "logvol", "a", "b", "c"))

nm4 <- nlmer(LOGTOTALDW ~ nfun4(w126.12.8.adj, centered_logvol, a, b, c) ~ (a + b | Study) + (c|Study),
             data = QA,
             control = nlmerControl(optimizer = "bobyqa", 
                                    optCtrl = list(maxfun = 2e7)),
             start = c(a = 1, b = 1, c = 1))
summary(nm4) #c = 1.25


aug4 <- broom.mixed::augment(nm4)

ggplot(aug4) + 
  aes(sample = .resid) + 
  geom_qq() + 
  geom_qq_line()

ggplot(aug4) + # pretty left-skewed
  aes(x = .resid) + 
  geom_histogram(aes(y = ..density..)) + 
  geom_density()

# With Common Covariate, B, C fixed (not random)

nform6 <- ~ log(a + d*logvol) + (-(x/b)^c)

nfun6 <- deriv(nform6,
               namevec = c("a", "b", "c", "d"),
               function.arg = c("x", "logvol", "a", "b", "c", "d"))

nm6 <- nlmer(LOGTOTALDW ~ nfun6(w126.12.8.adj, centered_logvol, a, b, c, d) ~ a + b | Study,
             data = QA,
             control = nlmerControl(optimizer = "bobyqa",
                                    tolPwrss = 1e-9,
                                    optCtrl = list(maxfun = 2e7)),
             start = c(a = 10, b = 100, c = 1, d = 1))
summary(nm6) #B = 93, C = 0.9774

aug6 <- broom.mixed::augment(nm6)

ggplot(aug6) + 
  aes(sample = .resid) + 
  geom_qq() + 
  geom_qq_line()

ggplot(aug6) + 
  aes(x = .resid) + 
  geom_histogram(aes(y = ..density..)) + 
  geom_density()


# Comparing models ------------------------------------------------

nform1 # common covariate, c random
nform2 # covariate for some, c random
nform4 # No covariate
nform6 # common covariate, c fixed

fixef(nm1) 
fixef(nm2) 
fixef(nm4) 
fixef(nm6) 


mean(aug1$.resid^2) 
mean(aug2$.resid^2)    
mean(aug4$.resid^2)
mean(aug6$.resid^2) # smallest

(SSRes1 <- sum(aug1$.resid^2))  
(SSRes2 <- sum(aug2$.resid^2)) 
(SSRes3 <- sum(aug3$.resid^2))   
(SSRes4 <- sum(aug4$.resid^2))  
(SSRes6 <- sum(aug6$.resid^2)) # smallest  

meanY <- mean(aug1$LOGTOTALDW) 
SStot <- sum((aug1$LOGTOTALDW - meanY)^2) 

(r_sq_1 <- 1 - SSRes1/SStot)
(r_sq_2 <- 1 - SSRes2/SStot)
(r_sq_3 <- 1 - SSRes3/SStot) 
(r_sq_4 <- 1 - SSRes4/SStot)
(r_sq_6 <- 1 - SSRes6/SStot) # largest

# Definitely going for common covariate, c fixed

SSreg <- sum((aug6$.fitted - meanY)^2)
SSreg/SStot

# Figure 
nform6

broom::tidy(nm6)

(coef_mod <- fixef(nm6))

QA <- QA %>% 
  mutate(adj_y = LOGTOTALDW - log(coef_mod[1] + coef_mod[4]*centered_logvol))

pred <- tibble(w126.12.8.adj = c(seq(0, max(QA$w126.12.8.adj), by = 0.5), max(QA$w126.12.8.adj)),
               adj_y = -(w126.12.8.adj/coef_mod[2])^coef_mod[3])

QA_plot <- ggplot(QA) + 
  aes(x = w126.12.8.adj, y = adj_y) +
  geom_point(aes(fill = Study), size = 2, shape = 21) + 
  geom_line(data = pred, color = "black", size = 0.75) 
QA_plot

qa_lines <- ggplot_build(QA_plot)$data[[2]] %>% 
  select(x, y) %>% 
  mutate(Species = factor("Quaking Aspen"))

#write.csv(qa_lines, "qa_lines.csv", row.names = FALSE)

qa_b <- tibble(b = coef_mod[2], c = coef_mod[3], Species = "Quaking Aspen")

round(100*(1 - exp(-(c(10, 20, 30, 40, 50)/coef_mod[2]))), 1) 

#write.csv(qa_b, "qa_params.csv", row.names = FALSE)
#write.csv(coef_mod, "qa_all_params.csv")

w126_frame <- QA %>% 
  group_by(Study) %>% 
  summarize(min_w126 = min(w126.12.8.adj),
            max_w126 = max(w126.12.8.adj)) %>% 
  mutate(x = map2(min_w126, max_w126, seq, by = 0.01)) %>% 
  unnest(cols = x) 

coef_frame <- coef(nm6)[1] %>% 
  as.data.frame() %>% 
  rownames_to_column("Study") %>% 
  select(Study, ends_with("b"), ends_with("c")) %>% 
  rename(b = Study.b, c = Study.c)

QA_lines <- full_join(w126_frame, coef_frame) %>% 
  mutate(y = -(x/b)^c)

nform6

intercept_frame <- coef(nm6)[1] %>% 
  as.data.frame() %>% 
  rownames_to_column("Study") %>% 
  select(Study, Study.a, Study.d)


QA_points <- full_join(QA, intercept_frame) %>% 
  rename(a = Study.a,
         d = Study.d) %>% 
  mutate(adj_y = LOGTOTALDW - log(a + d*centered_logvol))

QA_sub <- QA %>% select(Study) %>% mutate(Model = factor("Population"))

pred1_a <- pred %>% 
  mutate(Model = factor("Population")) %>% 
  full_join(QA_sub) %>% 
  rename(x = w126.12.8.adj, y = adj_y)

QA_lines <- QA_lines %>% mutate(Model = factor("Individual"))

pred2 <- full_join(QA_lines, pred1_a)

ggplot(QA_points) + 
  aes(x = w126.12.8.adj, y = adj_y) + 
  geom_point(shape = 21, size = 2, aes(fill = Study)) + 
  guides(fill = FALSE, color = FALSE) + 
  facet_wrap(. ~ Study, nrow = 2) + 
  geom_line(data = pred2 %>% filter(Model == "Individual"), aes(x = x, y = y, linetype = Model, color = Study), size = 1) + 
  geom_line(data = pred2 %>% filter(Model != "Individual"), aes(x = x, y = y, linetype = Model), color = "black", size = 1) 

ggplot(QA_points) + 
  aes(x = w126.12.8.adj, y = adj_y) + 
  geom_point(shape = 21, size = 2, aes(fill = Study)) + 
  geom_line(data = pred2 %>% filter(Model == "Individual"), aes(x = x, y = y, linetype = Model, color = Study), size = 1) + 
  geom_line(data = pred2 %>% filter(Model != "Individual"), aes(x = x, y = y, linetype = Model), color = "black", size = 1) 

y_hat <- -(QA_points$w126.12.8.adj/coef_mod[2])^coef_mod[3]
y <- QA_points$adj_y

plot(y, y_hat)
abline(a = 0, b = 1)

SSRes <- sum((y - y_hat)^2)
SSTot <- sum((y - mean(y))^2)

1 - SSRes/SSTot

mean((y - y_hat)^2) 


# Likelihood Confidence Interval -----------------------------------------------

# Step 1: Pull out relevant variables so we don't have to refer to data 

y <- QA$LOGTOTALDW
x <- QA$w126.12.8.adj
logvol <- QA$centered_logvol
Study <- QA$Study

# Step 2: Reparameterize the model so we can create a confidence interval around predicted biomass loss (theta)
coef_mod
nform6

# Use Taylor Series expansion around 0.5 to help with convergence

nlform_k <- ~ log(a + d*logvol) + ((x/x0) * (log(0.5) - 
                                               2*(theta - 0.5)^1 - 
                                               2*(theta - 0.5)^2 - 
                                               2.66666666666667*(theta - 0.5)^3 -
                                               4*(theta - 0.5)^4 - 
                                               6.4*(theta - 0.5)^5 -
                                               10.6666666666667*(theta - 0.5)^6 - 
                                               18.2857142857143*(theta - 0.5)^7))

nlfun_k <- deriv(nlform_k,
                 namevec = c("a", "d", "theta"),
                 function.arg = c("x", "x0", "logvol", "a", "d", "theta"))

# Step 3: At every break (e.g. 10, 20, 30, etc.), run the model at that fixed point, varying the value of theta

breaks <- c(seq(10, max(x), by = 5)) # our breaks

# Want a table where the log likelihoods are stored, one row for every theta, one column for every break

theta_vals <- seq(0, 1, by = 0.01) # 101 values for theta

M <- matrix(nrow = length(theta_vals), ncol = length(breaks)+ 1)

LL <- as_tibble(M) %>% # This will hold our likelihoods for every value of x0
  mutate_all(as.numeric) %>% 
  rename(theta = V1) %>%  
  mutate(theta = theta_vals)

mle <- rep(NA, length(breaks)) # this will hold the maximum likelihood estimate from initial model
ll_hat <- rep(NA, length(breaks)) # this will hold the log likelihood from initial model

for(i in 1:(ncol(LL) - 1)){
  
  x0 <- rep(breaks[i], length(x)) # Get the break value of interest
  
  nm_0 <- nlmer(y ~ nlfun_k(x, x0, logvol, a, d, theta) ~ theta | Study, # Fit Model to get MLE
                control = nlmerControl(optimizer = "bobyqa",
                                       #tolPwrss = 1e-5,
                                       optCtrl = list(maxfun = 2e5,
                                                      upper = c(Inf, Inf, Inf, 1), # bounds theta between 0 and 1
                                                      lower = c(-Inf, -Inf, -Inf, 0))),
                start = c(a = 4, d = 1, theta = 0.1))
  
  mle[i] <- fixef(nm_0)["theta"] # get the mle for that fixed value of x0
  ll_hat[i] <- logLik(nm_0) # get the log-likelihood for that fixed value of x0
  for(j in 1:nrow(LL)){
    
    theta_lim <- as.numeric(LL[j, 1]) # Get theta value
    
    try({nm_k <- nlmer(y ~ nlfun_k(x, x0, logvol, a, d, theta) ~ theta | Study, # fit the model
                       control = nlmerControl(optimizer = "bobyqa", 
                                              #tolPwrss = 6e-6, # reduce the tolerance to get convergence
                                              optCtrl = list(maxfun = 2e5,
                                                             upper = c(Inf, Inf, Inf, theta_lim + 0.005), # have tight bound on theta
                                                             lower = c(-Inf, -Inf, -Inf, theta_lim - 0.005))),
                       start = c(a = 4, d = 1, theta = theta_lim))}, silent = TRUE)
    # try() keeps loop running if it fails to converge
    
    LL[j, i + 1] <- as.numeric(logLik(nm_k)) # store log-likelihood
  }
}

#write.csv(LL, "qa_LL_profile_harvest1.csv", row.names = FALSE)
#write.csv(ll_hat, "qa_ll_hat_harvest1.csv", row.names = FALSE)
#write.csv(mle, "qa_mle_harvest1.csv", row.names = FALSE)

#LL <- read_csv("C:/Users/skoike/Desktop/Reanalysis/Quaking Aspen/qa_LL_profile_harvest1.csv")
#ll_0 <- read_csv("C:/Users/skoike/Desktop/Reanalysis/Quaking Aspen/qa_ll_hat_harvest1.csv")
#mle <- read_csv("C:/Users/skoike/Desktop/Reanalysis/Quaking Aspen/qa_mle_harvest1.csv")

#ll_hat <- as_vector(ll_0)
#mle <- as_vector(mle)

LL
ll_hat
mle


# Look at the LL profile
qplot(theta, V2, data = LL, geom = "line") + geom_vline(xintercept = mle[1], color = "red")
qplot(theta, V3, data = LL, geom = "line") + geom_vline(xintercept = mle[2], color = "red")
qplot(theta, V4, data = LL, geom = "line") + geom_vline(xintercept = mle[3], color = "red")
qplot(theta, V5, data = LL, geom = "line") + geom_vline(xintercept = mle[4], color = "red")
qplot(theta, V6, data = LL, geom = "line") + geom_vline(xintercept = mle[5], color = "red")
qplot(theta, V7, data = LL, geom = "line") + geom_vline(xintercept = mle[6], color = "red")
qplot(theta, V8, data = LL, geom = "line") + geom_vline(xintercept = mle[7], color = "red")
qplot(theta, V9, data = LL, geom = "line") + geom_vline(xintercept = mle[8], color = "red")
qplot(theta, V10, data = LL, geom = "line") + geom_vline(xintercept = mle[9], color = "red")
qplot(theta, V11, data = LL, geom = "line") + geom_vline(xintercept = mle[10], color = "red")
qplot(theta, V12, data = LL, geom = "line") + geom_vline(xintercept = mle[11], color = "red")
qplot(theta, V13, data = LL, geom = "line") + geom_vline(xintercept = mle[12], color = "red")
qplot(theta, V14, data = LL, geom = "line") + geom_vline(xintercept = mle[13], color = "red")
qplot(theta, V15, data = LL, geom = "line") + geom_vline(xintercept = mle[14], color = "red")
qplot(theta, V16, data = LL, geom = "line") + geom_vline(xintercept = mle[15], color = "red")
qplot(theta, V17, data = LL, geom = "line") + geom_vline(xintercept = mle[16], color = "red")


# Since the profiles are so erratic, we take a small window around the MLE 

LL_1 <- LL 

LL_2 <- LL_1 %>% pivot_longer(cols = -theta, names_to = "V", values_to = "LL")

ll_hat_frame <- tibble(V = colnames(LL)[-1], ll_hat)

q <- qchisq(0.95, 1) # Critical value: LR ~ chi-sq(1)

LL_4 <- full_join(LL_2, ll_hat_frame) %>% 
  group_by(V) %>% 
  mutate(LR = 2 * (ll_hat - LL)) %>% # LR statistic
  filter(LR <= q) %>% # Keep the values where we would not reject the null hypothesis
  slice(1, n()) %>% # Get the maximum and minimum of these theta values 
  select(V, theta) %>% 
  mutate(y = c("ymin", "ymax")) %>% 
  pivot_wider(names_from = y, values_from = theta) %>%
  mutate(V = str_replace(V, "V", ""),
         V = as.numeric(V)) %>% 
  arrange(V)


LL_4

# adjust for the fact that the mle from above does not correspond exactly with original model

pred_0 <- 1 - exp(-(breaks/coef_mod[2])^coef_mod[3])

plot(mle, pred_0)
abline(a = 0, b = 1)

adj <- mle - pred_0

LL_4$adj <- adj

LL_5 <- LL_4 %>%
  ungroup() %>% 
  mutate(ymin = ymin - adj,
         ymax = ymax - adj,
         x = breaks) %>% 
  select(-adj, -V)

LL_6 <- LL_5 %>% 
  add_row(ymin = 0, ymax = 0, x = 0, .before = 1)

LL_6

plot(LL_6$x, LL_6$ymax, type = "l")
lines(LL_6$x, LL_6$ymin)
lines(breaks, pred_0, lty = 2)


# Write file

write.csv(LL_6, "qa_para_ci.csv", row.names = FALSE)

