library(tidyverse)

study_14 <- read_csv("C:/Users/skoike/Desktop/Reanalysis/Red Alder/14_h1_mean_data.csv") %>% 
  mutate(Study = factor("Study 14")) 
study_27 <- read_csv("C:/Users/skoike/Desktop/Reanalysis/Red Alder/27_h1_mean_data.csv") %>% 
  mutate(Study = factor("Study 27"))
study_36 <- read_csv("C:/Users/skoike/Desktop/Reanalysis/Red Alder/36_h1_mean_data.csv") %>% 
  mutate(Study = factor("Study 36")) 
study_44 <- read_csv("C:/Users/skoike/Desktop/Reanalysis/Red Alder/44_h1_mean_data.csv") %>% 
  mutate(Study = factor("Study 44"))

studies <- full_join(study_14, study_27) %>%  
  full_join(study_36) %>% 
  full_join(study_44) %>% 
  mutate(Species = "Red Alder",
         Site = "FERF") %>% 
  rename(TREAT = OZ, CHAMB = CH) %>% 
  select(Species, Study, Site, Year, Harvest, Exp_days, CHAMB, TREAT, ends_with("DW"), everything())

#write.csv(studies, "ra_harvest_1.csv", row.names = FALSE)

library(RColorBrewer)

studies %>% 
  ggplot() + 
  aes(x = w126.12.8.adj, y = LOGTOTALDW, fill = Study, color = Study) + 
  geom_point(shape = 21, size = 2, color = "black") + 
  scale_fill_brewer(palette = "Set1") + 
  scale_color_brewer(palette = "Set1") +
  geom_smooth(method = "lm", se = FALSE)

studies %>% 
  ggplot() + 
  aes(x = LOGVOL_bl, y = LOGTOTALDW, fill = Study, color = Study) + 
  geom_point(shape = 21, size = 2, color = "black") + 
  scale_fill_brewer(palette = "Set1") + 
  scale_color_brewer(palette = "Set1") +
  geom_smooth(method = "lm", se = FALSE)



# Random effects Model ---------------------------------------------------
library(lme4)

RA <- studies %>% 
  group_by(Study) %>% 
  mutate(centered_logvol = LOGVOL_bl - mean(LOGVOL_bl)) %>% 
  select(Species, Study, Site, Year, Harvest, Exp_days, CHAMB, TREAT, 
         ends_with("DW"), centered_logvol, everything())


RA %>% 
  mutate(W126 = w126.12.8.adj*Exp_days/92) %>% 
  group_by(Study, Harvest, Site, TREAT) %>% 
  summarise(m = round(mean(W126), 1)) %>% 
  arrange(Study, m)

RA %>% 
  ungroup() %>% 
  nest_by(Study, Exp_days)

#write.csv(RA, "ra_chamber_mean_data.csv", row.names = FALSE)


fitmodel <- function(df){lm(LOGTOTALDW ~ centered_logvol, data = df)}

RA %>% 
  group_by(Study) %>% 
  nest() %>% 
  mutate(model = map(data, fitmodel),
         tidied = map(model, broom::tidy)) %>% 
  unnest(tidied) %>% 
  filter(term == "centered_logvol")

# Logvol not significant in any study

# -----------------------------------------------------------------

# No covariate, estimate c
nform1 <- ~ log(a) + (-(input/b)^c)

nfun1 <- deriv(nform1,
              namevec = c("a", "b", "c"),
              function.arg = c("input", "a", "b", "c"))

nm1 <- nlmer(LOGTOTALDW ~ nfun1(w126.12.8.adj, a, b, c) ~ a + b + c | Study,
             data = RA,
             control = nlmerControl(optimizer = "bobyqa", 
                                    optCtrl = list(maxfun = 2e5)),
             start = c(a = 50, b = 230, c = 1))
summary(nm1)

aug1 <- broom.mixed::augment(nm1)

aug1 %>% 
  ggplot() + 
  aes(x = .fitted, y = .resid, color = Study) + 
  geom_point() + 
  geom_hline(yintercept = 0, color = "red") + 
  scale_color_brewer(palette = "Set1")

aug1 %>% 
  ggplot() + 
  aes(sample = .resid) + 
  geom_qq() + 
  geom_qq_line()


# No covariate set c = 1 -------------------------------

nform2 <- ~ log(a) + (-(x/b))

nfun2 <- deriv(nform2,
               namevec = c("a", "b"),
               function.arg = c("x", "a", "b"))

nm2 <- nlmer(LOGTOTALDW ~ nfun2(w126.12.8.adj, a, b) ~ a + b | Study,
             data = RA,
             control = nlmerControl(optimizer = "bobyqa", optCtrl = list(maxfun = 2e5)),
             start = c(a = 1, b = 40))
summary(nm2)

aug2 <- broom.mixed::augment(nm2)

aug2 %>% 
  ggplot() + 
  aes(x = .fitted, y = .resid, color = Study) + 
  geom_point() + 
  geom_hline(yintercept = 0, color = "red") + 
  scale_color_brewer(palette = "Set1")

aug2 %>% 
  ggplot() + 
  aes(sample = .resid) + 
  geom_qq() + 
  geom_qq_line()


# Covariate, estimate c
nform3 <- ~ log(a + d*logvol) + (-(x/b)^c)

nfun3 <- deriv(nform3,
               namevec = c("a", "b", "c", "d"),
               function.arg = c("x", "logvol", "a", "b", "c", "d"))

nm3 <- nlmer(LOGTOTALDW ~ nfun3(w126.12.8.adj, centered_logvol, a, b, c, d) ~ a + b + c | Study,
             data = RA,
             control = nlmerControl(optimizer = "bobyqa", 
                                    optCtrl = list(maxfun = 2e5)),
             start = c(a = 50, b = 230, c = 1, d = 1))
summary(nm3)

aug3 <- broom.mixed::augment(nm3)

aug3 %>% 
  ggplot() + 
  aes(x = .fitted, y = .resid, color = Study) + 
  geom_point() + 
  geom_hline(yintercept = 0, color = "red") + 
  scale_color_brewer(palette = "Set1")

aug3 %>% 
  ggplot() + 
  aes(sample = .resid) + 
  geom_qq() + 
  geom_qq_line()

# Covariate, C = 1
nform4 <- ~ log(a + d*logvol) + (-(x/b))

nfun4 <- deriv(nform4,
               namevec = c("a", "b", "d"),
               function.arg = c("x", "logvol", "a", "b", "d"))

nm4 <- nlmer(LOGTOTALDW ~ nfun4(w126.12.8.adj, centered_logvol, a, b, d) ~ a + b | Study,
             data = RA,
             control = nlmerControl(optimizer = "bobyqa", 
                                    optCtrl = list(maxfun = 2e5)),
             start = c(a = 50, b = 230, d = 1))
summary(nm4)

aug4 <- broom.mixed::augment(nm4)

aug4 %>% 
  ggplot() + 
  aes(x = .fitted, y = .resid, color = Study) + 
  geom_point() + 
  geom_hline(yintercept = 0, color = "red") + 
  scale_color_brewer(palette = "Set1")

aug4 %>% 
  ggplot() + 
  aes(sample = .resid) + 
  geom_qq() + 
  geom_qq_line()


# Model Comparison -----------------------
nform1 # No Covariate, Estimated C
nform2 # No Covariate, Set C = 1
nform3 # Covariate, estimated C
nform4 # Covariate, C = 1

fixef(nm1) 
fixef(nm2)
fixef(nm3) 
fixef(nm4) 

mean(aug1$.resid^2) 
mean(aug2$.resid^2)  
mean(aug3$.resid^2)  
mean(aug4$.resid^2) # smallest


(SSRes1 <- sum(aug1$.resid^2))  
(SSRes2 <- sum(aug2$.resid^2)) 
(SSRes3 <- sum(aug3$.resid^2))
(SSRes4 <- sum(aug4$.resid^2)) # smallest

meanY <- mean(aug1$LOGTOTALDW) 
SStot <- sum((aug1$LOGTOTALDW - meanY)^2) 

(r_sq_1 <- 1 - SSRes1/SStot)
(r_sq_2 <- 1 - SSRes2/SStot) 
(r_sq_3 <- 1 - SSRes3/SStot)
(r_sq_4 <- 1 - SSRes4/SStot) # largest

SSreg <- sum((aug4$.fitted - meanY)^2)
SSreg/SStot

anova(nm2, nm4)

# Go with the Covariate C = 1, i.e. nm4

# Figure ?
nform2

#broom::tidy(nm4) %>% View()

(coef_mod <- fixef(nm2))

RA <- RA %>% mutate(adj_y = LOGTOTALDW - log(coef_mod[1]))

pred <- tibble(w126.12.8.adj =  c(seq(0, max(RA$w126.12.8.adj), by = 0.5), max(RA$w126.12.8.adj)),
               adj_y = -(w126.12.8.adj/coef_mod[2]))

RA_plot <- ggplot(RA) + 
  aes(x = w126.12.8.adj, y = adj_y, color = Study) +
  geom_point(size = 2) + 
  scale_color_brewer(palette = "Set1") + 
  geom_line(data = pred, color = "black", size = 0.75)
RA_plot

round(100*(1 - exp(-(c(10, 20, 30, 40, 50)/coef_mod[2]))), 1) 

ra_lines <- ggplot_build(RA_plot)$data[[2]] %>% 
  select(x, y) %>% 
  mutate(Species = factor("Red Alder"))

#write.csv(ra_lines, "ra_lines.csv", row.names = FALSE)

ra_b <- tibble(b = coef_mod[2], c = 1, Species = "Red Alder")

#write.csv(ra_b, "ra_params.csv", row.names = FALSE)
#write.csv(coef_mod, "ra_all_params.csv")


w126_frame <- RA %>% 
  group_by(Study) %>% 
  summarize(min_w126 = min(w126.12.8.adj),
            max_w126 = max(w126.12.8.adj)) %>% 
  mutate(x = map2(min_w126, max_w126, seq, by = 0.01)) %>% 
  unnest(cols = x) 

coef_frame <- coef(nm2)[1] %>% 
  as.data.frame() %>% 
  rownames_to_column("Study") %>% 
  select(Study, ends_with("b")) %>% 
  rename(b = Study.b)

RA_lines <- full_join(w126_frame, coef_frame) %>% 
  mutate(y = -(x/b))

nform2

intercept_frame <- coef(nm2)[1] %>% 
  as.data.frame() %>% 
  rownames_to_column("Study") %>% 
  select(Study, Study.a)


RA_points <- full_join(RA, intercept_frame) %>% 
  rename(a = Study.a) %>% 
  mutate(adj_y = LOGTOTALDW - log(a))

RA_sub <- RA %>% select(Study) %>% mutate(Model = factor("Population"))

pred1_a <- pred %>% 
  mutate(Model = factor("Population")) %>% 
  full_join(RA_sub) %>% 
  rename(x = w126.12.8.adj, y = adj_y)


RA_lines <- RA_lines %>% mutate(Model = factor("Individual"))

pred2 <- full_join(RA_lines, pred1_a)

ggplot(RA_points) + 
  aes(x = w126.12.8.adj, y = adj_y) + 
  geom_point(shape = 21, size = 2, aes(fill = Study)) + 
  guides(fill = FALSE, color = FALSE) + 
  facet_wrap(. ~ Study) + 
  geom_line(data = pred2 %>% filter(Model == "Individual"), aes(x = x, y = y, linetype = Model, color = Study), size = 1) + 
  geom_line(data = pred2 %>% filter(Model != "Individual"), aes(x = x, y = y, linetype = Model), color = "black", size = 1) + 
  scale_fill_brewer(palette = "Set1") + 
  scale_color_brewer(palette = "Set1")

ggplot(RA_points) + 
  aes(x = w126.12.8.adj, y = adj_y) + 
  geom_point(shape = 21, size = 2, aes(fill = Study)) + 
  geom_line(data = pred2 %>% filter(Model == "Individual"), aes(x = x, y = y, linetype = Model, color = Study), size = 1) + 
  geom_line(data = pred2 %>% filter(Model != "Individual"), aes(x = x, y = y, linetype = Model), color = "black", size = 1) + 
  scale_fill_brewer(palette = "Set1") + 
  scale_color_brewer(palette = "Set1") 

y_hat <- -(RA_points$w126.12.8.adj/coef_mod[2])
y <- RA_points$adj_y

plot(y, y_hat)
abline(a = 0, b = 1)

SSRes <- sum((y - y_hat)^2)
SSTot <- sum((y - mean(y))^2)

1 - SSRes/SSTot

mean((y - y_hat)^2) 


# Likelihood Confidence Interval -----------------------------------------------

# Step 1: Pull out relevant variables so we don't have to refer to data 

y <- RA$LOGTOTALDW
x <- RA$w126.12.8.adj
Study <- RA$Study

# Step 2: Reparameterize the model so we can create a confidence interval around predicted biomass loss (theta)
coef_mod
nform2

nlform_k <- ~ log(a) + ((x/x0) * log(1 - theta))

nlfun_k <- deriv(nlform_k,
                 namevec = c("a", "theta"),
                 function.arg = c("x", "x0", "a", "theta"))

# Step 3: At every break (e.g. 10, 20, 30, etc.), run the model at that fixed point, varying the value of theta

breaks <- c(seq(10, max(x), by = 5), max(x)) # our breaks

# Want a table where the log likelihoods are stored, one row for every theta, one column for every break

theta_vals <- seq(0, 1, by = 0.0075) # 134 values for theta

M <- matrix(nrow = length(theta_vals), ncol = length(breaks)+ 1)

LL <- as_tibble(M) %>% # This will hold our likelihoods for every value of x0
  mutate_all(as.numeric) %>% 
  rename(theta = V1) %>%  
  mutate(theta = theta_vals)

mle <- rep(NA, length(breaks)) # this will hold the maximum likelihood estimate from initial model
ll_hat <- rep(NA, length(breaks)) # this will hold the log likelihood from initial model

for(i in 1:(ncol(LL) - 1)){
  
  x0 <- rep(breaks[i], length(x)) # Get the break value of interest
  
  nm_0 <- nlmer(y ~ nlfun_k(x, x0, a, theta) ~ (a|Study) + (theta|Study), # Fit Model to get MLE
                control = nlmerControl(optimizer = "bobyqa",
                                       tolPwrss = 1e-8,
                                       optCtrl = list(maxfun = 2e5,
                                                      upper = c(rep(Inf, 3), 1), # bounds theta between 0 and 1
                                                      lower = c(rep(-Inf, 3), 0))),
                start = c(a = 1, theta = 0.5))
  
  mle[i] <- fixef(nm_0)["theta"] # get the mle for that fixed value of x0
  ll_hat[i] <- logLik(nm_0) # get the log-likelihood for that fixed value of x0
  for(j in 1:nrow(LL)){
    
    theta_lim <- as.numeric(LL[j, 1]) # Get theta value
    
    try({nm_k <- nlmer(y ~ nlfun_k(x, x0, a, theta) ~ (a|Study) + (theta|Study), # fit the model
                       control = nlmerControl(optimizer = "bobyqa",
                                              tolPwrss = 1e-8,
                                              optCtrl = list(maxfun = 2e5,
                                                             upper = c(rep(Inf, 3), theta_lim + 0.005), # have tight bound on theta
                                                             lower = c(rep(-Inf, 3), theta_lim - 0.005))),
                       start = c(a = 1, theta = theta_lim))}, silent = TRUE)
    # try() keeps loop running if it fails to converge
    
    LL[j, i + 1] <- as.numeric(logLik(nm_k)) # store log-likelihood
  }
}


#write.csv(LL, "ra_LL_profile.csv", row.names = FALSE)
#write.csv(ll_hat, "ra_ll_hat.csv", row.names = FALSE)
#write.csv(mle, "ra_mle_combined.csv", row.names = FALSE)

#LL <- read_csv("C:/Users/skoike/Desktop/Reanalysis/Red Alder/ra_LL_profile.csv")
#ll_0 <- read_csv("C:/Users/skoike/Desktop/Reanalysis/Red Alder/ra_ll_hat.csv")
#mle <- read_csv("C:/Users/skoike/Desktop/Reanalysis/Red Alder/ra_mle_combined.csv")

#ll_hat <- as_vector(ll_0)
#mle <- as_vector(mle)

LL
ll_hat
mle

# Look at the LL profile
qplot(theta, V2, data = LL, geom = "line") + geom_vline(xintercept = mle[1], color = "red")
qplot(theta, V3, data = LL, geom = "line") + geom_vline(xintercept = mle[2], color = "red")
qplot(theta, V4, data = LL, geom = "line") + geom_vline(xintercept = mle[3], color = "red")
qplot(theta, V5, data = LL, geom = "line") + geom_vline(xintercept = mle[4], color = "red")
qplot(theta, V6, data = LL, geom = "line") + geom_vline(xintercept = mle[5], color = "red")
qplot(theta, V7, data = LL, geom = "line") + geom_vline(xintercept = mle[6], color = "red")
qplot(theta, V8, data = LL, geom = "line") + geom_vline(xintercept = mle[7], color = "red")
qplot(theta, V9, data = LL, geom = "line") + geom_vline(xintercept = mle[8], color = "red")
qplot(theta, V10, data = LL, geom = "line") + geom_vline(xintercept = mle[9], color = "red")
qplot(theta, V11, data = LL, geom = "line") + geom_vline(xintercept = mle[10], color = "red")
qplot(theta, V12, data = LL, geom = "line") + geom_vline(xintercept = mle[11], color = "red")
qplot(theta, V13, data = LL, geom = "line") + geom_vline(xintercept = mle[12], color = "red")
qplot(theta, V14, data = LL, geom = "line") + geom_vline(xintercept = mle[13], color = "red")
qplot(theta, V15, data = LL, geom = "line") + geom_vline(xintercept = mle[14], color = "red")
qplot(theta, V16, data = LL, geom = "line") + geom_vline(xintercept = mle[15], color = "red")
qplot(theta, V17, data = LL, geom = "line") + geom_vline(xintercept = mle[16], color = "red")


LL_1 <- LL 


LL_2 <- LL_1 %>% pivot_longer(cols = -theta, names_to = "V", values_to = "LL")


ll_hat_frame <- tibble(V = colnames(LL)[-1], ll_hat)

q <- qchisq(0.95, 1) # Critical value: LR ~ chi-sq(1)

LL_4 <- full_join(LL_2, ll_hat_frame) %>% 
  group_by(V) %>% 
  mutate(LR = 2 * (ll_hat - LL)) %>% # LR statistic
  filter(LR <= q) %>% # Keep the values where we would not reject the null hypothesis
  slice(1, n()) %>% # Get the maximum and minimum of these theta values 
  select(V, theta) %>% 
  mutate(y = c("ymin", "ymax")) %>% 
  pivot_wider(names_from = y, values_from = theta) %>%
  mutate(V = str_replace(V, "V", ""),
         V = as.numeric(V)) %>% 
  arrange(V)

LL_4
# adjust for the fact that the mle from above does not correspond exactly with original model

pred_0 <- 1 - exp(-(breaks/coef_mod[2]))

plot(pred_0, mle)
abline(a = 0, b = 1)

adj <- mle - pred_0

LL_4$adj <- adj

LL_5 <- LL_4 %>%
  ungroup() %>% 
  mutate(ymin = ymin - adj,
         ymax = ymax - adj,
         x = breaks) %>% 
  select(-adj, -V)

LL_6 <- LL_5 %>% 
  add_row(ymin = 0, ymax = 0, x = 0, .before = 1)

LL_6

plot(LL_6$x, LL_6$ymax, type = "l", ylim = c(0, 0.6), xlim = c(0, 85))
lines(LL_6$x, LL_6$ymin)
lines(breaks, pred_0, lty = 2)

# Write file
LL_7 <- LL_6 %>% 
  slice(-c(2, 3, 4, 5, 7, 11, 12, 13, 14, 15, 17))

plot(LL_7$x, LL_7$ymax, type = "l", ylim = c(0, 0.6), xlim = c(0, 85))
lines(LL_7$x, LL_7$ymin)
lines(breaks, pred_0, lty = 2)

write.csv(LL_7, "ra_para_ci.csv", row.names = FALSE)
