library(tidyverse)

study_25 <- read_csv("C:/Users/skoike/Desktop/Reanalysis/Sugar Maple/25_h1_mean_data.csv") %>% 
  mutate(Study = factor("Study 25"),
         Site = "FERF") %>%
  rename(TREAT = OZ, LOGVOL_bl = LOGVOL.bl, VOL_bl = VOL.bl, CHAMB = CH)
study_90 <- read_csv("C:/Users/skoike/Desktop/Reanalysis/Sugar Maple/sugarmaple_mean_data.csv") %>% 
  mutate(Study = factor("1990"),
         Site = "Michigan",
         TREAT = as.character(TREAT)) %>% 
  rename(actual.24 = OZ.24,
         actual.24.adj = OZ.24.adj,
         actual.12.7 = OZ.12.7,
         actual.12.8 = OZ.12.8,
         actual.12.9 = OZ.12.9,
         actual.12.7.adj = OZ.12.7.adj,
         actual.12.8.adj = OZ.12.8.adj,
         actual.12.9.adj = OZ.12.9.adj)

studies <- full_join(study_25, study_90) 

#View(studies)

library(RColorBrewer)

studies %>% 
  ggplot() + 
  aes(x = w126.12.8.adj, y = LOGTOTALDW, fill = Study, color = Study) + 
  geom_point(shape = 21, size = 2, color = "black") + 
  scale_fill_brewer(palette = "Set1") + 
  scale_color_brewer(palette = "Set1") +
  geom_smooth(method = "lm", se = FALSE)


ggplot(studies) + 
  aes(x = LOGVOL_bl, y = LOGTOTALDW, fill = Study, color = Study) + 
  geom_point(shape = 21, size = 2, color = "black") + 
  scale_fill_brewer(palette = "Set1") + 
  geom_smooth(method = "lm", se = FALSE) + 
  scale_color_brewer(palette = "Set1") + 
  theme_bw()


# Random effects Model ---------------------------------------------------
library(lme4)

studies %>% group_by(Study, TREAT) %>% tally()

SM <- studies %>% 
  mutate(Species = "Sugar Maple") %>% 
  select(Species, Study, Site, Year, Harvest, Exp_days, CHAMB, TREAT, everything()) %>% 
  group_by(Study) %>% 
  mutate(centered_logvol = LOGVOL_bl - mean(LOGVOL_bl),
         TREAT = as_factor(TREAT))

studies %>% 
  mutate(W126 = w126.12.8.adj*Exp_days/92) %>% 
  group_by(Study, Harvest, Site, TREAT) %>% 
  summarise(m = round(mean(W126), 1)) %>% 
  arrange(Site, m)

SM %>% group_by(Study) %>% summarise(m = mean(LOGVOL_bl))

fitmodel <- function(df){lm(LOGTOTALDW ~ centered_logvol, data = df)}

SM %>% 
  nest() %>% 
  mutate(model = map(data, fitmodel),
         tidied = map(model, broom::tidy)) %>% 
  unnest(tidied) %>% 
  filter(term == "centered_logvol")

SM %>% 
  ungroup() %>% 
  nest_by(Study, Exp_days)


SM <- SM %>% 
  mutate(is_25 = ifelse(Study == "Study 25", 1, 0)) %>% 
  select(Species, Study, Site, Year, Harvest, Exp_days, CHAMB, TREAT, 
         ends_with("DW"), is_25, centered_logvol, everything())

#write.csv(SM, "sm_chamber_mean_data.csv", row.names = FALSE)


SM <- SM %>% select(Study, LOGTOTALDW, w126.12.8.adj, centered_logvol, is_25)
# With Common covariate

nform1 <- ~ log(a + d*logvol) + (-(x/b)^c)

nfun1 <- deriv(nform1,
               namevec = c("a", "b", "c", "d"),
               function.arg = c("x", "logvol", "a", "b", "c", "d"))

nm1 <- nlmer(LOGTOTALDW ~ nfun1(w126.12.8.adj, centered_logvol, a, b, c, d) ~ a + b + c | Study,
             data = SM,
             control = nlmerControl(optimizer = "bobyqa", tolPwrss = 7e-10, optCtrl = list(maxfun = 2e5)),
             start = c(a = 1, b = 1, c = 1, d = 1))

summary(nm1) # extreme coefficients


# With covariate, c = 1

nform2 <- ~ log(a + d*logvol) + (-(x/b))

nfun2 <- deriv(nform2,
               namevec = c("a", "b", "d"),
               function.arg = c("x", "logvol", "a", "b", "d"))

nm2 <- nlmer(LOGTOTALDW ~ nfun2(w126.12.8.adj, centered_logvol, a, b, d) ~ a + b | Study,
             data = SM,
             control = nlmerControl(optimizer = "bobyqa", optCtrl = list(maxfun = 2e5)),
             start = c(a = 1, b = 1, d = 1))
summary(nm2)

aug2 <- broom.mixed::augment(nm2)


aug2 %>% 
  ggplot() + 
  aes(x = .fitted, y = .resid, color = Study) + 
  geom_point() + 
  geom_hline(yintercept = 0, color = "red") + 
  scale_color_brewer(palette = "Set1")

aug2 %>% 
  ggplot() + 
  aes(sample = .resid) + 
  geom_qq() + 
  geom_qq_line()

#---------------------------------------------------------

#W/o Covariate

nform3 <- ~ log(a) + (-(x/b)^c)

nfun3 <- deriv(nform3,
               namevec = c("a", "b", "c"),
               function.arg = c("x", "a", "b", "c"))

nm3 <- nlmer(LOGTOTALDW ~ nfun3(w126.12.8.adj, a, b, c) ~ a + b + c | Study,
             data = SM,
             control = nlmerControl(optimizer = "bobyqa", tolPwrss = 1e-9, optCtrl = list(maxfun = 2e5)),
             start = c(a = 1, b = 1, c = 1))
summary(nm3)

aug3 <- broom.mixed::augment(nm3)

aug3 %>% 
  ggplot() + 
  aes(x = .fitted, y = .resid, color = Study) + 
  geom_point() + 
  geom_hline(yintercept = 0, color = "red") + 
  scale_color_brewer(palette = "Set1")

aug3 %>% 
  ggplot() + 
  aes(sample = .resid) + 
  geom_qq() + 
  geom_qq_line()

# W/o covariate, c = 1

nform4 <- ~ log(a) + (-(x/b))

nfun4 <- deriv(nform4,
               namevec = c("a", "b"),
               function.arg = c("x", "a", "b"))

nm4 <- nlmer(LOGTOTALDW ~ nfun4(w126.12.8.adj, a, b) ~ a + b | Study,
             data = SM,
             control = nlmerControl(optimizer = "bobyqa", optCtrl = list(maxfun = 2e5)),
             start = c(a = 1, b = 1))
summary(nm4)

aug4 <- broom.mixed::augment(nm4)


aug4 %>% 
  ggplot() + 
  aes(x = .fitted, y = .resid, color = Study) + 
  geom_point() + 
  geom_hline(yintercept = 0, color = "red") + 
  scale_color_brewer(palette = "Set1")

aug4 %>% 
  ggplot() + 
  aes(sample = .resid) + 
  geom_qq() + 
  geom_qq_line()

# W/ study 25 covariate, estimated C

nform5 <- ~ log(a + d*is_25*logvol) + (-(x/b)^c)

nfun5 <- deriv(nform5,
               namevec = c("a", "b", "c", "d"),
               function.arg = c("x", "logvol", "is_25", "a", "b", "c", "d"))

nm5 <- nlmer(LOGTOTALDW ~ nfun5(w126.12.8.adj, centered_logvol, is_25, a, b, c, d) ~ a + b + c | Study,
             data = SM,
             control = nlmerControl(optimizer = "bobyqa", tolPwrss = 1e-8, optCtrl = list(maxfun = 2e5)),
             start = c(a = 1, b = 1, c = 1, d = 1))
summary(nm5) # negative d 

aug5 <- broom.mixed::augment(nm5)


aug5 %>% 
  ggplot() + 
  aes(x = .fitted, y = .resid, color = Study) + 
  geom_point() + 
  geom_hline(yintercept = 0, color = "red") + 
  scale_color_brewer(palette = "Set1")

aug5 %>% 
  ggplot() + 
  aes(sample = .resid) + 
  geom_qq() + 
  geom_qq_line()

# W/ study 25 covariate, set C = 1

nform6 <- ~ log(a + d*is_25*logvol) + (-(x/b))

nfun6 <- deriv(nform6,
               namevec = c("a", "b", "d"),
               function.arg = c("x", "logvol", "is_25", "a", "b", "d"))

nm6 <- nlmer(LOGTOTALDW ~ nfun6(w126.12.8.adj, centered_logvol, is_25, a, b, d) ~ a + b | Study,
             data = SM,
             control = nlmerControl(optimizer = "bobyqa", optCtrl = list(maxfun = 2e5)),
             start = c(a = 1, b = 1, d = 1))
summary(nm6)

aug6 <- broom.mixed::augment(nm6)


aug6 %>% 
  ggplot() + 
  aes(x = .fitted, y = .resid, color = Study) + 
  geom_point() + 
  geom_hline(yintercept = 0, color = "red") + 
  scale_color_brewer(palette = "Set1")

aug6 %>% 
  ggplot() + 
  aes(sample = .resid) + 
  geom_qq() + 
  geom_qq_line()

# comparing Models ------------------------------------------
nform1 # Common Covariate, Estimated C
nform2 # Common Covariate, C = 1
nform3 # No Covariate, Estimated C
nform4 # No Covariate, C = 1
nform5 # Covariate Study 25, Estimated C
nform6 # Covariate Study 25, C = 1

fixef(nm1) # Bad Values
fixef(nm2)
fixef(nm3) # Bad Values
fixef(nm4)
fixef(nm5) # Bad Values
fixef(nm6)

mean(aug2$.resid^2) 
mean(aug4$.resid^2) 
mean(aug6$.resid^2) # slightly smaller

(SSRes2 <- sum(aug2$.resid^2)) 
(SSRes4 <- sum(aug4$.resid^2)) 
(SSRes6 <- sum(aug6$.resid^2)) # slightly smaller

meanY <- mean(aug2$LOGTOTALDW) 
SStot <- sum((aug2$LOGTOTALDW - meanY)^2) 

(r_sq_2 <- 1 - SSRes2/SStot) 
(r_sq_4 <- 1 - SSRes4/SStot) 
(r_sq_6 <- 1 - SSRes6/SStot) # slightly higher R2

SSreg <- sum((aug6$.fitted - meanY)^2)
SSreg/SStot

# Go with more parsimonious model of the covariate for Study 25 and c = 1 (linear)

# Figure 

# Linear ------------------------------------------------
nform6
(coef_mod <- fixef(nm6))

SM <- SM %>% mutate(adj_y = LOGTOTALDW - log(coef_mod[1] + coef_mod[3]*is_25*centered_logvol))

pred <- tibble(w126.12.8.adj =  c(seq(0, max(SM$w126.12.8.adj), by = 0.5), max(SM$w126.12.8.adj)),
               adj_y = -(w126.12.8.adj/coef_mod[2]))

SM_plot <- ggplot(SM) + 
  aes(x = w126.12.8.adj, y = adj_y, color = Study) +
  geom_point(size = 2) + 
  scale_color_brewer(palette = "Set1") + 
  geom_line(data = pred, color = "black", size = 0.75)
SM_plot

b <- round(100*(1 - exp(-(c(10, 20, 30, 40, 50)/coef_mod[2]))), 1)

b

sm_lines <- ggplot_build(SM_plot)$data[[2]] %>% 
  select(x, y) %>% 
  mutate(Species = factor("Sugar Maple"))

#write.csv(sm_lines, "sm_lines.csv", row.names = FALSE)

sm_b <- tibble(b = coef_mod[2], c = 1, Species = "Sugar Maple")

#write.csv(sm_b, "sm_params.csv", row.names = FALSE)
#write.csv(coef_mod, "sm_all_params.csv")

w126_frame <- SM %>% 
  group_by(Study) %>% 
  summarize(min_w126 = min(w126.12.8.adj),
            max_w126 = max(w126.12.8.adj)) %>% 
  mutate(x = map2(min_w126, max_w126, seq, by = 0.01)) %>% 
  unnest(cols = x) 

coef_frame <- coef(nm6)[1] %>% 
  as.data.frame() %>% 
  rownames_to_column("Study") %>% 
  select(Study, ends_with("b")) %>% 
  rename(b = Study.b)

SM_lines <- full_join(w126_frame, coef_frame) %>% 
  mutate(y = -(x/b))

nform6

intercept_frame <- coef(nm6)[1] %>% 
  as.data.frame() %>% 
  rownames_to_column("Study") %>% 
  select(Study, Study.a, Study.d)


SM_points <- full_join(SM, intercept_frame) %>% 
  rename(a = Study.a,
         d = Study.d) %>% 
  mutate(adj_y = LOGTOTALDW - log(a + d*is_25*centered_logvol))

SM_sub <- SM %>% select(Study) %>% mutate(Model = factor("Population"))

pred1_a <- pred %>% 
  mutate(Model = factor("Population")) %>% 
  full_join(SM_sub) %>% 
  rename(x = w126.12.8.adj, y = adj_y)

SM_lines <- SM_lines %>% mutate(Model = factor("Individual"))

pred2 <- full_join(SM_lines, pred1_a)

ggplot(SM_points) + 
  aes(x = w126.12.8.adj, y = adj_y) + 
  geom_point(shape = 21, size = 2, aes(fill = Study)) + 
  guides(fill = FALSE, color = FALSE) + 
  facet_wrap(. ~ Study) + 
  geom_line(data = pred2 %>% filter(Model == "Individual"), aes(x = x, y = y, linetype = Model, color = Study), size = 1) + 
  geom_line(data = pred2 %>% filter(Model != "Individual"), aes(x = x, y = y, linetype = Model), color = "black", size = 1) 

ggplot(SM_points) + 
  aes(x = w126.12.8.adj, y = adj_y) + 
  geom_point(shape = 21, size = 2, aes(fill = Study)) + 
  geom_line(data = pred2 %>% filter(Model == "Individual"), aes(x = x, y = y, linetype = Model, color = Study), size = 1) + 
  geom_line(data = pred2 %>% filter(Model != "Individual"), aes(x = x, y = y, linetype = Model), color = "black", size = 1) 


y_hat <- -(SM_points$w126.12.8.adj/coef_mod[2])
y <- SM_points$adj_y

plot(y, y_hat)
abline(a = 0, b = 1)

SSRes <- sum((y - y_hat)^2)
SSTot <- sum((y - mean(y))^2)

1 - SSRes/SSTot

mean((y - y_hat)^2) 



# Likelihood Confidence Interval -----------------------------------------------

# Step 1: Pull out relevant variables so we don't have to refer to data 

y <- SM$LOGTOTALDW
x <- SM$w126.12.8.adj
Study <- SM$Study
logvol <- SM$centered_logvol
is_25 <- SM$is_25

# Step 2: Reparameterize the model so we can create a confidence interval around predicted biomass loss (theta)

nlform_k <- ~ log(a + d*is_25*logvol) +  + ((x/x0) * log(1 - theta))

nlfun_k <- deriv(nlform_k,
                 namevec = c("a", "d", "theta"),
                 function.arg = c("x", "x0", "logvol", "is_25", "a", "d", "theta"))

# Step 3: At every break (e.g. 10, 20, 30, etc.), run the model at that fixed point, varying the value of theta

breaks <- c(seq(10, max(x), by = 5), max(x)) # our breaks

# Want a table where the log likelihoods are stored, one row for every theta, one column for every break

theta_vals <- seq(0, 1, by = 0.0075) # 101 values for theta (bounds?)

M <- matrix(nrow = length(theta_vals), ncol = length(breaks) + 1)

LL <- as_tibble(M) %>% # This will hold our likelihoods for every value of x0
  mutate_all(as.numeric) %>% 
  rename(theta = V1) %>%  
  mutate(theta = theta_vals)

mle <- rep(NA, length(breaks)) # this will hold the maximum likelihood estimate from initial model
ll_hat <- rep(NA, length(breaks)) # this will hold the log likelihood from initial model

for(i in 1:(ncol(LL) - 1)){
  
  x0 <- rep(breaks[i], length(x)) # Get the break value of interest
  
  nm_0 <- nlmer(y ~ nlfun_k(x, x0, logvol, is_25, a, d, theta) ~ (a|Study) + (theta|Study), # Fit Model to get MLE
                control = nlmerControl(optimizer = "bobyqa",
                                       optCtrl = list(maxfun = 2e5,
                                                      upper = c(Inf, Inf, Inf, Inf, 1), # bounds theta between 0 and 1
                                                      lower = c(-Inf, -Inf, -Inf, -Inf, 0))),
                start = c(a = 1, d = 1, theta = 0.5))
  
  mle[i] <- fixef(nm_0)["theta"] # get the mle for that fixed value of x0
  ll_hat[i] <- logLik(nm_0) # get the log-likelihood for that fixed value of x0
  for(j in 1:nrow(LL)){
    
    theta_lim <- as.numeric(LL[j, 1]) # Get theta value
    
    try({nm_k <- nlmer(y ~ nlfun_k(x, x0, logvol, is_25, a, d, theta) ~ (a|Study) + (theta|Study), # fit the model
                       control = nlmerControl(optimizer = "bobyqa",
                                              optCtrl = list(maxfun = 2e5,
                                                             upper = c(Inf, Inf, Inf, Inf, theta_lim + 0.005), # have tight bound on theta
                                                             lower = c(-Inf, -Inf, -Inf, -Inf, theta_lim - 0.005))),
                       start = c(a = 1, d = 1, theta = theta_lim))}, silent = TRUE)
    # try() keeps loop running if it fails to converge
    
    LL[j, i + 1] <- as.numeric(logLik(nm_k)) # store log-likelihood
  }
}

LL
ll_hat
mle
#write.csv(LL, "sm_LL_profile.csv", row.names = FALSE)
#write.csv(ll_hat, "sm_ll_hat.csv", row.names = FALSE)
#write.csv(mle, "sm_mle_combined.csv", row.names = FALSE)

# Look at the LL profile
qplot(theta, V2, data = LL, geom = "line") + geom_vline(xintercept = mle[1], color = "red")
qplot(theta, V3, data = LL, geom = "line") + geom_vline(xintercept = mle[2], color = "red")
qplot(theta, V4, data = LL, geom = "line") + geom_vline(xintercept = mle[3], color = "red")
qplot(theta, V5, data = LL, geom = "line") + geom_vline(xintercept = mle[4], color = "red")
qplot(theta, V6, data = LL, geom = "line") + geom_vline(xintercept = mle[5], color = "red")
qplot(theta, V7, data = LL, geom = "line") + geom_vline(xintercept = mle[6], color = "red")
qplot(theta, V8, data = LL, geom = "line") + geom_vline(xintercept = mle[7], color = "red")
qplot(theta, V9, data = LL, geom = "line") + geom_vline(xintercept = mle[8], color = "red")
qplot(theta, V10, data = LL, geom = "line") + geom_vline(xintercept = mle[9], color = "red")
qplot(theta, V11, data = LL, geom = "line") + geom_vline(xintercept = mle[10], color = "red")
qplot(theta, V12, data = LL, geom = "line") + geom_vline(xintercept = mle[11], color = "red")
qplot(theta, V13, data = LL, geom = "line") + geom_vline(xintercept = mle[12], color = "red")
qplot(theta, V14, data = LL, geom = "line") + geom_vline(xintercept = mle[13], color = "red")
qplot(theta, V15, data = LL, geom = "line") + geom_vline(xintercept = mle[14], color = "red")
qplot(theta, V16, data = LL, geom = "line") + geom_vline(xintercept = mle[15], color = "red")
qplot(theta, V17, data = LL, geom = "line") + geom_vline(xintercept = mle[16], color = "red")




# The profiles are well-behaved, but we'll take a small window around the MLE and add a smoothing curve in order
# to be precise when creating the likelihood CI

LL_1 <- LL 

LL_2 <- LL_1 %>% pivot_longer(cols = -theta, names_to = "V", values_to = "LL")

ll_hat_frame <- tibble(V = colnames(LL)[-1], ll_hat)

q <- qchisq(0.95, 1) # Critical value: LR ~ chi-sq(1)

LL_4 <- full_join(LL_2, ll_hat_frame) %>% 
  group_by(V) %>% 
  mutate(LR = 2 * (ll_hat - LL)) %>% # LR statistic
  filter(LR <= q) %>% # Keep the values where we would not reject the null hypothesis
  slice(1, n()) %>% # Get the maximum and minimum of these theta values 
  select(V, theta) %>% 
  mutate(y = c("ymin", "ymax")) %>% 
  pivot_wider(names_from = y, values_from = theta) %>%
  mutate(V = str_replace(V, "V", ""),
         V = as.numeric(V)) %>% 
  arrange(V)

LL_4

# adjust for the fact that the mle from above does not correspond exactly with original model

pred_0 <- 1 - exp(-(breaks/coef_mod[2]))

adj <- mle - pred_0

plot(mle, pred_0)
abline(a = 0, b = 1)

LL_4$adj <- adj

LL_5 <- LL_4 %>%
  ungroup() %>% 
  mutate(ymin = ymin - adj,
         ymax = ymax - adj,
         x = breaks) %>% 
  select(-adj, -V)

LL_5

LL_6 <- LL_5 %>% 
  add_row(ymin = 0, ymax = 0, x = 0, .before = 1)

LL_6

plot(LL_6$x, LL_6$ymax, type = "l")
lines(LL_6$x, LL_6$ymin)
lines(breaks, pred_0, lty = 2)

# Write file

write.csv(LL_6, "sm_para_ci.csv", row.names = FALSE)
