library(readr)
library(magrittr)
library(dplyr)

pred_wide <- read_csv("C:/Users/skoike/Desktop/Reanalysis/Tulip Poplar/tp_figure_pred.csv") %>% 
  filter(Model == "Individual")  %>% 
  mutate(Harvest = as.character(Harvest),
         Harvest = ifelse(Harvest == "1", "Harvest 1", "Harvest 2")) %>%
  select(x, y, Study, Harvest) %>% 
  pivot_wider(names_from = c(Study, Harvest), values_from = y, names_sep = ": ")

points_wide <- read_csv("C:/Users/skoike/Desktop/Reanalysis/Tulip Poplar/tp_figure_points.csv") %>% 
  rename(x = w126.12.8.adj, y = adj_y) %>%  
  select(x, y, Study, Harvest)  %>% 
  mutate(Harvest = as.character(Harvest),
         Harvest = ifelse(Harvest == "1", "Harvest 1", "Harvest 2")) %>%
  pivot_wider(names_from = c(Study, Harvest), values_from = y, names_sep = ": ")

# Harvest 1  ------------------------------------------------------------

### 1990 ------------------------

#dev.off()

png(file = "C:/Users/skoike/Desktop/tp_fig.png", 
    width = 12, height = 9, units = "in", res = 700)

par(mfrow=c(1,2),mai=c(2,0,0,0),oma=c(2,4,1,1),cex=1.2,mex=1.2,lwd=4,cex.lab=1.2,cex.axis=1.2)

# Adjusted Total Dry Weight (Log grams)


plot(points_wide$x, points_wide$`1990: Harvest 1`, 
     pch = 16, ylim = c(-0.8, 0.35),
     ylab = "",
     xlab = "")
text(x = 29, y = 0.23, labels = "A", cex = 2)
lines(pred_wide$x, pred_wide$`1990: Harvest 1`)


### 35 ------------------------
points(points_wide$x, points_wide$`1992: Harvest 1`, col = "red", pch = 16)
lines(pred_wide$x, pred_wide$`1992: Harvest 1`, col = "red")


### Add Legend ----------------

legend(0.01, -.6,
       legend = c("1990", 
                  "1992"),
       pt.cex = 1,
       cex = 0.9,
       pch = 16,
       lwd = 2,
       bty = "n",
       col = c("black", "red"))



# Harvest 2 --------------------------------------

plot(points_wide$x, points_wide$`1991: Harvest 2`, 
     pch = 17, ylim = c(-0.8, 0.35),
     yaxt = "n",
     col = "blue",
     ylab = "",
     xlab = "")
text(x = 29, y = 0.23, labels = "B", cex = 2)
lines(pred_wide$x, pred_wide$`1991: Harvest 2`, col = "blue")


### Add Legend ----------------

legend(0.01, -.6,
       legend = c("1991"),
       pt.cex = 1,
       cex = 0.9,
       ncol = 1,
       pch = 17,
       lwd = 2,
       bty = "n",
       col = "blue")
mtext("W126 (ppm-h)", outer = TRUE, side = 1, line = -4, cex = 1.8)
mtext("Adjusted Total Dry Weight (log g)", outer = TRUE, line = 3, adj = 0.8, side = 2, cex = 1.8)

dev.off()
