library(tidyverse)

# Read in predictive curve
TP <- read_csv("C:/Users/skoike/Desktop/Reanalysis/Tulip Poplar/tp_lines.csv")

# Read Parametric CI

para_ci <- read_csv("C:/Users/skoike/Desktop/Reanalysis/Tulip Poplar/tp_para_ci.csv") %>% 
  mutate_at(vars(-x), function(x){x*100}) %>% 
  arrange(x)

new_pred <- data.frame(x = TP$x)

# Smooth out ymin
f <- function(x, a, b){
  a * x^b
}

plot(para_ci$x, para_ci$ymin) 

y_lower_fcn <- minpack.lm::nlsLM(ymin ~ f(x, a, b), data = para_ci,
                                 start = list(a = 1, b = 1))
y_lower_fcn2 <- lm(ymin ~ -1 + x + I(x^2), data = para_ci)

new_ymin <- predict(y_lower_fcn, newdata = new_pred)
new_pred$new_ymin <- new_ymin
new_ymin2 <- predict(y_lower_fcn2, newdata = new_pred)
new_pred$new_ymin2 <- new_ymin2

plot(para_ci$x, para_ci$ymin)
lines(new_pred$x, new_pred$new_ymin)
lines(new_pred$x, new_pred$new_ymin2, col = "red")

# Smooth ymax
plot(para_ci$x, para_ci$ymax)

y_upper_fcn <- minpack.lm::nlsLM(ymax ~ f(x, a, b), data = para_ci, start = list(a = 1, b = 1))

new_ymax <- predict(y_upper_fcn, newdata = new_pred)
new_pred$new_ymax <- new_ymax

plot(para_ci$x, para_ci$ymax)
lines(new_pred$x, new_pred$new_ymax)


ci_plot <- ggplot(new_pred) + 
  aes(x = x) + 
  geom_ribbon(aes(ymin = new_ymin, ymax = new_ymax), alpha = 0.3) +
  geom_line(data = TP, aes(x = x, y = 100*(1 - exp(y))), size = 1, color = "blue") + 
  ylab("Predicted Relative Biomass Loss (%)") + 
  xlab("W126 (ppm-h)") + 
  scale_y_continuous(breaks = seq(0, 100, by = 20)) + 
  scale_x_continuous(breaks = seq(0, 100, by = 10))

ci_plot

# Export data for grid plot
#ggplot_build(ci_plot) data[[1]] has band info, data[[2]] has predicted curve

bands <- ggplot_build(ci_plot)$data[[1]] %>% select(x, ymin, ymax) %>% mutate(x = round(x, 7))
pred_curve <- ggplot_build(ci_plot)$data[[2]] %>% select(x, y) %>% mutate(x = round(x, 7))

tp_info <- full_join(bands, pred_curve) %>% 
  mutate(Species = factor("Tulip Poplar")) %>% 
  select(Species, x, y, ymin, ymax) 

#write.csv(tp_info, "tp_bands.csv", row.names = FALSE)

