library(tidyverse)

study_90 <- read_csv("C:/Users/skoike/Desktop/Reanalysis/Virginia Pine/vpine_90_mean_data.csv") %>% 
  rename(TREAT = TREATMENT) %>%  
  mutate(Study = factor("1990"),
         TREAT = as.character(TREAT))
study_91 <- read_csv("C:/Users/skoike/Desktop/Reanalysis/Virginia Pine/vpine_91_mean_data.csv") %>% 
  rename(TREAT = Trt) %>%  
  mutate(Study = factor("1991"),
         TREAT = as.character(TREAT))
study_92 <- read_csv("C:/Users/skoike/Desktop/Reanalysis/Virginia Pine/vpine_92_mean_data.csv") %>% 
  mutate(Study = factor("1992"))  %>% 
  rename(TREAT = Trt)

studies <- full_join(study_90, study_91) %>%  
  full_join(study_92) %>% 
  select(Study, CHAMB, LOGNEEDLEDW, LOGSTEMDW, LOGROOTDW, LOGBRANCHDW, LOGTOTALDW, LOGVOL_bl, everything()) %>% 
  rename(actual.24 = OZ.24,
         actual.24.adj = OZ.24.adj,
         actual.12.7 = OZ.12.7,
         actual.12.8 = OZ.12.8,
         actual.12.9 = OZ.12.9,
         actual.12.7.adj = OZ.12.7.adj,
         actual.12.8.adj = OZ.12.8.adj,
         actual.12.9.adj = OZ.12.9.adj)

studies %>% 
  ggplot() + 
  aes(x = w126.12.8.adj, y = LOGTOTALDW, fill = Study, color = Study) + 
  geom_point(shape = 21, size = 2, color = "black") + 
  scale_fill_brewer(palette = "Set1") + 
  scale_color_brewer(palette = "Set1") +
  geom_smooth(method = "lm", se = FALSE)

studies %>% 
  ggplot() + 
  aes(x = LOGVOL_bl, y = LOGTOTALDW, fill = Study, color = Study) + 
  geom_point(shape = 21, size = 2, color = "black") + 
  scale_fill_brewer(palette = "Set1") + 
  scale_color_brewer(palette = "Set1")

# Random effects Model ---------------------------------------------------
library(lme4)

VP1 <- studies %>% 
  mutate(TREAT = case_when(TREAT == "1" ~ "CF",
                           TREAT == "2" ~ "0.5x",
                           TREAT == "3" ~ "1x",
                           TREAT == "4" ~ "1.5x",
                           TREAT == "5" ~ "2x",
                           TREAT == "0.5x" ~ "0.5x",
                           TREAT == "1x" ~ "1x",
                           TREAT == "1.5x" ~ "1.5x",
                           TREAT == "2x" ~ "2x",
                           TREAT == "CF" ~ "CF",
                           TRUE ~ "AA"),
         TREAT = as_factor(TREAT),
         Site = "SMNP",
         Species = "Virginia Pine")


VP1 %>% 
  mutate(W126 = w126.12.8.adj*Exp_days/92) %>% 
  group_by(Study, Harvest, Site, TREAT) %>% 
  summarise(m = round(mean(W126), 1))

VP1a <- VP1 %>% 
  filter(TREAT != "AA") %>% #need to get rid of the ambient air volume measurements for centered volume
  group_by(Study) %>% 
  mutate(centered_logvol = LOGVOL_bl - mean(LOGVOL_bl), 
         is_92 = ifelse(Year == 1992, 1, 0)) %>% 
  mutate(centered_logvol = ifelse(is.na(centered_logvol), 0, centered_logvol)) %>% 
  select(Species, Study, Site, Year, Harvest, Exp_days, CHAMB, TREAT, 
         ends_with("DW"), is_92, centered_logvol, VOL_bl, everything())


VP2 <- full_join(VP1a, VP1 %>% filter(TREAT == "AA"))

#write.csv(VP2, "vp_chamber_mean_data.csv", row.names = FALSE)


VP <- VP1a %>% 
  select(Study, centered_logvol, w126.12.8.adj, LOGTOTALDW, is_92) 

# With covariate ---------------------------------------
ggplot(VP) + 
  aes(x = centered_logvol, y = LOGTOTALDW, fill = Study, color = Study) + 
  geom_point(shape = 21, size = 2.5, color = "black", alpha = 0.7) + 
  scale_fill_brewer(palette = "Set1") + 
  scale_color_brewer(palette = "Set1")

ggplot(VP) + 
  aes(x = w126.12.8.adj, y = LOGTOTALDW, fill = Study, color = Study) + 
  geom_point(size = 2.5, color = "black", alpha = 0.7, shape = 21) + 
  geom_smooth(method = "lm", se = FALSE) +
  scale_fill_brewer(palette = "Set1") + 
  scale_color_brewer(palette = "Set1")

# Random Coefficient Model -----------------------------------------------------

# Model 1
# Common B, C, Covariate
# Different Intercept/Covariate for Study 1992

nform1 <- ~ log(a + a_92*is_92 + (d + d_92*is_92)*logvol) + (-(x/b)^c) 

nfun1 <- deriv(nform1,
               namevec = c("a", "a_92", "b", "c", "d", "d_92"),
               function.arg = c("x", "logvol", "is_92", "a", "a_92", "b", "c", "d", "d_92"))

nl1 <- nlmer(LOGTOTALDW ~ nfun1(w126.12.8.adj, centered_logvol, is_92, a, a_92, b, c, d, d_92) ~ (a + b + c|Study),
             data = VP,
             control = nlmerControl(optimizer = "bobyqa", tolPwrss = 1e-9, optCtrl = list(maxfun = 2e5)),
             start = c(a = 10, a_92 = 1, b = 10, c = 1, d = 10, d_92 = 1))
summary(nl1) # B = 5.698e+09, C = 0.18

aug1 <- broom.mixed::augment(nl1)  

aug1 %>% 
  ggplot() + 
  aes(x = .fitted, y = .resid, fill = Study) + 
  geom_point(shape = 21, size = 2.5) + 
  geom_hline(yintercept = 0, color = "red") + 
  scale_fill_brewer(palette = "Set1")


# Model 2
# Common B, Covariate,
# C = 1
# Separate Intercept

nform2 <- ~ log(a + a_92*is_92 + (d + d_92*is_92)*logvol) + (-(x/b)) 

nfun2 <- deriv(nform2,
               namevec = c("a", "a_92", "b", "d", "d_92"),
               function.arg = c("x", "logvol", "is_92", "a", "a_92", "b", "d", "d_92"))

nl2 <- nlmer(LOGTOTALDW ~ nfun2(w126.12.8.adj, centered_logvol, is_92, a, a_92, b, d, d_92) ~ a + b | Study,
             data = VP,
             control = nlmerControl(optimizer = "bobyqa", tolPwrss = 1e-9, optCtrl = list(maxfun = 2e5)),
             start = c(a = 10, a_92 = 1, b = 10, d = 10, d_92 = 1))
summary(nl2) # B = 839.291, C = 1

aug2 <- broom.mixed::augment(nl2)  

aug2 %>% 
  ggplot() + 
  aes(x = .fitted, y = .resid, fill = Study) + 
  geom_point(shape = 21, size = 2.5) + 
  geom_hline(yintercept = 0, color = "red") + 
  scale_fill_brewer(palette = "Set1")


# Comparing Models --------------------------------------------------------------------------------
nform1 # Covariate, estimated c
nform2 # Covariate, C = 1

fixef(nl1)
fixef(nl2)

mean(aug1$.resid^2) # smallest
mean(aug2$.resid^2) 

(SSRes1 <- sum(aug1$.resid^2)) # smallest
(SSRes2 <- sum(aug2$.resid^2))

meanY <- mean(aug1$LOGTOTALDW)
SStot <- sum((aug1$LOGTOTALDW - meanY)^2) 

(r_sq_1 <- 1 - SSRes1/SStot) # Largest
(r_sq_2 <- 1 - SSRes2/SStot) 

anova(nl2, nl1)

SSreg <- sum((aug2$.fitted - meanY)^2)
SSreg/SStot

# Even though nl1 fits better, nl2 fits almost as well and is a simpler model

broom::tidy(nl2)

# Figure ?
nform2
(coef_mod <- fixef(nl2))

VP <- VP %>% 
  mutate(adj_y = LOGTOTALDW - log(coef_mod[1] + coef_mod[2]*is_92 + (coef_mod[4] + coef_mod[5]*is_92)*centered_logvol))

pred <- tibble(w126.12.8.adj =  c(seq(0, max(VP$w126.12.8.adj), by = 0.5), max(VP$w126.12.8.adj)),
               adj_y = -(w126.12.8.adj/coef_mod[3]))

VP_plot <- ggplot(VP) + 
  aes(x = w126.12.8.adj, y = adj_y) + 
  geom_point(size = 2, shape = 21, aes(fill = Study)) + 
  geom_line(data = pred, size = 1) + 
  scale_fill_brewer(palette = "Set1") 
VP_plot

round(100*(1 - exp(-(c(10, 20, 30, 40, 50)/coef_mod[3]))), 1) 

vp_lines <- ggplot_build(VP_plot)$data[[2]] %>% 
  select(x, y) %>% 
  mutate(Species = factor("Virginia Pine"))

#write.csv(vp_lines, "vp_lines.csv", row.names = FALSE)

vp_b <- tibble(b = coef_mod[3], c = 1, Species = "Virginia Pine")

#write.csv(vp_b, "vp_params.csv", row.names = FALSE)
#write.csv(coef_mod, "vp_all_params.csv")

w126_frame <- VP %>% 
  group_by(Study) %>% 
  summarize(min_w126 = min(w126.12.8.adj),
            max_w126 = max(w126.12.8.adj)) %>% 
  mutate(x = map2(min_w126, max_w126, seq, by = 0.01)) %>% 
  unnest(cols = x) 

coef_frame <- coef(nl2)[1] %>% 
  as.data.frame() %>% 
  rownames_to_column("Study") %>% 
  select(Study, ends_with("b")) %>% 
  rename(b = Study.b)

VP_lines <- full_join(w126_frame, coef_frame) %>% 
  mutate(y = -(x/b))

nform2

intercept_frame <- coef(nl2)[1] %>% 
  as.data.frame() %>% 
  rownames_to_column("Study") %>% 
  select(Study, Study.a, Study.a_92, Study.d, Study.d_92)


VP_points <- full_join(VP, intercept_frame) %>% 
  rename(a = Study.a,
         d = Study.d,
         a92 = Study.a_92,
         d92 = Study.d_92) %>% 
  mutate(adj_y = LOGTOTALDW - log(a + a92*is_92 + (d + d92*is_92)*centered_logvol))

VP_sub <- VP %>% select(Study) %>% mutate(Model = factor("Population"))

pred1_a <- pred %>% 
  mutate(Model = factor("Population")) %>% 
  full_join(VP_sub) %>% 
  rename(x = w126.12.8.adj, y = adj_y)

VP_lines <- VP_lines %>% mutate(Model = factor("Individual"))

pred2 <- full_join(VP_lines, pred1_a)

ggplot(VP_points) + 
  aes(x = w126.12.8.adj, y = adj_y) + 
  geom_point(size = 2, shape = 21, aes(fill = Study)) + 
  scale_fill_brewer(palette = "Set1") +
  facet_wrap(. ~ Study) +
  geom_line(data = pred2 %>% filter(Model == "Individual"), aes(x = x, y = y, linetype = Model, color = Study), size = 1) + 
  scale_color_brewer(palette = "Set1") + 
  geom_line(data = pred2 %>% filter(Model != "Individual"), aes(x = x, y = y, linetype = Model), color = "black", size = 1) 

y_hat <- -(VP_points$w126.12.8.adj/coef_mod[3])
y <- VP_points$adj_y

plot(y, y_hat)
abline(a = 0, b = 1)

SSRes <- sum((y - y_hat)^2)
SSTot <- sum((y - mean(y))^2)

1 - SSRes/SSTot

mean((y - y_hat)^2) 


# Likelihood Confidence Interval -----------------------------------------------

# Step 1: Pull out relevant variables so we don't have to refer to data 

y <- VP$LOGTOTALDW
x <- VP$w126.12.8.adj
Study <- VP$Study
is_92 <- VP$is_92
logvol <- VP$centered_logvol

# Step 2: Reparameterize the model so we can create a confidence interval around predicted biomass loss (theta)
nform2

nlform_k <- ~ log(a + a_92 * is_92 + (d + d_92 * is_92) * logvol) + ((x/x0) * log(1 - theta))

nlfun_k <- deriv(nlform_k,
                 namevec = c("a", "a_92", "d", "d_92", "theta"),
                 function.arg = c("x", "x0", "logvol", "is_92", "a", "a_92", "d", "d_92", "theta"))

# Step 3: At every break (e.g. 10, 20, 30, etc.), run the model at that fixed point, varying the value of theta

breaks <- c(seq(10, max(x), by = 5), max(x)) # our breaks

# Want a table where the log likelihoods are stored, one row for every theta, one column for every break

theta_vals <- seq(0, 1, by = 0.01) # 51 values for theta

M <- matrix(nrow = length(theta_vals), ncol = length(breaks) + 1)

LL <- as_tibble(M) %>% # This will hold our likelihoods for every value of x0
  mutate_all(as.numeric) %>% 
  rename(theta = V1) %>%  
  mutate(theta = theta_vals)

mle <- rep(NA, length(breaks)) # this will hold the maximum likelihood estimate from initial model
ll_hat <- rep(NA, length(breaks)) # this will hold the log likelihood from initial model

for(i in 1:(ncol(LL) - 1)){
  
  x0 <- rep(breaks[i], length(x)) # Get the break value of interest
  
  nm_0 <- nlmer(y ~ nlfun_k(x, x0, logvol, is_92, a, a_92, d, d_92, theta) ~ (a|Study) + (theta|Study), # Fit Model to get MLE
                control = nlmerControl(optimizer = "bobyqa", 
                                       optCtrl = list(maxfun = 2e5,
                                                      upper = c(rep(Inf, 6), 1),
                                                      lower = c(rep(-Inf, 6), 0))),
                start = c(a = 10, a_92 = 1, d = 10, d_92 = 1, theta = 0.1))
  
  mle[i] <- fixef(nm_0)["theta"] # get the mle for that fixed value of x0
  ll_hat[i] <- logLik(nm_0) # get the log-likelihood for that fixed value of x0
  for(j in 1:nrow(LL)){
    
    theta_lim <- as.numeric(LL[j, 1]) # Get theta value
    
    try({nm_k <- nlmer(y ~ nlfun_k(x, x0, logvol, is_92, a, a_92, d, d_92, theta) ~ (a|Study) + (theta|Study), # Fit Model to get MLE
                       control = nlmerControl(optimizer = "bobyqa", 
                                              optCtrl = list(maxfun = 2e5,
                                                             upper = c(rep(Inf, 6), theta_lim + 0.005),
                                                             lower = c(rep(-Inf, 6), theta_lim - 0.005))),
                       start = c(a = 10, a_92 = 1, d = 10, d_92 = 1, theta = theta_lim))}, silent = TRUE)
    # try() keeps loop running if it fails to converge
    
    LL[j, i + 1] <- as.numeric(logLik(nm_k)) # store log-likelihood
  }
}

LL
ll_hat
mle
#write.csv(LL, "vp_LL_profile.csv", row.names = FALSE)
#write.csv(ll_hat, "vp_ll_hat.csv", row.names = FALSE)
#write.csv(mle, "vp_mle_combined.csv", row.names = FALSE)

# Look at the LL profile
qplot(theta, V2, data = LL, geom = "line") + geom_vline(xintercept = mle[1], color = "red")
qplot(theta, V3, data = LL, geom = "line") + geom_vline(xintercept = mle[2], color = "red")
qplot(theta, V4, data = LL, geom = "line") + geom_vline(xintercept = mle[3], color = "red")
qplot(theta, V5, data = LL, geom = "line") + geom_vline(xintercept = mle[4], color = "red")
qplot(theta, V6, data = LL, geom = "line") + geom_vline(xintercept = mle[5], color = "red")
qplot(theta, V7, data = LL, geom = "line") + geom_vline(xintercept = mle[6], color = "red")

LL_1 <- LL 

LL_2 <- LL_1 %>% pivot_longer(cols = -theta, names_to = "V", values_to = "LL")

ll_hat_frame <- tibble(V = colnames(LL)[-1], ll_hat)

q <- qchisq(0.95, 1) # Critical value: LR ~ chi-sq(1)

LL_4 <- full_join(LL_2, ll_hat_frame) %>% 
  group_by(V) %>% 
  mutate(LR = 2 * (ll_hat - LL)) %>% # LR statistic
  filter(LR <= q) %>% # Keep the values where we would not reject the null hypothesis
  slice(1, n()) %>% # Get the maximum and minimum of these theta values 
  select(V, theta) %>% 
  mutate(y = c("ymin", "ymax")) %>% 
  pivot_wider(names_from = y, values_from = theta) %>%
  mutate(V = str_replace(V, "V", ""),
         V = as.numeric(V)) %>% 
  arrange(V)

LL_4

# adjust for the fact that the mle from above does not correspond exactly with original model

pred_0 <- 1 - exp(-breaks/coef_mod[3])

adj <- mle - pred_0

plot(mle, pred_0)
abline(a = 0, b = 1)

LL_4$adj <- adj

LL_5 <- LL_4 %>%
  ungroup() %>% 
  mutate(ymin = ymin - adj,
         ymax = ymax - adj,
         x = breaks) %>% 
  select(-adj, -V)

LL_6 <- LL_5 %>% 
  add_row(ymin = 0, ymax = 0, x = 0, .before = 1)

LL_6

plot(LL_6$x, LL_6$ymax, type = "l", ylim = c(0, 0.6), xlim = c(0, 85))
lines(LL_6$x, LL_6$ymin)
lines(breaks, pred_0, lty = 2)

# Write file

write.csv(LL_6, "vp_para_ci.csv", row.names = FALSE)
